import * as pulumi from "@pulumi/pulumi";
/**
 * The ``AWS::ACMPCA::Certificate`` resource is used to issue a certificate using your private certificate authority. For more information, see the [IssueCertificate](https://docs.aws.amazon.com/privateca/latest/APIReference/API_IssueCertificate.html) action.
 */
export declare function getCertificate(args: GetCertificateArgs, opts?: pulumi.InvokeOptions): Promise<GetCertificateResult>;
export interface GetCertificateArgs {
    /**
     * The Amazon Resource Name (ARN) of the issued certificate.
     */
    arn: string;
    /**
     * The Amazon Resource Name (ARN) for the private CA issues the certificate.
     */
    certificateAuthorityArn: string;
}
export interface GetCertificateResult {
    /**
     * The Amazon Resource Name (ARN) of the issued certificate.
     */
    readonly arn?: string;
    /**
     * The issued Base64 PEM-encoded certificate.
     */
    readonly certificate?: string;
}
/**
 * The ``AWS::ACMPCA::Certificate`` resource is used to issue a certificate using your private certificate authority. For more information, see the [IssueCertificate](https://docs.aws.amazon.com/privateca/latest/APIReference/API_IssueCertificate.html) action.
 */
export declare function getCertificateOutput(args: GetCertificateOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetCertificateResult>;
export interface GetCertificateOutputArgs {
    /**
     * The Amazon Resource Name (ARN) of the issued certificate.
     */
    arn: pulumi.Input<string>;
    /**
     * The Amazon Resource Name (ARN) for the private CA issues the certificate.
     */
    certificateAuthorityArn: pulumi.Input<string>;
}
