import * as pulumi from "@pulumi/pulumi";
import * as inputs from "../types/input";
import * as outputs from "../types/output";
/**
 * The ``AWS::ApiGateway::Deployment`` resource deploys an API Gateway ``RestApi`` resource to a stage so that clients can call the API over the internet. The stage acts as an environment.
 */
export declare class Deployment extends pulumi.CustomResource {
    /**
     * Get an existing Deployment resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): Deployment;
    /**
     * Returns true if the given object is an instance of Deployment.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is Deployment;
    /**
     * The input configuration for a canary deployment.
     */
    readonly deploymentCanarySettings: pulumi.Output<outputs.apigateway.DeploymentCanarySettings | undefined>;
    /**
     * The ID for the deployment. For example: `abc123` .
     */
    readonly deploymentId: pulumi.Output<string>;
    /**
     * The description for the Deployment resource to create.
     */
    readonly description: pulumi.Output<string | undefined>;
    /**
     * The string identifier of the associated RestApi.
     */
    readonly restApiId: pulumi.Output<string>;
    /**
     * The description of the Stage resource for the Deployment resource to create. To specify a stage description, you must also provide a stage name.
     */
    readonly stageDescription: pulumi.Output<outputs.apigateway.DeploymentStageDescription | undefined>;
    /**
     * The name of the Stage resource for the Deployment resource to create.
     */
    readonly stageName: pulumi.Output<string | undefined>;
    /**
     * Create a Deployment resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: DeploymentArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a Deployment resource.
 */
export interface DeploymentArgs {
    /**
     * The input configuration for a canary deployment.
     */
    deploymentCanarySettings?: pulumi.Input<inputs.apigateway.DeploymentCanarySettingsArgs>;
    /**
     * The description for the Deployment resource to create.
     */
    description?: pulumi.Input<string>;
    /**
     * The string identifier of the associated RestApi.
     */
    restApiId: pulumi.Input<string>;
    /**
     * The description of the Stage resource for the Deployment resource to create. To specify a stage description, you must also provide a stage name.
     */
    stageDescription?: pulumi.Input<inputs.apigateway.DeploymentStageDescriptionArgs>;
    /**
     * The name of the Stage resource for the Deployment resource to create.
     */
    stageName?: pulumi.Input<string>;
}
