import * as pulumi from "@pulumi/pulumi";
import * as outputs from "../types/output";
/**
 * The ``AWS::ApiGatewayV2::DomainName`` resource specifies a custom domain name for your API in Amazon API Gateway (API Gateway).
 *  You can use a custom domain name to provide a URL that's more intuitive and easier to recall. For more information about using custom domain names, see [Set up Custom Domain Name for an API in API Gateway](https://docs.aws.amazon.com/apigateway/latest/developerguide/how-to-custom-domains.html) in the *API Gateway Developer Guide*.
 */
export declare function getDomainName(args: GetDomainNameArgs, opts?: pulumi.InvokeOptions): Promise<GetDomainNameResult>;
export interface GetDomainNameArgs {
    /**
     * The custom domain name for your API in Amazon API Gateway. Uppercase letters and the underscore (``_``) character are not supported.
     */
    domainName: string;
}
export interface GetDomainNameResult {
    /**
     * Represents an Amazon Resource Name (ARN).
     */
    readonly domainNameArn?: string;
    /**
     * The domain name configurations.
     */
    readonly domainNameConfigurations?: outputs.apigatewayv2.DomainNameConfiguration[];
    /**
     * The mutual TLS authentication configuration for a custom domain name.
     */
    readonly mutualTlsAuthentication?: outputs.apigatewayv2.DomainNameMutualTlsAuthentication;
    /**
     * The domain name associated with the regional endpoint for this custom domain name. You set up this association by adding a DNS record that points the custom domain name to this regional domain name.
     */
    readonly regionalDomainName?: string;
    /**
     * The region-specific Amazon Route 53 Hosted Zone ID of the regional endpoint.
     */
    readonly regionalHostedZoneId?: string;
    /**
     * The collection of tags associated with a domain name.
     */
    readonly tags?: {
        [key: string]: string;
    };
}
/**
 * The ``AWS::ApiGatewayV2::DomainName`` resource specifies a custom domain name for your API in Amazon API Gateway (API Gateway).
 *  You can use a custom domain name to provide a URL that's more intuitive and easier to recall. For more information about using custom domain names, see [Set up Custom Domain Name for an API in API Gateway](https://docs.aws.amazon.com/apigateway/latest/developerguide/how-to-custom-domains.html) in the *API Gateway Developer Guide*.
 */
export declare function getDomainNameOutput(args: GetDomainNameOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetDomainNameResult>;
export interface GetDomainNameOutputArgs {
    /**
     * The custom domain name for your API in Amazon API Gateway. Uppercase letters and the underscore (``_``) character are not supported.
     */
    domainName: pulumi.Input<string>;
}
