import * as pulumi from "@pulumi/pulumi";
import * as outputs from "../types/output";
/**
 * Resource Type definition for AWS::AppConfig::Extension
 */
export declare function getExtension(args: GetExtensionArgs, opts?: pulumi.InvokeOptions): Promise<GetExtensionResult>;
export interface GetExtensionArgs {
    /**
     * The system-generated ID of the extension.
     */
    id: string;
}
export interface GetExtensionResult {
    /**
     * The actions defined in the extension.
     */
    readonly actions?: {
        [key: string]: outputs.appconfig.ExtensionAction[];
    };
    /**
     * The system-generated Amazon Resource Name (ARN) for the extension.
     */
    readonly arn?: string;
    /**
     * Description of the extension.
     */
    readonly description?: string;
    /**
     * The system-generated ID of the extension.
     */
    readonly id?: string;
    /**
     * The parameters accepted by the extension. You specify parameter values when you associate the extension to an AWS AppConfig resource by using the `CreateExtensionAssociation` API action. For AWS Lambda extension actions, these parameters are included in the Lambda request object.
     */
    readonly parameters?: {
        [key: string]: outputs.appconfig.ExtensionParameter;
    };
    /**
     * An array of key-value tags to apply to this resource.
     */
    readonly tags?: outputs.Tag[];
    /**
     * The extension version number.
     */
    readonly versionNumber?: number;
}
/**
 * Resource Type definition for AWS::AppConfig::Extension
 */
export declare function getExtensionOutput(args: GetExtensionOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetExtensionResult>;
export interface GetExtensionOutputArgs {
    /**
     * The system-generated ID of the extension.
     */
    id: pulumi.Input<string>;
}
