import * as pulumi from "@pulumi/pulumi";
import * as inputs from "../types/input";
import * as outputs from "../types/output";
/**
 * Resource Type definition for AWS:AppIntegrations::Application
 */
export declare class Application extends pulumi.CustomResource {
    /**
     * Get an existing Application resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): Application;
    /**
     * Returns true if the given object is an instance of Application.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is Application;
    /**
     * The Amazon Resource Name (ARN) of the application.
     */
    readonly applicationArn: pulumi.Output<string>;
    /**
     * Application source config
     */
    readonly applicationSourceConfig: pulumi.Output<outputs.appintegrations.ApplicationSourceConfigProperties>;
    /**
     * The id of the application.
     */
    readonly awsId: pulumi.Output<string>;
    /**
     * The application description.
     */
    readonly description: pulumi.Output<string>;
    /**
     * The name of the application.
     */
    readonly name: pulumi.Output<string>;
    /**
     * The namespace of the application.
     */
    readonly namespace: pulumi.Output<string>;
    /**
     * The configuration of events or requests that the application has access to.
     */
    readonly permissions: pulumi.Output<string[] | undefined>;
    /**
     * The tags (keys and values) associated with the application.
     */
    readonly tags: pulumi.Output<outputs.Tag[] | undefined>;
    /**
     * Create a Application resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: ApplicationArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a Application resource.
 */
export interface ApplicationArgs {
    /**
     * Application source config
     */
    applicationSourceConfig: pulumi.Input<inputs.appintegrations.ApplicationSourceConfigPropertiesArgs>;
    /**
     * The application description.
     */
    description: pulumi.Input<string>;
    /**
     * The name of the application.
     */
    name?: pulumi.Input<string>;
    /**
     * The namespace of the application.
     */
    namespace: pulumi.Input<string>;
    /**
     * The configuration of events or requests that the application has access to.
     */
    permissions?: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * The tags (keys and values) associated with the application.
     */
    tags?: pulumi.Input<pulumi.Input<inputs.TagArgs>[]>;
}
