import * as pulumi from "@pulumi/pulumi";
import * as inputs from "../types/input";
import * as outputs from "../types/output";
/**
 * Resource Type definition for AWS::APS::Workspace
 *
 * ## Example Usage
 * ### Example
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as aws_native from "@pulumi/aws-native";
 *
 * const apsWorkspace = new aws_native.aps.Workspace("apsWorkspace", {
 *     alias: "TestWorkspace",
 *     tags: [{
 *         key: "BusinessPurpose",
 *         value: "LoadTesting",
 *     }],
 * });
 *
 * ```
 * ### Example
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as aws_native from "@pulumi/aws-native";
 *
 * const apsWorkspace = new aws_native.aps.Workspace("apsWorkspace", {
 *     alias: "TestWorkspace",
 *     loggingConfiguration: {
 *         logGroupArn: "arn:aws:logs:{region}:{account}:log-group:test-log-group:*",
 *     },
 *     tags: [{
 *         key: "BusinessPurpose",
 *         value: "LoadTesting",
 *     }],
 * });
 *
 * ```
 * ### Example
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as aws_native from "@pulumi/aws-native";
 *
 * const apsWorkspace = new aws_native.aps.Workspace("apsWorkspace", {
 *     alias: "TestWorkspace",
 *     loggingConfiguration: {
 *         logGroupArn: "arn:aws:logs:{region}:{account}:log-group:test-log-group:*",
 *     },
 *     tags: [{
 *         key: "BusinessPurpose",
 *         value: "LoadTesting",
 *     }],
 * });
 *
 * ```
 */
export declare class Workspace extends pulumi.CustomResource {
    /**
     * Get an existing Workspace resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): Workspace;
    /**
     * Returns true if the given object is an instance of Workspace.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is Workspace;
    /**
     * The AMP Workspace alert manager definition data
     */
    readonly alertManagerDefinition: pulumi.Output<string | undefined>;
    /**
     * AMP Workspace alias.
     */
    readonly alias: pulumi.Output<string | undefined>;
    /**
     * Workspace arn.
     */
    readonly arn: pulumi.Output<string>;
    /**
     * KMS Key ARN used to encrypt and decrypt AMP workspace data.
     */
    readonly kmsKeyArn: pulumi.Output<string | undefined>;
    /**
     * Contains information about the logging configuration for the workspace.
     */
    readonly loggingConfiguration: pulumi.Output<outputs.aps.WorkspaceLoggingConfiguration | undefined>;
    /**
     * AMP Workspace prometheus endpoint
     */
    readonly prometheusEndpoint: pulumi.Output<string>;
    /**
     * An array of key-value pairs to apply to this resource.
     */
    readonly tags: pulumi.Output<outputs.Tag[] | undefined>;
    readonly workspaceConfiguration: pulumi.Output<outputs.aps.WorkspaceConfiguration | undefined>;
    /**
     * Required to identify a specific APS Workspace.
     */
    readonly workspaceId: pulumi.Output<string>;
    /**
     * Create a Workspace resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args?: WorkspaceArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a Workspace resource.
 */
export interface WorkspaceArgs {
    /**
     * The AMP Workspace alert manager definition data
     */
    alertManagerDefinition?: pulumi.Input<string>;
    /**
     * AMP Workspace alias.
     */
    alias?: pulumi.Input<string>;
    /**
     * KMS Key ARN used to encrypt and decrypt AMP workspace data.
     */
    kmsKeyArn?: pulumi.Input<string>;
    /**
     * Contains information about the logging configuration for the workspace.
     */
    loggingConfiguration?: pulumi.Input<inputs.aps.WorkspaceLoggingConfigurationArgs>;
    /**
     * An array of key-value pairs to apply to this resource.
     */
    tags?: pulumi.Input<pulumi.Input<inputs.TagArgs>[]>;
    workspaceConfiguration?: pulumi.Input<inputs.aps.WorkspaceConfigurationArgs>;
}
