import * as pulumi from "@pulumi/pulumi";
import * as inputs from "../types/input";
import * as outputs from "../types/output";
/**
 * Definition of AWS::Chatbot::CustomAction Resource Type
 */
export declare class CustomAction extends pulumi.CustomResource {
    /**
     * Get an existing CustomAction resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): CustomAction;
    /**
     * Returns true if the given object is an instance of CustomAction.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is CustomAction;
    /**
     * The name of the custom action. This name is included in the Amazon Resource Name (ARN).
     */
    readonly actionName: pulumi.Output<string>;
    /**
     * The name used to invoke this action in a chat channel. For example, `@Amazon Q run my-alias` .
     */
    readonly aliasName: pulumi.Output<string | undefined>;
    /**
     * Defines when this custom action button should be attached to a notification.
     */
    readonly attachments: pulumi.Output<outputs.chatbot.CustomActionAttachment[] | undefined>;
    /**
     * The fully defined ARN of the custom action.
     */
    readonly customActionArn: pulumi.Output<string>;
    /**
     * The definition of the command to run when invoked as an alias or as an action button.
     */
    readonly definition: pulumi.Output<outputs.chatbot.CustomActionDefinition>;
    /**
     * The tags to add to the configuration.
     */
    readonly tags: pulumi.Output<outputs.Tag[] | undefined>;
    /**
     * Create a CustomAction resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: CustomActionArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a CustomAction resource.
 */
export interface CustomActionArgs {
    /**
     * The name of the custom action. This name is included in the Amazon Resource Name (ARN).
     */
    actionName?: pulumi.Input<string>;
    /**
     * The name used to invoke this action in a chat channel. For example, `@Amazon Q run my-alias` .
     */
    aliasName?: pulumi.Input<string>;
    /**
     * Defines when this custom action button should be attached to a notification.
     */
    attachments?: pulumi.Input<pulumi.Input<inputs.chatbot.CustomActionAttachmentArgs>[]>;
    /**
     * The definition of the command to run when invoked as an alias or as an action button.
     */
    definition: pulumi.Input<inputs.chatbot.CustomActionDefinitionArgs>;
    /**
     * The tags to add to the configuration.
     */
    tags?: pulumi.Input<pulumi.Input<inputs.TagArgs>[]>;
}
