import * as pulumi from "@pulumi/pulumi";
import * as inputs from "../types/input";
import * as outputs from "../types/output";
/**
 * Creates a new origin access control in CloudFront. After you create an origin access control, you can add it to an origin in a CloudFront distribution so that CloudFront sends authenticated (signed) requests to the origin.
 *  This makes it possible to block public access to the origin, allowing viewers (users) to access the origin's content only through CloudFront.
 *  For more information about using a CloudFront origin access control, see [Restricting access to an origin](https://docs.aws.amazon.com/AmazonCloudFront/latest/DeveloperGuide/private-content-restricting-access-to-origin.html) in the *Amazon CloudFront Developer Guide*.
 */
export declare class OriginAccessControl extends pulumi.CustomResource {
    /**
     * Get an existing OriginAccessControl resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): OriginAccessControl;
    /**
     * Returns true if the given object is an instance of OriginAccessControl.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is OriginAccessControl;
    /**
     * The unique identifier of the origin access control.
     */
    readonly awsId: pulumi.Output<string>;
    /**
     * The origin access control.
     */
    readonly originAccessControlConfig: pulumi.Output<outputs.cloudfront.OriginAccessControlConfig>;
    /**
     * Create a OriginAccessControl resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: OriginAccessControlArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a OriginAccessControl resource.
 */
export interface OriginAccessControlArgs {
    /**
     * The origin access control.
     */
    originAccessControlConfig: pulumi.Input<inputs.cloudfront.OriginAccessControlConfigArgs>;
}
