import * as pulumi from "@pulumi/pulumi";
import * as inputs from "../types/input";
import * as outputs from "../types/output";
import * as enums from "../types/enums";
/**
 * The Amazon CloudTrail dashboard resource allows customers to manage managed dashboards and create custom dashboards. You can manually refresh custom and managed dashboards. For custom dashboards, you can also set up an automatic refresh schedule and modify dashboard widgets.
 */
export declare class Dashboard extends pulumi.CustomResource {
    /**
     * Get an existing Dashboard resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): Dashboard;
    /**
     * Returns true if the given object is an instance of Dashboard.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is Dashboard;
    /**
     * The timestamp of the dashboard creation.
     */
    readonly createdTimestamp: pulumi.Output<string>;
    /**
     * The ARN of the dashboard.
     */
    readonly dashboardArn: pulumi.Output<string>;
    /**
     * The name of the dashboard.
     */
    readonly name: pulumi.Output<string | undefined>;
    /**
     * Configures the automatic refresh schedule for the dashboard. Includes the frequency unit (DAYS or HOURS) and value, as well as the status (ENABLED or DISABLED) of the refresh schedule.
     */
    readonly refreshSchedule: pulumi.Output<outputs.cloudtrail.DashboardRefreshSchedule | undefined>;
    /**
     * The status of the dashboard. Values are CREATING, CREATED, UPDATING, UPDATED and DELETING.
     */
    readonly status: pulumi.Output<enums.cloudtrail.DashboardStatus>;
    /**
     * A list of tags.
     */
    readonly tags: pulumi.Output<outputs.Tag[] | undefined>;
    /**
     * Indicates whether the dashboard is protected from termination.
     */
    readonly terminationProtectionEnabled: pulumi.Output<boolean | undefined>;
    /**
     * The type of the dashboard. Values are CUSTOM and MANAGED.
     */
    readonly type: pulumi.Output<enums.cloudtrail.DashboardType>;
    /**
     * The timestamp showing when the dashboard was updated, if applicable. UpdatedTimestamp is always either the same or newer than the time shown in CreatedTimestamp.
     */
    readonly updatedTimestamp: pulumi.Output<string>;
    /**
     * List of widgets on the dashboard
     */
    readonly widgets: pulumi.Output<outputs.cloudtrail.DashboardWidget[] | undefined>;
    /**
     * Create a Dashboard resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args?: DashboardArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a Dashboard resource.
 */
export interface DashboardArgs {
    /**
     * The name of the dashboard.
     */
    name?: pulumi.Input<string>;
    /**
     * Configures the automatic refresh schedule for the dashboard. Includes the frequency unit (DAYS or HOURS) and value, as well as the status (ENABLED or DISABLED) of the refresh schedule.
     */
    refreshSchedule?: pulumi.Input<inputs.cloudtrail.DashboardRefreshScheduleArgs>;
    /**
     * A list of tags.
     */
    tags?: pulumi.Input<pulumi.Input<inputs.TagArgs>[]>;
    /**
     * Indicates whether the dashboard is protected from termination.
     */
    terminationProtectionEnabled?: pulumi.Input<boolean>;
    /**
     * List of widgets on the dashboard
     */
    widgets?: pulumi.Input<pulumi.Input<inputs.cloudtrail.DashboardWidgetArgs>[]>;
}
