import * as pulumi from "@pulumi/pulumi";
import * as inputs from "../types/input";
import * as outputs from "../types/output";
/**
 * Resource Type definition for AWS::Connect::ContactFlowModule.
 *
 * ## Example Usage
 * ### Example
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as aws_native from "@pulumi/aws-native";
 *
 * const cf11 = new aws_native.connect.ContactFlowModule("cf11", {
 *     name: "ExampleFlowModule",
 *     description: "flow module created using cfn",
 *     instanceArn: "arn:aws:connect:region-name:aws-account-id:instance/instance-arn",
 *     content: "ExampleFlowModule content(JSON) using Amazon Connect Flow Language.",
 *     tags: [{
 *         key: "testkey",
 *         value: "testValue",
 *     }],
 * });
 *
 * ```
 */
export declare class ContactFlowModule extends pulumi.CustomResource {
    /**
     * Get an existing ContactFlowModule resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): ContactFlowModule;
    /**
     * Returns true if the given object is an instance of ContactFlowModule.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is ContactFlowModule;
    /**
     * The identifier of the contact flow module (ARN).
     */
    readonly contactFlowModuleArn: pulumi.Output<string>;
    /**
     * The content of the contact flow module in JSON format.
     */
    readonly content: pulumi.Output<string>;
    /**
     * The description of the contact flow module.
     */
    readonly description: pulumi.Output<string | undefined>;
    /**
     * The identifier of the Amazon Connect instance (ARN).
     */
    readonly instanceArn: pulumi.Output<string>;
    /**
     * The name of the contact flow module.
     */
    readonly name: pulumi.Output<string>;
    /**
     * The state of the contact flow module.
     */
    readonly state: pulumi.Output<string | undefined>;
    /**
     * The status of the contact flow module.
     */
    readonly status: pulumi.Output<string>;
    /**
     * One or more tags.
     */
    readonly tags: pulumi.Output<outputs.Tag[] | undefined>;
    /**
     * Create a ContactFlowModule resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: ContactFlowModuleArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a ContactFlowModule resource.
 */
export interface ContactFlowModuleArgs {
    /**
     * The content of the contact flow module in JSON format.
     */
    content: pulumi.Input<string>;
    /**
     * The description of the contact flow module.
     */
    description?: pulumi.Input<string>;
    /**
     * The identifier of the Amazon Connect instance (ARN).
     */
    instanceArn: pulumi.Input<string>;
    /**
     * The name of the contact flow module.
     */
    name?: pulumi.Input<string>;
    /**
     * The state of the contact flow module.
     */
    state?: pulumi.Input<string>;
    /**
     * One or more tags.
     */
    tags?: pulumi.Input<pulumi.Input<inputs.TagArgs>[]>;
}
