import * as pulumi from "@pulumi/pulumi";
/**
 * Resource Schema of AWS::EC2::IPAMPoolCidr Type
 */
export declare class IpamPoolCidr extends pulumi.CustomResource {
    /**
     * Get an existing IpamPoolCidr resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): IpamPoolCidr;
    /**
     * Returns true if the given object is an instance of IpamPoolCidr.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is IpamPoolCidr;
    /**
     * Represents a single IPv4 or IPv6 CIDR
     */
    readonly cidr: pulumi.Output<string | undefined>;
    /**
     * Id of the IPAM Pool Cidr.
     */
    readonly ipamPoolCidrId: pulumi.Output<string>;
    /**
     * Id of the IPAM Pool.
     */
    readonly ipamPoolId: pulumi.Output<string>;
    /**
     * The desired netmask length of the provision. If set, IPAM will choose a block of free space with this size and return the CIDR representing it.
     */
    readonly netmaskLength: pulumi.Output<number | undefined>;
    /**
     * Provisioned state of the cidr.
     */
    readonly state: pulumi.Output<string>;
    /**
     * Create a IpamPoolCidr resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: IpamPoolCidrArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a IpamPoolCidr resource.
 */
export interface IpamPoolCidrArgs {
    /**
     * Represents a single IPv4 or IPv6 CIDR
     */
    cidr?: pulumi.Input<string>;
    /**
     * Id of the IPAM Pool.
     */
    ipamPoolId: pulumi.Input<string>;
    /**
     * The desired netmask length of the provision. If set, IPAM will choose a block of free space with this size and return the CIDR representing it.
     */
    netmaskLength?: pulumi.Input<number>;
}
