import * as pulumi from "@pulumi/pulumi";
import * as inputs from "../types/input";
import * as outputs from "../types/output";
/**
 * The AWS::EC2::TransitGatewayMulticastDomain type
 */
export declare class TransitGatewayMulticastDomain extends pulumi.CustomResource {
    /**
     * Get an existing TransitGatewayMulticastDomain resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): TransitGatewayMulticastDomain;
    /**
     * Returns true if the given object is an instance of TransitGatewayMulticastDomain.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is TransitGatewayMulticastDomain;
    /**
     * The time the transit gateway multicast domain was created.
     */
    readonly creationTime: pulumi.Output<string>;
    /**
     * The options for the transit gateway multicast domain.
     */
    readonly options: pulumi.Output<outputs.ec2.OptionsProperties | undefined>;
    /**
     * The state of the transit gateway multicast domain.
     */
    readonly state: pulumi.Output<string>;
    /**
     * The tags for the transit gateway multicast domain.
     */
    readonly tags: pulumi.Output<outputs.Tag[] | undefined>;
    /**
     * The ID of the transit gateway.
     */
    readonly transitGatewayId: pulumi.Output<string>;
    /**
     * The Amazon Resource Name (ARN) of the transit gateway multicast domain.
     */
    readonly transitGatewayMulticastDomainArn: pulumi.Output<string>;
    /**
     * The ID of the transit gateway multicast domain.
     */
    readonly transitGatewayMulticastDomainId: pulumi.Output<string>;
    /**
     * Create a TransitGatewayMulticastDomain resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: TransitGatewayMulticastDomainArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a TransitGatewayMulticastDomain resource.
 */
export interface TransitGatewayMulticastDomainArgs {
    /**
     * The options for the transit gateway multicast domain.
     */
    options?: pulumi.Input<inputs.ec2.OptionsPropertiesArgs>;
    /**
     * The tags for the transit gateway multicast domain.
     */
    tags?: pulumi.Input<pulumi.Input<inputs.TagArgs>[]>;
    /**
     * The ID of the transit gateway.
     */
    transitGatewayId: pulumi.Input<string>;
}
