import * as pulumi from "@pulumi/pulumi";
import * as inputs from "../types/input";
import * as outputs from "../types/output";
/**
 * The AWS::EC2::VerifiedAccessTrustProvider type describes a verified access trust provider
 */
export declare class VerifiedAccessTrustProvider extends pulumi.CustomResource {
    /**
     * Get an existing VerifiedAccessTrustProvider resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): VerifiedAccessTrustProvider;
    /**
     * Returns true if the given object is an instance of VerifiedAccessTrustProvider.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is VerifiedAccessTrustProvider;
    /**
     * The creation time.
     */
    readonly creationTime: pulumi.Output<string>;
    /**
     * A description for the Amazon Web Services Verified Access trust provider.
     */
    readonly description: pulumi.Output<string | undefined>;
    /**
     * The options for device-identity trust provider.
     */
    readonly deviceOptions: pulumi.Output<outputs.ec2.VerifiedAccessTrustProviderDeviceOptions | undefined>;
    /**
     * The type of device-based trust provider. Possible values: jamf|crowdstrike
     */
    readonly deviceTrustProviderType: pulumi.Output<string | undefined>;
    /**
     * The last updated time.
     */
    readonly lastUpdatedTime: pulumi.Output<string>;
    /**
     * The OpenID Connect (OIDC) options.
     */
    readonly nativeApplicationOidcOptions: pulumi.Output<outputs.ec2.VerifiedAccessTrustProviderNativeApplicationOidcOptions | undefined>;
    /**
     * The options for an OpenID Connect-compatible user-identity trust provider.
     */
    readonly oidcOptions: pulumi.Output<outputs.ec2.VerifiedAccessTrustProviderOidcOptions | undefined>;
    /**
     * The identifier to be used when working with policy rules.
     */
    readonly policyReferenceName: pulumi.Output<string>;
    /**
     * The configuration options for customer provided KMS encryption.
     */
    readonly sseSpecification: pulumi.Output<outputs.ec2.SseSpecificationProperties | undefined>;
    /**
     * An array of key-value pairs to apply to this resource.
     */
    readonly tags: pulumi.Output<outputs.Tag[] | undefined>;
    /**
     * Type of trust provider. Possible values: user|device
     */
    readonly trustProviderType: pulumi.Output<string>;
    /**
     * The type of device-based trust provider. Possible values: oidc|iam-identity-center
     */
    readonly userTrustProviderType: pulumi.Output<string | undefined>;
    /**
     * The ID of the Amazon Web Services Verified Access trust provider.
     */
    readonly verifiedAccessTrustProviderId: pulumi.Output<string>;
    /**
     * Create a VerifiedAccessTrustProvider resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: VerifiedAccessTrustProviderArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a VerifiedAccessTrustProvider resource.
 */
export interface VerifiedAccessTrustProviderArgs {
    /**
     * A description for the Amazon Web Services Verified Access trust provider.
     */
    description?: pulumi.Input<string>;
    /**
     * The options for device-identity trust provider.
     */
    deviceOptions?: pulumi.Input<inputs.ec2.VerifiedAccessTrustProviderDeviceOptionsArgs>;
    /**
     * The type of device-based trust provider. Possible values: jamf|crowdstrike
     */
    deviceTrustProviderType?: pulumi.Input<string>;
    /**
     * The OpenID Connect (OIDC) options.
     */
    nativeApplicationOidcOptions?: pulumi.Input<inputs.ec2.VerifiedAccessTrustProviderNativeApplicationOidcOptionsArgs>;
    /**
     * The options for an OpenID Connect-compatible user-identity trust provider.
     */
    oidcOptions?: pulumi.Input<inputs.ec2.VerifiedAccessTrustProviderOidcOptionsArgs>;
    /**
     * The identifier to be used when working with policy rules.
     */
    policyReferenceName: pulumi.Input<string>;
    /**
     * The configuration options for customer provided KMS encryption.
     */
    sseSpecification?: pulumi.Input<inputs.ec2.SseSpecificationPropertiesArgs>;
    /**
     * An array of key-value pairs to apply to this resource.
     */
    tags?: pulumi.Input<pulumi.Input<inputs.TagArgs>[]>;
    /**
     * Type of trust provider. Possible values: user|device
     */
    trustProviderType: pulumi.Input<string>;
    /**
     * The type of device-based trust provider. Possible values: oidc|iam-identity-center
     */
    userTrustProviderType?: pulumi.Input<string>;
}
