import * as pulumi from "@pulumi/pulumi";
import * as outputs from "../types/output";
/**
 * An object representing an Amazon EKS cluster.
 */
export declare function getCluster(args: GetClusterArgs, opts?: pulumi.InvokeOptions): Promise<GetClusterResult>;
export interface GetClusterArgs {
    /**
     * The unique name to give to your cluster.
     */
    name: string;
}
export interface GetClusterResult {
    /**
     * The access configuration for the cluster.
     */
    readonly accessConfig?: outputs.eks.ClusterAccessConfig;
    /**
     * The ARN of the cluster, such as arn:aws:eks:us-west-2:666666666666:cluster/prod.
     */
    readonly arn?: string;
    /**
     * The certificate-authority-data for your cluster.
     */
    readonly certificateAuthorityData?: string;
    /**
     * The cluster security group that was created by Amazon EKS for the cluster. Managed node groups use this security group for control plane to data plane communication.
     */
    readonly clusterSecurityGroupId?: string;
    /**
     * Indicates the current configuration of the compute capability on your EKS Auto Mode cluster. For example, if the capability is enabled or disabled. If the compute capability is enabled, EKS Auto Mode will create and delete EC2 Managed Instances in your AWS account. For more information, see EKS Auto Mode compute capability in the *Amazon EKS User Guide* .
     */
    readonly computeConfig?: outputs.eks.ClusterComputeConfig;
    /**
     * Amazon Resource Name (ARN) or alias of the customer master key (CMK).
     */
    readonly encryptionConfigKeyArn?: string;
    /**
     * The endpoint for your Kubernetes API server, such as https://5E1D0CEXAMPLEA591B746AFC5AB30262.yl4.us-west-2.eks.amazonaws.com.
     */
    readonly endpoint?: string;
    /**
     * The unique ID given to your cluster.
     */
    readonly id?: string;
    /**
     * The Kubernetes network configuration for the cluster.
     */
    readonly kubernetesNetworkConfig?: outputs.eks.ClusterKubernetesNetworkConfig;
    /**
     * The logging configuration for your cluster.
     */
    readonly logging?: outputs.eks.Logging;
    /**
     * The issuer URL for the cluster's OIDC identity provider, such as https://oidc.eks.us-west-2.amazonaws.com/id/EXAMPLED539D4633E53DE1B716D3041E. If you need to remove https:// from this output value, you can include the following code in your template.
     */
    readonly openIdConnectIssuerUrl?: string;
    /**
     * The configuration in the cluster for EKS Hybrid Nodes. You can add, change, or remove this configuration after the cluster is created.
     */
    readonly remoteNetworkConfig?: outputs.eks.ClusterRemoteNetworkConfig;
    /**
     * The VPC configuration that's used by the cluster control plane. Amazon EKS VPC resources have specific requirements to work properly with Kubernetes. For more information, see [Cluster VPC Considerations](https://docs.aws.amazon.com/eks/latest/userguide/network_reqs.html) and [Cluster Security Group Considerations](https://docs.aws.amazon.com/eks/latest/userguide/sec-group-reqs.html) in the *Amazon EKS User Guide* . You must specify at least two subnets. You can specify up to five security groups, but we recommend that you use a dedicated security group for your cluster control plane.
     */
    readonly resourcesVpcConfig?: outputs.eks.ClusterResourcesVpcConfig;
    /**
     * Indicates the current configuration of the block storage capability on your EKS Auto Mode cluster. For example, if the capability is enabled or disabled. If the block storage capability is enabled, EKS Auto Mode will create and delete EBS volumes in your AWS account. For more information, see EKS Auto Mode block storage capability in the *Amazon EKS User Guide* .
     */
    readonly storageConfig?: outputs.eks.ClusterStorageConfig;
    /**
     * An array of key-value pairs to apply to this resource.
     */
    readonly tags?: outputs.Tag[];
    /**
     * This value indicates if extended support is enabled or disabled for the cluster.
     *
     * [Learn more about EKS Extended Support in the *Amazon EKS User Guide* .](https://docs.aws.amazon.com/eks/latest/userguide/extended-support-control.html)
     */
    readonly upgradePolicy?: outputs.eks.ClusterUpgradePolicy;
    /**
     * The desired Kubernetes version for your cluster. If you don't specify a value here, the latest version available in Amazon EKS is used.
     */
    readonly version?: string;
    /**
     * The configuration for zonal shift for the cluster.
     */
    readonly zonalShiftConfig?: outputs.eks.ClusterZonalShiftConfig;
}
/**
 * An object representing an Amazon EKS cluster.
 */
export declare function getClusterOutput(args: GetClusterOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetClusterResult>;
export interface GetClusterOutputArgs {
    /**
     * The unique name to give to your cluster.
     */
    name: pulumi.Input<string>;
}
