import * as pulumi from "@pulumi/pulumi";
import * as outputs from "../types/output";
import * as enums from "../types/enums";
/**
 * A resource schema for a Variable in Amazon Fraud Detector.
 */
export declare function getVariable(args: GetVariableArgs, opts?: pulumi.InvokeOptions): Promise<GetVariableResult>;
export interface GetVariableArgs {
    /**
     * The ARN of the variable.
     */
    arn: string;
}
export interface GetVariableResult {
    /**
     * The ARN of the variable.
     */
    readonly arn?: string;
    /**
     * The time when the variable was created.
     */
    readonly createdTime?: string;
    /**
     * The source of the data.
     */
    readonly dataSource?: enums.frauddetector.VariableDataSource;
    /**
     * The data type.
     */
    readonly dataType?: enums.frauddetector.VariableDataType;
    /**
     * The default value for the variable when no value is received.
     */
    readonly defaultValue?: string;
    /**
     * The description.
     */
    readonly description?: string;
    /**
     * The time when the variable was last updated.
     */
    readonly lastUpdatedTime?: string;
    /**
     * Tags associated with this variable.
     */
    readonly tags?: outputs.Tag[];
    /**
     * The variable type. For more information see https://docs.aws.amazon.com/frauddetector/latest/ug/create-a-variable.html#variable-types
     */
    readonly variableType?: enums.frauddetector.VariableType;
}
/**
 * A resource schema for a Variable in Amazon Fraud Detector.
 */
export declare function getVariableOutput(args: GetVariableOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetVariableResult>;
export interface GetVariableOutputArgs {
    /**
     * The ARN of the variable.
     */
    arn: pulumi.Input<string>;
}
