import * as pulumi from "@pulumi/pulumi";
import * as inputs from "../types/input";
import * as outputs from "../types/output";
import * as enums from "../types/enums";
/**
 * Creates an authorizer.
 */
export declare class Authorizer extends pulumi.CustomResource {
    /**
     * Get an existing Authorizer resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): Authorizer;
    /**
     * Returns true if the given object is an instance of Authorizer.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is Authorizer;
    /**
     * The Amazon Resource Name (ARN) of the authorizer.
     */
    readonly arn: pulumi.Output<string>;
    /**
     * The authorizer's Lambda function ARN.
     */
    readonly authorizerFunctionArn: pulumi.Output<string>;
    /**
     * The authorizer name.
     */
    readonly authorizerName: pulumi.Output<string | undefined>;
    /**
     * When `true` , the result from the authorizer's Lambda function is cached for clients that use persistent HTTP connections. The results are cached for the time specified by the Lambda function in `refreshAfterInSeconds` . This value doesn't affect authorization of clients that use MQTT connections.
     */
    readonly enableCachingForHttp: pulumi.Output<boolean | undefined>;
    /**
     * Specifies whether AWS IoT validates the token signature in an authorization request.
     */
    readonly signingDisabled: pulumi.Output<boolean | undefined>;
    /**
     * The status of the authorizer.
     *
     * Valid values: `ACTIVE` | `INACTIVE`
     */
    readonly status: pulumi.Output<enums.iot.AuthorizerStatus | undefined>;
    /**
     * Metadata which can be used to manage the custom authorizer.
     *
     * > For URI Request parameters use format: ...key1=value1&key2=value2...
     * >
     * > For the CLI command-line parameter use format: &&tags "key1=value1&key2=value2..."
     * >
     * > For the cli-input-json file use format: "tags": "key1=value1&key2=value2..."
     */
    readonly tags: pulumi.Output<outputs.Tag[] | undefined>;
    /**
     * The key used to extract the token from the HTTP headers.
     */
    readonly tokenKeyName: pulumi.Output<string | undefined>;
    /**
     * The public keys used to validate the token signature returned by your custom authentication service.
     */
    readonly tokenSigningPublicKeys: pulumi.Output<{
        [key: string]: string;
    } | undefined>;
    /**
     * Create a Authorizer resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: AuthorizerArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a Authorizer resource.
 */
export interface AuthorizerArgs {
    /**
     * The authorizer's Lambda function ARN.
     */
    authorizerFunctionArn: pulumi.Input<string>;
    /**
     * The authorizer name.
     */
    authorizerName?: pulumi.Input<string>;
    /**
     * When `true` , the result from the authorizer's Lambda function is cached for clients that use persistent HTTP connections. The results are cached for the time specified by the Lambda function in `refreshAfterInSeconds` . This value doesn't affect authorization of clients that use MQTT connections.
     */
    enableCachingForHttp?: pulumi.Input<boolean>;
    /**
     * Specifies whether AWS IoT validates the token signature in an authorization request.
     */
    signingDisabled?: pulumi.Input<boolean>;
    /**
     * The status of the authorizer.
     *
     * Valid values: `ACTIVE` | `INACTIVE`
     */
    status?: pulumi.Input<enums.iot.AuthorizerStatus>;
    /**
     * Metadata which can be used to manage the custom authorizer.
     *
     * > For URI Request parameters use format: ...key1=value1&key2=value2...
     * >
     * > For the CLI command-line parameter use format: &&tags "key1=value1&key2=value2..."
     * >
     * > For the cli-input-json file use format: "tags": "key1=value1&key2=value2..."
     */
    tags?: pulumi.Input<pulumi.Input<inputs.TagArgs>[]>;
    /**
     * The key used to extract the token from the HTTP headers.
     */
    tokenKeyName?: pulumi.Input<string>;
    /**
     * The public keys used to validate the token signature returned by your custom authentication service.
     */
    tokenSigningPublicKeys?: pulumi.Input<{
        [key: string]: pulumi.Input<string>;
    }>;
}
