import * as pulumi from "@pulumi/pulumi";
import * as inputs from "../types/input";
import * as outputs from "../types/output";
import * as enums from "../types/enums";
/**
 * Use the AWS::IoT::CertificateProvider resource to declare an AWS IoT Certificate Provider.
 */
export declare class CertificateProvider extends pulumi.CustomResource {
    /**
     * Get an existing CertificateProvider resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): CertificateProvider;
    /**
     * Returns true if the given object is an instance of CertificateProvider.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is CertificateProvider;
    /**
     * A list of the operations that the certificate provider will use to generate certificates. Valid value: `CreateCertificateFromCsr` .
     */
    readonly accountDefaultForOperations: pulumi.Output<enums.iot.CertificateProviderOperation[]>;
    /**
     * Returns the Amazon Resource Name (ARN) for the certificate. For example:
     *
     * `{ "Fn::GetAtt": ["MyCertificateProvider", "Arn"] }`
     *
     * A value similar to the following is returned:
     *
     * `arn:aws:iot:ap-southeast-2:123456789012:certprovider/my-certificate-provider`
     */
    readonly arn: pulumi.Output<string>;
    /**
     * The name of the certificate provider.
     */
    readonly certificateProviderName: pulumi.Output<string | undefined>;
    /**
     * The ARN of the Lambda function.
     */
    readonly lambdaFunctionArn: pulumi.Output<string>;
    /**
     * An array of key-value pairs to apply to this resource.
     */
    readonly tags: pulumi.Output<outputs.Tag[] | undefined>;
    /**
     * Create a CertificateProvider resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: CertificateProviderArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a CertificateProvider resource.
 */
export interface CertificateProviderArgs {
    /**
     * A list of the operations that the certificate provider will use to generate certificates. Valid value: `CreateCertificateFromCsr` .
     */
    accountDefaultForOperations: pulumi.Input<pulumi.Input<enums.iot.CertificateProviderOperation>[]>;
    /**
     * The name of the certificate provider.
     */
    certificateProviderName?: pulumi.Input<string>;
    /**
     * The ARN of the Lambda function.
     */
    lambdaFunctionArn: pulumi.Input<string>;
    /**
     * An array of key-value pairs to apply to this resource.
     */
    tags?: pulumi.Input<pulumi.Input<inputs.TagArgs>[]>;
}
