import * as pulumi from "@pulumi/pulumi";
import * as outputs from "../types/output";
import * as enums from "../types/enums";
/**
 * Represents the resource definition of AWS IoT Command.
 */
export declare function getCommand(args: GetCommandArgs, opts?: pulumi.InvokeOptions): Promise<GetCommandResult>;
export interface GetCommandArgs {
    /**
     * The unique identifier for the command.
     */
    commandId: string;
}
export interface GetCommandResult {
    /**
     * The Amazon Resource Name (ARN) of the command.
     */
    readonly commandArn?: string;
    /**
     * The date and time when the command was created.
     */
    readonly createdAt?: string;
    /**
     * A flag indicating whether the command is deprecated.
     */
    readonly deprecated?: boolean;
    /**
     * The description of the command.
     */
    readonly description?: string;
    /**
     * The display name for the command.
     */
    readonly displayName?: string;
    /**
     * The list of mandatory parameters for the command.
     */
    readonly mandatoryParameters?: outputs.iot.CommandParameter[];
    /**
     * The namespace to which the command belongs.
     */
    readonly namespace?: enums.iot.CommandNamespace;
    /**
     * The payload associated with the command.
     */
    readonly payload?: outputs.iot.CommandPayload;
    /**
     * A flag indicating whether the command is pending deletion.
     */
    readonly pendingDeletion?: boolean;
    /**
     * The customer role associated with the command.
     */
    readonly roleArn?: string;
    /**
     * The tags to be associated with the command.
     */
    readonly tags?: outputs.Tag[];
}
/**
 * Represents the resource definition of AWS IoT Command.
 */
export declare function getCommandOutput(args: GetCommandOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetCommandResult>;
export interface GetCommandOutputArgs {
    /**
     * The unique identifier for the command.
     */
    commandId: pulumi.Input<string>;
}
