import * as pulumi from "@pulumi/pulumi";
import * as outputs from "../types/output";
/**
 * Resource schema for AWS::IoTTwinMaker::Entity
 */
export declare function getEntity(args: GetEntityArgs, opts?: pulumi.InvokeOptions): Promise<GetEntityResult>;
export interface GetEntityArgs {
    /**
     * The ID of the entity.
     */
    entityId: string;
    /**
     * The ID of the workspace.
     */
    workspaceId: string;
}
export interface GetEntityResult {
    /**
     * The ARN of the entity.
     */
    readonly arn?: string;
    /**
     * A map that sets information about a component type.
     */
    readonly components?: {
        [key: string]: outputs.iottwinmaker.EntityComponent;
    };
    /**
     * A map that sets information about a composite component.
     */
    readonly compositeComponents?: {
        [key: string]: outputs.iottwinmaker.EntityCompositeComponent;
    };
    /**
     * The date and time when the entity was created.
     */
    readonly creationDateTime?: string;
    /**
     * The description of the entity.
     */
    readonly description?: string;
    /**
     * The name of the entity.
     */
    readonly entityName?: string;
    /**
     * A Boolean value that specifies whether the entity has child entities or not.
     */
    readonly hasChildEntities?: boolean;
    /**
     * The ID of the parent entity.
     */
    readonly parentEntityId?: string;
    /**
     * The current status of the entity.
     */
    readonly status?: outputs.iottwinmaker.EntityStatus;
    /**
     * A key-value pair to associate with a resource.
     */
    readonly tags?: {
        [key: string]: string;
    };
    /**
     * The last date and time when the entity was updated.
     */
    readonly updateDateTime?: string;
}
/**
 * Resource schema for AWS::IoTTwinMaker::Entity
 */
export declare function getEntityOutput(args: GetEntityOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetEntityResult>;
export interface GetEntityOutputArgs {
    /**
     * The ID of the entity.
     */
    entityId: pulumi.Input<string>;
    /**
     * The ID of the workspace.
     */
    workspaceId: pulumi.Input<string>;
}
