import * as pulumi from "@pulumi/pulumi";
import * as inputs from "../types/input";
import * as outputs from "../types/output";
/**
 * An example resource schema demonstrating some basic constructs and validation rules.
 */
export declare class ServiceProfile extends pulumi.CustomResource {
    /**
     * Get an existing ServiceProfile resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): ServiceProfile;
    /**
     * Returns true if the given object is an instance of ServiceProfile.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is ServiceProfile;
    /**
     * Service profile Arn. Returned after successful create.
     */
    readonly arn: pulumi.Output<string>;
    /**
     * Service profile Id. Returned after successful create.
     */
    readonly awsId: pulumi.Output<string>;
    /**
     * LoRaWAN supports all LoRa specific attributes for service profile for CreateServiceProfile operation
     */
    readonly loRaWan: pulumi.Output<outputs.iotwireless.ServiceProfileLoRaWanServiceProfile | undefined>;
    /**
     * Name of service profile
     */
    readonly name: pulumi.Output<string | undefined>;
    /**
     * A list of key-value pairs that contain metadata for the service profile.
     */
    readonly tags: pulumi.Output<outputs.Tag[] | undefined>;
    /**
     * Create a ServiceProfile resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args?: ServiceProfileArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a ServiceProfile resource.
 */
export interface ServiceProfileArgs {
    /**
     * LoRaWAN supports all LoRa specific attributes for service profile for CreateServiceProfile operation
     */
    loRaWan?: pulumi.Input<inputs.iotwireless.ServiceProfileLoRaWanServiceProfileArgs>;
    /**
     * Name of service profile
     */
    name?: pulumi.Input<string>;
    /**
     * A list of key-value pairs that contain metadata for the service profile.
     */
    tags?: pulumi.Input<pulumi.Input<inputs.TagArgs>[]>;
}
