import * as pulumi from "@pulumi/pulumi";
import * as inputs from "../types/input";
import * as outputs from "../types/output";
import * as enums from "../types/enums";
/**
 * The ``AWS::LakeFormation::PrincipalPermissions`` resource represents the permissions that a principal has on a GLUDC resource (such as GLUlong databases or GLUlong tables). When you create a ``PrincipalPermissions`` resource, the permissions are granted via the LFlong ``GrantPermissions`` API operation. When you delete a ``PrincipalPermissions`` resource, the permissions on principal-resource pair are revoked via the LFlong ``RevokePermissions`` API operation.
 */
export declare class PrincipalPermissions extends pulumi.CustomResource {
    /**
     * Get an existing PrincipalPermissions resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): PrincipalPermissions;
    /**
     * Returns true if the given object is an instance of PrincipalPermissions.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is PrincipalPermissions;
    /**
     * The identifier for the GLUDC. By default, the account ID. The GLUDC is the persistent metadata store. It contains database definitions, table definitions, and other control information to manage your Lake Formation environment.
     */
    readonly catalog: pulumi.Output<string | undefined>;
    /**
     * The permissions granted or revoked.
     */
    readonly permissions: pulumi.Output<enums.lakeformation.PrincipalPermissionsPermission[]>;
    /**
     * Indicates the ability to grant permissions (as a subset of permissions granted).
     */
    readonly permissionsWithGrantOption: pulumi.Output<enums.lakeformation.PrincipalPermissionsPermission[]>;
    /**
     * The principal to be granted a permission.
     */
    readonly principal: pulumi.Output<outputs.lakeformation.PrincipalPermissionsDataLakePrincipal>;
    /**
     * Json encoding of the input principal. For example: `{"DataLakePrincipalIdentifier":"arn:aws:iam::123456789012:role/ExampleRole"}`
     */
    readonly principalIdentifier: pulumi.Output<string>;
    /**
     * The resource to be granted or revoked permissions.
     */
    readonly resource: pulumi.Output<outputs.lakeformation.PrincipalPermissionsResource>;
    /**
     * Json encoding of the input resource. For example: `{"Catalog":null,"Database":null,"Table":null,"TableWithColumns":null,"DataLocation":null,"DataCellsFilter":{"TableCatalogId":"123456789012","DatabaseName":"ExampleDatabase","TableName":"ExampleTable","Name":"ExampleFilter"},"LFTag":null,"LFTagPolicy":null}`
     */
    readonly resourceIdentifier: pulumi.Output<string>;
    /**
     * Create a PrincipalPermissions resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: PrincipalPermissionsArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a PrincipalPermissions resource.
 */
export interface PrincipalPermissionsArgs {
    /**
     * The identifier for the GLUDC. By default, the account ID. The GLUDC is the persistent metadata store. It contains database definitions, table definitions, and other control information to manage your Lake Formation environment.
     */
    catalog?: pulumi.Input<string>;
    /**
     * The permissions granted or revoked.
     */
    permissions: pulumi.Input<pulumi.Input<enums.lakeformation.PrincipalPermissionsPermission>[]>;
    /**
     * Indicates the ability to grant permissions (as a subset of permissions granted).
     */
    permissionsWithGrantOption: pulumi.Input<pulumi.Input<enums.lakeformation.PrincipalPermissionsPermission>[]>;
    /**
     * The principal to be granted a permission.
     */
    principal: pulumi.Input<inputs.lakeformation.PrincipalPermissionsDataLakePrincipalArgs>;
    /**
     * The resource to be granted or revoked permissions.
     */
    resource: pulumi.Input<inputs.lakeformation.PrincipalPermissionsResourceArgs>;
}
