import * as pulumi from "@pulumi/pulumi";
import * as inputs from "../types/input";
import * as outputs from "../types/output";
/**
 * Resource Type definition for AWS::Lightsail::Database
 */
export declare class Database extends pulumi.CustomResource {
    /**
     * Get an existing Database resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): Database;
    /**
     * Returns true if the given object is an instance of Database.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is Database;
    /**
     * The Availability Zone in which to create your new database. Use the us-east-2a case-sensitive format.
     */
    readonly availabilityZone: pulumi.Output<string | undefined>;
    /**
     * When true, enables automated backup retention for your database. Updates are applied during the next maintenance window because this can result in an outage.
     */
    readonly backupRetention: pulumi.Output<boolean | undefined>;
    /**
     * Indicates the certificate that needs to be associated with the database.
     */
    readonly caCertificateIdentifier: pulumi.Output<string | undefined>;
    /**
     * The Amazon Resource Name (ARN) of the database (for example, `arn:aws:lightsail:us-east-2:123456789101:RelationalDatabase/244ad76f-8aad-4741-809f-12345EXAMPLE` ).
     */
    readonly databaseArn: pulumi.Output<string>;
    /**
     * The name of the database to create when the Lightsail database resource is created. For MySQL, if this parameter isn't specified, no database is created in the database resource. For PostgreSQL, if this parameter isn't specified, a database named postgres is created in the database resource.
     */
    readonly masterDatabaseName: pulumi.Output<string>;
    /**
     * The password for the master user. The password can include any printable ASCII character except "/", """, or "@". It cannot contain spaces.
     */
    readonly masterUserPassword: pulumi.Output<string | undefined>;
    /**
     * The name for the master user.
     */
    readonly masterUsername: pulumi.Output<string>;
    /**
     * The daily time range during which automated backups are created for your new database if automated backups are enabled.
     */
    readonly preferredBackupWindow: pulumi.Output<string | undefined>;
    /**
     * The weekly time range during which system maintenance can occur on your new database.
     */
    readonly preferredMaintenanceWindow: pulumi.Output<string | undefined>;
    /**
     * Specifies the accessibility options for your new database. A value of true specifies a database that is available to resources outside of your Lightsail account. A value of false specifies a database that is available only to your Lightsail resources in the same region as your database.
     */
    readonly publiclyAccessible: pulumi.Output<boolean | undefined>;
    /**
     * The blueprint ID for your new database. A blueprint describes the major engine version of a database.
     */
    readonly relationalDatabaseBlueprintId: pulumi.Output<string>;
    /**
     * The bundle ID for your new database. A bundle describes the performance specifications for your database.
     */
    readonly relationalDatabaseBundleId: pulumi.Output<string>;
    /**
     * The name to use for your new Lightsail database resource.
     */
    readonly relationalDatabaseName: pulumi.Output<string>;
    /**
     * Update one or more parameters of the relational database.
     */
    readonly relationalDatabaseParameters: pulumi.Output<outputs.lightsail.DatabaseRelationalDatabaseParameter[] | undefined>;
    /**
     * When true, the master user password is changed to a new strong password generated by Lightsail. Use the get relational database master user password operation to get the new password.
     */
    readonly rotateMasterUserPassword: pulumi.Output<boolean | undefined>;
    /**
     * An array of key-value pairs to apply to this resource.
     */
    readonly tags: pulumi.Output<outputs.Tag[] | undefined>;
    /**
     * Create a Database resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: DatabaseArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a Database resource.
 */
export interface DatabaseArgs {
    /**
     * The Availability Zone in which to create your new database. Use the us-east-2a case-sensitive format.
     */
    availabilityZone?: pulumi.Input<string>;
    /**
     * When true, enables automated backup retention for your database. Updates are applied during the next maintenance window because this can result in an outage.
     */
    backupRetention?: pulumi.Input<boolean>;
    /**
     * Indicates the certificate that needs to be associated with the database.
     */
    caCertificateIdentifier?: pulumi.Input<string>;
    /**
     * The name of the database to create when the Lightsail database resource is created. For MySQL, if this parameter isn't specified, no database is created in the database resource. For PostgreSQL, if this parameter isn't specified, a database named postgres is created in the database resource.
     */
    masterDatabaseName: pulumi.Input<string>;
    /**
     * The password for the master user. The password can include any printable ASCII character except "/", """, or "@". It cannot contain spaces.
     */
    masterUserPassword?: pulumi.Input<string>;
    /**
     * The name for the master user.
     */
    masterUsername: pulumi.Input<string>;
    /**
     * The daily time range during which automated backups are created for your new database if automated backups are enabled.
     */
    preferredBackupWindow?: pulumi.Input<string>;
    /**
     * The weekly time range during which system maintenance can occur on your new database.
     */
    preferredMaintenanceWindow?: pulumi.Input<string>;
    /**
     * Specifies the accessibility options for your new database. A value of true specifies a database that is available to resources outside of your Lightsail account. A value of false specifies a database that is available only to your Lightsail resources in the same region as your database.
     */
    publiclyAccessible?: pulumi.Input<boolean>;
    /**
     * The blueprint ID for your new database. A blueprint describes the major engine version of a database.
     */
    relationalDatabaseBlueprintId: pulumi.Input<string>;
    /**
     * The bundle ID for your new database. A bundle describes the performance specifications for your database.
     */
    relationalDatabaseBundleId: pulumi.Input<string>;
    /**
     * The name to use for your new Lightsail database resource.
     */
    relationalDatabaseName: pulumi.Input<string>;
    /**
     * Update one or more parameters of the relational database.
     */
    relationalDatabaseParameters?: pulumi.Input<pulumi.Input<inputs.lightsail.DatabaseRelationalDatabaseParameterArgs>[]>;
    /**
     * When true, the master user password is changed to a new strong password generated by Lightsail. Use the get relational database master user password operation to get the new password.
     */
    rotateMasterUserPassword?: pulumi.Input<boolean>;
    /**
     * An array of key-value pairs to apply to this resource.
     */
    tags?: pulumi.Input<pulumi.Input<inputs.TagArgs>[]>;
}
