import * as pulumi from "@pulumi/pulumi";
import * as inputs from "../types/input";
import * as outputs from "../types/output";
import * as enums from "../types/enums";
/**
 * Definition of AWS::MediaLive::Cluster Resource Type
 */
export declare class Cluster extends pulumi.CustomResource {
    /**
     * Get an existing Cluster resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): Cluster;
    /**
     * Returns true if the given object is an instance of Cluster.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is Cluster;
    /**
     * The ARN of the Cluster.
     */
    readonly arn: pulumi.Output<string>;
    /**
     * The unique ID of the Cluster.
     */
    readonly awsId: pulumi.Output<string>;
    /**
     * The MediaLive Channels that are currently running on Nodes in this Cluster.
     */
    readonly channelIds: pulumi.Output<string[]>;
    readonly clusterType: pulumi.Output<enums.medialive.ClusterType | undefined>;
    /**
     * The IAM role your nodes will use.
     */
    readonly instanceRoleArn: pulumi.Output<string | undefined>;
    /**
     * The user-specified name of the Cluster to be created.
     */
    readonly name: pulumi.Output<string | undefined>;
    readonly networkSettings: pulumi.Output<outputs.medialive.ClusterNetworkSettings | undefined>;
    readonly state: pulumi.Output<enums.medialive.ClusterState>;
    /**
     * A collection of key-value pairs.
     */
    readonly tags: pulumi.Output<outputs.Tag[] | undefined>;
    /**
     * Create a Cluster resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args?: ClusterArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a Cluster resource.
 */
export interface ClusterArgs {
    clusterType?: pulumi.Input<enums.medialive.ClusterType>;
    /**
     * The IAM role your nodes will use.
     */
    instanceRoleArn?: pulumi.Input<string>;
    /**
     * The user-specified name of the Cluster to be created.
     */
    name?: pulumi.Input<string>;
    networkSettings?: pulumi.Input<inputs.medialive.ClusterNetworkSettingsArgs>;
    /**
     * A collection of key-value pairs.
     */
    tags?: pulumi.Input<pulumi.Input<inputs.TagArgs>[]>;
}
