import * as pulumi from "@pulumi/pulumi";
import * as outputs from "../types/output";
import * as enums from "../types/enums";
/**
 * Definition of AWS::Oam::Link Resource Type
 */
export declare function getLink(args: GetLinkArgs, opts?: pulumi.InvokeOptions): Promise<GetLinkResult>;
export interface GetLinkArgs {
    /**
     * The ARN of the link. For example, `arn:aws:oam:us-west-1:111111111111:link:abcd1234-a123-456a-a12b-a123b456c789`
     */
    arn: string;
}
export interface GetLinkResult {
    /**
     * The ARN of the link. For example, `arn:aws:oam:us-west-1:111111111111:link:abcd1234-a123-456a-a12b-a123b456c789`
     */
    readonly arn?: string;
    /**
     * The friendly human-readable name used to identify this source account when it is viewed from the monitoring account. For example, `my-account1` .
     */
    readonly label?: string;
    /**
     * Use this structure to optionally create filters that specify that only some metric namespaces or log groups are to be shared from the source account to the monitoring account.
     */
    readonly linkConfiguration?: outputs.oam.LinkConfiguration;
    /**
     * An array of strings that define which types of data that the source account shares with the monitoring account. Valid values are `AWS::CloudWatch::Metric | AWS::Logs::LogGroup | AWS::XRay::Trace | AWS::ApplicationInsights::Application | AWS::InternetMonitor::Monitor | AWS::ApplicationSignals::Service | AWS::ApplicationSignals::ServiceLevelObjective` .
     */
    readonly resourceTypes?: enums.oam.LinkResourceType[];
    /**
     * Tags to apply to the link
     */
    readonly tags?: {
        [key: string]: string;
    };
}
/**
 * Definition of AWS::Oam::Link Resource Type
 */
export declare function getLinkOutput(args: GetLinkOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetLinkResult>;
export interface GetLinkOutputArgs {
    /**
     * The ARN of the link. For example, `arn:aws:oam:us-west-1:111111111111:link:abcd1234-a123-456a-a12b-a123b456c789`
     */
    arn: pulumi.Input<string>;
}
