import * as pulumi from "@pulumi/pulumi";
/**
 * Resource Type definition for AWS::Oam::Sink
 */
export declare class Sink extends pulumi.CustomResource {
    /**
     * Get an existing Sink resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): Sink;
    /**
     * Returns true if the given object is an instance of Sink.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is Sink;
    /**
     * The Amazon resource name (ARN) of the ObservabilityAccessManager Sink
     */
    readonly arn: pulumi.Output<string>;
    /**
     * The name of the ObservabilityAccessManager Sink.
     */
    readonly name: pulumi.Output<string>;
    /**
     * The policy of this ObservabilityAccessManager Sink.
     *
     * Search the [CloudFormation User Guide](https://docs.aws.amazon.com/cloudformation/) for `AWS::Oam::Sink` for more information about the expected schema for this property.
     */
    readonly policy: pulumi.Output<any | undefined>;
    /**
     * Tags to apply to the sink
     */
    readonly tags: pulumi.Output<{
        [key: string]: string;
    } | undefined>;
    /**
     * Create a Sink resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args?: SinkArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a Sink resource.
 */
export interface SinkArgs {
    /**
     * The name of the ObservabilityAccessManager Sink.
     */
    name?: pulumi.Input<string>;
    /**
     * The policy of this ObservabilityAccessManager Sink.
     *
     * Search the [CloudFormation User Guide](https://docs.aws.amazon.com/cloudformation/) for `AWS::Oam::Sink` for more information about the expected schema for this property.
     */
    policy?: any;
    /**
     * Tags to apply to the sink
     */
    tags?: pulumi.Input<{
        [key: string]: pulumi.Input<string>;
    }>;
}
