import * as pulumi from "@pulumi/pulumi";
import * as inputs from "../types/input";
import * as outputs from "../types/output";
/**
 * Represents a Connector that connects AWS PrivateCA and your directory
 */
export declare class Connector extends pulumi.CustomResource {
    /**
     * Get an existing Connector resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): Connector;
    /**
     * Returns true if the given object is an instance of Connector.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is Connector;
    /**
     * The Amazon Resource Name (ARN) of the certificate authority being used.
     */
    readonly certificateAuthorityArn: pulumi.Output<string>;
    /**
     * The Amazon Resource Name (ARN) that was returned when you called [CreateConnector](https://docs.aws.amazon.com/pca-connector-ad/latest/APIReference/API_CreateConnector.html) .
     */
    readonly connectorArn: pulumi.Output<string>;
    /**
     * The identifier of the Active Directory.
     */
    readonly directoryId: pulumi.Output<string>;
    /**
     * Metadata assigned to a connector consisting of a key-value pair.
     */
    readonly tags: pulumi.Output<{
        [key: string]: string;
    } | undefined>;
    /**
     * Information of the VPC and security group(s) used with the connector.
     */
    readonly vpcInformation: pulumi.Output<outputs.pcaconnectorad.ConnectorVpcInformation>;
    /**
     * Create a Connector resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: ConnectorArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a Connector resource.
 */
export interface ConnectorArgs {
    /**
     * The Amazon Resource Name (ARN) of the certificate authority being used.
     */
    certificateAuthorityArn: pulumi.Input<string>;
    /**
     * The identifier of the Active Directory.
     */
    directoryId: pulumi.Input<string>;
    /**
     * Metadata assigned to a connector consisting of a key-value pair.
     */
    tags?: pulumi.Input<{
        [key: string]: pulumi.Input<string>;
    }>;
    /**
     * Information of the VPC and security group(s) used with the connector.
     */
    vpcInformation: pulumi.Input<inputs.pcaconnectorad.ConnectorVpcInformationArgs>;
}
