import * as pulumi from "@pulumi/pulumi";
import * as inputs from "../types/input";
import * as outputs from "../types/output";
import * as enums from "../types/enums";
/**
 * Resource schema for AWS::Personalize::Dataset.
 *
 * ## Example Usage
 * ### Example
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as aws_native from "@pulumi/aws-native";
 *
 * const myDataset = new aws_native.personalize.Dataset("myDataset", {
 *     name: "my-dataset-name",
 *     datasetType: aws_native.personalize.DatasetType.Interactions,
 *     datasetGroupArn: "arn:aws:personalize:us-west-2:123456789012:dataset-group/dataset-group-name",
 *     schemaArn: "arn:aws:personalize:us-west-2:123456789012:schema/schema-name",
 *     datasetImportJob: {
 *         jobName: "my-import-job-name",
 *         dataSource: {
 *             dataLocation: "s3://bucket-name/file-name.csv",
 *         },
 *         roleArn: "arn:aws:iam::123456789012:role/personalize-role",
 *     },
 * });
 *
 * ```
 * ### Example
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as aws_native from "@pulumi/aws-native";
 *
 * const myDataset = new aws_native.personalize.Dataset("myDataset", {
 *     name: "my-dataset-name",
 *     datasetType: aws_native.personalize.DatasetType.Interactions,
 *     datasetGroupArn: "arn:aws:personalize:us-west-2:123456789012:dataset-group/dataset-group-name",
 *     schemaArn: "arn:aws:personalize:us-west-2:123456789012:schema/schema-name",
 *     datasetImportJob: {
 *         jobName: "my-import-job-name",
 *         dataSource: {
 *             dataLocation: "s3://bucket-name/file-name.csv",
 *         },
 *         roleArn: "arn:aws:iam::123456789012:role/personalize-role",
 *     },
 * });
 *
 * ```
 */
export declare class Dataset extends pulumi.CustomResource {
    /**
     * Get an existing Dataset resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): Dataset;
    /**
     * Returns true if the given object is an instance of Dataset.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is Dataset;
    /**
     * The ARN of the dataset
     */
    readonly datasetArn: pulumi.Output<string>;
    /**
     * The Amazon Resource Name (ARN) of the dataset group to add the dataset to
     */
    readonly datasetGroupArn: pulumi.Output<string>;
    /**
     * Describes a job that imports training data from a data source (Amazon S3 bucket) to an Amazon Personalize dataset. If you specify a dataset import job as part of a dataset, all dataset import job fields are required.
     */
    readonly datasetImportJob: pulumi.Output<outputs.personalize.DatasetImportJob | undefined>;
    /**
     * The type of dataset
     */
    readonly datasetType: pulumi.Output<enums.personalize.DatasetType>;
    /**
     * The name for the dataset
     */
    readonly name: pulumi.Output<string>;
    /**
     * The ARN of the schema to associate with the dataset. The schema defines the dataset fields.
     */
    readonly schemaArn: pulumi.Output<string>;
    /**
     * Create a Dataset resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: DatasetArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a Dataset resource.
 */
export interface DatasetArgs {
    /**
     * The Amazon Resource Name (ARN) of the dataset group to add the dataset to
     */
    datasetGroupArn: pulumi.Input<string>;
    /**
     * Describes a job that imports training data from a data source (Amazon S3 bucket) to an Amazon Personalize dataset. If you specify a dataset import job as part of a dataset, all dataset import job fields are required.
     */
    datasetImportJob?: pulumi.Input<inputs.personalize.DatasetImportJobArgs>;
    /**
     * The type of dataset
     */
    datasetType: pulumi.Input<enums.personalize.DatasetType>;
    /**
     * The name for the dataset
     */
    name?: pulumi.Input<string>;
    /**
     * The ARN of the schema to associate with the dataset. The schema defines the dataset fields.
     */
    schemaArn: pulumi.Input<string>;
}
