import * as pulumi from "@pulumi/pulumi";
import * as outputs from "../types/output";
import * as enums from "../types/enums";
/**
 * Definition of AWS::QBusiness::WebExperience Resource Type
 */
export declare function getWebExperience(args: GetWebExperienceArgs, opts?: pulumi.InvokeOptions): Promise<GetWebExperienceResult>;
export interface GetWebExperienceArgs {
    /**
     * The identifier of the Amazon Q Business web experience.
     */
    applicationId: string;
    /**
     * The identifier of your Amazon Q Business web experience.
     */
    webExperienceId: string;
}
export interface GetWebExperienceResult {
    /**
     * The container for browser extension configuration for an Amazon Q Business web experience.
     */
    readonly browserExtensionConfiguration?: outputs.qbusiness.WebExperienceBrowserExtensionConfiguration;
    /**
     * The Unix timestamp when the Amazon Q Business application was last updated.
     */
    readonly createdAt?: string;
    /**
     * Contains the configuration information to customize the logo, font, and color of an Amazon Q Business web experience with individual files for each property or a CSS file for them all.
     */
    readonly customizationConfiguration?: outputs.qbusiness.WebExperienceCustomizationConfiguration;
    /**
     * The endpoint URLs for your Amazon Q Business web experience. The URLs are unique and fully hosted by AWS .
     */
    readonly defaultEndpoint?: string;
    /**
     * Provides information about the identity provider (IdP) used to authenticate end users of an Amazon Q Business web experience.
     */
    readonly identityProviderConfiguration?: outputs.qbusiness.WebExperienceIdentityProviderConfiguration0Properties | outputs.qbusiness.WebExperienceIdentityProviderConfiguration1Properties;
    /**
     * Sets the website domain origins that are allowed to embed the Amazon Q Business web experience. The *domain origin* refers to the base URL for accessing a website including the protocol ( `http/https` ), the domain name, and the port number (if specified).
     *
     * > You must only submit a *base URL* and not a full path. For example, `https://docs.aws.amazon.com` .
     */
    readonly origins?: string[];
    /**
     * The Amazon Resource Name (ARN) of the service role attached to your web experience.
     *
     * > You must provide this value if you're using IAM Identity Center to manage end user access to your application. If you're using legacy identity management to manage user access, you don't need to provide this value.
     */
    readonly roleArn?: string;
    /**
     * Determines whether sample prompts are enabled in the web experience for an end user.
     */
    readonly samplePromptsControlMode?: enums.qbusiness.WebExperienceSamplePromptsControlMode;
    /**
     * The status of your Amazon Q Business web experience.
     */
    readonly status?: enums.qbusiness.WebExperienceStatus;
    /**
     * A subtitle to personalize your Amazon Q Business web experience.
     */
    readonly subtitle?: string;
    /**
     * A list of key-value pairs that identify or categorize your Amazon Q Business web experience. You can also use tags to help control access to the web experience. Tag keys and values can consist of Unicode letters, digits, white space, and any of the following symbols: _ . : / = + - @.
     */
    readonly tags?: outputs.Tag[];
    /**
     * The title for your Amazon Q Business web experience.
     */
    readonly title?: string;
    /**
     * The Unix timestamp when your Amazon Q Business web experience was updated.
     */
    readonly updatedAt?: string;
    /**
     * The Amazon Resource Name (ARN) of an Amazon Q Business web experience.
     */
    readonly webExperienceArn?: string;
    /**
     * The identifier of your Amazon Q Business web experience.
     */
    readonly webExperienceId?: string;
    /**
     * A message in an Amazon Q Business web experience.
     */
    readonly welcomeMessage?: string;
}
/**
 * Definition of AWS::QBusiness::WebExperience Resource Type
 */
export declare function getWebExperienceOutput(args: GetWebExperienceOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetWebExperienceResult>;
export interface GetWebExperienceOutputArgs {
    /**
     * The identifier of the Amazon Q Business web experience.
     */
    applicationId: pulumi.Input<string>;
    /**
     * The identifier of your Amazon Q Business web experience.
     */
    webExperienceId: pulumi.Input<string>;
}
