import * as pulumi from "@pulumi/pulumi";
import * as inputs from "../types/input";
import * as outputs from "../types/output";
/**
 * Resource Type definition for AWS::Route53::CidrCollection.
 */
export declare class CidrCollection extends pulumi.CustomResource {
    /**
     * Get an existing CidrCollection resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): CidrCollection;
    /**
     * Returns true if the given object is an instance of CidrCollection.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is CidrCollection;
    /**
     * The Amazon resource name (ARN) to uniquely identify the AWS resource.
     */
    readonly arn: pulumi.Output<string>;
    /**
     * UUID of the CIDR collection.
     */
    readonly awsId: pulumi.Output<string>;
    /**
     * A complex type that contains information about the list of CIDR locations.
     */
    readonly locations: pulumi.Output<outputs.route53.CidrCollectionLocation[] | undefined>;
    /**
     * A unique name for the CIDR collection.
     */
    readonly name: pulumi.Output<string>;
    /**
     * Create a CidrCollection resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args?: CidrCollectionArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a CidrCollection resource.
 */
export interface CidrCollectionArgs {
    /**
     * A complex type that contains information about the list of CIDR locations.
     */
    locations?: pulumi.Input<pulumi.Input<inputs.route53.CidrCollectionLocationArgs>[]>;
    /**
     * A unique name for the CIDR collection.
     */
    name?: pulumi.Input<string>;
}
