import * as pulumi from "@pulumi/pulumi";
/**
 * In the response to an [AssociateResolverRule](https://docs.aws.amazon.com/Route53/latest/APIReference/API_route53resolver_AssociateResolverRule.html), [DisassociateResolverRule](https://docs.aws.amazon.com/Route53/latest/APIReference/API_route53resolver_DisassociateResolverRule.html), or [ListResolverRuleAssociations](https://docs.aws.amazon.com/Route53/latest/APIReference/API_route53resolver_ListResolverRuleAssociations.html) request, provides information about an association between a resolver rule and a VPC. The association determines which DNS queries that originate in the VPC are forwarded to your network.
 */
export declare class ResolverRuleAssociation extends pulumi.CustomResource {
    /**
     * Get an existing ResolverRuleAssociation resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): ResolverRuleAssociation;
    /**
     * Returns true if the given object is an instance of ResolverRuleAssociation.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is ResolverRuleAssociation;
    /**
     * The name of an association between a Resolver rule and a VPC.
     */
    readonly name: pulumi.Output<string | undefined>;
    /**
     * The ID of the resolver rule association that you want to get information about, such as `rslvr-rrassoc-97242eaf88example` .
     */
    readonly resolverRuleAssociationId: pulumi.Output<string>;
    /**
     * The ID of the Resolver rule that you associated with the VPC that is specified by ``VPCId``.
     */
    readonly resolverRuleId: pulumi.Output<string>;
    /**
     * The ID of the VPC that you associated the Resolver rule with.
     */
    readonly vpcId: pulumi.Output<string>;
    /**
     * Create a ResolverRuleAssociation resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: ResolverRuleAssociationArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a ResolverRuleAssociation resource.
 */
export interface ResolverRuleAssociationArgs {
    /**
     * The name of an association between a Resolver rule and a VPC.
     */
    name?: pulumi.Input<string>;
    /**
     * The ID of the Resolver rule that you associated with the VPC that is specified by ``VPCId``.
     */
    resolverRuleId: pulumi.Input<string>;
    /**
     * The ID of the VPC that you associated the Resolver rule with.
     */
    vpcId: pulumi.Input<string>;
}
