import * as pulumi from "@pulumi/pulumi";
import * as inputs from "../types/input";
import * as outputs from "../types/output";
/**
 * Resource Type definition for AWS::SES::Template
 *
 * ## Example Usage
 * ### Example
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as aws_native from "@pulumi/aws-native";
 *
 * const config = new pulumi.Config();
 * const templateName = config.require("templateName");
 * const subjectPart = config.require("subjectPart");
 * const textPart = config.require("textPart");
 * const htmlPart = config.require("htmlPart");
 * const template = new aws_native.ses.Template("template", {template: {
 *     templateName: templateName,
 *     subjectPart: subjectPart,
 *     textPart: textPart,
 *     htmlPart: htmlPart,
 * }});
 *
 * ```
 * ### Example
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as aws_native from "@pulumi/aws-native";
 *
 * const config = new pulumi.Config();
 * const templateName = config.require("templateName");
 * const subjectPart = config.require("subjectPart");
 * const textPart = config.require("textPart");
 * const htmlPart = config.require("htmlPart");
 * const template = new aws_native.ses.Template("template", {template: {
 *     templateName: templateName,
 *     subjectPart: subjectPart,
 *     textPart: textPart,
 *     htmlPart: htmlPart,
 * }});
 *
 * ```
 */
export declare class Template extends pulumi.CustomResource {
    /**
     * Get an existing Template resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): Template;
    /**
     * Returns true if the given object is an instance of Template.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is Template;
    readonly awsId: pulumi.Output<string>;
    /**
     * The content of the email, composed of a subject line and either an HTML part or a text-only part.
     */
    readonly template: pulumi.Output<outputs.ses.Template | undefined>;
    /**
     * Create a Template resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args?: TemplateArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a Template resource.
 */
export interface TemplateArgs {
    /**
     * The content of the email, composed of a subject line and either an HTML part or a text-only part.
     */
    template?: pulumi.Input<inputs.ses.TemplateArgs>;
}
