import * as pulumi from "@pulumi/pulumi";
import * as outputs from "../types/output";
import * as enums from "../types/enums";
/**
 * Resource Type definition for Identity Center (SSO) Instance
 */
export declare function getInstance(args: GetInstanceArgs, opts?: pulumi.InvokeOptions): Promise<GetInstanceResult>;
export interface GetInstanceArgs {
    /**
     * The SSO Instance ARN that is returned upon creation of the Identity Center (SSO) Instance
     */
    instanceArn: string;
}
export interface GetInstanceResult {
    /**
     * The ID of the identity store associated with the created Identity Center (SSO) Instance
     */
    readonly identityStoreId?: string;
    /**
     * The SSO Instance ARN that is returned upon creation of the Identity Center (SSO) Instance
     */
    readonly instanceArn?: string;
    /**
     * The name you want to assign to this Identity Center (SSO) Instance
     */
    readonly name?: string;
    /**
     * The AWS accountId of the owner of the Identity Center (SSO) Instance
     */
    readonly ownerAccountId?: string;
    /**
     * The status of the Identity Center (SSO) Instance, create_in_progress/delete_in_progress/active
     */
    readonly status?: enums.sso.InstanceStatus;
    /**
     * Specifies tags to be attached to the instance of IAM Identity Center.
     */
    readonly tags?: outputs.Tag[];
}
/**
 * Resource Type definition for Identity Center (SSO) Instance
 */
export declare function getInstanceOutput(args: GetInstanceOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetInstanceResult>;
export interface GetInstanceOutputArgs {
    /**
     * The SSO Instance ARN that is returned upon creation of the Identity Center (SSO) Instance
     */
    instanceArn: pulumi.Input<string>;
}
