import * as pulumi from "@pulumi/pulumi";
import * as inputs from "../types/input";
import * as enums from "../types/enums";
/**
 * Auto-naming specification for the resource.
 */
export interface AutoNamingArgs {
    /**
     * The maximum length of the name.
     */
    maxLength?: pulumi.Input<number>;
    /**
     * The minimum length of the name.
     */
    minLength?: pulumi.Input<number>;
    /**
     * The name of the property in the Cloud Control payload that is used to set the name of the resource.
     */
    propertyName?: pulumi.Input<string>;
}
/**
 * A set of tags to apply to the resource.
 */
export interface CreateOnlyTagArgs {
    /**
     * The key name of the tag
     */
    key: pulumi.Input<string>;
    /**
     * The value of the tag
     */
    value: pulumi.Input<string>;
}
/**
 * The configuration for a Provider to assume a role.
 */
export interface ProviderAssumeRoleArgs {
    /**
     * Number of seconds to restrict the assume role session duration.
     */
    durationSeconds?: pulumi.Input<number>;
    /**
     * External identifier to use when assuming the role.
     */
    externalId?: pulumi.Input<string>;
    /**
     * IAM Policy JSON describing further restricting permissions for the IAM Role being assumed.
     */
    policy?: pulumi.Input<string>;
    /**
     * Set of Amazon Resource Names (ARNs) of IAM Policies describing further restricting permissions for the role.
     */
    policyArns?: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * Amazon Resource Name (ARN) of the IAM Role to assume.
     */
    roleArn?: pulumi.Input<string>;
    /**
     * Session name to use when assuming the role.
     */
    sessionName?: pulumi.Input<string>;
    /**
     * Map of assume role session tags.
     */
    tags?: pulumi.Input<{
        [key: string]: pulumi.Input<string>;
    }>;
    /**
     * A list of keys for session tags that you want to set as transitive. If you set a tag key as transitive, the corresponding key and value passes to subsequent sessions in a role chain.
     */
    transitiveTagKeys?: pulumi.Input<pulumi.Input<string>[]>;
}
/**
 * The configuration for automatically naming resources.
 */
export interface ProviderAutoNamingArgs {
    /**
     * Automatically trim the auto-generated name to meet the maximum length constraint.
     */
    autoTrim?: pulumi.Input<boolean>;
    /**
     * The minimum length of the random suffix to append to the auto-generated name.
     */
    randomSuffixMinLength?: pulumi.Input<number>;
}
/**
 * providerAutoNamingArgsProvideDefaults sets the appropriate defaults for ProviderAutoNamingArgs
 */
export declare function providerAutoNamingArgsProvideDefaults(val: ProviderAutoNamingArgs): ProviderAutoNamingArgs;
/**
 * The configuration with resource tag settings to apply across all resources handled by this provider. This is designed to replace redundant per-resource `tags` configurations. Provider tags can be overridden with new values, but not excluded from specific resources. To override provider tag values, use the `tags` argument within a resource to configure new tag values for matching keys.
 */
export interface ProviderDefaultTagsArgs {
    /**
     * A group of tags to set across all resources.
     */
    tags?: pulumi.Input<{
        [key: string]: pulumi.Input<string>;
    }>;
}
/**
 * The configuration for for customizing service endpoints.
 */
export interface ProviderEndpointArgs {
    /**
     * Override the default endpoint for AWS CloudControl
     */
    cloudcontrol?: pulumi.Input<string>;
    /**
     * Override the default endpoint for AWS CloudFormation
     */
    cloudformation?: pulumi.Input<string>;
    /**
     * Override the default endpoint for AWS Elastic Compute Cloud (EC2)
     */
    ec2?: pulumi.Input<string>;
    /**
     * Override the default endpoint for AWS Systems Manager
     */
    ssm?: pulumi.Input<string>;
    /**
     * Override the default endpoint for AWS Security Token Service (STS)
     */
    sts?: pulumi.Input<string>;
}
/**
 * The configuration with resource tag settings to ignore across all resources handled by this provider (except any individual service tag resources such as `ec2.Tag`) for situations where external systems are managing certain resource tags.
 */
export interface ProviderIgnoreTagsArgs {
    /**
     * List of exact resource tag keys to ignore across all resources handled by this provider. This configuration prevents Pulumi from returning the tag in any `tags` attributes and displaying any configuration difference for the tag value. If any resource configuration still has this tag key configured in the `tags` argument, it will display a perpetual difference until the tag is removed from the argument or `ignoreChanges` is also used.
     */
    keyPrefixes?: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * List of resource tag key prefixes to ignore across all resources handled by this provider. This configuration prevents Pulumi from returning any tag key matching the prefixes in any `tags` attributes and displaying any configuration difference for those tag values. If any resource configuration still has a tag matching one of the prefixes configured in the `tags` argument, it will display a perpetual difference until the tag is removed from the argument or `ignoreChanges` is also used.
     */
    keys?: pulumi.Input<pulumi.Input<string>[]>;
}
/**
 * A set of tags to apply to the resource.
 */
export interface TagArgs {
    /**
     * The key name of the tag
     */
    key: pulumi.Input<string>;
    /**
     * The value of the tag
     */
    value: pulumi.Input<string>;
}
export declare namespace accessanalyzer {
    /**
     * The criteria for an analysis rule for an analyzer.
     */
    interface AnalyzerAnalysisRuleCriteriaArgs {
        /**
         * A list of AWS account IDs to apply to the analysis rule criteria. The accounts cannot include the organization analyzer owner account. Account IDs can only be applied to the analysis rule criteria for organization-level analyzers.
         */
        accountIds?: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * An array of key-value pairs to match for your resources. You can use the set of Unicode letters, digits, whitespace, _, ., /, =, +, and -.
         *
         * For the tag key, you can specify a value that is 1 to 128 characters in length and cannot be prefixed with aws:.
         *
         * For the tag value, you can specify a value that is 0 to 256 characters in length. If the specified tag value is 0 characters, the rule is applied to all principals with the specified tag key.
         */
        resourceTags?: pulumi.Input<pulumi.Input<pulumi.Input<inputs.accessanalyzer.AnalyzerTagArgs>[]>[]>;
    }
    /**
     * An Access Analyzer archive rule. Archive rules automatically archive new findings that meet the criteria you define when you create the rule.
     */
    interface AnalyzerArchiveRuleArgs {
        /**
         * The criteria for the rule.
         */
        filter: pulumi.Input<pulumi.Input<inputs.accessanalyzer.AnalyzerFilterArgs>[]>;
        /**
         * The archive rule name
         */
        ruleName: pulumi.Input<string>;
    }
    /**
     * The configuration for the analyzer
     */
    interface AnalyzerConfigurationPropertiesArgs {
        /**
         * Specifies the configuration of an unused access analyzer for an AWS organization or account.
         */
        unusedAccessConfiguration?: pulumi.Input<inputs.accessanalyzer.AnalyzerUnusedAccessConfigurationArgs>;
    }
    interface AnalyzerFilterArgs {
        /**
         * A "contains" condition to match for the rule.
         */
        contains?: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * An "equals" condition to match for the rule.
         */
        eq?: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * An "exists" condition to match for the rule.
         */
        exists?: pulumi.Input<boolean>;
        /**
         * A "not equal" condition to match for the rule.
         */
        neq?: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * The property used to define the criteria in the filter for the rule.
         */
        property: pulumi.Input<string>;
    }
    /**
     * A key-value pair to associate with a resource.
     */
    interface AnalyzerTagArgs {
        /**
         * The key name of the tag. You can specify a value that is 1 to 127 Unicode characters in length and cannot be prefixed with aws:. You can use any of the following characters: the set of Unicode letters, digits, whitespace, _, ., /, =, +, and -.
         */
        key: pulumi.Input<string>;
        /**
         * The value for the tag. You can specify a value that is 0 to 255 Unicode characters in length and cannot be prefixed with aws:. You can use any of the following characters: the set of Unicode letters, digits, whitespace, _, ., /, =, +, and -.
         */
        value?: pulumi.Input<string>;
    }
    /**
     * The Configuration for Unused Access Analyzer
     */
    interface AnalyzerUnusedAccessConfigurationArgs {
        /**
         * Contains information about rules for the analyzer.
         */
        analysisRule?: pulumi.Input<inputs.accessanalyzer.AnalyzerUnusedAccessConfigurationAnalysisRulePropertiesArgs>;
        /**
         * The specified access age in days for which to generate findings for unused access. For example, if you specify 90 days, the analyzer will generate findings for IAM entities within the accounts of the selected organization for any access that hasn't been used in 90 or more days since the analyzer's last scan. You can choose a value between 1 and 365 days.
         */
        unusedAccessAge?: pulumi.Input<number>;
    }
    /**
     * Contains information about rules for the analyzer.
     */
    interface AnalyzerUnusedAccessConfigurationAnalysisRulePropertiesArgs {
        /**
         * A list of rules for the analyzer containing criteria to exclude from analysis. Entities that meet the rule criteria will not generate findings.
         */
        exclusions?: pulumi.Input<pulumi.Input<inputs.accessanalyzer.AnalyzerAnalysisRuleCriteriaArgs>[]>;
    }
}
export declare namespace acmpca {
    /**
     * Contains X.509 certificate information to be placed in an issued certificate. An ``APIPassthrough`` or ``APICSRPassthrough`` template variant must be selected, or else this parameter is ignored.
     *  If conflicting or duplicate certificate information is supplied from other sources, AWS Private CA applies [order of operation rules](https://docs.aws.amazon.com/privateca/latest/userguide/UsingTemplates.html#template-order-of-operations) to determine what information is used.
     */
    interface CertificateApiPassthroughArgs {
        /**
         * Specifies X.509 extension information for a certificate.
         */
        extensions?: pulumi.Input<inputs.acmpca.CertificateExtensionsArgs>;
        /**
         * Contains information about the certificate subject. The Subject field in the certificate identifies the entity that owns or controls the public key in the certificate. The entity can be a user, computer, device, or service. The Subject must contain an X.500 distinguished name (DN). A DN is a sequence of relative distinguished names (RDNs). The RDNs are separated by commas in the certificate.
         */
        subject?: pulumi.Input<inputs.acmpca.CertificateSubjectArgs>;
    }
    /**
     * Structure that contains X.509 AccessDescription information.
     */
    interface CertificateAuthorityAccessDescriptionArgs {
        accessLocation: pulumi.Input<inputs.acmpca.CertificateAuthorityGeneralNameArgs>;
        accessMethod: pulumi.Input<inputs.acmpca.CertificateAuthorityAccessMethodArgs>;
    }
    /**
     * Structure that contains X.509 AccessMethod information. Assign one and ONLY one field.
     */
    interface CertificateAuthorityAccessMethodArgs {
        accessMethodType?: pulumi.Input<string>;
        customObjectIdentifier?: pulumi.Input<string>;
    }
    /**
     * Your certificate authority can create and maintain a certificate revocation list (CRL). A CRL contains information about certificates that have been revoked.
     */
    interface CertificateAuthorityCrlConfigurationArgs {
        /**
         * Configures the default behavior of the CRL Distribution Point extension for certificates issued by your CA. If this field is not provided, then the CRL Distribution Point extension will be present and contain the default CRL URL.
         */
        crlDistributionPointExtensionConfiguration?: pulumi.Input<inputs.acmpca.CertificateAuthorityCrlDistributionPointExtensionConfigurationArgs>;
        /**
         * Specifies the type of CRL. This setting determines the maximum number of certificates that the certificate authority can issue and revoke. For more information, see [AWS Private CA quotas](https://docs.aws.amazon.com/general/latest/gr/pca.html#limits_pca) .
         *
         * - `COMPLETE` - The default setting. AWS Private CA maintains a single CRL file for all unexpired certificates issued by a CA that have been revoked for any reason. Each certificate that AWS Private CA issues is bound to a specific CRL through the CRL distribution point (CDP) defined in [RFC 5280](https://docs.aws.amazon.com/https://datatracker.ietf.org/doc/html/rfc5280) .
         * - `PARTITIONED` - Compared to complete CRLs, partitioned CRLs dramatically increase the number of certificates your private CA can issue.
         *
         * > When using partitioned CRLs, you must validate that the CRL's associated issuing distribution point (IDP) URI matches the certiﬁcate's CDP URI to ensure the right CRL has been fetched. AWS Private CA marks the IDP extension as critical, which your client must be able to process.
         */
        crlType?: pulumi.Input<string>;
        /**
         * Name inserted into the certificate *CRL Distribution Points* extension that enables the use of an alias for the CRL distribution point. Use this value if you don't want the name of your S3 bucket to be public.
         *
         * > The content of a Canonical Name (CNAME) record must conform to [RFC2396](https://docs.aws.amazon.com/https://www.ietf.org/rfc/rfc2396.txt) restrictions on the use of special characters in URIs. Additionally, the value of the CNAME must not include a protocol prefix such as "http://" or "https://".
         */
        customCname?: pulumi.Input<string>;
        /**
         * Designates a custom file path in S3 for CRL(s). For example, `http://<CustomName>/<CustomPath>/<CrlPartition_GUID>.crl` .
         */
        customPath?: pulumi.Input<string>;
        /**
         * Boolean value that specifies whether certificate revocation lists (CRLs) are enabled. You can use this value to enable certificate revocation for a new CA when you call the `CreateCertificateAuthority` operation or for an existing CA when you call the `UpdateCertificateAuthority` operation.
         */
        enabled: pulumi.Input<boolean>;
        /**
         * Validity period of the CRL in days.
         */
        expirationInDays?: pulumi.Input<number>;
        /**
         * Name of the S3 bucket that contains the CRL. If you do not provide a value for the *CustomCname* argument, the name of your S3 bucket is placed into the *CRL Distribution Points* extension of the issued certificate. You can change the name of your bucket by calling the [UpdateCertificateAuthority](https://docs.aws.amazon.com/privateca/latest/APIReference/API_UpdateCertificateAuthority.html) operation. You must specify a [bucket policy](https://docs.aws.amazon.com/privateca/latest/userguide/PcaCreateCa.html#s3-policies) that allows AWS Private CA to write the CRL to your bucket.
         *
         * > The `S3BucketName` parameter must conform to the [S3 bucket naming rules](https://docs.aws.amazon.com/AmazonS3/latest/userguide/bucketnamingrules.html) .
         */
        s3BucketName?: pulumi.Input<string>;
        /**
         * Determines whether the CRL will be publicly readable or privately held in the CRL Amazon S3 bucket. If you choose PUBLIC_READ, the CRL will be accessible over the public internet. If you choose BUCKET_OWNER_FULL_CONTROL, only the owner of the CRL S3 bucket can access the CRL, and your PKI clients may need an alternative method of access.
         *
         * If no value is specified, the default is PUBLIC_READ.
         *
         * *Note:* This default can cause CA creation to fail in some circumstances. If you have have enabled the Block Public Access (BPA) feature in your S3 account, then you must specify the value of this parameter as `BUCKET_OWNER_FULL_CONTROL` , and not doing so results in an error. If you have disabled BPA in S3, then you can specify either `BUCKET_OWNER_FULL_CONTROL` or `PUBLIC_READ` as the value.
         *
         * For more information, see [Blocking public access to the S3 bucket](https://docs.aws.amazon.com/privateca/latest/userguide/PcaCreateCa.html#s3-bpa) .
         */
        s3ObjectAcl?: pulumi.Input<string>;
    }
    /**
     * Configures the default behavior of the CRL Distribution Point extension for certificates issued by your certificate authority
     */
    interface CertificateAuthorityCrlDistributionPointExtensionConfigurationArgs {
        /**
         * Configures whether the CRL Distribution Point extension should be populated with the default URL to the CRL. If set to `true` , then the CDP extension will not be present in any certificates issued by that CA unless otherwise specified through CSR or API passthrough.
         *
         * > Only set this if you have another way to distribute the CRL Distribution Points for certificates issued by your CA, such as the Matter Distributed Compliance Ledger.
         * >
         * > This configuration cannot be enabled with a custom CNAME set.
         */
        omitExtension: pulumi.Input<boolean>;
    }
    /**
     * Structure that contains CSR pass though extensions information.
     */
    interface CertificateAuthorityCsrExtensionsArgs {
        /**
         * Indicates the purpose of the certificate and of the key contained in the certificate.
         */
        keyUsage?: pulumi.Input<inputs.acmpca.CertificateAuthorityKeyUsageArgs>;
        /**
         * For CA certificates, provides a path to additional information pertaining to the CA, such as revocation and policy. For more information, see [Subject Information Access](https://docs.aws.amazon.com/https://datatracker.ietf.org/doc/html/rfc5280#section-4.2.2.2) in RFC 5280.
         */
        subjectInformationAccess?: pulumi.Input<pulumi.Input<inputs.acmpca.CertificateAuthorityAccessDescriptionArgs>[]>;
    }
    /**
     * Structure that contains X.500 attribute type and value.
     */
    interface CertificateAuthorityCustomAttributeArgs {
        objectIdentifier: pulumi.Input<string>;
        value: pulumi.Input<string>;
    }
    /**
     * Structure that contains X.509 EdiPartyName information.
     */
    interface CertificateAuthorityEdiPartyNameArgs {
        nameAssigner?: pulumi.Input<string>;
        partyName: pulumi.Input<string>;
    }
    /**
     * Structure that contains X.509 GeneralName information. Assign one and ONLY one field.
     */
    interface CertificateAuthorityGeneralNameArgs {
        directoryName?: pulumi.Input<inputs.acmpca.CertificateAuthoritySubjectArgs>;
        dnsName?: pulumi.Input<string>;
        ediPartyName?: pulumi.Input<inputs.acmpca.CertificateAuthorityEdiPartyNameArgs>;
        ipAddress?: pulumi.Input<string>;
        otherName?: pulumi.Input<inputs.acmpca.CertificateAuthorityOtherNameArgs>;
        registeredId?: pulumi.Input<string>;
        rfc822Name?: pulumi.Input<string>;
        uniformResourceIdentifier?: pulumi.Input<string>;
    }
    /**
     * Structure that contains X.509 KeyUsage information.
     */
    interface CertificateAuthorityKeyUsageArgs {
        /**
         * Key can be used to sign CRLs.
         */
        crlSign?: pulumi.Input<boolean>;
        /**
         * Key can be used to decipher data.
         */
        dataEncipherment?: pulumi.Input<boolean>;
        /**
         * Key can be used only to decipher data.
         */
        decipherOnly?: pulumi.Input<boolean>;
        /**
         * Key can be used for digital signing.
         */
        digitalSignature?: pulumi.Input<boolean>;
        /**
         * Key can be used only to encipher data.
         */
        encipherOnly?: pulumi.Input<boolean>;
        /**
         * Key can be used in a key-agreement protocol.
         */
        keyAgreement?: pulumi.Input<boolean>;
        /**
         * Key can be used to sign certificates.
         */
        keyCertSign?: pulumi.Input<boolean>;
        /**
         * Key can be used to encipher data.
         */
        keyEncipherment?: pulumi.Input<boolean>;
        /**
         * Key can be used for non-repudiation.
         */
        nonRepudiation?: pulumi.Input<boolean>;
    }
    /**
     * Helps to configure online certificate status protocol (OCSP) responder for your certificate authority
     */
    interface CertificateAuthorityOcspConfigurationArgs {
        /**
         * Flag enabling use of the Online Certificate Status Protocol (OCSP) for validating certificate revocation status.
         */
        enabled: pulumi.Input<boolean>;
        /**
         * By default, AWS Private CA injects an Amazon domain into certificates being validated by the Online Certificate Status Protocol (OCSP). A customer can alternatively use this object to define a CNAME specifying a customized OCSP domain.
         *
         * > The content of a Canonical Name (CNAME) record must conform to [RFC2396](https://docs.aws.amazon.com/https://www.ietf.org/rfc/rfc2396.txt) restrictions on the use of special characters in URIs. Additionally, the value of the CNAME must not include a protocol prefix such as "http://" or "https://".
         */
        ocspCustomCname?: pulumi.Input<string>;
    }
    /**
     * Structure that contains X.509 OtherName information.
     */
    interface CertificateAuthorityOtherNameArgs {
        typeId: pulumi.Input<string>;
        value: pulumi.Input<string>;
    }
    /**
     * Certificate Authority revocation information.
     */
    interface CertificateAuthorityRevocationConfigurationArgs {
        /**
         * Configuration of the certificate revocation list (CRL), if any, maintained by your private CA.
         */
        crlConfiguration?: pulumi.Input<inputs.acmpca.CertificateAuthorityCrlConfigurationArgs>;
        /**
         * Configuration of Online Certificate Status Protocol (OCSP) support, if any, maintained by your private CA.
         */
        ocspConfiguration?: pulumi.Input<inputs.acmpca.CertificateAuthorityOcspConfigurationArgs>;
    }
    /**
     * Structure that contains X.500 distinguished name information for your CA.
     */
    interface CertificateAuthoritySubjectArgs {
        commonName?: pulumi.Input<string>;
        country?: pulumi.Input<string>;
        customAttributes?: pulumi.Input<pulumi.Input<inputs.acmpca.CertificateAuthorityCustomAttributeArgs>[]>;
        distinguishedNameQualifier?: pulumi.Input<string>;
        generationQualifier?: pulumi.Input<string>;
        givenName?: pulumi.Input<string>;
        initials?: pulumi.Input<string>;
        locality?: pulumi.Input<string>;
        organization?: pulumi.Input<string>;
        organizationalUnit?: pulumi.Input<string>;
        pseudonym?: pulumi.Input<string>;
        serialNumber?: pulumi.Input<string>;
        state?: pulumi.Input<string>;
        surname?: pulumi.Input<string>;
        title?: pulumi.Input<string>;
    }
    /**
     * Defines the X.500 relative distinguished name (RDN).
     */
    interface CertificateCustomAttributeArgs {
        /**
         * Specifies the object identifier (OID) of the attribute type of the relative distinguished name (RDN).
         */
        objectIdentifier: pulumi.Input<string>;
        /**
         * Specifies the attribute value of relative distinguished name (RDN).
         */
        value: pulumi.Input<string>;
    }
    /**
     * Specifies the X.509 extension information for a certificate.
     *  Extensions present in ``CustomExtensions`` follow the ``ApiPassthrough`` [template rules](https://docs.aws.amazon.com/privateca/latest/userguide/UsingTemplates.html#template-order-of-operations).
     */
    interface CertificateCustomExtensionArgs {
        /**
         * Specifies the critical flag of the X.509 extension.
         */
        critical?: pulumi.Input<boolean>;
        /**
         * Specifies the object identifier (OID) of the X.509 extension. For more information, see the [Global OID reference database.](https://docs.aws.amazon.com/https://oidref.com/2.5.29)
         */
        objectIdentifier: pulumi.Input<string>;
        /**
         * Specifies the base64-encoded value of the X.509 extension.
         */
        value: pulumi.Input<string>;
    }
    /**
     * Describes an Electronic Data Interchange (EDI) entity as described in as defined in [Subject Alternative Name](https://docs.aws.amazon.com/https://datatracker.ietf.org/doc/html/rfc5280) in RFC 5280.
     */
    interface CertificateEdiPartyNameArgs {
        /**
         * Specifies the name assigner.
         */
        nameAssigner: pulumi.Input<string>;
        /**
         * Specifies the party name.
         */
        partyName: pulumi.Input<string>;
    }
    /**
     * Specifies additional purposes for which the certified public key may be used other than basic purposes indicated in the ``KeyUsage`` extension.
     */
    interface CertificateExtendedKeyUsageArgs {
        /**
         * Specifies a custom ``ExtendedKeyUsage`` with an object identifier (OID).
         */
        extendedKeyUsageObjectIdentifier?: pulumi.Input<string>;
        /**
         * Specifies a standard ``ExtendedKeyUsage`` as defined as in [RFC 5280](https://docs.aws.amazon.com/https://datatracker.ietf.org/doc/html/rfc5280#section-4.2.1.12).
         */
        extendedKeyUsageType?: pulumi.Input<string>;
    }
    /**
     * Contains X.509 extension information for a certificate.
     */
    interface CertificateExtensionsArgs {
        /**
         * Contains a sequence of one or more policy information terms, each of which consists of an object identifier (OID) and optional qualifiers. For more information, see NIST's definition of [Object Identifier (OID)](https://docs.aws.amazon.com/https://csrc.nist.gov/glossary/term/Object_Identifier).
         *  In an end-entity certificate, these terms indicate the policy under which the certificate was issued and the purposes for which it may be used. In a CA certificate, these terms limit the set of policies for certification paths that include this certificate.
         */
        certificatePolicies?: pulumi.Input<pulumi.Input<inputs.acmpca.CertificatePolicyInformationArgs>[]>;
        /**
         * Contains a sequence of one or more X.509 extensions, each of which consists of an object identifier (OID), a base64-encoded value, and the critical flag. For more information, see the [Global OID reference database.](https://docs.aws.amazon.com/https://oidref.com/2.5.29)
         */
        customExtensions?: pulumi.Input<pulumi.Input<inputs.acmpca.CertificateCustomExtensionArgs>[]>;
        /**
         * Specifies additional purposes for which the certified public key may be used other than basic purposes indicated in the ``KeyUsage`` extension.
         */
        extendedKeyUsage?: pulumi.Input<pulumi.Input<inputs.acmpca.CertificateExtendedKeyUsageArgs>[]>;
        /**
         * Defines one or more purposes for which the key contained in the certificate can be used. Default value for each option is false.
         */
        keyUsage?: pulumi.Input<inputs.acmpca.CertificateKeyUsageArgs>;
        /**
         * The subject alternative name extension allows identities to be bound to the subject of the certificate. These identities may be included in addition to or in place of the identity in the subject field of the certificate.
         */
        subjectAlternativeNames?: pulumi.Input<pulumi.Input<inputs.acmpca.CertificateGeneralNameArgs>[]>;
    }
    /**
     * Describes an ASN.1 X.400 ``GeneralName`` as defined in [RFC 5280](https://docs.aws.amazon.com/https://datatracker.ietf.org/doc/html/rfc5280). Only one of the following naming options should be provided. Providing more than one option results in an ``InvalidArgsException`` error.
     */
    interface CertificateGeneralNameArgs {
        /**
         * Contains information about the certificate subject. The certificate can be one issued by your private certificate authority (CA) or it can be your private CA certificate. The Subject field in the certificate identifies the entity that owns or controls the public key in the certificate. The entity can be a user, computer, device, or service. The Subject must contain an X.500 distinguished name (DN). A DN is a sequence of relative distinguished names (RDNs). The RDNs are separated by commas in the certificate. The DN must be unique for each entity, but your private CA can issue more than one certificate with the same DN to the same entity.
         */
        directoryName?: pulumi.Input<inputs.acmpca.CertificateSubjectArgs>;
        /**
         * Represents ``GeneralName`` as a DNS name.
         */
        dnsName?: pulumi.Input<string>;
        /**
         * Represents ``GeneralName`` as an ``EdiPartyName`` object.
         */
        ediPartyName?: pulumi.Input<inputs.acmpca.CertificateEdiPartyNameArgs>;
        /**
         * Represents ``GeneralName`` as an IPv4 or IPv6 address.
         */
        ipAddress?: pulumi.Input<string>;
        /**
         * Represents ``GeneralName`` using an ``OtherName`` object.
         */
        otherName?: pulumi.Input<inputs.acmpca.CertificateOtherNameArgs>;
        /**
         * Represents ``GeneralName`` as an object identifier (OID).
         */
        registeredId?: pulumi.Input<string>;
        /**
         * Represents ``GeneralName`` as an [RFC 822](https://docs.aws.amazon.com/https://datatracker.ietf.org/doc/html/rfc822) email address.
         */
        rfc822Name?: pulumi.Input<string>;
        /**
         * Represents ``GeneralName`` as a URI.
         */
        uniformResourceIdentifier?: pulumi.Input<string>;
    }
    /**
     * Defines one or more purposes for which the key contained in the certificate can be used. Default value for each option is false.
     */
    interface CertificateKeyUsageArgs {
        /**
         * Key can be used to sign CRLs.
         */
        crlSign?: pulumi.Input<boolean>;
        /**
         * Key can be used to decipher data.
         */
        dataEncipherment?: pulumi.Input<boolean>;
        /**
         * Key can be used only to decipher data.
         */
        decipherOnly?: pulumi.Input<boolean>;
        /**
         * Key can be used for digital signing.
         */
        digitalSignature?: pulumi.Input<boolean>;
        /**
         * Key can be used only to encipher data.
         */
        encipherOnly?: pulumi.Input<boolean>;
        /**
         * Key can be used in a key-agreement protocol.
         */
        keyAgreement?: pulumi.Input<boolean>;
        /**
         * Key can be used to sign certificates.
         */
        keyCertSign?: pulumi.Input<boolean>;
        /**
         * Key can be used to encipher data.
         */
        keyEncipherment?: pulumi.Input<boolean>;
        /**
         * Key can be used for non-repudiation.
         */
        nonRepudiation?: pulumi.Input<boolean>;
    }
    /**
     * Defines a custom ASN.1 X.400 ``GeneralName`` using an object identifier (OID) and value. The OID must satisfy the regular expression shown below. For more information, see NIST's definition of [Object Identifier (OID)](https://docs.aws.amazon.com/https://csrc.nist.gov/glossary/term/Object_Identifier).
     */
    interface CertificateOtherNameArgs {
        /**
         * Specifies an OID.
         */
        typeId: pulumi.Input<string>;
        /**
         * Specifies an OID value.
         */
        value: pulumi.Input<string>;
    }
    /**
     * Defines the X.509 ``CertificatePolicies`` extension.
     */
    interface CertificatePolicyInformationArgs {
        /**
         * Specifies the object identifier (OID) of the certificate policy under which the certificate was issued. For more information, see NIST's definition of [Object Identifier (OID)](https://docs.aws.amazon.com/https://csrc.nist.gov/glossary/term/Object_Identifier).
         */
        certPolicyId: pulumi.Input<string>;
        /**
         * Modifies the given ``CertPolicyId`` with a qualifier. AWS Private CA supports the certification practice statement (CPS) qualifier.
         */
        policyQualifiers?: pulumi.Input<pulumi.Input<inputs.acmpca.CertificatePolicyQualifierInfoArgs>[]>;
    }
    /**
     * Modifies the ``CertPolicyId`` of a ``PolicyInformation`` object with a qualifier. AWS Private CA supports the certification practice statement (CPS) qualifier.
     */
    interface CertificatePolicyQualifierInfoArgs {
        /**
         * Identifies the qualifier modifying a ``CertPolicyId``.
         */
        policyQualifierId: pulumi.Input<string>;
        /**
         * Defines the qualifier type. AWS Private CA supports the use of a URI for a CPS qualifier in this field.
         */
        qualifier: pulumi.Input<inputs.acmpca.CertificateQualifierArgs>;
    }
    /**
     * Defines a ``PolicyInformation`` qualifier. AWS Private CA supports the [certification practice statement (CPS) qualifier](https://docs.aws.amazon.com/https://datatracker.ietf.org/doc/html/rfc5280#section-4.2.1.4) defined in RFC 5280.
     */
    interface CertificateQualifierArgs {
        /**
         * Contains a pointer to a certification practice statement (CPS) published by the CA.
         */
        cpsUri: pulumi.Input<string>;
    }
    /**
     * Contains information about the certificate subject. The ``Subject`` field in the certificate identifies the entity that owns or controls the public key in the certificate. The entity can be a user, computer, device, or service. The ``Subject``must contain an X.500 distinguished name (DN). A DN is a sequence of relative distinguished names (RDNs). The RDNs are separated by commas in the certificate.
     */
    interface CertificateSubjectArgs {
        /**
         * For CA and end-entity certificates in a private PKI, the common name (CN) can be any string within the length limit.
         *  Note: In publicly trusted certificates, the common name must be a fully qualified domain name (FQDN) associated with the certificate subject.
         */
        commonName?: pulumi.Input<string>;
        /**
         * Two-digit code that specifies the country in which the certificate subject located.
         */
        country?: pulumi.Input<string>;
        /**
         * Contains a sequence of one or more X.500 relative distinguished names (RDNs), each of which consists of an object identifier (OID) and a value. For more information, see NIST’s definition of [Object Identifier (OID)](https://docs.aws.amazon.com/https://csrc.nist.gov/glossary/term/Object_Identifier).
         *   Custom attributes cannot be used in combination with standard attributes.
         */
        customAttributes?: pulumi.Input<pulumi.Input<inputs.acmpca.CertificateCustomAttributeArgs>[]>;
        /**
         * Disambiguating information for the certificate subject.
         */
        distinguishedNameQualifier?: pulumi.Input<string>;
        /**
         * Typically a qualifier appended to the name of an individual. Examples include Jr. for junior, Sr. for senior, and III for third.
         */
        generationQualifier?: pulumi.Input<string>;
        /**
         * First name.
         */
        givenName?: pulumi.Input<string>;
        /**
         * Concatenation that typically contains the first letter of the *GivenName*, the first letter of the middle name if one exists, and the first letter of the *Surname*.
         */
        initials?: pulumi.Input<string>;
        /**
         * The locality (such as a city or town) in which the certificate subject is located.
         */
        locality?: pulumi.Input<string>;
        /**
         * Legal name of the organization with which the certificate subject is affiliated.
         */
        organization?: pulumi.Input<string>;
        /**
         * A subdivision or unit of the organization (such as sales or finance) with which the certificate subject is affiliated.
         */
        organizationalUnit?: pulumi.Input<string>;
        /**
         * Typically a shortened version of a longer *GivenName*. For example, Jonathan is often shortened to John. Elizabeth is often shortened to Beth, Liz, or Eliza.
         */
        pseudonym?: pulumi.Input<string>;
        /**
         * The certificate serial number.
         */
        serialNumber?: pulumi.Input<string>;
        /**
         * State in which the subject of the certificate is located.
         */
        state?: pulumi.Input<string>;
        /**
         * Family name. In the US and the UK, for example, the surname of an individual is ordered last. In Asian cultures the surname is typically ordered first.
         */
        surname?: pulumi.Input<string>;
        /**
         * A title such as Mr. or Ms., which is pre-pended to the name to refer formally to the certificate subject.
         */
        title?: pulumi.Input<string>;
    }
    /**
     * Length of time for which the certificate issued by your private certificate authority (CA), or by the private CA itself, is valid in days, months, or years. You can issue a certificate by calling the ``IssueCertificate`` operation.
     */
    interface CertificateValidityArgs {
        /**
         * Specifies whether the ``Value`` parameter represents days, months, or years.
         */
        type: pulumi.Input<string>;
        /**
         * A long integer interpreted according to the value of ``Type``, below.
         */
        value: pulumi.Input<number>;
    }
}
export declare namespace amazonmq {
}
export declare namespace amplify {
    interface AppAutoBranchCreationConfigArgs {
        /**
         * Automated branch creation glob patterns for the Amplify app.
         */
        autoBranchCreationPatterns?: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * Sets password protection for your auto created branch.
         */
        basicAuthConfig?: pulumi.Input<inputs.amplify.AppBasicAuthConfigArgs>;
        /**
         * The build specification (build spec) for the autocreated branch.
         */
        buildSpec?: pulumi.Input<string>;
        /**
         * Enables automated branch creation for the Amplify app.
         */
        enableAutoBranchCreation?: pulumi.Input<boolean>;
        /**
         * Enables auto building for the auto created branch.
         */
        enableAutoBuild?: pulumi.Input<boolean>;
        /**
         * Enables performance mode for the branch.
         *
         * Performance mode optimizes for faster hosting performance by keeping content cached at the edge for a longer interval. When performance mode is enabled, hosting configuration or code changes can take up to 10 minutes to roll out.
         */
        enablePerformanceMode?: pulumi.Input<boolean>;
        /**
         * Sets whether pull request previews are enabled for each branch that Amplify Hosting automatically creates for your app. Amplify creates previews by deploying your app to a unique URL whenever a pull request is opened for the branch. Development and QA teams can use this preview to test the pull request before it's merged into a production or integration branch.
         *
         * To provide backend support for your preview, Amplify Hosting automatically provisions a temporary backend environment that it deletes when the pull request is closed. If you want to specify a dedicated backend environment for your previews, use the `PullRequestEnvironmentName` property.
         *
         * For more information, see [Web Previews](https://docs.aws.amazon.com/amplify/latest/userguide/pr-previews.html) in the *AWS Amplify Hosting User Guide* .
         */
        enablePullRequestPreview?: pulumi.Input<boolean>;
        /**
         * The environment variables for the autocreated branch.
         */
        environmentVariables?: pulumi.Input<pulumi.Input<inputs.amplify.AppEnvironmentVariableArgs>[]>;
        /**
         * The framework for the autocreated branch.
         */
        framework?: pulumi.Input<string>;
        /**
         * If pull request previews are enabled, you can use this property to specify a dedicated backend environment for your previews. For example, you could specify an environment named `prod` , `test` , or `dev` that you initialized with the Amplify CLI.
         *
         * To enable pull request previews, set the `EnablePullRequestPreview` property to `true` .
         *
         * If you don't specify an environment, Amplify Hosting provides backend support for each preview by automatically provisioning a temporary backend environment. Amplify deletes this environment when the pull request is closed.
         *
         * For more information about creating backend environments, see [Feature Branch Deployments and Team Workflows](https://docs.aws.amazon.com/amplify/latest/userguide/multi-environments.html) in the *AWS Amplify Hosting User Guide* .
         */
        pullRequestEnvironmentName?: pulumi.Input<string>;
        /**
         * Stage for the auto created branch.
         */
        stage?: pulumi.Input<enums.amplify.AppAutoBranchCreationConfigStage>;
    }
    interface AppBasicAuthConfigArgs {
        /**
         * Enables basic authorization for the Amplify app's branches.
         */
        enableBasicAuth?: pulumi.Input<boolean>;
        /**
         * The password for basic authorization.
         */
        password?: pulumi.Input<string>;
        /**
         * The user name for basic authorization.
         */
        username?: pulumi.Input<string>;
    }
    interface AppCacheConfigArgs {
        /**
         * The type of cache configuration to use for an Amplify app.
         *
         * The `AMPLIFY_MANAGED` cache configuration automatically applies an optimized cache configuration for your app based on its platform, routing rules, and rewrite rules. This is the default setting.
         *
         * The `AMPLIFY_MANAGED_NO_COOKIES` cache configuration type is the same as `AMPLIFY_MANAGED` , except that it excludes all cookies from the cache key.
         */
        type?: pulumi.Input<enums.amplify.AppCacheConfigType>;
    }
    interface AppCustomRuleArgs {
        /**
         * The condition for a URL rewrite or redirect rule, such as a country code.
         */
        condition?: pulumi.Input<string>;
        /**
         * The source pattern for a URL rewrite or redirect rule.
         */
        source: pulumi.Input<string>;
        /**
         * The status code for a URL rewrite or redirect rule.
         *
         * - **200** - Represents a 200 rewrite rule.
         * - **301** - Represents a 301 (moved pemanently) redirect rule. This and all future requests should be directed to the target URL.
         * - **302** - Represents a 302 temporary redirect rule.
         * - **404** - Represents a 404 redirect rule.
         * - **404-200** - Represents a 404 rewrite rule.
         */
        status?: pulumi.Input<string>;
        /**
         * The target pattern for a URL rewrite or redirect rule.
         */
        target: pulumi.Input<string>;
    }
    interface AppEnvironmentVariableArgs {
        /**
         * The environment variable name.
         */
        name: pulumi.Input<string>;
        /**
         * The environment variable value.
         */
        value: pulumi.Input<string>;
    }
    interface BranchBackendArgs {
        /**
         * The Amazon Resource Name (ARN) for the AWS CloudFormation stack.
         */
        stackArn?: pulumi.Input<string>;
    }
    interface BranchBasicAuthConfigArgs {
        /**
         * Enables basic authorization for the branch.
         */
        enableBasicAuth?: pulumi.Input<boolean>;
        /**
         * The password for basic authorization.
         */
        password: pulumi.Input<string>;
        username: pulumi.Input<string>;
    }
    interface BranchEnvironmentVariableArgs {
        /**
         * The environment variable name.
         */
        name: pulumi.Input<string>;
        /**
         * The environment variable value.
         */
        value: pulumi.Input<string>;
    }
    interface DomainCertificateSettingsArgs {
        /**
         * The certificate type.
         *
         * Specify `AMPLIFY_MANAGED` to use the default certificate that Amplify provisions for you.
         *
         * Specify `CUSTOM` to use your own certificate that you have already added to AWS Certificate Manager in your AWS account . Make sure you request (or import) the certificate in the US East (N. Virginia) Region (us-east-1). For more information about using ACM, see [Importing certificates into AWS Certificate Manager](https://docs.aws.amazon.com/acm/latest/userguide/import-certificate.html) in the *ACM User guide* .
         */
        certificateType?: pulumi.Input<enums.amplify.DomainCertificateSettingsCertificateType>;
        /**
         * The Amazon resource name (ARN) for the custom certificate that you have already added to AWS Certificate Manager in your AWS account .
         *
         * This field is required only when the certificate type is `CUSTOM` .
         */
        customCertificateArn?: pulumi.Input<string>;
    }
    interface DomainSubDomainSettingArgs {
        /**
         * The branch name setting for the subdomain.
         *
         * *Length Constraints:* Minimum length of 1. Maximum length of 255.
         *
         * *Pattern:* (?s).+
         */
        branchName: pulumi.Input<string>;
        /**
         * The prefix setting for the subdomain.
         */
        prefix: pulumi.Input<string>;
    }
}
export declare namespace amplifyuibuilder {
    interface ComponentActionParametersArgs {
        /**
         * The HTML anchor link to the location to open. Specify this value for a navigation action.
         */
        anchor?: pulumi.Input<inputs.amplifyuibuilder.ComponentPropertyArgs>;
        /**
         * A dictionary of key-value pairs mapping Amplify Studio properties to fields in a data model. Use when the action performs an operation on an Amplify DataStore model.
         */
        fields?: pulumi.Input<{
            [key: string]: pulumi.Input<inputs.amplifyuibuilder.ComponentPropertyArgs>;
        }>;
        /**
         * Specifies whether the user should be signed out globally. Specify this value for an auth sign out action.
         */
        global?: pulumi.Input<inputs.amplifyuibuilder.ComponentPropertyArgs>;
        /**
         * The unique ID of the component that the `ActionParameters` apply to.
         */
        id?: pulumi.Input<inputs.amplifyuibuilder.ComponentPropertyArgs>;
        /**
         * The name of the data model. Use when the action performs an operation on an Amplify DataStore model.
         */
        model?: pulumi.Input<string>;
        /**
         * A key-value pair that specifies the state property name and its initial value.
         */
        state?: pulumi.Input<inputs.amplifyuibuilder.ComponentMutationActionSetStateParameterArgs>;
        /**
         * The element within the same component to modify when the action occurs.
         */
        target?: pulumi.Input<inputs.amplifyuibuilder.ComponentPropertyArgs>;
        /**
         * The type of navigation action. Valid values are `url` and `anchor` . This value is required for a navigation action.
         */
        type?: pulumi.Input<inputs.amplifyuibuilder.ComponentPropertyArgs>;
        /**
         * The URL to the location to open. Specify this value for a navigation action.
         */
        url?: pulumi.Input<inputs.amplifyuibuilder.ComponentPropertyArgs>;
    }
    interface ComponentBindingPropertiesValueArgs {
        /**
         * Describes the properties to customize with data at runtime.
         */
        bindingProperties?: pulumi.Input<inputs.amplifyuibuilder.ComponentBindingPropertiesValuePropertiesArgs>;
        /**
         * The default value of the property.
         */
        defaultValue?: pulumi.Input<string>;
        /**
         * The property type.
         */
        type?: pulumi.Input<string>;
    }
    interface ComponentBindingPropertiesValuePropertiesArgs {
        /**
         * An Amazon S3 bucket.
         */
        bucket?: pulumi.Input<string>;
        /**
         * The default value to assign to the property.
         */
        defaultValue?: pulumi.Input<string>;
        /**
         * The field to bind the data to.
         */
        field?: pulumi.Input<string>;
        /**
         * The storage key for an Amazon S3 bucket.
         */
        key?: pulumi.Input<string>;
        /**
         * An Amplify DataStore model.
         */
        model?: pulumi.Input<string>;
        /**
         * A list of predicates for binding a component's properties to data.
         */
        predicates?: pulumi.Input<pulumi.Input<inputs.amplifyuibuilder.ComponentPredicateArgs>[]>;
        /**
         * The name of a component slot.
         */
        slotName?: pulumi.Input<string>;
        /**
         * An authenticated user attribute.
         */
        userAttribute?: pulumi.Input<string>;
    }
    interface ComponentChildArgs {
        /**
         * The list of `ComponentChild` instances for this component.
         */
        children?: pulumi.Input<pulumi.Input<inputs.amplifyuibuilder.ComponentChildArgs>[]>;
        /**
         * The type of the child component.
         */
        componentType: pulumi.Input<string>;
        /**
         * Describes the events that can be raised on the child component. Use for the workflow feature in Amplify Studio that allows you to bind events and actions to components.
         */
        events?: pulumi.Input<{
            [key: string]: pulumi.Input<inputs.amplifyuibuilder.ComponentEventArgs>;
        }>;
        /**
         * The name of the child component.
         */
        name: pulumi.Input<string>;
        /**
         * Describes the properties of the child component. You can't specify `tags` as a valid property for `properties` .
         */
        properties: pulumi.Input<{
            [key: string]: pulumi.Input<inputs.amplifyuibuilder.ComponentPropertyArgs>;
        }>;
        /**
         * The unique ID of the child component in its original source system, such as Figma.
         */
        sourceId?: pulumi.Input<string>;
    }
    interface ComponentConditionPropertyArgs {
        /**
         * The value to assign to the property if the condition is not met.
         */
        else?: pulumi.Input<inputs.amplifyuibuilder.ComponentPropertyArgs>;
        /**
         * The name of a field. Specify this when the property is a data model.
         */
        field?: pulumi.Input<string>;
        /**
         * The value of the property to evaluate.
         */
        operand?: pulumi.Input<string>;
        /**
         * The type of the property to evaluate.
         */
        operandType?: pulumi.Input<string>;
        /**
         * The operator to use to perform the evaluation, such as `eq` to represent equals.
         */
        operator?: pulumi.Input<string>;
        /**
         * The name of the conditional property.
         */
        property?: pulumi.Input<string>;
        /**
         * The value to assign to the property if the condition is met.
         */
        then?: pulumi.Input<inputs.amplifyuibuilder.ComponentPropertyArgs>;
    }
    interface ComponentDataConfigurationArgs {
        /**
         * A list of IDs to use to bind data to a component. Use this property to bind specifically chosen data, rather than data retrieved from a query.
         */
        identifiers?: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * The name of the data model to use to bind data to a component.
         */
        model: pulumi.Input<string>;
        /**
         * Represents the conditional logic to use when binding data to a component. Use this property to retrieve only a subset of the data in a collection.
         */
        predicate?: pulumi.Input<inputs.amplifyuibuilder.ComponentPredicateArgs>;
        /**
         * Describes how to sort the component's properties.
         */
        sort?: pulumi.Input<pulumi.Input<inputs.amplifyuibuilder.ComponentSortPropertyArgs>[]>;
    }
    interface ComponentEventArgs {
        /**
         * The action to perform when a specific event is raised.
         */
        action?: pulumi.Input<string>;
        /**
         * Binds an event to an action on a component. When you specify a `bindingEvent` , the event is called when the action is performed.
         */
        bindingEvent?: pulumi.Input<string>;
        /**
         * Describes information about the action.
         */
        parameters?: pulumi.Input<inputs.amplifyuibuilder.ComponentActionParametersArgs>;
    }
    interface ComponentFormBindingElementArgs {
        /**
         * The name of the component to retrieve a value from.
         */
        element: pulumi.Input<string>;
        /**
         * The property to retrieve a value from.
         */
        property: pulumi.Input<string>;
    }
    interface ComponentMutationActionSetStateParameterArgs {
        /**
         * The name of the component that is being modified.
         */
        componentName: pulumi.Input<string>;
        /**
         * The name of the component property to apply the state configuration to.
         */
        property: pulumi.Input<string>;
        /**
         * The state configuration to assign to the property.
         */
        set: pulumi.Input<inputs.amplifyuibuilder.ComponentPropertyArgs>;
    }
    interface ComponentPredicateArgs {
        /**
         * A list of predicates to combine logically.
         */
        and?: pulumi.Input<pulumi.Input<inputs.amplifyuibuilder.ComponentPredicateArgs>[]>;
        /**
         * The field to query.
         */
        field?: pulumi.Input<string>;
        /**
         * The value to use when performing the evaluation.
         */
        operand?: pulumi.Input<string>;
        /**
         * The type of value to use when performing the evaluation.
         */
        operandType?: pulumi.Input<string>;
        /**
         * The operator to use to perform the evaluation.
         */
        operator?: pulumi.Input<string>;
        /**
         * A list of predicates to combine logically.
         */
        or?: pulumi.Input<pulumi.Input<inputs.amplifyuibuilder.ComponentPredicateArgs>[]>;
    }
    interface ComponentPropertyArgs {
        /**
         * The information to bind the component property to data at runtime.
         */
        bindingProperties?: pulumi.Input<inputs.amplifyuibuilder.ComponentPropertyBindingPropertiesArgs>;
        /**
         * The information to bind the component property to form data.
         */
        bindings?: pulumi.Input<{
            [key: string]: pulumi.Input<inputs.amplifyuibuilder.ComponentFormBindingElementArgs>;
        }>;
        /**
         * The information to bind the component property to data at runtime. Use this for collection components.
         */
        collectionBindingProperties?: pulumi.Input<inputs.amplifyuibuilder.ComponentPropertyBindingPropertiesArgs>;
        /**
         * The name of the component that is affected by an event.
         */
        componentName?: pulumi.Input<string>;
        /**
         * A list of component properties to concatenate to create the value to assign to this component property.
         */
        concat?: pulumi.Input<pulumi.Input<inputs.amplifyuibuilder.ComponentPropertyArgs>[]>;
        /**
         * The conditional expression to use to assign a value to the component property.
         */
        condition?: pulumi.Input<inputs.amplifyuibuilder.ComponentConditionPropertyArgs>;
        /**
         * Specifies whether the user configured the property in Amplify Studio after importing it.
         */
        configured?: pulumi.Input<boolean>;
        /**
         * The default value to assign to the component property.
         */
        defaultValue?: pulumi.Input<string>;
        /**
         * An event that occurs in your app. Use this for workflow data binding.
         */
        event?: pulumi.Input<string>;
        /**
         * The default value assigned to the property when the component is imported into an app.
         */
        importedValue?: pulumi.Input<string>;
        /**
         * The data model to use to assign a value to the component property.
         */
        model?: pulumi.Input<string>;
        /**
         * The name of the component's property that is affected by an event.
         */
        property?: pulumi.Input<string>;
        /**
         * The component type.
         */
        type?: pulumi.Input<string>;
        /**
         * An authenticated user attribute to use to assign a value to the component property.
         */
        userAttribute?: pulumi.Input<string>;
        /**
         * The value to assign to the component property.
         */
        value?: pulumi.Input<string>;
    }
    interface ComponentPropertyBindingPropertiesArgs {
        /**
         * The data field to bind the property to.
         */
        field?: pulumi.Input<string>;
        /**
         * The component property to bind to the data field.
         */
        property: pulumi.Input<string>;
    }
    interface ComponentSortPropertyArgs {
        /**
         * The direction of the sort, either ascending or descending.
         */
        direction: pulumi.Input<enums.amplifyuibuilder.ComponentSortDirection>;
        /**
         * The field to perform the sort on.
         */
        field: pulumi.Input<string>;
    }
    interface ComponentVariantArgs {
        /**
         * The properties of the component variant that can be overriden when customizing an instance of the component. You can't specify `tags` as a valid property for `overrides` .
         */
        overrides?: pulumi.Input<{
            [key: string]: any;
        }>;
        /**
         * The combination of variants that comprise this variant.
         */
        variantValues?: pulumi.Input<{
            [key: string]: pulumi.Input<string>;
        }>;
    }
    interface FormButtonArgs {
        /**
         * Describes the button's properties.
         */
        children?: pulumi.Input<string>;
        /**
         * Specifies whether the button is visible on the form.
         */
        excluded?: pulumi.Input<boolean>;
        /**
         * The position of the button.
         */
        position?: pulumi.Input<inputs.amplifyuibuilder.FormFieldPosition0PropertiesArgs | inputs.amplifyuibuilder.FormFieldPosition1PropertiesArgs | inputs.amplifyuibuilder.FormFieldPosition2PropertiesArgs>;
    }
    interface FormCtaArgs {
        /**
         * Displays a cancel button.
         */
        cancel?: pulumi.Input<inputs.amplifyuibuilder.FormButtonArgs>;
        /**
         * Displays a clear button.
         */
        clear?: pulumi.Input<inputs.amplifyuibuilder.FormButtonArgs>;
        /**
         * The position of the button.
         */
        position?: pulumi.Input<enums.amplifyuibuilder.FormButtonsPosition>;
        /**
         * Displays a submit button.
         */
        submit?: pulumi.Input<inputs.amplifyuibuilder.FormButtonArgs>;
    }
    interface FormDataTypeConfigArgs {
        /**
         * The data source type, either an Amplify DataStore model or a custom data type.
         */
        dataSourceType: pulumi.Input<enums.amplifyuibuilder.FormDataSourceType>;
        /**
         * The unique name of the data type you are using as the data source for the form.
         */
        dataTypeName: pulumi.Input<string>;
    }
    interface FormFieldConfigArgs {
        /**
         * Specifies whether to hide a field.
         */
        excluded?: pulumi.Input<boolean>;
        /**
         * Describes the configuration for the default input value to display for a field.
         */
        inputType?: pulumi.Input<inputs.amplifyuibuilder.FormFieldInputConfigArgs>;
        /**
         * The label for the field.
         */
        label?: pulumi.Input<string>;
        /**
         * Specifies the field position.
         */
        position?: pulumi.Input<inputs.amplifyuibuilder.FormFieldPosition0PropertiesArgs | inputs.amplifyuibuilder.FormFieldPosition1PropertiesArgs | inputs.amplifyuibuilder.FormFieldPosition2PropertiesArgs>;
        /**
         * The validations to perform on the value in the field.
         */
        validations?: pulumi.Input<pulumi.Input<inputs.amplifyuibuilder.FormFieldValidationConfigurationArgs>[]>;
    }
    interface FormFieldInputConfigArgs {
        /**
         * Specifies whether a field has a default value.
         */
        defaultChecked?: pulumi.Input<boolean>;
        /**
         * The default country code for a phone number.
         */
        defaultCountryCode?: pulumi.Input<string>;
        /**
         * The default value for the field.
         */
        defaultValue?: pulumi.Input<string>;
        /**
         * The text to display to describe the field.
         */
        descriptiveText?: pulumi.Input<string>;
        /**
         * The configuration for the file uploader field.
         */
        fileUploaderConfig?: pulumi.Input<inputs.amplifyuibuilder.FormFileUploaderFieldConfigArgs>;
        /**
         * Specifies whether to render the field as an array. This property is ignored if the `dataSourceType` for the form is a Data Store.
         */
        isArray?: pulumi.Input<boolean>;
        /**
         * The maximum value to display for the field.
         */
        maxValue?: pulumi.Input<number>;
        /**
         * The minimum value to display for the field.
         */
        minValue?: pulumi.Input<number>;
        /**
         * The name of the field.
         */
        name?: pulumi.Input<string>;
        /**
         * The text to display as a placeholder for the field.
         */
        placeholder?: pulumi.Input<string>;
        /**
         * Specifies a read only field.
         */
        readOnly?: pulumi.Input<boolean>;
        /**
         * Specifies a field that requires input.
         */
        required?: pulumi.Input<boolean>;
        /**
         * The stepping increment for a numeric value in a field.
         */
        step?: pulumi.Input<number>;
        /**
         * The input type for the field.
         */
        type: pulumi.Input<string>;
        /**
         * The value for the field.
         */
        value?: pulumi.Input<string>;
        /**
         * The information to use to customize the input fields with data at runtime.
         */
        valueMappings?: pulumi.Input<inputs.amplifyuibuilder.FormValueMappingsArgs>;
    }
    interface FormFieldPosition0PropertiesArgs {
        fixed: pulumi.Input<enums.amplifyuibuilder.FormFixedPosition>;
    }
    interface FormFieldPosition1PropertiesArgs {
        rightOf: pulumi.Input<string>;
    }
    interface FormFieldPosition2PropertiesArgs {
        below: pulumi.Input<string>;
    }
    interface FormFieldValidationConfigurationArgs {
        /**
         * The validation to perform on a number value.
         */
        numValues?: pulumi.Input<pulumi.Input<number>[]>;
        /**
         * The validation to perform on a string value.
         */
        strValues?: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * The validation to perform on an object type. ``
         */
        type: pulumi.Input<string>;
        /**
         * The validation message to display.
         */
        validationMessage?: pulumi.Input<string>;
    }
    interface FormFileUploaderFieldConfigArgs {
        /**
         * The file types that are allowed to be uploaded by the file uploader. Provide this information in an array of strings specifying the valid file extensions.
         */
        acceptedFileTypes: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * The access level to assign to the uploaded files in the Amazon S3 bucket where they are stored. The valid values for this property are `private` , `protected` , or `public` . For detailed information about the permissions associated with each access level, see [File access levels](https://docs.aws.amazon.com/https://docs.amplify.aws/lib/storage/configureaccess/q/platform/js/) in the *Amplify documentation* .
         */
        accessLevel: pulumi.Input<enums.amplifyuibuilder.FormStorageAccessLevel>;
        /**
         * Allows the file upload operation to be paused and resumed. The default value is `false` .
         *
         * When `isResumable` is set to `true` , the file uploader uses a multipart upload to break the files into chunks before upload. The progress of the upload isn't continuous, because the file uploader uploads a chunk at a time.
         */
        isResumable?: pulumi.Input<boolean>;
        /**
         * Specifies the maximum number of files that can be selected to upload. The default value is an unlimited number of files.
         */
        maxFileCount?: pulumi.Input<number>;
        /**
         * The maximum file size in bytes that the file uploader will accept. The default value is an unlimited file size.
         */
        maxSize?: pulumi.Input<number>;
        /**
         * Specifies whether to display or hide the image preview after selecting a file for upload. The default value is `true` to display the image preview.
         */
        showThumbnails?: pulumi.Input<boolean>;
    }
    interface FormInputBindingPropertiesValueArgs {
        /**
         * Describes the properties to customize with data at runtime.
         */
        bindingProperties?: pulumi.Input<inputs.amplifyuibuilder.FormInputBindingPropertiesValuePropertiesArgs>;
        /**
         * The property type.
         */
        type?: pulumi.Input<string>;
    }
    interface FormInputBindingPropertiesValuePropertiesArgs {
        /**
         * An Amplify DataStore model.
         */
        model?: pulumi.Input<string>;
    }
    interface FormInputValuePropertyArgs {
        /**
         * The information to bind fields to data at runtime.
         */
        bindingProperties?: pulumi.Input<inputs.amplifyuibuilder.FormInputValuePropertyBindingPropertiesArgs>;
        /**
         * A list of form properties to concatenate to create the value to assign to this field property.
         */
        concat?: pulumi.Input<pulumi.Input<inputs.amplifyuibuilder.FormInputValuePropertyArgs>[]>;
        /**
         * The value to assign to the input field.
         */
        value?: pulumi.Input<string>;
    }
    interface FormInputValuePropertyBindingPropertiesArgs {
        /**
         * The data field to bind the property to.
         */
        field?: pulumi.Input<string>;
        /**
         * The form property to bind to the data field.
         */
        property: pulumi.Input<string>;
    }
    interface FormSectionalElementArgs {
        /**
         * Excludes a sectional element that was generated by default for a specified data model.
         */
        excluded?: pulumi.Input<boolean>;
        /**
         * Specifies the size of the font for a `Heading` sectional element. Valid values are `1 | 2 | 3 | 4 | 5 | 6` .
         */
        level?: pulumi.Input<number>;
        /**
         * Specifies the orientation for a `Divider` sectional element. Valid values are `horizontal` or `vertical` .
         */
        orientation?: pulumi.Input<string>;
        /**
         * Specifies the position of the text in a field for a `Text` sectional element.
         */
        position?: pulumi.Input<inputs.amplifyuibuilder.FormFieldPosition0PropertiesArgs | inputs.amplifyuibuilder.FormFieldPosition1PropertiesArgs | inputs.amplifyuibuilder.FormFieldPosition2PropertiesArgs>;
        /**
         * The text for a `Text` sectional element.
         */
        text?: pulumi.Input<string>;
        /**
         * The type of sectional element. Valid values are `Heading` , `Text` , and `Divider` .
         */
        type: pulumi.Input<string>;
    }
    interface FormStyleArgs {
        /**
         * The spacing for the horizontal gap.
         */
        horizontalGap?: pulumi.Input<inputs.amplifyuibuilder.FormStyleConfig0PropertiesArgs | inputs.amplifyuibuilder.FormStyleConfig1PropertiesArgs>;
        /**
         * The size of the outer padding for the form.
         */
        outerPadding?: pulumi.Input<inputs.amplifyuibuilder.FormStyleConfig0PropertiesArgs | inputs.amplifyuibuilder.FormStyleConfig1PropertiesArgs>;
        /**
         * The spacing for the vertical gap.
         */
        verticalGap?: pulumi.Input<inputs.amplifyuibuilder.FormStyleConfig0PropertiesArgs | inputs.amplifyuibuilder.FormStyleConfig1PropertiesArgs>;
    }
    interface FormStyleConfig0PropertiesArgs {
        tokenReference: pulumi.Input<string>;
    }
    interface FormStyleConfig1PropertiesArgs {
        value: pulumi.Input<string>;
    }
    interface FormValueMappingArgs {
        /**
         * The value to display for the complex object.
         */
        displayValue?: pulumi.Input<inputs.amplifyuibuilder.FormInputValuePropertyArgs>;
        /**
         * The complex object.
         */
        value: pulumi.Input<inputs.amplifyuibuilder.FormInputValuePropertyArgs>;
    }
    interface FormValueMappingsArgs {
        /**
         * The information to bind fields to data at runtime.
         */
        bindingProperties?: pulumi.Input<{
            [key: string]: pulumi.Input<inputs.amplifyuibuilder.FormInputBindingPropertiesValueArgs>;
        }>;
        /**
         * The value and display value pairs.
         */
        values: pulumi.Input<pulumi.Input<inputs.amplifyuibuilder.FormValueMappingArgs>[]>;
    }
    interface ThemeValueArgs {
        /**
         * A list of key-value pairs that define the theme's properties.
         */
        children?: pulumi.Input<pulumi.Input<inputs.amplifyuibuilder.ThemeValuesArgs>[]>;
        /**
         * The value of a theme property.
         */
        value?: pulumi.Input<string>;
    }
    interface ThemeValuesArgs {
        /**
         * The name of the property.
         */
        key?: pulumi.Input<string>;
        /**
         * The value of the property.
         */
        value?: pulumi.Input<inputs.amplifyuibuilder.ThemeValueArgs>;
    }
}
export declare namespace apigateway {
    /**
     * ``StageKey`` is a property of the [AWS::ApiGateway::ApiKey](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-apigateway-apikey.html) resource that specifies the stage to associate with the API key. This association allows only clients with the key to make requests to methods in that stage.
     */
    interface ApiKeyStageKeyArgs {
        /**
         * The string identifier of the associated RestApi.
         */
        restApiId?: pulumi.Input<string>;
        /**
         * The stage name associated with the stage key.
         */
        stageName?: pulumi.Input<string>;
    }
    /**
     * The ``AccessLogSetting`` property type specifies settings for logging access in this stage.
     *   ``AccessLogSetting`` is a property of the [StageDescription](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-apigateway-deployment-stagedescription.html) property type.
     */
    interface DeploymentAccessLogSettingArgs {
        /**
         * The Amazon Resource Name (ARN) of the CloudWatch Logs log group or Kinesis Data Firehose delivery stream to receive access logs. If you specify a Kinesis Data Firehose delivery stream, the stream name must begin with `amazon-apigateway-` .
         */
        destinationArn?: pulumi.Input<string>;
        /**
         * A single line format of the access logs of data, as specified by selected $context variables. The format must include at least `$context.requestId` .
         */
        format?: pulumi.Input<string>;
    }
    /**
     * The ``CanarySetting`` property type specifies settings for the canary deployment in this stage.
     *  ``CanarySetting`` is a property of the [StageDescription](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-apigateway-deployment-stagedescription.html) property type.
     */
    interface DeploymentCanarySettingArgs {
        /**
         * The percent (0-100) of traffic diverted to a canary deployment.
         */
        percentTraffic?: pulumi.Input<number>;
        /**
         * Stage variables overridden for a canary release deployment, including new stage variables introduced in the canary. These stage variables are represented as a string-to-string map between stage variable names and their values.
         */
        stageVariableOverrides?: pulumi.Input<{
            [key: string]: pulumi.Input<string>;
        }>;
        /**
         * A Boolean flag to indicate whether the canary deployment uses the stage cache or not.
         */
        useStageCache?: pulumi.Input<boolean>;
    }
    /**
     * The ``DeploymentCanarySettings`` property type specifies settings for the canary deployment.
     */
    interface DeploymentCanarySettingsArgs {
        /**
         * The percentage (0.0-100.0) of traffic routed to the canary deployment.
         */
        percentTraffic?: pulumi.Input<number>;
        /**
         * A stage variable overrides used for the canary release deployment. They can override existing stage variables or add new stage variables for the canary release deployment. These stage variables are represented as a string-to-string map between stage variable names and their values.
         */
        stageVariableOverrides?: pulumi.Input<{
            [key: string]: pulumi.Input<string>;
        }>;
        /**
         * A Boolean flag to indicate whether the canary release deployment uses the stage cache or not.
         */
        useStageCache?: pulumi.Input<boolean>;
    }
    /**
     * The ``MethodSetting`` property type configures settings for all methods in a stage.
     *  The ``MethodSettings`` property of the [Amazon API Gateway Deployment StageDescription](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-apigateway-deployment-stagedescription.html) property type contains a list of ``MethodSetting`` property types.
     */
    interface DeploymentMethodSettingArgs {
        /**
         * Specifies whether the cached responses are encrypted.
         */
        cacheDataEncrypted?: pulumi.Input<boolean>;
        /**
         * Specifies the time to live (TTL), in seconds, for cached responses. The higher the TTL, the longer the response will be cached.
         */
        cacheTtlInSeconds?: pulumi.Input<number>;
        /**
         * Specifies whether responses should be cached and returned for requests. A cache cluster must be enabled on the stage for responses to be cached.
         */
        cachingEnabled?: pulumi.Input<boolean>;
        /**
         * Specifies whether data trace logging is enabled for this method, which affects the log entries pushed to Amazon CloudWatch Logs. This can be useful to troubleshoot APIs, but can result in logging sensitive data. We recommend that you don't enable this option for production APIs.
         */
        dataTraceEnabled?: pulumi.Input<boolean>;
        /**
         * The HTTP method.
         */
        httpMethod?: pulumi.Input<string>;
        /**
         * Specifies the logging level for this method, which affects the log entries pushed to Amazon CloudWatch Logs. Valid values are `OFF` , `ERROR` , and `INFO` . Choose `ERROR` to write only error-level entries to CloudWatch Logs, or choose `INFO` to include all `ERROR` events as well as extra informational events.
         */
        loggingLevel?: pulumi.Input<string>;
        /**
         * Specifies whether Amazon CloudWatch metrics are enabled for this method.
         */
        metricsEnabled?: pulumi.Input<boolean>;
        /**
         * The resource path for this method. Forward slashes (``/``) are encoded as ``~1`` and the initial slash must include a forward slash. For example, the path value ``/resource/subresource`` must be encoded as ``/~1resource~1subresource``. To specify the root path, use only a slash (``/``).
         */
        resourcePath?: pulumi.Input<string>;
        /**
         * Specifies the throttling burst limit.
         */
        throttlingBurstLimit?: pulumi.Input<number>;
        /**
         * Specifies the throttling rate limit.
         */
        throttlingRateLimit?: pulumi.Input<number>;
    }
    /**
     * ``StageDescription`` is a property of the [AWS::ApiGateway::Deployment](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-apigateway-deployment.html) resource that configures a deployment stage.
     */
    interface DeploymentStageDescriptionArgs {
        /**
         * Specifies settings for logging access in this stage.
         */
        accessLogSetting?: pulumi.Input<inputs.apigateway.DeploymentAccessLogSettingArgs>;
        /**
         * Specifies whether a cache cluster is enabled for the stage. To activate a method-level cache, set `CachingEnabled` to `true` for a method.
         */
        cacheClusterEnabled?: pulumi.Input<boolean>;
        /**
         * The size of the stage's cache cluster. For more information, see [cacheClusterSize](https://docs.aws.amazon.com/apigateway/latest/api/API_CreateStage.html#apigw-CreateStage-request-cacheClusterSize) in the *API Gateway API Reference*.
         */
        cacheClusterSize?: pulumi.Input<string>;
        /**
         * Indicates whether the cached responses are encrypted.
         */
        cacheDataEncrypted?: pulumi.Input<boolean>;
        /**
         * The time-to-live (TTL) period, in seconds, that specifies how long API Gateway caches responses.
         */
        cacheTtlInSeconds?: pulumi.Input<number>;
        /**
         * Indicates whether responses are cached and returned for requests. You must enable a cache cluster on the stage to cache responses. For more information, see [Enable API Gateway Caching in a Stage to Enhance API Performance](https://docs.aws.amazon.com/apigateway/latest/developerguide/api-gateway-caching.html) in the *API Gateway Developer Guide*.
         */
        cachingEnabled?: pulumi.Input<boolean>;
        /**
         * Specifies settings for the canary deployment in this stage.
         */
        canarySetting?: pulumi.Input<inputs.apigateway.DeploymentCanarySettingArgs>;
        /**
         * The identifier of the client certificate that API Gateway uses to call your integration endpoints in the stage.
         */
        clientCertificateId?: pulumi.Input<string>;
        /**
         * Indicates whether data trace logging is enabled for methods in the stage. API Gateway pushes these logs to Amazon CloudWatch Logs.
         */
        dataTraceEnabled?: pulumi.Input<boolean>;
        /**
         * A description of the purpose of the stage.
         */
        description?: pulumi.Input<string>;
        /**
         * The version identifier of the API documentation snapshot.
         */
        documentationVersion?: pulumi.Input<string>;
        /**
         * The logging level for this method. For valid values, see the ``loggingLevel`` property of the [MethodSetting](https://docs.aws.amazon.com/apigateway/latest/api/API_MethodSetting.html) resource in the *Amazon API Gateway API Reference*.
         */
        loggingLevel?: pulumi.Input<string>;
        /**
         * Configures settings for all of the stage's methods.
         */
        methodSettings?: pulumi.Input<pulumi.Input<inputs.apigateway.DeploymentMethodSettingArgs>[]>;
        /**
         * Indicates whether Amazon CloudWatch metrics are enabled for methods in the stage.
         */
        metricsEnabled?: pulumi.Input<boolean>;
        /**
         * An array of arbitrary tags (key-value pairs) to associate with the stage.
         */
        tags?: pulumi.Input<pulumi.Input<inputs.apigateway.DeploymentTagArgs>[]>;
        /**
         * The target request burst rate limit. This allows more requests through for a period of time than the target rate limit. For more information, see [Manage API Request Throttling](https://docs.aws.amazon.com/apigateway/latest/developerguide/api-gateway-request-throttling.html) in the *API Gateway Developer Guide*.
         */
        throttlingBurstLimit?: pulumi.Input<number>;
        /**
         * The target request steady-state rate limit. For more information, see [Manage API Request Throttling](https://docs.aws.amazon.com/apigateway/latest/developerguide/api-gateway-request-throttling.html) in the *API Gateway Developer Guide*.
         */
        throttlingRateLimit?: pulumi.Input<number>;
        /**
         * Specifies whether active tracing with X-ray is enabled for this stage.
         *  For more information, see [Trace API Gateway API Execution with X-Ray](https://docs.aws.amazon.com/apigateway/latest/developerguide/apigateway-xray.html) in the *API Gateway Developer Guide*.
         */
        tracingEnabled?: pulumi.Input<boolean>;
        /**
         * A map that defines the stage variables. Variable names must consist of alphanumeric characters, and the values must match the following regular expression: ``[A-Za-z0-9-._~:/?#&=,]+``.
         */
        variables?: pulumi.Input<{
            [key: string]: pulumi.Input<string>;
        }>;
    }
    interface DeploymentTagArgs {
        /**
         * The key name of the tag
         */
        key: pulumi.Input<string>;
        /**
         * The value for the tag
         */
        value: pulumi.Input<string>;
    }
    /**
     * The ``Location`` property specifies the location of the Amazon API Gateway API entity that the documentation applies to. ``Location`` is a property of the [AWS::ApiGateway::DocumentationPart](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-apigateway-documentationpart.html) resource.
     *  For more information about each property, including constraints and valid values, see [DocumentationPart](https://docs.aws.amazon.com/apigateway/latest/api/API_DocumentationPartLocation.html) in the *Amazon API Gateway REST API Reference*.
     */
    interface DocumentationPartLocationArgs {
        /**
         * The HTTP verb of a method. It is a valid field for the API entity types of `METHOD` , `PATH_PARAMETER` , `QUERY_PARAMETER` , `REQUEST_HEADER` , `REQUEST_BODY` , `RESPONSE` , `RESPONSE_HEADER` , and `RESPONSE_BODY` . The default value is `*` for any method. When an applicable child entity inherits the content of an entity of the same type with more general specifications of the other `location` attributes, the child entity's `method` attribute must match that of the parent entity exactly.
         */
        method?: pulumi.Input<string>;
        /**
         * The name of the targeted API entity. It is a valid and required field for the API entity types of `AUTHORIZER` , `MODEL` , `PATH_PARAMETER` , `QUERY_PARAMETER` , `REQUEST_HEADER` , `REQUEST_BODY` and `RESPONSE_HEADER` . It is an invalid field for any other entity type.
         */
        name?: pulumi.Input<string>;
        /**
         * The URL path of the target. It is a valid field for the API entity types of `RESOURCE` , `METHOD` , `PATH_PARAMETER` , `QUERY_PARAMETER` , `REQUEST_HEADER` , `REQUEST_BODY` , `RESPONSE` , `RESPONSE_HEADER` , and `RESPONSE_BODY` . The default value is `/` for the root resource. When an applicable child entity inherits the content of another entity of the same type with more general specifications of the other `location` attributes, the child entity's `path` attribute must match that of the parent entity as a prefix.
         */
        path?: pulumi.Input<string>;
        /**
         * The HTTP status code of a response. It is a valid field for the API entity types of `RESPONSE` , `RESPONSE_HEADER` , and `RESPONSE_BODY` . The default value is `*` for any status code. When an applicable child entity inherits the content of an entity of the same type with more general specifications of the other `location` attributes, the child entity's `statusCode` attribute must match that of the parent entity exactly.
         */
        statusCode?: pulumi.Input<string>;
        /**
         * The type of API entity to which the documentation content applies. Valid values are `API` , `AUTHORIZER` , `MODEL` , `RESOURCE` , `METHOD` , `PATH_PARAMETER` , `QUERY_PARAMETER` , `REQUEST_HEADER` , `REQUEST_BODY` , `RESPONSE` , `RESPONSE_HEADER` , and `RESPONSE_BODY` . Content inheritance does not apply to any entity of the `API` , `AUTHORIZER` , `METHOD` , `MODEL` , `REQUEST_BODY` , or `RESOURCE` type.
         */
        type?: pulumi.Input<enums.apigateway.DocumentationPartLocationType>;
    }
    interface DomainNameEndpointConfigurationArgs {
        /**
         * The IP address types that can invoke this DomainName. Use `ipv4` to allow only IPv4 addresses to invoke this DomainName, or use `dualstack` to allow both IPv4 and IPv6 addresses to invoke this DomainName. For the `PRIVATE` endpoint type, only `dualstack` is supported.
         */
        ipAddressType?: pulumi.Input<string>;
        /**
         * A list of endpoint types of an API (RestApi) or its custom domain name (DomainName). For an edge-optimized API and its custom domain name, the endpoint type is `"EDGE"` . For a regional API and its custom domain name, the endpoint type is `REGIONAL` . For a private API, the endpoint type is `PRIVATE` .
         */
        types?: pulumi.Input<pulumi.Input<string>[]>;
    }
    interface DomainNameMutualTlsAuthenticationArgs {
        /**
         * An Amazon S3 URL that specifies the truststore for mutual TLS authentication, for example `s3://bucket-name/key-name` . The truststore can contain certificates from public or private certificate authorities. To update the truststore, upload a new version to S3, and then update your custom domain name to use the new version. To update the truststore, you must have permissions to access the S3 object.
         */
        truststoreUri?: pulumi.Input<string>;
        /**
         * The version of the S3 object that contains your truststore. To specify a version, you must have versioning enabled for the S3 bucket.
         */
        truststoreVersion?: pulumi.Input<string>;
    }
    interface DomainNameV2EndpointConfigurationArgs {
        ipAddressType?: pulumi.Input<string>;
        /**
         * A list of endpoint types of an API (RestApi) or its custom domain name (DomainName). For an edge-optimized API and its custom domain name, the endpoint type is `"EDGE"` . For a regional API and its custom domain name, the endpoint type is `REGIONAL` . For a private API, the endpoint type is `PRIVATE` .
         */
        types?: pulumi.Input<pulumi.Input<string>[]>;
    }
    /**
     * ``Integration`` is a property of the [AWS::ApiGateway::Method](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-apigateway-method.html) resource that specifies information about the target backend that a method calls.
     */
    interface MethodIntegrationArgs {
        /**
         * A list of request parameters whose values API Gateway caches. To be valid values for `cacheKeyParameters` , these parameters must also be specified for Method `requestParameters` .
         */
        cacheKeyParameters?: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * Specifies a group of related cached parameters. By default, API Gateway uses the resource ID as the `cacheNamespace` . You can specify the same `cacheNamespace` across resources to return the same cached data for requests to different resources.
         */
        cacheNamespace?: pulumi.Input<string>;
        /**
         * The ID of the VpcLink used for the integration when `connectionType=VPC_LINK` and undefined, otherwise.
         */
        connectionId?: pulumi.Input<string>;
        /**
         * The type of the network connection to the integration endpoint. The valid value is `INTERNET` for connections through the public routable internet or `VPC_LINK` for private connections between API Gateway and a network load balancer in a VPC. The default value is `INTERNET` .
         */
        connectionType?: pulumi.Input<enums.apigateway.MethodIntegrationConnectionType>;
        /**
         * Specifies how to handle request payload content type conversions. Supported values are `CONVERT_TO_BINARY` and `CONVERT_TO_TEXT` , with the following behaviors:
         *
         * If this property is not defined, the request payload will be passed through from the method request to integration request without modification, provided that the `passthroughBehavior` is configured to support payload pass-through.
         */
        contentHandling?: pulumi.Input<enums.apigateway.MethodIntegrationContentHandling>;
        /**
         * Specifies the credentials required for the integration, if any. For AWS integrations, three options are available. To specify an IAM Role for API Gateway to assume, use the role's Amazon Resource Name (ARN). To require that the caller's identity be passed through from the request, specify the string `arn:aws:iam::\*:user/\*` . To use resource-based permissions on supported AWS services, specify null.
         */
        credentials?: pulumi.Input<string>;
        /**
         * Specifies the integration's HTTP method type. For the Type property, if you specify `MOCK` , this property is optional. For Lambda integrations, you must set the integration method to `POST` . For all other types, you must specify this property.
         */
        integrationHttpMethod?: pulumi.Input<string>;
        /**
         * Specifies the integration's responses.
         */
        integrationResponses?: pulumi.Input<pulumi.Input<inputs.apigateway.MethodIntegrationResponseArgs>[]>;
        /**
         * Specifies how the method request body of an unmapped content type will be passed through the integration request to the back end without transformation. A content type is unmapped if no mapping template is defined in the integration or the content type does not match any of the mapped content types, as specified in `requestTemplates` . The valid value is one of the following: `WHEN_NO_MATCH` : passes the method request body through the integration request to the back end without transformation when the method request content type does not match any content type associated with the mapping templates defined in the integration request. `WHEN_NO_TEMPLATES` : passes the method request body through the integration request to the back end without transformation when no mapping template is defined in the integration request. If a template is defined when this option is selected, the method request of an unmapped content-type will be rejected with an HTTP 415 Unsupported Media Type response. `NEVER` : rejects the method request with an HTTP 415 Unsupported Media Type response when either the method request content type does not match any content type associated with the mapping templates defined in the integration request or no mapping template is defined in the integration request.
         */
        passthroughBehavior?: pulumi.Input<enums.apigateway.MethodIntegrationPassthroughBehavior>;
        /**
         * A key-value map specifying request parameters that are passed from the method request to the back end. The key is an integration request parameter name and the associated value is a method request parameter value or static value that must be enclosed within single quotes and pre-encoded as required by the back end. The method request parameter value must match the pattern of `method.request.{location}.{name}` , where `location` is `querystring` , `path` , or `header` and `name` must be a valid and unique method request parameter name.
         */
        requestParameters?: pulumi.Input<{
            [key: string]: pulumi.Input<string>;
        }>;
        /**
         * Represents a map of Velocity templates that are applied on the request payload based on the value of the Content-Type header sent by the client. The content type value is the key in this map, and the template (as a String) is the value.
         */
        requestTemplates?: pulumi.Input<{
            [key: string]: pulumi.Input<string>;
        }>;
        /**
         * Custom timeout between 50 and 29,000 milliseconds. The default value is 29,000 milliseconds or 29 seconds.
         */
        timeoutInMillis?: pulumi.Input<number>;
        /**
         * Specifies an API method integration type. The valid value is one of the following:
         *
         * For the HTTP and HTTP proxy integrations, each integration can specify a protocol ( `http/https` ), port and path. Standard 80 and 443 ports are supported as well as custom ports above 1024. An HTTP or HTTP proxy integration with a `connectionType` of `VPC_LINK` is referred to as a private integration and uses a VpcLink to connect API Gateway to a network load balancer of a VPC.
         */
        type: pulumi.Input<enums.apigateway.MethodIntegrationType>;
        /**
         * Specifies Uniform Resource Identifier (URI) of the integration endpoint.
         *
         * For `HTTP` or `HTTP_PROXY` integrations, the URI must be a fully formed, encoded HTTP(S) URL according to the RFC-3986 specification for standard integrations. If `connectionType` is `VPC_LINK` specify the Network Load Balancer DNS name. For `AWS` or `AWS_PROXY` integrations, the URI is of the form `arn:aws:apigateway:{region}:{subdomain.service|service}:path|action/{service_api}` . Here, {Region} is the API Gateway region (e.g., us-east-1); {service} is the name of the integrated AWS service (e.g., s3); and {subdomain} is a designated subdomain supported by certain AWS service for fast host-name lookup. action can be used for an AWS service action-based API, using an Action={name}&{p1}={v1}&p2={v2}... query string. The ensuing {service_api} refers to a supported action {name} plus any required input parameters. Alternatively, path can be used for an AWS service path-based API. The ensuing service_api refers to the path to an AWS service resource, including the region of the integrated AWS service, if applicable. For example, for integration with the S3 API of GetObject, the uri can be either `arn:aws:apigateway:us-west-2:s3:action/GetObject&Bucket={bucket}&Key={key}` or `arn:aws:apigateway:us-west-2:s3:path/{bucket}/{key}`
         */
        uri?: pulumi.Input<string>;
    }
    /**
     * ``IntegrationResponse`` is a property of the [Amazon API Gateway Method Integration](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-apitgateway-method-integration.html) property type that specifies the response that API Gateway sends after a method's backend finishes processing a request.
     */
    interface MethodIntegrationResponseArgs {
        /**
         * Specifies how to handle response payload content type conversions. Supported values are `CONVERT_TO_BINARY` and `CONVERT_TO_TEXT` , with the following behaviors:
         *
         * If this property is not defined, the response payload will be passed through from the integration response to the method response without modification.
         */
        contentHandling?: pulumi.Input<enums.apigateway.MethodIntegrationResponseContentHandling>;
        /**
         * A key-value map specifying response parameters that are passed to the method response from the back end. The key is a method response header parameter name and the mapped value is an integration response header value, a static value enclosed within a pair of single quotes, or a JSON expression from the integration response body. The mapping key must match the pattern of `method.response.header.{name}` , where `name` is a valid and unique header name. The mapped non-static value must match the pattern of `integration.response.header.{name}` or `integration.response.body.{JSON-expression}` , where `name` is a valid and unique response header name and `JSON-expression` is a valid JSON expression without the `$` prefix.
         */
        responseParameters?: pulumi.Input<{
            [key: string]: pulumi.Input<string>;
        }>;
        /**
         * Specifies the templates used to transform the integration response body. Response templates are represented as a key/value map, with a content-type as the key and a template as the value.
         */
        responseTemplates?: pulumi.Input<{
            [key: string]: pulumi.Input<string>;
        }>;
        /**
         * Specifies the regular expression (regex) pattern used to choose an integration response based on the response from the back end. For example, if the success response returns nothing and the error response returns some string, you could use the `.+` regex to match error response. However, make sure that the error response does not contain any newline ( `\n` ) character in such cases. If the back end is an AWS Lambda function, the AWS Lambda function error header is matched. For all other HTTP and AWS back ends, the HTTP status code is matched.
         */
        selectionPattern?: pulumi.Input<string>;
        /**
         * Specifies the status code that is used to map the integration response to an existing MethodResponse.
         */
        statusCode: pulumi.Input<string>;
    }
    interface MethodResponseArgs {
        /**
         * Specifies the Model resources used for the response's content-type. Response models are represented as a key/value map, with a content-type as the key and a Model name as the value.
         */
        responseModels?: pulumi.Input<{
            [key: string]: pulumi.Input<string>;
        }>;
        /**
         * A key-value map specifying required or optional response parameters that API Gateway can send back to the caller. A key defines a method response header and the value specifies whether the associated method response header is required or not. The expression of the key must match the pattern `method.response.header.{name}` , where `name` is a valid and unique header name. API Gateway passes certain integration response data to the method response headers specified here according to the mapping you prescribe in the API's IntegrationResponse. The integration response data that can be mapped include an integration response header expressed in `integration.response.header.{name}` , a static value enclosed within a pair of single quotes (e.g., `'application/json'` ), or a JSON expression from the back-end response payload in the form of `integration.response.body.{JSON-expression}` , where `JSON-expression` is a valid JSON expression without the `$` prefix.)
         */
        responseParameters?: pulumi.Input<{
            [key: string]: pulumi.Input<boolean | string>;
        }>;
        /**
         * The method response's status code.
         */
        statusCode: pulumi.Input<string>;
    }
    /**
     * The ``EndpointConfiguration`` property type specifies the endpoint types of a REST API.
     *  ``EndpointConfiguration`` is a property of the [AWS::ApiGateway::RestApi](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-apigateway-restapi.html) resource.
     */
    interface RestApiEndpointConfigurationArgs {
        /**
         * The IP address types that can invoke an API (RestApi). Use `ipv4` to allow only IPv4 addresses to invoke an API, or use `dualstack` to allow both IPv4 and IPv6 addresses to invoke an API. For the `PRIVATE` endpoint type, only `dualstack` is supported.
         */
        ipAddressType?: pulumi.Input<string>;
        /**
         * A list of endpoint types of an API (RestApi) or its custom domain name (DomainName). For an edge-optimized API and its custom domain name, the endpoint type is `"EDGE"` . For a regional API and its custom domain name, the endpoint type is `REGIONAL` . For a private API, the endpoint type is `PRIVATE` .
         */
        types?: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * A list of VpcEndpointIds of an API (RestApi) against which to create Route53 ALIASes. It is only supported for `PRIVATE` endpoint type.
         */
        vpcEndpointIds?: pulumi.Input<pulumi.Input<string>[]>;
    }
    /**
     * ``S3Location`` is a property of the [AWS::ApiGateway::RestApi](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-apigateway-restapi.html) resource that specifies the Amazon S3 location of a OpenAPI (formerly Swagger) file that defines a set of RESTful APIs in JSON or YAML.
     *  On January 1, 2016, the Swagger Specification was donated to the [OpenAPI initiative](https://docs.aws.amazon.com/https://www.openapis.org/), becoming the foundation of the OpenAPI Specification.
     */
    interface RestApiS3LocationArgs {
        /**
         * The name of the S3 bucket where the OpenAPI file is stored.
         */
        bucket?: pulumi.Input<string>;
        /**
         * The Amazon S3 ETag (a file checksum) of the OpenAPI file. If you don't specify a value, API Gateway skips ETag validation of your OpenAPI file.
         */
        eTag?: pulumi.Input<string>;
        /**
         * The file name of the OpenAPI file (Amazon S3 object name).
         */
        key?: pulumi.Input<string>;
        /**
         * For versioning-enabled buckets, a specific version of the OpenAPI file.
         */
        version?: pulumi.Input<string>;
    }
    /**
     * The ``AccessLogSetting`` property type specifies settings for logging access in this stage.
     *   ``AccessLogSetting`` is a property of the [AWS::ApiGateway::Stage](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-apigateway-stage.html) resource.
     */
    interface StageAccessLogSettingArgs {
        /**
         * The Amazon Resource Name (ARN) of the CloudWatch Logs log group or Kinesis Data Firehose delivery stream to receive access logs. If you specify a Kinesis Data Firehose delivery stream, the stream name must begin with ``amazon-apigateway-``. This parameter is required to enable access logging.
         */
        destinationArn?: pulumi.Input<string>;
        /**
         * A single line format of the access logs of data, as specified by selected [$context variables](https://docs.aws.amazon.com/apigateway/latest/developerguide/api-gateway-mapping-template-reference.html#context-variable-reference). The format must include at least ``$context.requestId``. This parameter is required to enable access logging.
         */
        format?: pulumi.Input<string>;
    }
    interface StageCanarySettingArgs {
        /**
         * The ID of the canary deployment.
         */
        deploymentId?: pulumi.Input<string>;
        /**
         * The percent (0-100) of traffic diverted to a canary deployment.
         */
        percentTraffic?: pulumi.Input<number>;
        /**
         * Stage variables overridden for a canary release deployment, including new stage variables introduced in the canary. These stage variables are represented as a string-to-string map between stage variable names and their values.
         */
        stageVariableOverrides?: pulumi.Input<{
            [key: string]: pulumi.Input<string>;
        }>;
        /**
         * A Boolean flag to indicate whether the canary deployment uses the stage cache or not.
         */
        useStageCache?: pulumi.Input<boolean>;
    }
    /**
     * The ``MethodSetting`` property type configures settings for all methods in a stage.
     *  The ``MethodSettings`` property of the ``AWS::ApiGateway::Stage`` resource contains a list of ``MethodSetting`` property types.
     */
    interface StageMethodSettingArgs {
        /**
         * Specifies whether the cached responses are encrypted.
         */
        cacheDataEncrypted?: pulumi.Input<boolean>;
        /**
         * Specifies the time to live (TTL), in seconds, for cached responses. The higher the TTL, the longer the response will be cached.
         */
        cacheTtlInSeconds?: pulumi.Input<number>;
        /**
         * Specifies whether responses should be cached and returned for requests. A cache cluster must be enabled on the stage for responses to be cached.
         */
        cachingEnabled?: pulumi.Input<boolean>;
        /**
         * Specifies whether data trace logging is enabled for this method, which affects the log entries pushed to Amazon CloudWatch Logs. This can be useful to troubleshoot APIs, but can result in logging sensitive data. We recommend that you don't enable this option for production APIs.
         */
        dataTraceEnabled?: pulumi.Input<boolean>;
        /**
         * The HTTP method. To apply settings to multiple resources and methods, specify an asterisk (``*``) for the ``HttpMethod`` and ``/*`` for the ``ResourcePath``. This parameter is required when you specify a ``MethodSetting``.
         */
        httpMethod?: pulumi.Input<string>;
        /**
         * Specifies the logging level for this method, which affects the log entries pushed to Amazon CloudWatch Logs. Valid values are `OFF` , `ERROR` , and `INFO` . Choose `ERROR` to write only error-level entries to CloudWatch Logs, or choose `INFO` to include all `ERROR` events as well as extra informational events.
         */
        loggingLevel?: pulumi.Input<string>;
        /**
         * Specifies whether Amazon CloudWatch metrics are enabled for this method.
         */
        metricsEnabled?: pulumi.Input<boolean>;
        /**
         * The resource path for this method. Forward slashes (``/``) are encoded as ``~1`` and the initial slash must include a forward slash. For example, the path value ``/resource/subresource`` must be encoded as ``/~1resource~1subresource``. To specify the root path, use only a slash (``/``). To apply settings to multiple resources and methods, specify an asterisk (``*``) for the ``HttpMethod`` and ``/*`` for the ``ResourcePath``. This parameter is required when you specify a ``MethodSetting``.
         */
        resourcePath?: pulumi.Input<string>;
        /**
         * Specifies the throttling burst limit.
         */
        throttlingBurstLimit?: pulumi.Input<number>;
        /**
         * Specifies the throttling rate limit.
         */
        throttlingRateLimit?: pulumi.Input<number>;
    }
    interface UsagePlanApiStageArgs {
        /**
         * API Id of the associated API stage in a usage plan.
         */
        apiId?: pulumi.Input<string>;
        /**
         * API stage name of the associated API stage in a usage plan.
         */
        stage?: pulumi.Input<string>;
        /**
         * Map containing method level throttling information for API stage in a usage plan.
         */
        throttle?: pulumi.Input<{
            [key: string]: pulumi.Input<inputs.apigateway.UsagePlanThrottleSettingsArgs>;
        }>;
    }
    /**
     * ``QuotaSettings`` is a property of the [AWS::ApiGateway::UsagePlan](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-apigateway-usageplan.html) resource that specifies a target for the maximum number of requests users can make to your REST APIs.
     *  In some cases clients can exceed the targets that you set. Don’t rely on usage plans to control costs. Consider using [](https://docs.aws.amazon.com/cost-management/latest/userguide/budgets-managing-costs.html) to monitor costs and [](https://docs.aws.amazon.com/waf/latest/developerguide/waf-chapter.html) to manage API requests.
     */
    interface UsagePlanQuotaSettingsArgs {
        /**
         * The target maximum number of requests that can be made in a given time period.
         */
        limit?: pulumi.Input<number>;
        /**
         * The number of requests subtracted from the given limit in the initial time period.
         */
        offset?: pulumi.Input<number>;
        /**
         * The time period in which the limit applies. Valid values are "DAY", "WEEK" or "MONTH".
         */
        period?: pulumi.Input<string>;
    }
    /**
     * ``ThrottleSettings`` is a property of the [AWS::ApiGateway::UsagePlan](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-apigateway-usageplan.html) resource that specifies the overall request rate (average requests per second) and burst capacity when users call your REST APIs.
     */
    interface UsagePlanThrottleSettingsArgs {
        burstLimit?: pulumi.Input<number>;
        rateLimit?: pulumi.Input<number>;
    }
}
export declare namespace apigatewayv2 {
    /**
     * The ``BodyS3Location`` property specifies an S3 location from which to import an OpenAPI definition. Supported only for HTTP APIs.
     */
    interface ApiBodyS3LocationArgs {
        /**
         * The S3 bucket that contains the OpenAPI definition to import. Required if you specify a ``BodyS3Location`` for an API.
         */
        bucket?: pulumi.Input<string>;
        /**
         * The Etag of the S3 object.
         */
        etag?: pulumi.Input<string>;
        /**
         * The key of the S3 object. Required if you specify a ``BodyS3Location`` for an API.
         */
        key?: pulumi.Input<string>;
        /**
         * The version of the S3 object.
         */
        version?: pulumi.Input<string>;
    }
    /**
     * The ``Cors`` property specifies a CORS configuration for an API. Supported only for HTTP APIs. See [Configuring CORS](https://docs.aws.amazon.com/apigateway/latest/developerguide/http-api-cors.html) for more information.
     */
    interface ApiCorsArgs {
        /**
         * Specifies whether credentials are included in the CORS request. Supported only for HTTP APIs.
         */
        allowCredentials?: pulumi.Input<boolean>;
        /**
         * Represents a collection of allowed headers. Supported only for HTTP APIs.
         */
        allowHeaders?: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * Represents a collection of allowed HTTP methods. Supported only for HTTP APIs.
         */
        allowMethods?: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * Represents a collection of allowed origins. Supported only for HTTP APIs.
         */
        allowOrigins?: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * Represents a collection of exposed headers. Supported only for HTTP APIs.
         */
        exposeHeaders?: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * The number of seconds that the browser should cache preflight request results. Supported only for HTTP APIs.
         */
        maxAge?: pulumi.Input<number>;
    }
    /**
     * The ``JWTConfiguration`` property specifies the configuration of a JWT authorizer. Required for the ``JWT`` authorizer type. Supported only for HTTP APIs.
     */
    interface AuthorizerJwtConfigurationArgs {
        /**
         * A list of the intended recipients of the JWT. A valid JWT must provide an ``aud`` that matches at least one entry in this list. See [RFC 7519](https://docs.aws.amazon.com/https://tools.ietf.org/html/rfc7519#section-4.1.3). Required for the ``JWT`` authorizer type. Supported only for HTTP APIs.
         */
        audience?: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * The base domain of the identity provider that issues JSON Web Tokens. For example, an Amazon Cognito user pool has the following format: ``https://cognito-idp.{region}.amazonaws.com/{userPoolId}``. Required for the ``JWT`` authorizer type. Supported only for HTTP APIs.
         */
        issuer?: pulumi.Input<string>;
    }
    /**
     * The ``DomainNameConfiguration`` property type specifies the configuration for an API's domain name.
     *   ``DomainNameConfiguration`` is a property of the [AWS::ApiGatewayV2::DomainName](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-apigatewayv2-domainname.html) resource.
     */
    interface DomainNameConfigurationArgs {
        /**
         * An AWS-managed certificate that will be used by the edge-optimized endpoint for this domain name. AWS Certificate Manager is the only supported source.
         */
        certificateArn?: pulumi.Input<string>;
        /**
         * The user-friendly name of the certificate that will be used by the edge-optimized endpoint for this domain name.
         */
        certificateName?: pulumi.Input<string>;
        /**
         * The endpoint type.
         */
        endpointType?: pulumi.Input<string>;
        /**
         * The Amazon resource name (ARN) for the public certificate issued by ACMlong. This ARN is used to validate custom domain ownership. It's required only if you configure mutual TLS and use either an ACM-imported or a private CA certificate ARN as the regionalCertificateArn.
         */
        ownershipVerificationCertificateArn?: pulumi.Input<string>;
        /**
         * The Transport Layer Security (TLS) version of the security policy for this domain name. The valid values are ``TLS_1_0`` and ``TLS_1_2``.
         */
        securityPolicy?: pulumi.Input<string>;
    }
    /**
     * If specified, API Gateway performs two-way authentication between the client and the server. Clients must present a trusted certificate to access your API.
     */
    interface DomainNameMutualTlsAuthenticationArgs {
        /**
         * An Amazon S3 URL that specifies the truststore for mutual TLS authentication, for example, ``s3://bucket-name/key-name``. The truststore can contain certificates from public or private certificate authorities. To update the truststore, upload a new version to S3, and then update your custom domain name to use the new version. To update the truststore, you must have permissions to access the S3 object.
         */
        truststoreUri?: pulumi.Input<string>;
        /**
         * The version of the S3 object that contains your truststore. To specify a version, you must have versioning enabled for the S3 bucket.
         */
        truststoreVersion?: pulumi.Input<string>;
    }
    /**
     * response parameter
     */
    interface IntegrationResponseParameterArgs {
        destination?: pulumi.Input<string>;
        source?: pulumi.Input<string>;
    }
    /**
     * map of response parameter lists
     */
    interface IntegrationResponseParameterMapArgs {
        responseParameters?: pulumi.Input<pulumi.Input<inputs.apigatewayv2.IntegrationResponseParameterArgs>[]>;
    }
    /**
     * The TlsConfig property specifies the TLS configuration for a private integration. Supported only for HTTP APIs.
     */
    interface IntegrationTlsConfigArgs {
        /**
         * If you specify a server name, API Gateway uses it to verify the hostname on the integration's certificate. The server name is also included in the TLS handshake to support Server Name Indication (SNI) or virtual hosting.
         */
        serverNameToVerify?: pulumi.Input<string>;
    }
    interface RouteParameterConstraintsArgs {
        required: pulumi.Input<boolean>;
    }
    /**
     * Specifies whether the parameter is required.
     */
    interface RouteResponseParameterConstraintsArgs {
        /**
         * Specifies whether the parameter is required.
         */
        required: pulumi.Input<boolean>;
    }
}
export declare namespace appconfig {
    /**
     * A list of methods for validating the configuration.
     */
    interface ConfigurationProfileValidatorsArgs {
        /**
         * Either the JSON Schema content or the Amazon Resource Name (ARN) of an Lambda function.
         */
        content?: pulumi.Input<string>;
        /**
         * AWS AppConfig supports validators of type JSON_SCHEMA and LAMBDA.
         */
        type?: pulumi.Input<string>;
    }
    interface DeploymentDynamicExtensionParametersArgs {
        /**
         * The ARN or ID of the extension for which you are inserting a dynamic parameter.
         */
        extensionReference?: pulumi.Input<string>;
        /**
         * The parameter name.
         */
        parameterName?: pulumi.Input<string>;
        /**
         * The parameter value.
         */
        parameterValue?: pulumi.Input<string>;
    }
    /**
     * Amazon CloudWatch alarm to monitor during the deployment process.
     */
    interface EnvironmentMonitorArgs {
        /**
         * Amazon Resource Name (ARN) of the Amazon CloudWatch alarm.
         */
        alarmArn: pulumi.Input<string>;
        /**
         * ARN of an AWS Identity and Access Management (IAM) role for AWS AppConfig to monitor AlarmArn.
         */
        alarmRoleArn?: pulumi.Input<string>;
    }
    /**
     * An action for an extension to take at a specific action point.
     */
    interface ExtensionActionArgs {
        /**
         * The description of the extension Action.
         */
        description?: pulumi.Input<string>;
        /**
         * The name of the extension action.
         */
        name: pulumi.Input<string>;
        /**
         * The ARN of the role for invoking the extension action.
         */
        roleArn?: pulumi.Input<string>;
        /**
         * The URI of the extension action.
         */
        uri: pulumi.Input<string>;
    }
    /**
     * A parameter for the extension to send to a specific action.
     */
    interface ExtensionParameterArgs {
        /**
         * The description of the extension Parameter.
         */
        description?: pulumi.Input<string>;
        dynamic?: pulumi.Input<boolean>;
        required: pulumi.Input<boolean>;
    }
}
export declare namespace appflow {
    /**
     * Contains information about the configuration of the lambda which is being registered as the connector.
     */
    interface ConnectorLambdaConnectorProvisioningConfigArgs {
        /**
         * Lambda ARN of the connector being registered.
         */
        lambdaArn: pulumi.Input<string>;
    }
    interface ConnectorProfileAmplitudeConnectorProfileCredentialsArgs {
        /**
         * A unique alphanumeric identiﬁer used to authenticate a user, developer, or calling program to your API.
         */
        apiKey: pulumi.Input<string>;
        /**
         * The Secret Access Key portion of the credentials.
         */
        secretKey: pulumi.Input<string>;
    }
    interface ConnectorProfileApiKeyCredentialsArgs {
        /**
         * The API key required for API key authentication.
         */
        apiKey: pulumi.Input<string>;
        /**
         * The API secret key required for API key authentication.
         */
        apiSecretKey?: pulumi.Input<string>;
    }
    interface ConnectorProfileBasicAuthCredentialsArgs {
        /**
         * The password to use to connect to a resource.
         */
        password: pulumi.Input<string>;
        /**
         * The username to use to connect to a resource.
         */
        username: pulumi.Input<string>;
    }
    /**
     * Connector specific configurations needed to create connector profile
     */
    interface ConnectorProfileConfigArgs {
        /**
         * The connector-specific credentials required by each connector.
         */
        connectorProfileCredentials?: pulumi.Input<inputs.appflow.ConnectorProfileCredentialsArgs>;
        /**
         * The connector-specific properties of the profile configuration.
         */
        connectorProfileProperties?: pulumi.Input<inputs.appflow.ConnectorProfilePropertiesArgs>;
    }
    interface ConnectorProfileConnectorOAuthRequestArgs {
        /**
         * The code provided by the connector when it has been authenticated via the connected app.
         */
        authCode?: pulumi.Input<string>;
        /**
         * The URL to which the authentication server redirects the browser after authorization has been
         * granted.
         */
        redirectUri?: pulumi.Input<string>;
    }
    /**
     * Connector specific configuration needed to create connector profile based on Authentication mechanism
     */
    interface ConnectorProfileCredentialsArgs {
        /**
         * The connector-specific credentials required when using Amplitude.
         */
        amplitude?: pulumi.Input<inputs.appflow.ConnectorProfileAmplitudeConnectorProfileCredentialsArgs>;
        /**
         * The connector-specific profile credentials that are required when using the custom connector.
         */
        customConnector?: pulumi.Input<inputs.appflow.ConnectorProfileCustomConnectorProfileCredentialsArgs>;
        /**
         * The connector-specific credentials required when using Datadog.
         */
        datadog?: pulumi.Input<inputs.appflow.ConnectorProfileDatadogConnectorProfileCredentialsArgs>;
        /**
         * The connector-specific credentials required when using Dynatrace.
         */
        dynatrace?: pulumi.Input<inputs.appflow.ConnectorProfileDynatraceConnectorProfileCredentialsArgs>;
        /**
         * The connector-specific credentials required when using Google Analytics.
         */
        googleAnalytics?: pulumi.Input<inputs.appflow.ConnectorProfileGoogleAnalyticsConnectorProfileCredentialsArgs>;
        /**
         * The connector-specific credentials required when using Infor Nexus.
         */
        inforNexus?: pulumi.Input<inputs.appflow.ConnectorProfileInforNexusConnectorProfileCredentialsArgs>;
        /**
         * The connector-specific credentials required when using Marketo.
         */
        marketo?: pulumi.Input<inputs.appflow.ConnectorProfileMarketoConnectorProfileCredentialsArgs>;
        /**
         * The connector-specific credentials required when using Salesforce Pardot.
         */
        pardot?: pulumi.Input<inputs.appflow.ConnectorProfilePardotConnectorProfileCredentialsArgs>;
        /**
         * The connector-specific credentials required when using Amazon Redshift.
         */
        redshift?: pulumi.Input<inputs.appflow.ConnectorProfileRedshiftConnectorProfileCredentialsArgs>;
        /**
         * The connector-specific credentials required when using Salesforce.
         */
        salesforce?: pulumi.Input<inputs.appflow.ConnectorProfileSalesforceConnectorProfileCredentialsArgs>;
        /**
         * The connector-specific profile credentials required when using SAPOData.
         */
        sapoData?: pulumi.Input<inputs.appflow.ConnectorProfileSapoDataConnectorProfileCredentialsArgs>;
        /**
         * The connector-specific credentials required when using ServiceNow.
         */
        serviceNow?: pulumi.Input<inputs.appflow.ConnectorProfileServiceNowConnectorProfileCredentialsArgs>;
        /**
         * The connector-specific credentials required when using Singular.
         */
        singular?: pulumi.Input<inputs.appflow.ConnectorProfileSingularConnectorProfileCredentialsArgs>;
        /**
         * The connector-specific credentials required when using Slack.
         */
        slack?: pulumi.Input<inputs.appflow.ConnectorProfileSlackConnectorProfileCredentialsArgs>;
        /**
         * The connector-specific credentials required when using Snowflake.
         */
        snowflake?: pulumi.Input<inputs.appflow.ConnectorProfileSnowflakeConnectorProfileCredentialsArgs>;
        /**
         * The connector-specific credentials required when using Trend Micro.
         */
        trendmicro?: pulumi.Input<inputs.appflow.ConnectorProfileTrendmicroConnectorProfileCredentialsArgs>;
        /**
         * The connector-specific credentials required when using Veeva.
         */
        veeva?: pulumi.Input<inputs.appflow.ConnectorProfileVeevaConnectorProfileCredentialsArgs>;
        /**
         * The connector-specific credentials required when using Zendesk.
         */
        zendesk?: pulumi.Input<inputs.appflow.ConnectorProfileZendeskConnectorProfileCredentialsArgs>;
    }
    interface ConnectorProfileCustomAuthCredentialsArgs {
        /**
         * A map that holds custom authentication credentials.
         */
        credentialsMap?: pulumi.Input<{
            [key: string]: pulumi.Input<string>;
        }>;
        /**
         * The custom authentication type that the connector uses.
         */
        customAuthenticationType: pulumi.Input<string>;
    }
    interface ConnectorProfileCustomConnectorProfileCredentialsArgs {
        /**
         * The API keys required for the authentication of the user.
         */
        apiKey?: pulumi.Input<inputs.appflow.ConnectorProfileApiKeyCredentialsArgs>;
        /**
         * The authentication type that the custom connector uses for authenticating while creating a connector profile.
         */
        authenticationType: pulumi.Input<enums.appflow.ConnectorProfileAuthenticationType>;
        /**
         * The basic credentials that are required for the authentication of the user.
         */
        basic?: pulumi.Input<inputs.appflow.ConnectorProfileBasicAuthCredentialsArgs>;
        /**
         * If the connector uses the custom authentication mechanism, this holds the required credentials.
         */
        custom?: pulumi.Input<inputs.appflow.ConnectorProfileCustomAuthCredentialsArgs>;
        /**
         * The OAuth 2.0 credentials required for the authentication of the user.
         */
        oauth2?: pulumi.Input<inputs.appflow.ConnectorProfileOAuth2CredentialsArgs>;
    }
    interface ConnectorProfileCustomConnectorProfilePropertiesArgs {
        /**
         * The OAuth 2.0 properties required for OAuth 2.0 authentication.
         */
        oAuth2Properties?: pulumi.Input<inputs.appflow.ConnectorProfileOAuth2PropertiesArgs>;
        /**
         * A map of properties that are required to create a profile for the custom connector.
         */
        profileProperties?: pulumi.Input<{
            [key: string]: pulumi.Input<string>;
        }>;
    }
    interface ConnectorProfileDatadogConnectorProfileCredentialsArgs {
        /**
         * A unique alphanumeric identiﬁer used to authenticate a user, developer, or calling program to your API.
         */
        apiKey: pulumi.Input<string>;
        /**
         * Application keys, in conjunction with your API key, give you full access to Datadog’s programmatic API. Application keys are associated with the user account that created them. The application key is used to log all requests made to the API.
         */
        applicationKey: pulumi.Input<string>;
    }
    interface ConnectorProfileDatadogConnectorProfilePropertiesArgs {
        /**
         * The location of the Datadog resource
         */
        instanceUrl: pulumi.Input<string>;
    }
    interface ConnectorProfileDynatraceConnectorProfileCredentialsArgs {
        /**
         * The API tokens used by Dynatrace API to authenticate various API calls.
         */
        apiToken: pulumi.Input<string>;
    }
    interface ConnectorProfileDynatraceConnectorProfilePropertiesArgs {
        /**
         * The location of the Dynatrace resource
         */
        instanceUrl: pulumi.Input<string>;
    }
    interface ConnectorProfileGoogleAnalyticsConnectorProfileCredentialsArgs {
        /**
         * The credentials used to access protected resources.
         */
        accessToken?: pulumi.Input<string>;
        /**
         * The identiﬁer for the desired client.
         */
        clientId: pulumi.Input<string>;
        /**
         * The client secret used by the oauth client to authenticate to the authorization server.
         */
        clientSecret: pulumi.Input<string>;
        /**
         * The oauth needed to request security tokens from the connector endpoint.
         */
        connectorOAuthRequest?: pulumi.Input<inputs.appflow.ConnectorProfileConnectorOAuthRequestArgs>;
        /**
         * The credentials used to acquire new access tokens.
         */
        refreshToken?: pulumi.Input<string>;
    }
    interface ConnectorProfileInforNexusConnectorProfileCredentialsArgs {
        /**
         * The Access Key portion of the credentials.
         */
        accessKeyId: pulumi.Input<string>;
        /**
         * The encryption keys used to encrypt data.
         */
        datakey: pulumi.Input<string>;
        /**
         * The secret key used to sign requests.
         */
        secretAccessKey: pulumi.Input<string>;
        /**
         * The identiﬁer for the user.
         */
        userId: pulumi.Input<string>;
    }
    interface ConnectorProfileInforNexusConnectorProfilePropertiesArgs {
        /**
         * The location of the InforNexus resource
         */
        instanceUrl: pulumi.Input<string>;
    }
    interface ConnectorProfileMarketoConnectorProfileCredentialsArgs {
        /**
         * The credentials used to access protected resources.
         */
        accessToken?: pulumi.Input<string>;
        /**
         * The identiﬁer for the desired client.
         */
        clientId: pulumi.Input<string>;
        /**
         * The client secret used by the oauth client to authenticate to the authorization server.
         */
        clientSecret: pulumi.Input<string>;
        /**
         * The oauth needed to request security tokens from the connector endpoint.
         */
        connectorOAuthRequest?: pulumi.Input<inputs.appflow.ConnectorProfileConnectorOAuthRequestArgs>;
    }
    interface ConnectorProfileMarketoConnectorProfilePropertiesArgs {
        /**
         * The location of the Marketo resource
         */
        instanceUrl: pulumi.Input<string>;
    }
    interface ConnectorProfileOAuth2CredentialsArgs {
        /**
         * The access token used to access the connector on your behalf.
         */
        accessToken?: pulumi.Input<string>;
        /**
         * The identifier for the desired client.
         */
        clientId?: pulumi.Input<string>;
        /**
         * The client secret used by the OAuth client to authenticate to the authorization server.
         */
        clientSecret?: pulumi.Input<string>;
        oAuthRequest?: pulumi.Input<inputs.appflow.ConnectorProfileConnectorOAuthRequestArgs>;
        /**
         * The refresh token used to refresh an expired access token.
         */
        refreshToken?: pulumi.Input<string>;
    }
    interface ConnectorProfileOAuth2PropertiesArgs {
        /**
         * The OAuth 2.0 grant type used by connector for OAuth 2.0 authentication.
         */
        oAuth2GrantType?: pulumi.Input<enums.appflow.ConnectorProfileOAuth2GrantType>;
        /**
         * The token URL required for OAuth 2.0 authentication.
         */
        tokenUrl?: pulumi.Input<string>;
        /**
         * Associates your token URL with a map of properties that you define. Use this parameter to provide any additional details that the connector requires to authenticate your request.
         */
        tokenUrlCustomProperties?: pulumi.Input<{
            [key: string]: pulumi.Input<string>;
        }>;
    }
    interface ConnectorProfileOAuthPropertiesArgs {
        /**
         * The authorization code url required to redirect to SAP Login Page to fetch authorization code for OAuth type authentication.
         */
        authCodeUrl?: pulumi.Input<string>;
        /**
         * The OAuth scopes required for OAuth type authentication.
         */
        oAuthScopes?: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * The token url required to fetch access/refresh tokens using authorization code and also to refresh expired access token using refresh token.
         */
        tokenUrl?: pulumi.Input<string>;
    }
    interface ConnectorProfilePardotConnectorProfileCredentialsArgs {
        /**
         * The credentials used to access protected resources.
         */
        accessToken?: pulumi.Input<string>;
        /**
         * The client credentials to fetch access token and refresh token.
         */
        clientCredentialsArn?: pulumi.Input<string>;
        /**
         * The oauth needed to request security tokens from the connector endpoint.
         */
        connectorOAuthRequest?: pulumi.Input<inputs.appflow.ConnectorProfileConnectorOAuthRequestArgs>;
        /**
         * The credentials used to acquire new access tokens.
         */
        refreshToken?: pulumi.Input<string>;
    }
    interface ConnectorProfilePardotConnectorProfilePropertiesArgs {
        /**
         * The Business unit id of Salesforce Pardot instance to be connected
         */
        businessUnitId: pulumi.Input<string>;
        /**
         * The location of the Salesforce Pardot resource
         */
        instanceUrl?: pulumi.Input<string>;
        /**
         * Indicates whether the connector profile applies to a demo or production environment
         */
        isSandboxEnvironment?: pulumi.Input<boolean>;
    }
    /**
     * Connector specific properties needed to create connector profile - currently not needed for Amplitude, Trendmicro, Googleanalytics and Singular
     */
    interface ConnectorProfilePropertiesArgs {
        /**
         * The properties required by the custom connector.
         */
        customConnector?: pulumi.Input<inputs.appflow.ConnectorProfileCustomConnectorProfilePropertiesArgs>;
        /**
         * The connector-specific properties required by Datadog.
         */
        datadog?: pulumi.Input<inputs.appflow.ConnectorProfileDatadogConnectorProfilePropertiesArgs>;
        /**
         * The connector-specific properties required by Dynatrace.
         */
        dynatrace?: pulumi.Input<inputs.appflow.ConnectorProfileDynatraceConnectorProfilePropertiesArgs>;
        /**
         * The connector-specific properties required by Infor Nexus.
         */
        inforNexus?: pulumi.Input<inputs.appflow.ConnectorProfileInforNexusConnectorProfilePropertiesArgs>;
        /**
         * The connector-specific properties required by Marketo.
         */
        marketo?: pulumi.Input<inputs.appflow.ConnectorProfileMarketoConnectorProfilePropertiesArgs>;
        /**
         * The connector-specific properties required by Salesforce Pardot.
         */
        pardot?: pulumi.Input<inputs.appflow.ConnectorProfilePardotConnectorProfilePropertiesArgs>;
        /**
         * The connector-specific properties required by Amazon Redshift.
         */
        redshift?: pulumi.Input<inputs.appflow.ConnectorProfileRedshiftConnectorProfilePropertiesArgs>;
        /**
         * The connector-specific properties required by Salesforce.
         */
        salesforce?: pulumi.Input<inputs.appflow.ConnectorProfileSalesforceConnectorProfilePropertiesArgs>;
        /**
         * The connector-specific profile properties required when using SAPOData.
         */
        sapoData?: pulumi.Input<inputs.appflow.ConnectorProfileSapoDataConnectorProfilePropertiesArgs>;
        /**
         * The connector-specific properties required by serviceNow.
         */
        serviceNow?: pulumi.Input<inputs.appflow.ConnectorProfileServiceNowConnectorProfilePropertiesArgs>;
        /**
         * The connector-specific properties required by Slack.
         */
        slack?: pulumi.Input<inputs.appflow.ConnectorProfileSlackConnectorProfilePropertiesArgs>;
        /**
         * The connector-specific properties required by Snowflake.
         */
        snowflake?: pulumi.Input<inputs.appflow.ConnectorProfileSnowflakeConnectorProfilePropertiesArgs>;
        /**
         * The connector-specific properties required by Veeva.
         */
        veeva?: pulumi.Input<inputs.appflow.ConnectorProfileVeevaConnectorProfilePropertiesArgs>;
        /**
         * The connector-specific properties required by Zendesk.
         */
        zendesk?: pulumi.Input<inputs.appflow.ConnectorProfileZendeskConnectorProfilePropertiesArgs>;
    }
    interface ConnectorProfileRedshiftConnectorProfileCredentialsArgs {
        /**
         * The password that corresponds to the username.
         */
        password?: pulumi.Input<string>;
        /**
         * The name of the user.
         */
        username?: pulumi.Input<string>;
    }
    interface ConnectorProfileRedshiftConnectorProfilePropertiesArgs {
        /**
         * The name of the Amazon S3 bucket associated with Redshift.
         */
        bucketName: pulumi.Input<string>;
        /**
         * The object key for the destination bucket in which Amazon AppFlow will place the ﬁles.
         */
        bucketPrefix?: pulumi.Input<string>;
        /**
         * The unique identifier of the Amazon Redshift cluster.
         */
        clusterIdentifier?: pulumi.Input<string>;
        /**
         * The Amazon Resource Name (ARN) of the IAM role that grants Amazon AppFlow access to the data through the Amazon Redshift Data API.
         */
        dataApiRoleArn?: pulumi.Input<string>;
        /**
         * The name of the Amazon Redshift database that will store the transferred data.
         */
        databaseName?: pulumi.Input<string>;
        /**
         * The JDBC URL of the Amazon Redshift cluster.
         */
        databaseUrl?: pulumi.Input<string>;
        /**
         * If Amazon AppFlow will connect to Amazon Redshift Serverless or Amazon Redshift cluster.
         */
        isRedshiftServerless?: pulumi.Input<boolean>;
        /**
         * The Amazon Resource Name (ARN) of the IAM role.
         */
        roleArn: pulumi.Input<string>;
        /**
         * The name of the Amazon Redshift serverless workgroup
         */
        workgroupName?: pulumi.Input<string>;
    }
    interface ConnectorProfileSalesforceConnectorProfileCredentialsArgs {
        /**
         * The credentials used to access protected resources.
         */
        accessToken?: pulumi.Input<string>;
        /**
         * The client credentials to fetch access token and refresh token.
         */
        clientCredentialsArn?: pulumi.Input<string>;
        /**
         * The oauth needed to request security tokens from the connector endpoint.
         */
        connectorOAuthRequest?: pulumi.Input<inputs.appflow.ConnectorProfileConnectorOAuthRequestArgs>;
        /**
         * The credentials used to access your Salesforce records
         */
        jwtToken?: pulumi.Input<string>;
        /**
         * The grant types to fetch an access token
         */
        oAuth2GrantType?: pulumi.Input<enums.appflow.ConnectorProfileOAuth2GrantType>;
        /**
         * The credentials used to acquire new access tokens.
         */
        refreshToken?: pulumi.Input<string>;
    }
    interface ConnectorProfileSalesforceConnectorProfilePropertiesArgs {
        /**
         * The location of the Salesforce resource
         */
        instanceUrl?: pulumi.Input<string>;
        /**
         * Indicates whether the connector profile applies to a sandbox or production environment
         */
        isSandboxEnvironment?: pulumi.Input<boolean>;
        /**
         * Indicates whether to make Metadata And Authorization calls over Pivate Network
         */
        usePrivateLinkForMetadataAndAuthorization?: pulumi.Input<boolean>;
    }
    interface ConnectorProfileSapoDataConnectorProfileCredentialsArgs {
        /**
         * The SAPOData basic authentication credentials.
         */
        basicAuthCredentials?: pulumi.Input<inputs.appflow.ConnectorProfileBasicAuthCredentialsArgs>;
        /**
         * The SAPOData OAuth type authentication credentials.
         */
        oAuthCredentials?: pulumi.Input<inputs.appflow.ConnectorProfileSapoDataConnectorProfileCredentialsOAuthCredentialsPropertiesArgs>;
    }
    /**
     * The SAPOData OAuth type authentication credentials.
     */
    interface ConnectorProfileSapoDataConnectorProfileCredentialsOAuthCredentialsPropertiesArgs {
        accessToken?: pulumi.Input<string>;
        clientId?: pulumi.Input<string>;
        clientSecret?: pulumi.Input<string>;
        connectorOAuthRequest?: pulumi.Input<inputs.appflow.ConnectorProfileConnectorOAuthRequestArgs>;
        refreshToken?: pulumi.Input<string>;
    }
    interface ConnectorProfileSapoDataConnectorProfilePropertiesArgs {
        /**
         * The location of the SAPOData resource.
         */
        applicationHostUrl?: pulumi.Input<string>;
        /**
         * The application path to catalog service.
         */
        applicationServicePath?: pulumi.Input<string>;
        /**
         * The client number for the client creating the connection.
         */
        clientNumber?: pulumi.Input<string>;
        /**
         * If you set this parameter to true, Amazon AppFlow bypasses the single sign-on (SSO) settings in your SAP account when it accesses your SAP OData instance.
         */
        disableSso?: pulumi.Input<boolean>;
        /**
         * The logon language of SAPOData instance.
         */
        logonLanguage?: pulumi.Input<string>;
        /**
         * The SAPOData OAuth properties required for OAuth type authentication.
         */
        oAuthProperties?: pulumi.Input<inputs.appflow.ConnectorProfileOAuthPropertiesArgs>;
        /**
         * The port number of the SAPOData instance.
         */
        portNumber?: pulumi.Input<number>;
        /**
         * The SAPOData Private Link service name to be used for private data transfers.
         */
        privateLinkServiceName?: pulumi.Input<string>;
    }
    interface ConnectorProfileServiceNowConnectorProfileCredentialsArgs {
        /**
         * The OAuth 2.0 credentials required to authenticate the user.
         */
        oAuth2Credentials?: pulumi.Input<inputs.appflow.ConnectorProfileOAuth2CredentialsArgs>;
        /**
         * The password that corresponds to the username.
         */
        password?: pulumi.Input<string>;
        /**
         * The name of the user.
         */
        username?: pulumi.Input<string>;
    }
    interface ConnectorProfileServiceNowConnectorProfilePropertiesArgs {
        /**
         * The location of the ServiceNow resource
         */
        instanceUrl: pulumi.Input<string>;
    }
    interface ConnectorProfileSingularConnectorProfileCredentialsArgs {
        /**
         * A unique alphanumeric identiﬁer used to authenticate a user, developer, or calling program to your API.
         */
        apiKey: pulumi.Input<string>;
    }
    interface ConnectorProfileSlackConnectorProfileCredentialsArgs {
        /**
         * The credentials used to access protected resources.
         */
        accessToken?: pulumi.Input<string>;
        /**
         * The identiﬁer for the desired client.
         */
        clientId: pulumi.Input<string>;
        /**
         * The client secret used by the oauth client to authenticate to the authorization server.
         */
        clientSecret: pulumi.Input<string>;
        /**
         * The oauth needed to request security tokens from the connector endpoint.
         */
        connectorOAuthRequest?: pulumi.Input<inputs.appflow.ConnectorProfileConnectorOAuthRequestArgs>;
    }
    interface ConnectorProfileSlackConnectorProfilePropertiesArgs {
        /**
         * The location of the Slack resource
         */
        instanceUrl: pulumi.Input<string>;
    }
    interface ConnectorProfileSnowflakeConnectorProfileCredentialsArgs {
        /**
         * The password that corresponds to the username.
         */
        password: pulumi.Input<string>;
        /**
         * The name of the user.
         */
        username: pulumi.Input<string>;
    }
    interface ConnectorProfileSnowflakeConnectorProfilePropertiesArgs {
        /**
         * The name of the account.
         */
        accountName?: pulumi.Input<string>;
        /**
         * The name of the Amazon S3 bucket associated with Snowﬂake.
         */
        bucketName: pulumi.Input<string>;
        /**
         * The bucket prefix that refers to the Amazon S3 bucket associated with Snowﬂake.
         */
        bucketPrefix?: pulumi.Input<string>;
        /**
         * The Snowﬂake Private Link service name to be used for private data transfers.
         */
        privateLinkServiceName?: pulumi.Input<string>;
        /**
         * The region of the Snowﬂake account.
         */
        region?: pulumi.Input<string>;
        /**
         * The name of the Amazon S3 stage that was created while setting up an Amazon S3 stage in the
         * Snowﬂake account. This is written in the following format: < Database>< Schema><Stage Name>.
         */
        stage: pulumi.Input<string>;
        /**
         * The name of the Snowﬂake warehouse.
         */
        warehouse: pulumi.Input<string>;
    }
    interface ConnectorProfileTrendmicroConnectorProfileCredentialsArgs {
        /**
         * The Secret Access Key portion of the credentials.
         */
        apiSecretKey: pulumi.Input<string>;
    }
    interface ConnectorProfileVeevaConnectorProfileCredentialsArgs {
        /**
         * The password that corresponds to the username.
         */
        password: pulumi.Input<string>;
        /**
         * The name of the user.
         */
        username: pulumi.Input<string>;
    }
    interface ConnectorProfileVeevaConnectorProfilePropertiesArgs {
        /**
         * The location of the Veeva resource
         */
        instanceUrl: pulumi.Input<string>;
    }
    interface ConnectorProfileZendeskConnectorProfileCredentialsArgs {
        /**
         * The credentials used to access protected resources.
         */
        accessToken?: pulumi.Input<string>;
        /**
         * The identiﬁer for the desired client.
         */
        clientId: pulumi.Input<string>;
        /**
         * The client secret used by the oauth client to authenticate to the authorization server.
         */
        clientSecret: pulumi.Input<string>;
        /**
         * The oauth needed to request security tokens from the connector endpoint.
         */
        connectorOAuthRequest?: pulumi.Input<inputs.appflow.ConnectorProfileConnectorOAuthRequestArgs>;
    }
    interface ConnectorProfileZendeskConnectorProfilePropertiesArgs {
        /**
         * The location of the Zendesk resource
         */
        instanceUrl: pulumi.Input<string>;
    }
    /**
     * Contains information about the configuration of the connector being registered.
     */
    interface ConnectorProvisioningConfigArgs {
        /**
         * Contains information about the configuration of the lambda which is being registered as the connector.
         */
        lambda?: pulumi.Input<inputs.appflow.ConnectorLambdaConnectorProvisioningConfigArgs>;
    }
    interface FlowAggregationConfigArgs {
        /**
         * Specifies whether Amazon AppFlow aggregates the flow records into a single file, or leave them unaggregated.
         */
        aggregationType?: pulumi.Input<enums.appflow.FlowAggregationType>;
        /**
         * The desired file size, in MB, for each output file that Amazon AppFlow writes to the flow destination. For each file, Amazon AppFlow attempts to achieve the size that you specify. The actual file sizes might differ from this target based on the number and size of the records that each file contains.
         */
        targetFileSize?: pulumi.Input<number>;
    }
    interface FlowAmplitudeSourcePropertiesArgs {
        /**
         * The object specified in the Amplitude flow source.
         */
        object: pulumi.Input<string>;
    }
    /**
     * Operation to be performed on provided source fields
     */
    interface FlowConnectorOperatorArgs {
        /**
         * The operation to be performed on the provided Amplitude source fields.
         */
        amplitude?: pulumi.Input<enums.appflow.FlowAmplitudeConnectorOperator>;
        /**
         * Operators supported by the custom connector.
         */
        customConnector?: pulumi.Input<enums.appflow.FlowOperator>;
        /**
         * The operation to be performed on the provided Datadog source fields.
         */
        datadog?: pulumi.Input<enums.appflow.FlowDatadogConnectorOperator>;
        /**
         * The operation to be performed on the provided Dynatrace source fields.
         */
        dynatrace?: pulumi.Input<enums.appflow.FlowDynatraceConnectorOperator>;
        /**
         * The operation to be performed on the provided Google Analytics source fields.
         */
        googleAnalytics?: pulumi.Input<enums.appflow.FlowGoogleAnalyticsConnectorOperator>;
        /**
         * The operation to be performed on the provided Infor Nexus source fields.
         */
        inforNexus?: pulumi.Input<enums.appflow.FlowInforNexusConnectorOperator>;
        /**
         * The operation to be performed on the provided Marketo source fields.
         */
        marketo?: pulumi.Input<enums.appflow.FlowMarketoConnectorOperator>;
        /**
         * The operation to be performed on the provided Salesforce Pardot source fields.
         */
        pardot?: pulumi.Input<enums.appflow.FlowPardotConnectorOperator>;
        /**
         * The operation to be performed on the provided Amazon S3 source fields.
         */
        s3?: pulumi.Input<enums.appflow.FlowS3ConnectorOperator>;
        /**
         * The operation to be performed on the provided Salesforce source fields.
         */
        salesforce?: pulumi.Input<enums.appflow.FlowSalesforceConnectorOperator>;
        /**
         * The operation to be performed on the provided SAPOData source fields.
         */
        sapoData?: pulumi.Input<enums.appflow.FlowSapoDataConnectorOperator>;
        /**
         * The operation to be performed on the provided ServiceNow source fields.
         */
        serviceNow?: pulumi.Input<enums.appflow.FlowServiceNowConnectorOperator>;
        /**
         * The operation to be performed on the provided Singular source fields.
         */
        singular?: pulumi.Input<enums.appflow.FlowSingularConnectorOperator>;
        /**
         * The operation to be performed on the provided Slack source fields.
         */
        slack?: pulumi.Input<enums.appflow.FlowSlackConnectorOperator>;
        /**
         * The operation to be performed on the provided Trend Micro source fields.
         */
        trendmicro?: pulumi.Input<enums.appflow.FlowTrendmicroConnectorOperator>;
        /**
         * The operation to be performed on the provided Veeva source fields.
         */
        veeva?: pulumi.Input<enums.appflow.FlowVeevaConnectorOperator>;
        /**
         * The operation to be performed on the provided Zendesk source fields.
         */
        zendesk?: pulumi.Input<enums.appflow.FlowZendeskConnectorOperator>;
    }
    interface FlowCustomConnectorDestinationPropertiesArgs {
        /**
         * The custom properties that are specific to the connector when it's used as a destination in the flow.
         */
        customProperties?: pulumi.Input<{
            [key: string]: pulumi.Input<string>;
        }>;
        /**
         * The entity specified in the custom connector as a destination in the flow.
         */
        entityName: pulumi.Input<string>;
        /**
         * The settings that determine how Amazon AppFlow handles an error when placing data in the custom connector as destination.
         */
        errorHandlingConfig?: pulumi.Input<inputs.appflow.FlowErrorHandlingConfigArgs>;
        /**
         * List of fields used as ID when performing a write operation.
         */
        idFieldNames?: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * Specifies the type of write operation to be performed in the custom connector when it's used as destination.
         */
        writeOperationType?: pulumi.Input<enums.appflow.FlowWriteOperationType>;
    }
    interface FlowCustomConnectorSourcePropertiesArgs {
        /**
         * Custom properties that are required to use the custom connector as a source.
         */
        customProperties?: pulumi.Input<{
            [key: string]: pulumi.Input<string>;
        }>;
        /**
         * The API of the connector application that Amazon AppFlow uses to transfer your data.
         */
        dataTransferApi?: pulumi.Input<inputs.appflow.FlowCustomConnectorSourcePropertiesDataTransferApiPropertiesArgs>;
        /**
         * The entity specified in the custom connector as a source in the flow.
         */
        entityName: pulumi.Input<string>;
    }
    /**
     * The API of the connector application that Amazon AppFlow uses to transfer your data.
     */
    interface FlowCustomConnectorSourcePropertiesDataTransferApiPropertiesArgs {
        name: pulumi.Input<string>;
        type: pulumi.Input<enums.appflow.FlowCustomConnectorSourcePropertiesDataTransferApiPropertiesType>;
    }
    interface FlowDatadogSourcePropertiesArgs {
        /**
         * The object specified in the Datadog flow source.
         */
        object: pulumi.Input<string>;
    }
    /**
     * Destination connector details
     */
    interface FlowDestinationConnectorPropertiesArgs {
        /**
         * The properties that are required to query the custom Connector.
         */
        customConnector?: pulumi.Input<inputs.appflow.FlowCustomConnectorDestinationPropertiesArgs>;
        /**
         * The properties required to query Amazon EventBridge.
         */
        eventBridge?: pulumi.Input<inputs.appflow.FlowEventBridgeDestinationPropertiesArgs>;
        /**
         * The properties required to query Amazon Lookout for Metrics.
         */
        lookoutMetrics?: pulumi.Input<inputs.appflow.FlowLookoutMetricsDestinationPropertiesArgs>;
        /**
         * The properties required to query Marketo.
         */
        marketo?: pulumi.Input<inputs.appflow.FlowMarketoDestinationPropertiesArgs>;
        /**
         * The properties required to query Amazon Redshift.
         */
        redshift?: pulumi.Input<inputs.appflow.FlowRedshiftDestinationPropertiesArgs>;
        /**
         * The properties required to query Amazon S3.
         */
        s3?: pulumi.Input<inputs.appflow.FlowS3DestinationPropertiesArgs>;
        /**
         * The properties required to query Salesforce.
         */
        salesforce?: pulumi.Input<inputs.appflow.FlowSalesforceDestinationPropertiesArgs>;
        /**
         * The properties required to query SAPOData.
         */
        sapoData?: pulumi.Input<inputs.appflow.FlowSapoDataDestinationPropertiesArgs>;
        /**
         * The properties required to query Snowflake.
         */
        snowflake?: pulumi.Input<inputs.appflow.FlowSnowflakeDestinationPropertiesArgs>;
        /**
         * The properties required to query Upsolver.
         */
        upsolver?: pulumi.Input<inputs.appflow.FlowUpsolverDestinationPropertiesArgs>;
        /**
         * The properties required to query Zendesk.
         */
        zendesk?: pulumi.Input<inputs.appflow.FlowZendeskDestinationPropertiesArgs>;
    }
    /**
     * Configurations of destination connector.
     */
    interface FlowDestinationFlowConfigArgs {
        /**
         * The API version that the destination connector uses.
         */
        apiVersion?: pulumi.Input<string>;
        /**
         * Name of destination connector profile
         */
        connectorProfileName?: pulumi.Input<string>;
        /**
         * Destination connector type
         */
        connectorType: pulumi.Input<enums.appflow.FlowConnectorType>;
        /**
         * Destination connector details
         */
        destinationConnectorProperties: pulumi.Input<inputs.appflow.FlowDestinationConnectorPropertiesArgs>;
    }
    interface FlowDynatraceSourcePropertiesArgs {
        /**
         * The object specified in the Dynatrace flow source.
         */
        object: pulumi.Input<string>;
    }
    interface FlowErrorHandlingConfigArgs {
        /**
         * Specifies the name of the Amazon S3 bucket.
         */
        bucketName?: pulumi.Input<string>;
        /**
         * Specifies the Amazon S3 bucket prefix.
         */
        bucketPrefix?: pulumi.Input<string>;
        /**
         * Specifies if the flow should fail after the first instance of a failure when attempting to place data in the destination.
         */
        failOnFirstError?: pulumi.Input<boolean>;
    }
    interface FlowEventBridgeDestinationPropertiesArgs {
        /**
         * The object specified in the Amplitude flow source.
         */
        errorHandlingConfig?: pulumi.Input<inputs.appflow.FlowErrorHandlingConfigArgs>;
        /**
         * The object specified in the Amazon EventBridge flow destination.
         */
        object: pulumi.Input<string>;
    }
    /**
     * Trigger settings of the flow.
     */
    interface FlowGlueDataCatalogArgs {
        /**
         * A string containing the value for the tag
         */
        databaseName: pulumi.Input<string>;
        /**
         * A string containing the value for the tag
         */
        roleArn: pulumi.Input<string>;
        /**
         * A string containing the value for the tag
         */
        tablePrefix: pulumi.Input<string>;
    }
    interface FlowGoogleAnalyticsSourcePropertiesArgs {
        /**
         * The object specified in the Google Analytics flow source.
         */
        object: pulumi.Input<string>;
    }
    /**
     * Configuration for scheduled incremental data pull
     */
    interface FlowIncrementalPullConfigArgs {
        /**
         * A field that specifies the date time or timestamp field as the criteria to use when importing incremental records from the source.
         */
        datetimeTypeFieldName?: pulumi.Input<string>;
    }
    interface FlowInforNexusSourcePropertiesArgs {
        /**
         * The object specified in the Infor Nexus flow source.
         */
        object: pulumi.Input<string>;
    }
    interface FlowLookoutMetricsDestinationPropertiesArgs {
        /**
         * The object specified in the Amazon Lookout for Metrics flow destination.
         */
        object?: pulumi.Input<string>;
    }
    interface FlowMarketoDestinationPropertiesArgs {
        /**
         * The settings that determine how Amazon AppFlow handles an error when placing data in the destination. For example, this setting would determine if the flow should fail after one insertion error, or continue and attempt to insert every record regardless of the initial failure. `ErrorHandlingConfig` is a part of the destination connector details.
         */
        errorHandlingConfig?: pulumi.Input<inputs.appflow.FlowErrorHandlingConfigArgs>;
        /**
         * The object specified in the Marketo flow destination.
         */
        object: pulumi.Input<string>;
    }
    interface FlowMarketoSourcePropertiesArgs {
        /**
         * The object specified in the Marketo flow source.
         */
        object: pulumi.Input<string>;
    }
    /**
     * Configurations of metadata catalog of the flow.
     */
    interface FlowMetadataCatalogConfigArgs {
        /**
         * Configurations of glue data catalog of the flow.
         */
        glueDataCatalog?: pulumi.Input<inputs.appflow.FlowGlueDataCatalogArgs>;
    }
    interface FlowPardotSourcePropertiesArgs {
        /**
         * The object specified in the Salesforce Pardot flow source.
         */
        object: pulumi.Input<string>;
    }
    interface FlowPrefixConfigArgs {
        /**
         * Specifies whether the destination file path includes either or both of the following elements:
         *
         * - **EXECUTION_ID** - The ID that Amazon AppFlow assigns to the flow run.
         * - **SCHEMA_VERSION** - The version number of your data schema. Amazon AppFlow assigns this version number. The version number increases by one when you change any of the following settings in your flow configuration:
         *
         * - Source-to-destination field mappings
         * - Field data types
         * - Partition keys
         */
        pathPrefixHierarchy?: pulumi.Input<pulumi.Input<enums.appflow.FlowPathPrefix>[]>;
        /**
         * Determines the level of granularity for the date and time that's included in the prefix.
         */
        prefixFormat?: pulumi.Input<enums.appflow.FlowPrefixFormat>;
        /**
         * Determines the format of the prefix, and whether it applies to the file name, file path, or both.
         */
        prefixType?: pulumi.Input<enums.appflow.FlowPrefixType>;
    }
    interface FlowRedshiftDestinationPropertiesArgs {
        /**
         * The object key for the bucket in which Amazon AppFlow places the destination files.
         */
        bucketPrefix?: pulumi.Input<string>;
        /**
         * The settings that determine how Amazon AppFlow handles an error when placing data in the Amazon Redshift destination. For example, this setting would determine if the flow should fail after one insertion error, or continue and attempt to insert every record regardless of the initial failure. `ErrorHandlingConfig` is a part of the destination connector details.
         */
        errorHandlingConfig?: pulumi.Input<inputs.appflow.FlowErrorHandlingConfigArgs>;
        /**
         * The intermediate bucket that Amazon AppFlow uses when moving data into Amazon Redshift.
         */
        intermediateBucketName: pulumi.Input<string>;
        /**
         * The object specified in the Amazon Redshift flow destination.
         */
        object: pulumi.Input<string>;
    }
    interface FlowS3DestinationPropertiesArgs {
        /**
         * The Amazon S3 bucket name in which Amazon AppFlow places the transferred data.
         */
        bucketName: pulumi.Input<string>;
        /**
         * The object key for the destination bucket in which Amazon AppFlow places the files.
         */
        bucketPrefix?: pulumi.Input<string>;
        /**
         * The configuration that determines how Amazon AppFlow should format the flow output data when Amazon S3 is used as the destination.
         */
        s3OutputFormatConfig?: pulumi.Input<inputs.appflow.FlowS3OutputFormatConfigArgs>;
    }
    interface FlowS3InputFormatConfigArgs {
        /**
         * The file type that Amazon AppFlow gets from your Amazon S3 bucket.
         */
        s3InputFileType?: pulumi.Input<enums.appflow.FlowS3InputFormatConfigS3InputFileType>;
    }
    interface FlowS3OutputFormatConfigArgs {
        /**
         * The aggregation settings that you can use to customize the output format of your flow data.
         */
        aggregationConfig?: pulumi.Input<inputs.appflow.FlowAggregationConfigArgs>;
        /**
         * Indicates the file type that Amazon AppFlow places in the Amazon S3 bucket.
         */
        fileType?: pulumi.Input<enums.appflow.FlowFileType>;
        /**
         * Determines the prefix that Amazon AppFlow applies to the folder name in the Amazon S3 bucket. You can name folders according to the flow frequency and date.
         */
        prefixConfig?: pulumi.Input<inputs.appflow.FlowPrefixConfigArgs>;
        /**
         * If your file output format is Parquet, use this parameter to set whether Amazon AppFlow preserves the data types in your source data when it writes the output to Amazon S3.
         *
         * - `true` : Amazon AppFlow preserves the data types when it writes to Amazon S3. For example, an integer or `1` in your source data is still an integer in your output.
         * - `false` : Amazon AppFlow converts all of the source data into strings when it writes to Amazon S3. For example, an integer of `1` in your source data becomes the string `"1"` in the output.
         */
        preserveSourceDataTyping?: pulumi.Input<boolean>;
    }
    interface FlowS3SourcePropertiesArgs {
        /**
         * The Amazon S3 bucket name where the source files are stored.
         */
        bucketName: pulumi.Input<string>;
        /**
         * The object key for the Amazon S3 bucket in which the source files are stored.
         */
        bucketPrefix: pulumi.Input<string>;
        /**
         * When you use Amazon S3 as the source, the configuration format that you provide the flow input data.
         */
        s3InputFormatConfig?: pulumi.Input<inputs.appflow.FlowS3InputFormatConfigArgs>;
    }
    interface FlowSalesforceDestinationPropertiesArgs {
        /**
         * Specifies which Salesforce API is used by Amazon AppFlow when your flow transfers data to Salesforce.
         *
         * - **AUTOMATIC** - The default. Amazon AppFlow selects which API to use based on the number of records that your flow transfers to Salesforce. If your flow transfers fewer than 1,000 records, Amazon AppFlow uses Salesforce REST API. If your flow transfers 1,000 records or more, Amazon AppFlow uses Salesforce Bulk API 2.0.
         *
         * Each of these Salesforce APIs structures data differently. If Amazon AppFlow selects the API automatically, be aware that, for recurring flows, the data output might vary from one flow run to the next. For example, if a flow runs daily, it might use REST API on one day to transfer 900 records, and it might use Bulk API 2.0 on the next day to transfer 1,100 records. For each of these flow runs, the respective Salesforce API formats the data differently. Some of the differences include how dates are formatted and null values are represented. Also, Bulk API 2.0 doesn't transfer Salesforce compound fields.
         *
         * By choosing this option, you optimize flow performance for both small and large data transfers, but the tradeoff is inconsistent formatting in the output.
         * - **BULKV2** - Amazon AppFlow uses only Salesforce Bulk API 2.0. This API runs asynchronous data transfers, and it's optimal for large sets of data. By choosing this option, you ensure that your flow writes consistent output, but you optimize performance only for large data transfers.
         *
         * Note that Bulk API 2.0 does not transfer Salesforce compound fields.
         * - **REST_SYNC** - Amazon AppFlow uses only Salesforce REST API. By choosing this option, you ensure that your flow writes consistent output, but you decrease performance for large data transfers that are better suited for Bulk API 2.0. In some cases, if your flow attempts to transfer a vary large set of data, it might fail with a timed out error.
         */
        dataTransferApi?: pulumi.Input<enums.appflow.FlowDataTransferApi>;
        /**
         * The settings that determine how Amazon AppFlow handles an error when placing data in the Salesforce destination. For example, this setting would determine if the flow should fail after one insertion error, or continue and attempt to insert every record regardless of the initial failure. `ErrorHandlingConfig` is a part of the destination connector details.
         */
        errorHandlingConfig?: pulumi.Input<inputs.appflow.FlowErrorHandlingConfigArgs>;
        /**
         * List of fields used as ID when performing a write operation.
         */
        idFieldNames?: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * The object specified in the Salesforce flow destination.
         */
        object: pulumi.Input<string>;
        /**
         * This specifies the type of write operation to be performed in Salesforce. When the value is `UPSERT` , then `idFieldNames` is required.
         */
        writeOperationType?: pulumi.Input<enums.appflow.FlowWriteOperationType>;
    }
    interface FlowSalesforceSourcePropertiesArgs {
        /**
         * Specifies which Salesforce API is used by Amazon AppFlow when your flow transfers data from Salesforce.
         *
         * - **AUTOMATIC** - The default. Amazon AppFlow selects which API to use based on the number of records that your flow transfers from Salesforce. If your flow transfers fewer than 1,000,000 records, Amazon AppFlow uses Salesforce REST API. If your flow transfers 1,000,000 records or more, Amazon AppFlow uses Salesforce Bulk API 2.0.
         *
         * Each of these Salesforce APIs structures data differently. If Amazon AppFlow selects the API automatically, be aware that, for recurring flows, the data output might vary from one flow run to the next. For example, if a flow runs daily, it might use REST API on one day to transfer 900,000 records, and it might use Bulk API 2.0 on the next day to transfer 1,100,000 records. For each of these flow runs, the respective Salesforce API formats the data differently. Some of the differences include how dates are formatted and null values are represented. Also, Bulk API 2.0 doesn't transfer Salesforce compound fields.
         *
         * By choosing this option, you optimize flow performance for both small and large data transfers, but the tradeoff is inconsistent formatting in the output.
         * - **BULKV2** - Amazon AppFlow uses only Salesforce Bulk API 2.0. This API runs asynchronous data transfers, and it's optimal for large sets of data. By choosing this option, you ensure that your flow writes consistent output, but you optimize performance only for large data transfers.
         *
         * Note that Bulk API 2.0 does not transfer Salesforce compound fields.
         * - **REST_SYNC** - Amazon AppFlow uses only Salesforce REST API. By choosing this option, you ensure that your flow writes consistent output, but you decrease performance for large data transfers that are better suited for Bulk API 2.0. In some cases, if your flow attempts to transfer a vary large set of data, it might fail wituh a timed out error.
         */
        dataTransferApi?: pulumi.Input<enums.appflow.FlowDataTransferApi>;
        /**
         * The flag that enables dynamic fetching of new (recently added) fields in the Salesforce objects while running a flow.
         */
        enableDynamicFieldUpdate?: pulumi.Input<boolean>;
        /**
         * Indicates whether Amazon AppFlow includes deleted files in the flow run.
         */
        includeDeletedRecords?: pulumi.Input<boolean>;
        /**
         * The object specified in the Salesforce flow source.
         */
        object: pulumi.Input<string>;
    }
    interface FlowSapoDataDestinationPropertiesArgs {
        /**
         * The settings that determine how Amazon AppFlow handles an error when placing data in the destination. For example, this setting would determine if the flow should fail after one insertion error, or continue and attempt to insert every record regardless of the initial failure. `ErrorHandlingConfig` is a part of the destination connector details.
         */
        errorHandlingConfig?: pulumi.Input<inputs.appflow.FlowErrorHandlingConfigArgs>;
        /**
         * List of fields used as ID when performing a write operation.
         */
        idFieldNames?: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * The object path specified in the SAPOData flow destination.
         */
        objectPath: pulumi.Input<string>;
        /**
         * Determines how Amazon AppFlow handles the success response that it gets from the connector after placing data.
         *
         * For example, this setting would determine where to write the response from a destination connector upon a successful insert operation.
         */
        successResponseHandlingConfig?: pulumi.Input<inputs.appflow.FlowSuccessResponseHandlingConfigArgs>;
        /**
         * The possible write operations in the destination connector. When this value is not provided, this defaults to the `INSERT` operation.
         */
        writeOperationType?: pulumi.Input<enums.appflow.FlowWriteOperationType>;
    }
    /**
     * SAP Source connector page size
     */
    interface FlowSapoDataPaginationConfigArgs {
        /**
         * The maximum number of records that Amazon AppFlow receives in each page of the response from your SAP application. For transfers of OData records, the maximum page size is 3,000. For transfers of data that comes from an ODP provider, the maximum page size is 10,000.
         */
        maxPageSize: pulumi.Input<number>;
    }
    /**
     * SAP Source connector parallelism factor
     */
    interface FlowSapoDataParallelismConfigArgs {
        /**
         * The maximum number of processes that Amazon AppFlow runs at the same time when it retrieves your data from your SAP application.
         */
        maxParallelism: pulumi.Input<number>;
    }
    interface FlowSapoDataSourcePropertiesArgs {
        /**
         * The object path specified in the SAPOData flow source.
         */
        objectPath: pulumi.Input<string>;
        /**
         * Sets the page size for each concurrent process that transfers OData records from your SAP instance.
         */
        paginationConfig?: pulumi.Input<inputs.appflow.FlowSapoDataPaginationConfigArgs>;
        /**
         * Sets the number of concurrent processes that transfers OData records from your SAP instance.
         */
        parallelismConfig?: pulumi.Input<inputs.appflow.FlowSapoDataParallelismConfigArgs>;
    }
    /**
     * Details required for scheduled trigger type
     */
    interface FlowScheduledTriggerPropertiesArgs {
        /**
         * Specifies whether a scheduled flow has an incremental data transfer or a complete data transfer for each flow run.
         */
        dataPullMode?: pulumi.Input<enums.appflow.FlowScheduledTriggerPropertiesDataPullMode>;
        /**
         * Specifies the date range for the records to import from the connector in the first flow run.
         */
        firstExecutionFrom?: pulumi.Input<number>;
        /**
         * Defines how many times a scheduled flow fails consecutively before Amazon AppFlow deactivates it.
         */
        flowErrorDeactivationThreshold?: pulumi.Input<number>;
        /**
         * The time at which the scheduled flow ends. The time is formatted as a timestamp that follows the ISO 8601 standard, such as `2022-04-27T13:00:00-07:00` .
         */
        scheduleEndTime?: pulumi.Input<number>;
        /**
         * The scheduling expression that determines the rate at which the schedule will run, for example `rate(5minutes)` .
         */
        scheduleExpression: pulumi.Input<string>;
        /**
         * Specifies the optional offset that is added to the time interval for a schedule-triggered flow.
         */
        scheduleOffset?: pulumi.Input<number>;
        /**
         * The time at which the scheduled flow starts. The time is formatted as a timestamp that follows the ISO 8601 standard, such as `2022-04-26T13:00:00-07:00` .
         */
        scheduleStartTime?: pulumi.Input<number>;
        /**
         * Specifies the time zone used when referring to the dates and times of a scheduled flow, such as `America/New_York` . This time zone is only a descriptive label. It doesn't affect how Amazon AppFlow interprets the timestamps that you specify to schedule the flow.
         *
         * If you want to schedule a flow by using times in a particular time zone, indicate the time zone as a UTC offset in your timestamps. For example, the UTC offsets for the `America/New_York` timezone are `-04:00` EDT and `-05:00 EST` .
         */
        timeZone?: pulumi.Input<string>;
    }
    interface FlowServiceNowSourcePropertiesArgs {
        /**
         * The object specified in the ServiceNow flow source.
         */
        object: pulumi.Input<string>;
    }
    interface FlowSingularSourcePropertiesArgs {
        /**
         * The object specified in the Singular flow source.
         */
        object: pulumi.Input<string>;
    }
    interface FlowSlackSourcePropertiesArgs {
        /**
         * The object specified in the Slack flow source.
         */
        object: pulumi.Input<string>;
    }
    interface FlowSnowflakeDestinationPropertiesArgs {
        /**
         * The object key for the destination bucket in which Amazon AppFlow places the files.
         */
        bucketPrefix?: pulumi.Input<string>;
        /**
         * The settings that determine how Amazon AppFlow handles an error when placing data in the Snowflake destination. For example, this setting would determine if the flow should fail after one insertion error, or continue and attempt to insert every record regardless of the initial failure. `ErrorHandlingConfig` is a part of the destination connector details.
         */
        errorHandlingConfig?: pulumi.Input<inputs.appflow.FlowErrorHandlingConfigArgs>;
        /**
         * The intermediate bucket that Amazon AppFlow uses when moving data into Snowflake.
         */
        intermediateBucketName: pulumi.Input<string>;
        /**
         * The object specified in the Snowflake flow destination.
         */
        object: pulumi.Input<string>;
    }
    /**
     * Source connector details required to query a connector
     */
    interface FlowSourceConnectorPropertiesArgs {
        /**
         * Specifies the information that is required for querying Amplitude.
         */
        amplitude?: pulumi.Input<inputs.appflow.FlowAmplitudeSourcePropertiesArgs>;
        /**
         * The properties that are applied when the custom connector is being used as a source.
         */
        customConnector?: pulumi.Input<inputs.appflow.FlowCustomConnectorSourcePropertiesArgs>;
        /**
         * Specifies the information that is required for querying Datadog.
         */
        datadog?: pulumi.Input<inputs.appflow.FlowDatadogSourcePropertiesArgs>;
        /**
         * Specifies the information that is required for querying Dynatrace.
         */
        dynatrace?: pulumi.Input<inputs.appflow.FlowDynatraceSourcePropertiesArgs>;
        /**
         * Specifies the information that is required for querying Google Analytics.
         */
        googleAnalytics?: pulumi.Input<inputs.appflow.FlowGoogleAnalyticsSourcePropertiesArgs>;
        /**
         * Specifies the information that is required for querying Infor Nexus.
         */
        inforNexus?: pulumi.Input<inputs.appflow.FlowInforNexusSourcePropertiesArgs>;
        /**
         * Specifies the information that is required for querying Marketo.
         */
        marketo?: pulumi.Input<inputs.appflow.FlowMarketoSourcePropertiesArgs>;
        /**
         * Specifies the information that is required for querying Salesforce Pardot.
         */
        pardot?: pulumi.Input<inputs.appflow.FlowPardotSourcePropertiesArgs>;
        /**
         * Specifies the information that is required for querying Amazon S3.
         */
        s3?: pulumi.Input<inputs.appflow.FlowS3SourcePropertiesArgs>;
        /**
         * Specifies the information that is required for querying Salesforce.
         */
        salesforce?: pulumi.Input<inputs.appflow.FlowSalesforceSourcePropertiesArgs>;
        /**
         * The properties that are applied when using SAPOData as a flow source.
         */
        sapoData?: pulumi.Input<inputs.appflow.FlowSapoDataSourcePropertiesArgs>;
        /**
         * Specifies the information that is required for querying ServiceNow.
         */
        serviceNow?: pulumi.Input<inputs.appflow.FlowServiceNowSourcePropertiesArgs>;
        /**
         * Specifies the information that is required for querying Singular.
         */
        singular?: pulumi.Input<inputs.appflow.FlowSingularSourcePropertiesArgs>;
        /**
         * Specifies the information that is required for querying Slack.
         */
        slack?: pulumi.Input<inputs.appflow.FlowSlackSourcePropertiesArgs>;
        /**
         * Specifies the information that is required for querying Trend Micro.
         */
        trendmicro?: pulumi.Input<inputs.appflow.FlowTrendmicroSourcePropertiesArgs>;
        /**
         * Specifies the information that is required for querying Veeva.
         */
        veeva?: pulumi.Input<inputs.appflow.FlowVeevaSourcePropertiesArgs>;
        /**
         * Specifies the information that is required for querying Zendesk.
         */
        zendesk?: pulumi.Input<inputs.appflow.FlowZendeskSourcePropertiesArgs>;
    }
    /**
     * Configurations of Source connector of the flow.
     */
    interface FlowSourceFlowConfigArgs {
        /**
         * The API version that the destination connector uses.
         */
        apiVersion?: pulumi.Input<string>;
        /**
         * Name of source connector profile
         */
        connectorProfileName?: pulumi.Input<string>;
        /**
         * Type of source connector
         */
        connectorType: pulumi.Input<enums.appflow.FlowConnectorType>;
        /**
         * Configuration for scheduled incremental data pull
         */
        incrementalPullConfig?: pulumi.Input<inputs.appflow.FlowIncrementalPullConfigArgs>;
        /**
         * Source connector details required to query a connector
         */
        sourceConnectorProperties: pulumi.Input<inputs.appflow.FlowSourceConnectorPropertiesArgs>;
    }
    interface FlowSuccessResponseHandlingConfigArgs {
        /**
         * The name of the Amazon S3 bucket.
         */
        bucketName?: pulumi.Input<string>;
        /**
         * The Amazon S3 bucket prefix.
         */
        bucketPrefix?: pulumi.Input<string>;
    }
    interface FlowTaskArgs {
        /**
         * Operation to be performed on provided source fields
         */
        connectorOperator?: pulumi.Input<inputs.appflow.FlowConnectorOperatorArgs>;
        /**
         * A field value on which source field should be validated
         */
        destinationField?: pulumi.Input<string>;
        /**
         * Source fields on which particular task will be applied
         */
        sourceFields: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * A Map used to store task related info
         */
        taskProperties?: pulumi.Input<pulumi.Input<inputs.appflow.FlowTaskPropertiesObjectArgs>[]>;
        /**
         * Type of task
         */
        taskType: pulumi.Input<enums.appflow.FlowTaskType>;
    }
    /**
     * An object used to store task related info
     */
    interface FlowTaskPropertiesObjectArgs {
        /**
         * The task property key.
         */
        key: pulumi.Input<enums.appflow.FlowOperatorPropertiesKeys>;
        /**
         * The task property value.
         */
        value: pulumi.Input<string>;
    }
    interface FlowTrendmicroSourcePropertiesArgs {
        /**
         * The object specified in the Trend Micro flow source.
         */
        object: pulumi.Input<string>;
    }
    /**
     * Trigger settings of the flow.
     */
    interface FlowTriggerConfigArgs {
        /**
         * Details required based on the type of trigger
         */
        triggerProperties?: pulumi.Input<inputs.appflow.FlowScheduledTriggerPropertiesArgs>;
        /**
         * Trigger type of the flow
         */
        triggerType: pulumi.Input<enums.appflow.FlowTriggerType>;
    }
    interface FlowUpsolverDestinationPropertiesArgs {
        /**
         * The Upsolver Amazon S3 bucket name in which Amazon AppFlow places the transferred data.
         */
        bucketName: pulumi.Input<string>;
        /**
         * The object key for the destination Upsolver Amazon S3 bucket in which Amazon AppFlow places the files.
         */
        bucketPrefix?: pulumi.Input<string>;
        /**
         * The configuration that determines how data is formatted when Upsolver is used as the flow destination.
         */
        s3OutputFormatConfig: pulumi.Input<inputs.appflow.FlowUpsolverS3OutputFormatConfigArgs>;
    }
    interface FlowUpsolverS3OutputFormatConfigArgs {
        /**
         * The aggregation settings that you can use to customize the output format of your flow data.
         */
        aggregationConfig?: pulumi.Input<inputs.appflow.FlowAggregationConfigArgs>;
        /**
         * Indicates the file type that Amazon AppFlow places in the Upsolver Amazon S3 bucket.
         */
        fileType?: pulumi.Input<enums.appflow.FlowFileType>;
        /**
         * Specifies elements that Amazon AppFlow includes in the file and folder names in the flow destination.
         */
        prefixConfig: pulumi.Input<inputs.appflow.FlowPrefixConfigArgs>;
    }
    interface FlowVeevaSourcePropertiesArgs {
        /**
         * The document type specified in the Veeva document extract flow.
         */
        documentType?: pulumi.Input<string>;
        /**
         * Boolean value to include All Versions of files in Veeva document extract flow.
         */
        includeAllVersions?: pulumi.Input<boolean>;
        /**
         * Boolean value to include file renditions in Veeva document extract flow.
         */
        includeRenditions?: pulumi.Input<boolean>;
        /**
         * Boolean value to include source files in Veeva document extract flow.
         */
        includeSourceFiles?: pulumi.Input<boolean>;
        /**
         * The object specified in the Veeva flow source.
         */
        object: pulumi.Input<string>;
    }
    interface FlowZendeskDestinationPropertiesArgs {
        /**
         * The settings that determine how Amazon AppFlow handles an error when placing data in the destination. For example, this setting would determine if the flow should fail after one insertion error, or continue and attempt to insert every record regardless of the initial failure. `ErrorHandlingConfig` is a part of the destination connector details.
         */
        errorHandlingConfig?: pulumi.Input<inputs.appflow.FlowErrorHandlingConfigArgs>;
        /**
         * List of fields used as ID when performing a write operation.
         */
        idFieldNames?: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * The object specified in the Zendesk flow destination.
         */
        object: pulumi.Input<string>;
        /**
         * The possible write operations in the destination connector. When this value is not provided, this defaults to the `INSERT` operation.
         */
        writeOperationType?: pulumi.Input<enums.appflow.FlowWriteOperationType>;
    }
    interface FlowZendeskSourcePropertiesArgs {
        /**
         * The object specified in the Zendesk flow source.
         */
        object: pulumi.Input<string>;
    }
}
export declare namespace appintegrations {
    interface ApplicationExternalUrlConfigArgs {
        /**
         * The URL to access the application.
         */
        accessUrl: pulumi.Input<string>;
        /**
         * Additional URLs to allow list if different than the access URL.
         */
        approvedOrigins?: pulumi.Input<pulumi.Input<string>[]>;
    }
    /**
     * Application source config
     */
    interface ApplicationSourceConfigPropertiesArgs {
        /**
         * The external URL source for the application.
         */
        externalUrlConfig: pulumi.Input<inputs.appintegrations.ApplicationExternalUrlConfigArgs>;
    }
    /**
     * The configuration for what files should be pulled from the source.
     */
    interface DataIntegrationFileConfigurationArgs {
        /**
         * Restrictions for what files should be pulled from the source.
         */
        filters?: pulumi.Input<{
            [key: string]: pulumi.Input<pulumi.Input<string>[]>;
        }>;
        /**
         * Identifiers for the source folders to pull all files from recursively.
         */
        folders: pulumi.Input<pulumi.Input<string>[]>;
    }
    interface DataIntegrationScheduleConfigArgs {
        /**
         * The start date for objects to import in the first flow run. Epoch or ISO timestamp format is supported.
         */
        firstExecutionFrom?: pulumi.Input<string>;
        /**
         * The name of the object to pull from the data source.
         */
        object?: pulumi.Input<string>;
        /**
         * How often the data should be pulled from data source.
         */
        scheduleExpression: pulumi.Input<string>;
    }
    interface EventIntegrationEventFilterArgs {
        /**
         * The source of the events.
         */
        source: pulumi.Input<string>;
    }
}
export declare namespace applicationautoscaling {
    /**
     * ``ScalableTargetAction`` specifies the minimum and maximum capacity for the ``ScalableTargetAction`` property of the [AWS::ApplicationAutoScaling::ScalableTarget ScheduledAction](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-applicationautoscaling-scalabletarget-scheduledaction.html) property type.
     */
    interface ScalableTargetActionArgs {
        /**
         * The maximum capacity.
         */
        maxCapacity?: pulumi.Input<number>;
        /**
         * The minimum capacity.
         */
        minCapacity?: pulumi.Input<number>;
    }
    /**
     * ``ScheduledAction`` is a property of the [AWS::ApplicationAutoScaling::ScalableTarget](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-applicationautoscaling-scalabletarget.html) resource that specifies a scheduled action for a scalable target.
     *  For more information, see [Scheduled scaling](https://docs.aws.amazon.com/autoscaling/application/userguide/application-auto-scaling-scheduled-scaling.html) in the *Application Auto Scaling User Guide*.
     */
    interface ScalableTargetScheduledActionArgs {
        /**
         * The date and time that the action is scheduled to end, in UTC.
         */
        endTime?: pulumi.Input<string>;
        /**
         * The new minimum and maximum capacity. You can set both values or just one. At the scheduled time, if the current capacity is below the minimum capacity, Application Auto Scaling scales out to the minimum capacity. If the current capacity is above the maximum capacity, Application Auto Scaling scales in to the maximum capacity.
         */
        scalableTargetAction?: pulumi.Input<inputs.applicationautoscaling.ScalableTargetActionArgs>;
        /**
         * The schedule for this action. The following formats are supported:
         *   +  At expressions - "``at(yyyy-mm-ddThh:mm:ss)``"
         *   +  Rate expressions - "``rate(value unit)``"
         *   +  Cron expressions - "``cron(fields)``"
         *
         *  At expressions are useful for one-time schedules. Cron expressions are useful for scheduled actions that run periodically at a specified date and time, and rate expressions are useful for scheduled actions that run at a regular interval.
         *  At and cron expressions use Universal Coordinated Time (UTC) by default.
         *  The cron format consists of six fields separated by white spaces: [Minutes] [Hours] [Day_of_Month] [Month] [Day_of_Week] [Year].
         *  For rate expressions, *value* is a positive integer and *unit* is ``minute`` | ``minutes`` | ``hour`` | ``hours`` | ``day`` | ``days``.
         */
        schedule: pulumi.Input<string>;
        /**
         * The name of the scheduled action. This name must be unique among all other scheduled actions on the specified scalable target.
         */
        scheduledActionName: pulumi.Input<string>;
        /**
         * The date and time that the action is scheduled to begin, in UTC.
         */
        startTime?: pulumi.Input<string>;
        /**
         * The time zone used when referring to the date and time of a scheduled action, when the scheduled action uses an at or cron expression.
         */
        timezone?: pulumi.Input<string>;
    }
    /**
     * ``SuspendedState`` is a property of the [AWS::ApplicationAutoScaling::ScalableTarget](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-applicationautoscaling-scalabletarget.html) resource that specifies whether the scaling activities for a scalable target are in a suspended state.
     *  For more information, see [Suspending and resuming scaling](https://docs.aws.amazon.com/autoscaling/application/userguide/application-auto-scaling-suspend-resume-scaling.html) in the *Application Auto Scaling User Guide*.
     */
    interface ScalableTargetSuspendedStateArgs {
        /**
         * Whether scale in by a target tracking scaling policy or a step scaling policy is suspended. Set the value to ``true`` if you don't want Application Auto Scaling to remove capacity when a scaling policy is triggered. The default is ``false``.
         */
        dynamicScalingInSuspended?: pulumi.Input<boolean>;
        /**
         * Whether scale out by a target tracking scaling policy or a step scaling policy is suspended. Set the value to ``true`` if you don't want Application Auto Scaling to add capacity when a scaling policy is triggered. The default is ``false``.
         */
        dynamicScalingOutSuspended?: pulumi.Input<boolean>;
        /**
         * Whether scheduled scaling is suspended. Set the value to ``true`` if you don't want Application Auto Scaling to add or remove capacity by initiating scheduled actions. The default is ``false``.
         */
        scheduledScalingSuspended?: pulumi.Input<boolean>;
    }
    /**
     * Contains customized metric specification information for a target tracking scaling policy for Application Auto Scaling.
     *  For information about the available metrics for a service, see [services that publish CloudWatch metrics](https://docs.aws.amazon.com/AmazonCloudWatch/latest/monitoring/aws-services-cloudwatch-metrics.html) in the *Amazon CloudWatch User Guide*.
     *  To create your customized metric specification:
     *   +  Add values for each required parameter from CloudWatch. You can use an existing metric, or a new metric that you create. To use your own metric, you must first publish the metric to CloudWatch. For more information, see [Publish custom metrics](https://docs.aws.amazon.com/AmazonCloudWatch/latest/monitoring/publishingMetrics.html) in the *Amazon CloudWatch User Guide*.
     *   +  Choose a metric that changes proportionally with capacity. The value of the metric should increase or decrease in inverse proportion to the number of capacity units. That is, the value of the metric should decrease when capacity increases, and increase when capacity decreases.
     *
     *  For an example of how creating new metrics can be useful, see [Scaling based on Amazon SQS](https://docs.aws.amazon.com/autoscaling/ec2/userguide/as-using-sqs-queue.html) in the *Amazon EC2 Auto Scaling User Guide*. This topic mentions Auto Scaling groups, but the same scenario for Amazon SQS can apply to the target tracking scaling policies that you create for a Spot Fleet by using Application Auto Scaling.
     *  For more information about the CloudWatch terminology below, see [Amazon CloudWatch concepts](https://docs.aws.amazon.com/AmazonCloudWatch/latest/monitoring/cloudwatch_concepts.html).
     *   ``CustomizedMetricSpecification`` is a property of the [AWS::ApplicationAutoScaling::ScalingPolicy TargetTrackingScalingPolicyConfiguration](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-applicationautoscaling-scalingpolicy-targettrackingscalingpolicyconfiguration.html) property type.
     */
    interface ScalingPolicyCustomizedMetricSpecificationArgs {
        /**
         * The dimensions of the metric.
         *  Conditional: If you published your metric with dimensions, you must specify the same dimensions in your scaling policy.
         */
        dimensions?: pulumi.Input<pulumi.Input<inputs.applicationautoscaling.ScalingPolicyMetricDimensionArgs>[]>;
        /**
         * The name of the metric. To get the exact metric name, namespace, and dimensions, inspect the [Metric](https://docs.aws.amazon.com/AmazonCloudWatch/latest/APIReference/API_Metric.html) object that's returned by a call to [ListMetrics](https://docs.aws.amazon.com/AmazonCloudWatch/latest/APIReference/API_ListMetrics.html).
         */
        metricName?: pulumi.Input<string>;
        /**
         * The metrics to include in the target tracking scaling policy, as a metric data query. This can include both raw metric and metric math expressions.
         */
        metrics?: pulumi.Input<pulumi.Input<inputs.applicationautoscaling.ScalingPolicyTargetTrackingMetricDataQueryArgs>[]>;
        /**
         * The namespace of the metric.
         */
        namespace?: pulumi.Input<string>;
        /**
         * The statistic of the metric.
         */
        statistic?: pulumi.Input<string>;
        /**
         * The unit of the metric. For a complete list of the units that CloudWatch supports, see the [MetricDatum](https://docs.aws.amazon.com/AmazonCloudWatch/latest/APIReference/API_MetricDatum.html) data type in the *Amazon CloudWatch API Reference*.
         */
        unit?: pulumi.Input<string>;
    }
    /**
     * ``MetricDimension`` specifies a name/value pair that is part of the identity of a CloudWatch metric for the ``Dimensions`` property of the [AWS::ApplicationAutoScaling::ScalingPolicy CustomizedMetricSpecification](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-applicationautoscaling-scalingpolicy-customizedmetricspecification.html) property type. Duplicate dimensions are not allowed.
     */
    interface ScalingPolicyMetricDimensionArgs {
        /**
         * The name of the dimension.
         */
        name: pulumi.Input<string>;
        /**
         * The value of the dimension.
         */
        value: pulumi.Input<string>;
    }
    /**
     * Contains predefined metric specification information for a target tracking scaling policy for Application Auto Scaling.
     *   ``PredefinedMetricSpecification`` is a property of the [AWS::ApplicationAutoScaling::ScalingPolicy TargetTrackingScalingPolicyConfiguration](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-applicationautoscaling-scalingpolicy-targettrackingscalingpolicyconfiguration.html) property type.
     */
    interface ScalingPolicyPredefinedMetricSpecificationArgs {
        /**
         * The metric type. The ``ALBRequestCountPerTarget`` metric type applies only to Spot fleet requests and ECS services.
         */
        predefinedMetricType: pulumi.Input<string>;
        /**
         * Identifies the resource associated with the metric type. You can't specify a resource label unless the metric type is ``ALBRequestCountPerTarget`` and there is a target group attached to the Spot Fleet or ECS service.
         *  You create the resource label by appending the final portion of the load balancer ARN and the final portion of the target group ARN into a single value, separated by a forward slash (/). The format of the resource label is:
         *   ``app/my-alb/778d41231b141a0f/targetgroup/my-alb-target-group/943f017f100becff``.
         *  Where:
         *   +  app/<load-balancer-name>/<load-balancer-id> is the final portion of the load balancer ARN
         *   +  targetgroup/<target-group-name>/<target-group-id> is the final portion of the target group ARN.
         *
         *  To find the ARN for an Application Load Balancer, use the [DescribeLoadBalancers](https://docs.aws.amazon.com/elasticloadbalancing/latest/APIReference/API_DescribeLoadBalancers.html) API operation. To find the ARN for the target group, use the [DescribeTargetGroups](https://docs.aws.amazon.com/elasticloadbalancing/latest/APIReference/API_DescribeTargetGroups.html) API operation.
         */
        resourceLabel?: pulumi.Input<string>;
    }
    /**
     * Represents a CloudWatch metric of your choosing for a predictive scaling policy.
     */
    interface ScalingPolicyPredictiveScalingCustomizedCapacityMetricArgs {
        /**
         * One or more metric data queries to provide data points for a metric specification.
         */
        metricDataQueries: pulumi.Input<pulumi.Input<inputs.applicationautoscaling.ScalingPolicyPredictiveScalingMetricDataQueryArgs>[]>;
    }
    /**
     * The customized load metric specification.
     */
    interface ScalingPolicyPredictiveScalingCustomizedLoadMetricArgs {
        metricDataQueries: pulumi.Input<pulumi.Input<inputs.applicationautoscaling.ScalingPolicyPredictiveScalingMetricDataQueryArgs>[]>;
    }
    /**
     * One or more metric data queries to provide data points for a metric specification.
     */
    interface ScalingPolicyPredictiveScalingCustomizedScalingMetricArgs {
        /**
         * One or more metric data queries to provide data points for a metric specification.
         */
        metricDataQueries: pulumi.Input<pulumi.Input<inputs.applicationautoscaling.ScalingPolicyPredictiveScalingMetricDataQueryArgs>[]>;
    }
    /**
     * Describes the scaling metric.
     */
    interface ScalingPolicyPredictiveScalingMetricArgs {
        /**
         * Describes the dimensions of the metric.
         */
        dimensions?: pulumi.Input<pulumi.Input<inputs.applicationautoscaling.ScalingPolicyPredictiveScalingMetricDimensionArgs>[]>;
        /**
         * The name of the metric.
         */
        metricName?: pulumi.Input<string>;
        /**
         * The namespace of the metric.
         */
        namespace?: pulumi.Input<string>;
    }
    /**
     * The metric data to return. Also defines whether this call is returning data for one metric only, or whether it is performing a math expression on the values of returned metric statistics to create a new time series. A time series is a series of data points, each of which is associated with a timestamp.
     */
    interface ScalingPolicyPredictiveScalingMetricDataQueryArgs {
        /**
         * The math expression to perform on the returned data, if this object is performing a math expression. This expression can use the ``Id`` of the other metrics to refer to those metrics, and can also use the ``Id`` of other expressions to use the result of those expressions.
         *  Conditional: Within each ``MetricDataQuery`` object, you must specify either ``Expression`` or ``MetricStat``, but not both.
         */
        expression?: pulumi.Input<string>;
        /**
         * A short name that identifies the object's results in the response. This name must be unique among all ``MetricDataQuery`` objects specified for a single scaling policy. If you are performing math expressions on this set of data, this name represents that data and can serve as a variable in the mathematical expression. The valid characters are letters, numbers, and underscores. The first character must be a lowercase letter.
         */
        id?: pulumi.Input<string>;
        /**
         * A human-readable label for this metric or expression. This is especially useful if this is a math expression, so that you know what the value represents.
         */
        label?: pulumi.Input<string>;
        /**
         * Information about the metric data to return.
         *  Conditional: Within each ``MetricDataQuery`` object, you must specify either ``Expression`` or ``MetricStat``, but not both.
         */
        metricStat?: pulumi.Input<inputs.applicationautoscaling.ScalingPolicyPredictiveScalingMetricStatArgs>;
        /**
         * Indicates whether to return the timestamps and raw data values of this metric.
         *  If you use any math expressions, specify ``true`` for this value for only the final math expression that the metric specification is based on. You must specify ``false`` for ``ReturnData`` for all the other metrics and expressions used in the metric specification.
         *  If you are only retrieving metrics and not performing any math expressions, do not specify anything for ``ReturnData``. This sets it to its default (``true``).
         */
        returnData?: pulumi.Input<boolean>;
    }
    /**
     * Describes the dimension of a metric.
     */
    interface ScalingPolicyPredictiveScalingMetricDimensionArgs {
        /**
         * The name of the dimension.
         */
        name?: pulumi.Input<string>;
        /**
         * The value of the dimension.
         */
        value?: pulumi.Input<string>;
    }
    /**
     * This structure specifies the metrics and target utilization settings for a predictive scaling policy.
     *  You must specify either a metric pair, or a load metric and a scaling metric individually. Specifying a metric pair instead of individual metrics provides a simpler way to configure metrics for a scaling policy. You choose the metric pair, and the policy automatically knows the correct sum and average statistics to use for the load metric and the scaling metric.
     */
    interface ScalingPolicyPredictiveScalingMetricSpecificationArgs {
        /**
         * The customized capacity metric specification.
         */
        customizedCapacityMetricSpecification?: pulumi.Input<inputs.applicationautoscaling.ScalingPolicyPredictiveScalingCustomizedCapacityMetricArgs>;
        /**
         * The customized load metric specification.
         */
        customizedLoadMetricSpecification?: pulumi.Input<inputs.applicationautoscaling.ScalingPolicyPredictiveScalingCustomizedLoadMetricArgs>;
        /**
         * The customized scaling metric specification.
         */
        customizedScalingMetricSpecification?: pulumi.Input<inputs.applicationautoscaling.ScalingPolicyPredictiveScalingCustomizedScalingMetricArgs>;
        /**
         * The predefined load metric specification.
         */
        predefinedLoadMetricSpecification?: pulumi.Input<inputs.applicationautoscaling.ScalingPolicyPredictiveScalingPredefinedLoadMetricArgs>;
        /**
         * The predefined metric pair specification that determines the appropriate scaling metric and load metric to use.
         */
        predefinedMetricPairSpecification?: pulumi.Input<inputs.applicationautoscaling.ScalingPolicyPredictiveScalingPredefinedMetricPairArgs>;
        /**
         * The predefined scaling metric specification.
         */
        predefinedScalingMetricSpecification?: pulumi.Input<inputs.applicationautoscaling.ScalingPolicyPredictiveScalingPredefinedScalingMetricArgs>;
        /**
         * Specifies the target utilization.
         */
        targetValue: pulumi.Input<number>;
    }
    /**
     * This structure defines the CloudWatch metric to return, along with the statistic and unit.
     */
    interface ScalingPolicyPredictiveScalingMetricStatArgs {
        /**
         * The CloudWatch metric to return, including the metric name, namespace, and dimensions. To get the exact metric name, namespace, and dimensions, inspect the [Metric](https://docs.aws.amazon.com/AmazonCloudWatch/latest/APIReference/API_Metric.html) object that is returned by a call to [ListMetrics](https://docs.aws.amazon.com/AmazonCloudWatch/latest/APIReference/API_ListMetrics.html).
         */
        metric?: pulumi.Input<inputs.applicationautoscaling.ScalingPolicyPredictiveScalingMetricArgs>;
        /**
         * The statistic to return. It can include any CloudWatch statistic or extended statistic. For a list of valid values, see the table in [Statistics](https://docs.aws.amazon.com/AmazonCloudWatch/latest/monitoring/cloudwatch_concepts.html#Statistic) in the *Amazon CloudWatch User Guide*.
         *  The most commonly used metrics for predictive scaling are ``Average`` and ``Sum``.
         */
        stat?: pulumi.Input<string>;
        /**
         * The unit to use for the returned data points. For a complete list of the units that CloudWatch supports, see the [MetricDatum](https://docs.aws.amazon.com/AmazonCloudWatch/latest/APIReference/API_MetricDatum.html) data type in the *Amazon CloudWatch API Reference*.
         */
        unit?: pulumi.Input<string>;
    }
    /**
     * Represents a predictive scaling policy configuration.
     */
    interface ScalingPolicyPredictiveScalingPolicyConfigurationArgs {
        /**
         * Defines the behavior that should be applied if the forecast capacity approaches or exceeds the maximum capacity. Defaults to ``HonorMaxCapacity`` if not specified.
         */
        maxCapacityBreachBehavior?: pulumi.Input<string>;
        /**
         * The size of the capacity buffer to use when the forecast capacity is close to or exceeds the maximum capacity. The value is specified as a percentage relative to the forecast capacity. For example, if the buffer is 10, this means a 10 percent buffer, such that if the forecast capacity is 50, and the maximum capacity is 40, then the effective maximum capacity is 55.
         *  Required if the ``MaxCapacityBreachBehavior`` property is set to ``IncreaseMaxCapacity``, and cannot be used otherwise.
         */
        maxCapacityBuffer?: pulumi.Input<number>;
        /**
         * This structure includes the metrics and target utilization to use for predictive scaling.
         *  This is an array, but we currently only support a single metric specification. That is, you can specify a target value and a single metric pair, or a target value and one scaling metric and one load metric.
         */
        metricSpecifications: pulumi.Input<pulumi.Input<inputs.applicationautoscaling.ScalingPolicyPredictiveScalingMetricSpecificationArgs>[]>;
        /**
         * The predictive scaling mode. Defaults to ``ForecastOnly`` if not specified.
         */
        mode?: pulumi.Input<string>;
        /**
         * The amount of time, in seconds, that the start time can be advanced.
         *  The value must be less than the forecast interval duration of 3600 seconds (60 minutes). Defaults to 300 seconds if not specified.
         */
        schedulingBufferTime?: pulumi.Input<number>;
    }
    /**
     * Describes a load metric for a predictive scaling policy.
     *  When returned in the output of ``DescribePolicies``, it indicates that a predictive scaling policy uses individually specified load and scaling metrics instead of a metric pair.
     */
    interface ScalingPolicyPredictiveScalingPredefinedLoadMetricArgs {
        /**
         * The metric type.
         */
        predefinedMetricType: pulumi.Input<string>;
        /**
         * A label that uniquely identifies a target group.
         */
        resourceLabel?: pulumi.Input<string>;
    }
    /**
     * Represents a metric pair for a predictive scaling policy.
     */
    interface ScalingPolicyPredictiveScalingPredefinedMetricPairArgs {
        /**
         * Indicates which metrics to use. There are two different types of metrics for each metric type: one is a load metric and one is a scaling metric.
         */
        predefinedMetricType: pulumi.Input<string>;
        /**
         * A label that uniquely identifies a specific target group from which to determine the total and average request count.
         */
        resourceLabel?: pulumi.Input<string>;
    }
    /**
     * Describes a scaling metric for a predictive scaling policy.
     *  When returned in the output of ``DescribePolicies``, it indicates that a predictive scaling policy uses individually specified load and scaling metrics instead of a metric pair.
     */
    interface ScalingPolicyPredictiveScalingPredefinedScalingMetricArgs {
        /**
         * The metric type.
         */
        predefinedMetricType: pulumi.Input<string>;
        /**
         * A label that uniquely identifies a specific target group from which to determine the average request count.
         */
        resourceLabel?: pulumi.Input<string>;
    }
    /**
     * ``StepAdjustment`` specifies a step adjustment for the ``StepAdjustments`` property of the [AWS::ApplicationAutoScaling::ScalingPolicy StepScalingPolicyConfiguration](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-applicationautoscaling-scalingpolicy-stepscalingpolicyconfiguration.html) property type.
     *  For the following examples, suppose that you have an alarm with a breach threshold of 50:
     *   +  To trigger a step adjustment when the metric is greater than or equal to 50 and less than 60, specify a lower bound of 0 and an upper bound of 10.
     *   +  To trigger a step adjustment when the metric is greater than 40 and less than or equal to 50, specify a lower bound of -10 and an upper bound of 0.
     *
     *  For more information, see [Step adjustments](https://docs.aws.amazon.com/autoscaling/application/userguide/application-auto-scaling-step-scaling-policies.html#as-scaling-steps) in the *Application Auto Scaling User Guide*.
     *  You can find a sample template snippet in the [Examples](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-applicationautoscaling-scalingpolicy.html#aws-resource-applicationautoscaling-scalingpolicy--examples) section of the ``AWS::ApplicationAutoScaling::ScalingPolicy`` documentation.
     */
    interface ScalingPolicyStepAdjustmentArgs {
        /**
         * The lower bound for the difference between the alarm threshold and the CloudWatch metric. If the metric value is above the breach threshold, the lower bound is inclusive (the metric must be greater than or equal to the threshold plus the lower bound). Otherwise, it is exclusive (the metric must be greater than the threshold plus the lower bound). A null value indicates negative infinity.
         *  You must specify at least one upper or lower bound.
         */
        metricIntervalLowerBound?: pulumi.Input<number>;
        /**
         * The upper bound for the difference between the alarm threshold and the CloudWatch metric. If the metric value is above the breach threshold, the upper bound is exclusive (the metric must be less than the threshold plus the upper bound). Otherwise, it is inclusive (the metric must be less than or equal to the threshold plus the upper bound). A null value indicates positive infinity.
         *  You must specify at least one upper or lower bound.
         */
        metricIntervalUpperBound?: pulumi.Input<number>;
        /**
         * The amount by which to scale. The adjustment is based on the value that you specified in the ``AdjustmentType`` property (either an absolute number or a percentage). A positive value adds to the current capacity and a negative number subtracts from the current capacity.
         */
        scalingAdjustment: pulumi.Input<number>;
    }
    /**
     * ``StepScalingPolicyConfiguration`` is a property of the [AWS::ApplicationAutoScaling::ScalingPolicy](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-applicationautoscaling-scalingpolicy.html) resource that specifies a step scaling policy configuration for Application Auto Scaling.
     *  For more information, see [Step scaling policies](https://docs.aws.amazon.com/autoscaling/application/userguide/application-auto-scaling-step-scaling-policies.html) in the *Application Auto Scaling User Guide*.
     */
    interface ScalingPolicyStepScalingPolicyConfigurationArgs {
        /**
         * Specifies whether the ``ScalingAdjustment`` value in the ``StepAdjustment`` property is an absolute number or a percentage of the current capacity.
         */
        adjustmentType?: pulumi.Input<string>;
        /**
         * The amount of time, in seconds, to wait for a previous scaling activity to take effect. If not specified, the default value is 300. For more information, see [Cooldown period](https://docs.aws.amazon.com/autoscaling/application/userguide/step-scaling-policy-overview.html#step-scaling-cooldown) in the *Application Auto Scaling User Guide*.
         */
        cooldown?: pulumi.Input<number>;
        /**
         * The aggregation type for the CloudWatch metrics. Valid values are ``Minimum``, ``Maximum``, and ``Average``. If the aggregation type is null, the value is treated as ``Average``.
         */
        metricAggregationType?: pulumi.Input<string>;
        /**
         * The minimum value to scale by when the adjustment type is ``PercentChangeInCapacity``. For example, suppose that you create a step scaling policy to scale out an Amazon ECS service by 25 percent and you specify a ``MinAdjustmentMagnitude`` of 2. If the service has 4 tasks and the scaling policy is performed, 25 percent of 4 is 1. However, because you specified a ``MinAdjustmentMagnitude`` of 2, Application Auto Scaling scales out the service by 2 tasks.
         */
        minAdjustmentMagnitude?: pulumi.Input<number>;
        /**
         * A set of adjustments that enable you to scale based on the size of the alarm breach.
         *  At least one step adjustment is required if you are adding a new step scaling policy configuration.
         */
        stepAdjustments?: pulumi.Input<pulumi.Input<inputs.applicationautoscaling.ScalingPolicyStepAdjustmentArgs>[]>;
    }
    /**
     * Represents a specific metric for a target tracking scaling policy for Application Auto Scaling.
     *  Metric is a property of the [AWS::ApplicationAutoScaling::ScalingPolicy TargetTrackingMetricStat](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-applicationautoscaling-scalingpolicy-targettrackingmetricstat.html) property type.
     */
    interface ScalingPolicyTargetTrackingMetricArgs {
        /**
         * The dimensions for the metric. For the list of available dimensions, see the AWS documentation available from the table in [services that publish CloudWatch metrics](https://docs.aws.amazon.com/AmazonCloudWatch/latest/monitoring/aws-services-cloudwatch-metrics.html) in the *Amazon CloudWatch User Guide*.
         *  Conditional: If you published your metric with dimensions, you must specify the same dimensions in your scaling policy.
         */
        dimensions?: pulumi.Input<pulumi.Input<inputs.applicationautoscaling.ScalingPolicyTargetTrackingMetricDimensionArgs>[]>;
        /**
         * The name of the metric.
         */
        metricName?: pulumi.Input<string>;
        /**
         * The namespace of the metric. For more information, see the table in [services that publish CloudWatch metrics](https://docs.aws.amazon.com/AmazonCloudWatch/latest/monitoring/aws-services-cloudwatch-metrics.html) in the *Amazon CloudWatch User Guide*.
         */
        namespace?: pulumi.Input<string>;
    }
    /**
     * The metric data to return. Also defines whether this call is returning data for one metric only, or whether it is performing a math expression on the values of returned metric statistics to create a new time series. A time series is a series of data points, each of which is associated with a timestamp.
     *  You can call for a single metric or perform math expressions on multiple metrics. Any expressions used in a metric specification must eventually return a single time series.
     *  For more information and examples, see [Create a target tracking scaling policy for Application Auto Scaling using metric math](https://docs.aws.amazon.com/autoscaling/application/userguide/application-auto-scaling-target-tracking-metric-math.html) in the *Application Auto Scaling User Guide*.
     *   ``TargetTrackingMetricDataQuery`` is a property of the [AWS::ApplicationAutoScaling::ScalingPolicy CustomizedMetricSpecification](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-applicationautoscaling-scalingpolicy-customizedmetricspecification.html) property type.
     */
    interface ScalingPolicyTargetTrackingMetricDataQueryArgs {
        /**
         * The math expression to perform on the returned data, if this object is performing a math expression. This expression can use the ``Id`` of the other metrics to refer to those metrics, and can also use the ``Id`` of other expressions to use the result of those expressions.
         *  Conditional: Within each ``TargetTrackingMetricDataQuery`` object, you must specify either ``Expression`` or ``MetricStat``, but not both.
         */
        expression?: pulumi.Input<string>;
        /**
         * A short name that identifies the object's results in the response. This name must be unique among all ``MetricDataQuery`` objects specified for a single scaling policy. If you are performing math expressions on this set of data, this name represents that data and can serve as a variable in the mathematical expression. The valid characters are letters, numbers, and underscores. The first character must be a lowercase letter.
         */
        id?: pulumi.Input<string>;
        /**
         * A human-readable label for this metric or expression. This is especially useful if this is a math expression, so that you know what the value represents.
         */
        label?: pulumi.Input<string>;
        /**
         * Information about the metric data to return.
         *  Conditional: Within each ``MetricDataQuery`` object, you must specify either ``Expression`` or ``MetricStat``, but not both.
         */
        metricStat?: pulumi.Input<inputs.applicationautoscaling.ScalingPolicyTargetTrackingMetricStatArgs>;
        /**
         * Indicates whether to return the timestamps and raw data values of this metric.
         *  If you use any math expressions, specify ``true`` for this value for only the final math expression that the metric specification is based on. You must specify ``false`` for ``ReturnData`` for all the other metrics and expressions used in the metric specification.
         *  If you are only retrieving metrics and not performing any math expressions, do not specify anything for ``ReturnData``. This sets it to its default (``true``).
         */
        returnData?: pulumi.Input<boolean>;
    }
    /**
     * ``TargetTrackingMetricDimension`` specifies a name/value pair that is part of the identity of a CloudWatch metric for the ``Dimensions`` property of the [AWS::ApplicationAutoScaling::ScalingPolicy TargetTrackingMetric](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-applicationautoscaling-scalingpolicy-targettrackingmetric.html) property type. Duplicate dimensions are not allowed.
     */
    interface ScalingPolicyTargetTrackingMetricDimensionArgs {
        /**
         * The name of the dimension.
         */
        name?: pulumi.Input<string>;
        /**
         * The value of the dimension.
         */
        value?: pulumi.Input<string>;
    }
    /**
     * This structure defines the CloudWatch metric to return, along with the statistic and unit.
     *   ``TargetTrackingMetricStat`` is a property of the [AWS::ApplicationAutoScaling::ScalingPolicy TargetTrackingMetricDataQuery](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-applicationautoscaling-scalingpolicy-targettrackingmetricdataquery.html) property type.
     *  For more information about the CloudWatch terminology below, see [Amazon CloudWatch concepts](https://docs.aws.amazon.com/AmazonCloudWatch/latest/monitoring/cloudwatch_concepts.html) in the *Amazon CloudWatch User Guide*.
     */
    interface ScalingPolicyTargetTrackingMetricStatArgs {
        /**
         * The CloudWatch metric to return, including the metric name, namespace, and dimensions. To get the exact metric name, namespace, and dimensions, inspect the [Metric](https://docs.aws.amazon.com/AmazonCloudWatch/latest/APIReference/API_Metric.html) object that is returned by a call to [ListMetrics](https://docs.aws.amazon.com/AmazonCloudWatch/latest/APIReference/API_ListMetrics.html).
         */
        metric?: pulumi.Input<inputs.applicationautoscaling.ScalingPolicyTargetTrackingMetricArgs>;
        /**
         * The statistic to return. It can include any CloudWatch statistic or extended statistic. For a list of valid values, see the table in [Statistics](https://docs.aws.amazon.com/AmazonCloudWatch/latest/monitoring/cloudwatch_concepts.html#Statistic) in the *Amazon CloudWatch User Guide*.
         *  The most commonly used metric for scaling is ``Average``.
         */
        stat?: pulumi.Input<string>;
        /**
         * The unit to use for the returned data points. For a complete list of the units that CloudWatch supports, see the [MetricDatum](https://docs.aws.amazon.com/AmazonCloudWatch/latest/APIReference/API_MetricDatum.html) data type in the *Amazon CloudWatch API Reference*.
         */
        unit?: pulumi.Input<string>;
    }
    /**
     * ``TargetTrackingScalingPolicyConfiguration`` is a property of the [AWS::ApplicationAutoScaling::ScalingPolicy](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-applicationautoscaling-scalingpolicy.html) resource that specifies a target tracking scaling policy configuration for Application Auto Scaling. Use a target tracking scaling policy to adjust the capacity of the specified scalable target in response to actual workloads, so that resource utilization remains at or near the target utilization value.
     *  For more information, see [Target tracking scaling policies](https://docs.aws.amazon.com/autoscaling/application/userguide/application-auto-scaling-target-tracking.html) in the *Application Auto Scaling User Guide*.
     */
    interface ScalingPolicyTargetTrackingScalingPolicyConfigurationArgs {
        /**
         * A customized metric. You can specify either a predefined metric or a customized metric.
         */
        customizedMetricSpecification?: pulumi.Input<inputs.applicationautoscaling.ScalingPolicyCustomizedMetricSpecificationArgs>;
        /**
         * Indicates whether scale in by the target tracking scaling policy is disabled. If the value is ``true``, scale in is disabled and the target tracking scaling policy won't remove capacity from the scalable target. Otherwise, scale in is enabled and the target tracking scaling policy can remove capacity from the scalable target. The default value is ``false``.
         */
        disableScaleIn?: pulumi.Input<boolean>;
        /**
         * A predefined metric. You can specify either a predefined metric or a customized metric.
         */
        predefinedMetricSpecification?: pulumi.Input<inputs.applicationautoscaling.ScalingPolicyPredefinedMetricSpecificationArgs>;
        /**
         * The amount of time, in seconds, after a scale-in activity completes before another scale-in activity can start. For more information and for default values, see [Define cooldown periods](https://docs.aws.amazon.com/autoscaling/application/userguide/target-tracking-scaling-policy-overview.html#target-tracking-cooldown) in the *Application Auto Scaling User Guide*.
         */
        scaleInCooldown?: pulumi.Input<number>;
        /**
         * The amount of time, in seconds, to wait for a previous scale-out activity to take effect. For more information and for default values, see [Define cooldown periods](https://docs.aws.amazon.com/autoscaling/application/userguide/target-tracking-scaling-policy-overview.html#target-tracking-cooldown) in the *Application Auto Scaling User Guide*.
         */
        scaleOutCooldown?: pulumi.Input<number>;
        /**
         * The target value for the metric. Although this property accepts numbers of type Double, it won't accept values that are either too small or too large. Values must be in the range of -2^360 to 2^360. The value must be a valid number based on the choice of metric. For example, if the metric is CPU utilization, then the target value is a percent value that represents how much of the CPU can be used before scaling out.
         */
        targetValue: pulumi.Input<number>;
    }
}
export declare namespace applicationinsights {
    /**
     * A CloudWatch alarm to be monitored for the component.
     */
    interface ApplicationAlarmArgs {
        /**
         * The name of the CloudWatch alarm to be monitored for the component.
         */
        alarmName: pulumi.Input<string>;
        /**
         * Indicates the degree of outage when the alarm goes off.
         */
        severity?: pulumi.Input<enums.applicationinsights.ApplicationAlarmSeverity>;
    }
    /**
     * A metric to be monitored for the component.
     */
    interface ApplicationAlarmMetricArgs {
        /**
         * The name of the metric to be monitored for the component.
         */
        alarmMetricName: pulumi.Input<string>;
    }
    /**
     * The configuration settings of the component.
     */
    interface ApplicationComponentConfigurationArgs {
        /**
         * The configuration settings
         */
        configurationDetails?: pulumi.Input<inputs.applicationinsights.ApplicationConfigurationDetailsArgs>;
        /**
         * Sub component configurations of the component.
         */
        subComponentTypeConfigurations?: pulumi.Input<pulumi.Input<inputs.applicationinsights.ApplicationSubComponentTypeConfigurationArgs>[]>;
    }
    /**
     * The monitoring setting of the component.
     */
    interface ApplicationComponentMonitoringSettingArgs {
        /**
         * The ARN of the compnonent.
         */
        componentArn?: pulumi.Input<string>;
        /**
         * The component monitoring configuration mode.
         */
        componentConfigurationMode: pulumi.Input<enums.applicationinsights.ApplicationComponentMonitoringSettingComponentConfigurationMode>;
        /**
         * The name of the component.
         */
        componentName?: pulumi.Input<string>;
        /**
         * The monitoring configuration of the component.
         */
        customComponentConfiguration?: pulumi.Input<inputs.applicationinsights.ApplicationComponentConfigurationArgs>;
        /**
         * The overwritten settings on default component monitoring configuration.
         */
        defaultOverwriteComponentConfiguration?: pulumi.Input<inputs.applicationinsights.ApplicationComponentConfigurationArgs>;
        /**
         * The tier of the application component.
         */
        tier: pulumi.Input<string>;
    }
    /**
     * The configuration settings.
     */
    interface ApplicationConfigurationDetailsArgs {
        /**
         * A list of metrics to monitor for the component.
         */
        alarmMetrics?: pulumi.Input<pulumi.Input<inputs.applicationinsights.ApplicationAlarmMetricArgs>[]>;
        /**
         * A list of alarms to monitor for the component.
         */
        alarms?: pulumi.Input<pulumi.Input<inputs.applicationinsights.ApplicationAlarmArgs>[]>;
        /**
         * The HA cluster Prometheus Exporter settings.
         */
        haClusterPrometheusExporter?: pulumi.Input<inputs.applicationinsights.ApplicationHaClusterPrometheusExporterArgs>;
        /**
         * The HANA DB Prometheus Exporter settings.
         */
        hanaPrometheusExporter?: pulumi.Input<inputs.applicationinsights.ApplicationHanaPrometheusExporterArgs>;
        /**
         * The JMX Prometheus Exporter settings.
         */
        jmxPrometheusExporter?: pulumi.Input<inputs.applicationinsights.ApplicationJmxPrometheusExporterArgs>;
        /**
         * A list of logs to monitor for the component.
         */
        logs?: pulumi.Input<pulumi.Input<inputs.applicationinsights.ApplicationLogArgs>[]>;
        /**
         * The NetWeaver Prometheus Exporter settings.
         */
        netWeaverPrometheusExporter?: pulumi.Input<inputs.applicationinsights.ApplicationNetWeaverPrometheusExporterArgs>;
        /**
         * A list of processes to monitor for the component. Only Windows EC2 instances can have a processes section.
         */
        processes?: pulumi.Input<pulumi.Input<inputs.applicationinsights.ApplicationProcessArgs>[]>;
        /**
         * The SQL Prometheus Exporter settings.
         */
        sqlServerPrometheusExporter?: pulumi.Input<inputs.applicationinsights.ApplicationSqlServerPrometheusExporterArgs>;
        /**
         * A list of Windows Events to log.
         */
        windowsEvents?: pulumi.Input<pulumi.Input<inputs.applicationinsights.ApplicationWindowsEventArgs>[]>;
    }
    /**
     * The custom grouped component.
     */
    interface ApplicationCustomComponentArgs {
        /**
         * The name of the component.
         */
        componentName: pulumi.Input<string>;
        /**
         * The list of resource ARNs that belong to the component.
         */
        resourceList: pulumi.Input<pulumi.Input<string>[]>;
    }
    /**
     * The HA cluster Prometheus Exporter settings.
     */
    interface ApplicationHaClusterPrometheusExporterArgs {
        /**
         * Prometheus exporter port.
         */
        prometheusPort?: pulumi.Input<string>;
    }
    /**
     * The HANA DB Prometheus Exporter settings.
     */
    interface ApplicationHanaPrometheusExporterArgs {
        /**
         * A flag which indicates agreeing to install SAP HANA DB client.
         */
        agreeToInstallHanadbClient: pulumi.Input<boolean>;
        /**
         * The HANA DB port.
         */
        hanaPort: pulumi.Input<string>;
        /**
         * The secret name which manages the HANA DB credentials e.g. {
         *   "username": "<>",
         *   "password": "<>"
         * }.
         */
        hanaSecretName: pulumi.Input<string>;
        /**
         * HANA DB SID.
         */
        hanasid: pulumi.Input<string>;
        /**
         * Prometheus exporter port.
         */
        prometheusPort?: pulumi.Input<string>;
    }
    /**
     * The JMX Prometheus Exporter settings.
     */
    interface ApplicationJmxPrometheusExporterArgs {
        /**
         * Java agent host port
         */
        hostPort?: pulumi.Input<string>;
        /**
         * JMX service URL.
         */
        jmxurl?: pulumi.Input<string>;
        /**
         * Prometheus exporter port.
         */
        prometheusPort?: pulumi.Input<string>;
    }
    /**
     * A log to be monitored for the component.
     */
    interface ApplicationLogArgs {
        /**
         * The type of encoding of the logs to be monitored.
         */
        encoding?: pulumi.Input<enums.applicationinsights.ApplicationLogEncoding>;
        /**
         * The CloudWatch log group name to be associated to the monitored log.
         */
        logGroupName?: pulumi.Input<string>;
        /**
         * The path of the logs to be monitored.
         */
        logPath?: pulumi.Input<string>;
        /**
         * The log type decides the log patterns against which Application Insights analyzes the log.
         */
        logType: pulumi.Input<string>;
        /**
         * The name of the log pattern set.
         */
        patternSet?: pulumi.Input<string>;
    }
    /**
     * The log pattern.
     */
    interface ApplicationLogPatternArgs {
        /**
         * The log pattern.
         */
        pattern: pulumi.Input<string>;
        /**
         * The name of the log pattern.
         */
        patternName: pulumi.Input<string>;
        /**
         * Rank of the log pattern.
         */
        rank: pulumi.Input<number>;
    }
    /**
     * The log pattern set.
     */
    interface ApplicationLogPatternSetArgs {
        /**
         * The log patterns of a set.
         */
        logPatterns: pulumi.Input<pulumi.Input<inputs.applicationinsights.ApplicationLogPatternArgs>[]>;
        /**
         * The name of the log pattern set.
         */
        patternSetName: pulumi.Input<string>;
    }
    /**
     * The NetWeaver Prometheus Exporter Settings.
     */
    interface ApplicationNetWeaverPrometheusExporterArgs {
        /**
         * SAP instance numbers for ASCS, ERS, and App Servers.
         */
        instanceNumbers: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * Prometheus exporter port.
         */
        prometheusPort?: pulumi.Input<string>;
        /**
         * SAP NetWeaver SID.
         */
        sapsid: pulumi.Input<string>;
    }
    /**
     * A process to be monitored for the component.
     */
    interface ApplicationProcessArgs {
        /**
         * A list of metrics to monitor for the component.
         */
        alarmMetrics: pulumi.Input<pulumi.Input<inputs.applicationinsights.ApplicationAlarmMetricArgs>[]>;
        /**
         * The name of the process to be monitored for the component.
         */
        processName: pulumi.Input<string>;
    }
    /**
     * The SQL prometheus exporter settings.
     */
    interface ApplicationSqlServerPrometheusExporterArgs {
        /**
         * Prometheus exporter port.
         */
        prometheusPort: pulumi.Input<string>;
        /**
         * Secret name which managers SQL exporter connection. e.g. {"data_source_name": "sqlserver://<USERNAME>:<PASSWORD>@localhost:1433"}
         */
        sqlSecretName: pulumi.Input<string>;
    }
    /**
     * The configuration settings of sub components.
     */
    interface ApplicationSubComponentConfigurationDetailsArgs {
        /**
         * A list of metrics to monitor for the component.
         */
        alarmMetrics?: pulumi.Input<pulumi.Input<inputs.applicationinsights.ApplicationAlarmMetricArgs>[]>;
        /**
         * A list of logs to monitor for the component.
         */
        logs?: pulumi.Input<pulumi.Input<inputs.applicationinsights.ApplicationLogArgs>[]>;
        /**
         * A list of processes to monitor for the component. Only Windows EC2 instances can have a processes section.
         */
        processes?: pulumi.Input<pulumi.Input<inputs.applicationinsights.ApplicationProcessArgs>[]>;
        /**
         * A list of Windows Events to log.
         */
        windowsEvents?: pulumi.Input<pulumi.Input<inputs.applicationinsights.ApplicationWindowsEventArgs>[]>;
    }
    /**
     * One type sub component configurations for the component.
     */
    interface ApplicationSubComponentTypeConfigurationArgs {
        /**
         * The configuration settings of sub components.
         */
        subComponentConfigurationDetails: pulumi.Input<inputs.applicationinsights.ApplicationSubComponentConfigurationDetailsArgs>;
        /**
         * The sub component type.
         */
        subComponentType: pulumi.Input<enums.applicationinsights.ApplicationSubComponentTypeConfigurationSubComponentType>;
    }
    /**
     * A Windows Event to be monitored for the component.
     */
    interface ApplicationWindowsEventArgs {
        /**
         * The levels of event to log.
         */
        eventLevels: pulumi.Input<pulumi.Input<enums.applicationinsights.ApplicationEventLevel>[]>;
        /**
         * The type of Windows Events to log.
         */
        eventName: pulumi.Input<string>;
        /**
         * The CloudWatch log group name to be associated to the monitored log.
         */
        logGroupName: pulumi.Input<string>;
        /**
         * The name of the log pattern set.
         */
        patternSet?: pulumi.Input<string>;
    }
}
export declare namespace applicationsignals {
    /**
     * This object defines the length of the look-back window used to calculate one burn rate metric for this SLO. The burn rate measures how fast the service is consuming the error budget, relative to the attainment goal of the SLO. A burn rate of exactly 1 indicates that the SLO goal will be met exactly.
     * For example, if you specify 60 as the number of minutes in the look-back window, the burn rate is calculated as the following:
     * burn rate = error rate over the look-back window / (1 - attainment goal percentage)
     */
    interface ServiceLevelObjectiveBurnRateConfigurationArgs {
        /**
         * The number of minutes to use as the look-back window.
         */
        lookBackWindowMinutes: pulumi.Input<number>;
    }
    /**
     * If the interval for this service level objective is a calendar interval, this structure contains the interval specifications.
     */
    interface ServiceLevelObjectiveCalendarIntervalArgs {
        /**
         * Specifies the duration of each calendar interval. For example, if `Duration` is `1` and `DurationUnit` is `MONTH` , each interval is one month, aligned with the calendar.
         */
        duration: pulumi.Input<number>;
        /**
         * Specifies the calendar interval unit.
         */
        durationUnit: pulumi.Input<enums.applicationsignals.ServiceLevelObjectiveDurationUnit>;
        /**
         * Epoch time in seconds you want the first interval to start. Be sure to choose a time that configures the intervals the way that you want. For example, if you want weekly intervals starting on Mondays at 6 a.m., be sure to specify a start time that is a Monday at 6 a.m.
         * As soon as one calendar interval ends, another automatically begins.
         */
        startTime: pulumi.Input<number>;
    }
    /**
     * Configuration for identifying a dependency and its operation
     */
    interface ServiceLevelObjectiveDependencyConfigArgs {
        /**
         * If this SLO is related to a metric collected by Application Signals, you must use this field to specify which dependency the SLO metric is related to.
         *
         * - `Type` designates the type of object this is.
         * - `ResourceType` specifies the type of the resource. This field is used only when the value of the `Type` field is `Resource` or `AWS::Resource` .
         * - `Name` specifies the name of the object. This is used only if the value of the `Type` field is `Service` , `RemoteService` , or `AWS::Service` .
         * - `Identifier` identifies the resource objects of this resource. This is used only if the value of the `Type` field is `Resource` or `AWS::Resource` .
         * - `Environment` specifies the location where this object is hosted, or what it belongs to.
         */
        dependencyKeyAttributes: pulumi.Input<{
            [key: string]: pulumi.Input<string>;
        }>;
        /**
         * When the SLO monitors a specific operation of the dependency, this field specifies the name of that operation in the dependency.
         */
        dependencyOperationName: pulumi.Input<string>;
    }
    /**
     * A dimension is a name/value pair that is part of the identity of a metric. Because dimensions are part of the unique identifier for a metric, whenever you add a unique name/value pair to one of your metrics, you are creating a new variation of that metric. For example, many Amazon EC2 metrics publish `InstanceId` as a dimension name, and the actual instance ID as the value for that dimension. You can assign up to 30 dimensions to a metric.
     */
    interface ServiceLevelObjectiveDimensionArgs {
        /**
         * The name of the dimension. Dimension names must contain only ASCII characters, must include at least one non-whitespace character, and cannot start with a colon (:). ASCII control characters are not supported as part of dimension names.
         */
        name: pulumi.Input<string>;
        /**
         * The value of the dimension. Dimension values must contain only ASCII characters and must include at least one non-whitespace character. ASCII control characters are not supported as part of dimension values
         */
        value: pulumi.Input<string>;
    }
    /**
     * This object defines a time exclusion window for this SLO. The time exclusion window is used to exclude breaching data points from affecting attainment rate, error budget, and burn rate metrics.
     */
    interface ServiceLevelObjectiveExclusionWindowArgs {
        /**
         * An optional reason for scheduling this time exclusion window. Default is 'No reason'.
         */
        reason?: pulumi.Input<string>;
        recurrenceRule?: pulumi.Input<inputs.applicationsignals.ServiceLevelObjectiveRecurrenceRuleArgs>;
        /**
         * The time you want the exclusion window to start at. Note that time exclusion windows can only be scheduled in the future, not the past.
         */
        startTime?: pulumi.Input<string>;
        window: pulumi.Input<inputs.applicationsignals.ServiceLevelObjectiveWindowArgs>;
    }
    /**
     * A structure that contains the attributes that determine the goal of the SLO. This includes the time period for evaluation and the attainment threshold.
     */
    interface ServiceLevelObjectiveGoalArgs {
        /**
         * The threshold that determines if the goal is being met. An attainment goal is the ratio of good periods that meet the threshold requirements to the total periods within the interval. For example, an attainment goal of 99.9% means that within your interval, you are targeting 99.9% of the periods to be in healthy state.
         * If you omit this parameter, 99 is used to represent 99% as the attainment goal.
         */
        attainmentGoal?: pulumi.Input<number>;
        /**
         * The time period used to evaluate the SLO. It can be either a calendar interval or rolling interval.
         *
         * If you omit this parameter, a rolling interval of 7 days is used.
         */
        interval?: pulumi.Input<inputs.applicationsignals.ServiceLevelObjectiveIntervalArgs>;
        /**
         * The percentage of remaining budget over total budget that you want to get warnings for. If you omit this parameter, the default of 50.0 is used.
         */
        warningThreshold?: pulumi.Input<number>;
    }
    /**
     * The time period used to evaluate the SLO. It can be either a calendar interval or rolling interval.
     * If you omit this parameter, a rolling interval of 7 days is used.
     */
    interface ServiceLevelObjectiveIntervalArgs {
        /**
         * If the interval is a calendar interval, this structure contains the interval specifications.
         */
        calendarInterval?: pulumi.Input<inputs.applicationsignals.ServiceLevelObjectiveCalendarIntervalArgs>;
        /**
         * If the interval is a rolling interval, this structure contains the interval specifications.
         */
        rollingInterval?: pulumi.Input<inputs.applicationsignals.ServiceLevelObjectiveRollingIntervalArgs>;
    }
    /**
     * This structure defines the metric used for a service level indicator, including the metric name, namespace, and dimensions.
     */
    interface ServiceLevelObjectiveMetricArgs {
        /**
         * An array of one or more dimensions to use to define the metric that you want to use.
         */
        dimensions?: pulumi.Input<pulumi.Input<inputs.applicationsignals.ServiceLevelObjectiveDimensionArgs>[]>;
        /**
         * The name of the metric to use.
         */
        metricName?: pulumi.Input<string>;
        /**
         * The namespace of the metric.
         */
        namespace?: pulumi.Input<string>;
    }
    /**
     * Use this structure to define a metric or metric math expression that you want to use as for a service level objective.
     * Each `MetricDataQuery` in the `MetricDataQueries` array specifies either a metric to retrieve, or a metric math expression to be performed on retrieved metrics. A single `MetricDataQueries` array can include as many as 20 `MetricDataQuery` structures in the array. The 20 structures can include as many as 10 structures that contain a `MetricStat` parameter to retrieve a metric, and as many as 10 structures that contain the `Expression` parameter to perform a math expression. Of those Expression structures, exactly one must have true as the value for `ReturnData`. The result of this expression used for the SLO.
     */
    interface ServiceLevelObjectiveMetricDataQueryArgs {
        /**
         * The ID of the account where the metrics are located, if this is a cross-account alarm.
         */
        accountId?: pulumi.Input<string>;
        /**
         * The math expression to be performed on the returned data.
         */
        expression?: pulumi.Input<string>;
        /**
         * A short name used to tie this object to the results in the response.
         */
        id: pulumi.Input<string>;
        /**
         * A metric to be used directly for the SLO, or to be used in the math expression that will be used for the SLO. Within one MetricDataQuery, you must specify either Expression or MetricStat but not both.
         */
        metricStat?: pulumi.Input<inputs.applicationsignals.ServiceLevelObjectiveMetricStatArgs>;
        /**
         * This option indicates whether to return the timestamps and raw data values of this metric.
         */
        returnData?: pulumi.Input<boolean>;
    }
    /**
     * A metric to be used directly for the SLO, or to be used in the math expression that will be used for the SLO. Within one MetricDataQuery object, you must specify either Expression or MetricStat but not both.
     */
    interface ServiceLevelObjectiveMetricStatArgs {
        metric: pulumi.Input<inputs.applicationsignals.ServiceLevelObjectiveMetricArgs>;
        /**
         * The granularity, in seconds, to be used for the metric.
         */
        period: pulumi.Input<number>;
        /**
         * The statistic to use for comparison to the threshold. It can be any CloudWatch statistic or extended statistic.
         */
        stat: pulumi.Input<string>;
        /**
         * If you omit Unit then all data that was collected with any unit is returned, along with the corresponding units that were specified when the data was reported to CloudWatch. If you specify a unit, the operation returns only data that was collected with that unit specified. If you specify a unit that does not match the data collected, the results of the operation are null. CloudWatch does not perform unit conversions.
         */
        unit?: pulumi.Input<string>;
    }
    /**
     * This structure defines the metric that is used as the "good request" or "bad request" value for a request-based SLO. This value observed for the metric defined in `TotalRequestCountMetric` is divided by the number found for `MonitoredRequestCountMetric` to determine the percentage of successful requests that this SLO tracks.
     */
    interface ServiceLevelObjectiveMonitoredRequestCountMetricArgs {
        /**
         * If you want to count "bad requests" to determine the percentage of successful requests for this request-based SLO, specify the metric to use as "bad requests" in this structure.
         */
        badCountMetric?: pulumi.Input<pulumi.Input<inputs.applicationsignals.ServiceLevelObjectiveMetricDataQueryArgs>[]>;
        /**
         * If you want to count "good requests" to determine the percentage of successful requests for this request-based SLO, specify the metric to use as "good requests" in this structure.
         */
        goodCountMetric?: pulumi.Input<pulumi.Input<inputs.applicationsignals.ServiceLevelObjectiveMetricDataQueryArgs>[]>;
    }
    /**
     * This object defines how often to repeat a time exclusion window.
     */
    interface ServiceLevelObjectiveRecurrenceRuleArgs {
        /**
         * A cron or rate expression denoting how often to repeat this exclusion window.
         */
        expression: pulumi.Input<string>;
    }
    /**
     * This structure contains information about the performance metric that a request-based SLO monitors.
     */
    interface ServiceLevelObjectiveRequestBasedSliArgs {
        /**
         * The arithmetic operation used when comparing the specified metric to the threshold.
         */
        comparisonOperator?: pulumi.Input<enums.applicationsignals.ServiceLevelObjectiveRequestBasedSliComparisonOperator>;
        /**
         * The value that the SLI metric is compared to.
         */
        metricThreshold?: pulumi.Input<number>;
        /**
         * A structure that contains information about the metric that the SLO monitors.
         */
        requestBasedSliMetric: pulumi.Input<inputs.applicationsignals.ServiceLevelObjectiveRequestBasedSliMetricArgs>;
    }
    /**
     * This structure contains the information about the metric that is used for a request-based SLO.
     */
    interface ServiceLevelObjectiveRequestBasedSliMetricArgs {
        /**
         * Identifies the dependency using the `DependencyKeyAttributes` and `DependencyOperationName` .
         */
        dependencyConfig?: pulumi.Input<inputs.applicationsignals.ServiceLevelObjectiveDependencyConfigArgs>;
        /**
         * This is a string-to-string map that contains information about the type of object that this SLO is related to. It can include the following fields.
         *
         * - `Type` designates the type of object that this SLO is related to.
         * - `ResourceType` specifies the type of the resource. This field is used only when the value of the `Type` field is `Resource` or `AWS::Resource` .
         * - `Name` specifies the name of the object. This is used only if the value of the `Type` field is `Service` , `RemoteService` , or `AWS::Service` .
         * - `Identifier` identifies the resource objects of this resource. This is used only if the value of the `Type` field is `Resource` or `AWS::Resource` .
         * - `Environment` specifies the location where this object is hosted, or what it belongs to.
         * - `AwsAccountId` allows you to create an SLO for an object that exists in another account.
         */
        keyAttributes?: pulumi.Input<{
            [key: string]: pulumi.Input<string>;
        }>;
        /**
         * If the SLO monitors either the LATENCY or AVAILABILITY metric that Application Signals collects, this field displays which of those metrics is used.
         */
        metricType?: pulumi.Input<enums.applicationsignals.ServiceLevelObjectiveRequestBasedSliMetricMetricType>;
        /**
         * Use this structure to define the metric that you want to use as the "good request" or "bad request" value for a request-based SLO. This value observed for the metric defined in `TotalRequestCountMetric` will be divided by the number found for `MonitoredRequestCountMetric` to determine the percentage of successful requests that this SLO tracks.
         */
        monitoredRequestCountMetric?: pulumi.Input<inputs.applicationsignals.ServiceLevelObjectiveMonitoredRequestCountMetricArgs>;
        /**
         * If the SLO monitors a specific operation of the service, this field displays that operation name.
         */
        operationName?: pulumi.Input<string>;
        /**
         * This structure defines the metric that is used as the "total requests" number for a request-based SLO. The number observed for this metric is divided by the number of "good requests" or "bad requests" that is observed for the metric defined in `MonitoredRequestCountMetric`.
         */
        totalRequestCountMetric?: pulumi.Input<pulumi.Input<inputs.applicationsignals.ServiceLevelObjectiveMetricDataQueryArgs>[]>;
    }
    /**
     * If the interval is a calendar interval, this structure contains the interval specifications.
     */
    interface ServiceLevelObjectiveRollingIntervalArgs {
        /**
         * Specifies the duration of each rolling interval. For example, if `Duration` is `7` and `DurationUnit` is `DAY` , each rolling interval is seven days.
         */
        duration: pulumi.Input<number>;
        /**
         * Specifies the rolling interval unit.
         */
        durationUnit: pulumi.Input<enums.applicationsignals.ServiceLevelObjectiveDurationUnit>;
    }
    /**
     * This structure contains information about the performance metric that an SLO monitors.
     */
    interface ServiceLevelObjectiveSliArgs {
        /**
         * The arithmetic operation used when comparing the specified metric to the threshold.
         */
        comparisonOperator: pulumi.Input<enums.applicationsignals.ServiceLevelObjectiveSliComparisonOperator>;
        /**
         * The value that the SLI metric is compared to.
         */
        metricThreshold: pulumi.Input<number>;
        /**
         * Use this structure to specify the metric to be used for the SLO.
         */
        sliMetric: pulumi.Input<inputs.applicationsignals.ServiceLevelObjectiveSliMetricArgs>;
    }
    /**
     * A structure that contains information about the metric that the SLO monitors.
     */
    interface ServiceLevelObjectiveSliMetricArgs {
        /**
         * Identifies the dependency using the `DependencyKeyAttributes` and `DependencyOperationName` .
         */
        dependencyConfig?: pulumi.Input<inputs.applicationsignals.ServiceLevelObjectiveDependencyConfigArgs>;
        /**
         * If this SLO is related to a metric collected by Application Signals, you must use this field to specify which service the SLO metric is related to. To do so, you must specify at least the `Type` , `Name` , and `Environment` attributes.
         *
         * This is a string-to-string map. It can include the following fields.
         *
         * - `Type` designates the type of object this is.
         * - `ResourceType` specifies the type of the resource. This field is used only when the value of the `Type` field is `Resource` or `AWS::Resource` .
         * - `Name` specifies the name of the object. This is used only if the value of the `Type` field is `Service` , `RemoteService` , or `AWS::Service` .
         * - `Identifier` identifies the resource objects of this resource. This is used only if the value of the `Type` field is `Resource` or `AWS::Resource` .
         * - `Environment` specifies the location where this object is hosted, or what it belongs to.
         */
        keyAttributes?: pulumi.Input<{
            [key: string]: pulumi.Input<string>;
        }>;
        /**
         * If this SLO monitors a CloudWatch metric or the result of a CloudWatch metric math expression, use this structure to specify that metric or expression.
         */
        metricDataQueries?: pulumi.Input<pulumi.Input<inputs.applicationsignals.ServiceLevelObjectiveMetricDataQueryArgs>[]>;
        /**
         * If the SLO monitors either the LATENCY or AVAILABILITY metric that Application Signals collects, this field displays which of those metrics is used.
         */
        metricType?: pulumi.Input<enums.applicationsignals.ServiceLevelObjectiveSliMetricMetricType>;
        /**
         * If the SLO monitors a specific operation of the service, this field displays that operation name.
         */
        operationName?: pulumi.Input<string>;
        /**
         * The number of seconds to use as the period for SLO evaluation. Your application's performance is compared to the SLI during each period. For each period, the application is determined to have either achieved or not achieved the necessary performance.
         */
        periodSeconds?: pulumi.Input<number>;
        /**
         * The statistic to use for comparison to the threshold. It can be any CloudWatch statistic or extended statistic
         */
        statistic?: pulumi.Input<string>;
    }
    /**
     * This object defines the length of time an exclusion window should span.
     */
    interface ServiceLevelObjectiveWindowArgs {
        duration: pulumi.Input<number>;
        durationUnit: pulumi.Input<enums.applicationsignals.ServiceLevelObjectiveDurationUnit>;
    }
}
export declare namespace apprunner {
    /**
     * Describes the configuration of the tracing feature within an AWS App Runner observability configuration.
     */
    interface ObservabilityConfigurationTraceConfigurationArgs {
        /**
         * The implementation provider chosen for tracing App Runner services.
         */
        vendor: pulumi.Input<enums.apprunner.ObservabilityConfigurationTraceConfigurationVendor>;
    }
    /**
     * Authentication Configuration
     */
    interface ServiceAuthenticationConfigurationArgs {
        /**
         * Access Role Arn
         */
        accessRoleArn?: pulumi.Input<string>;
        /**
         * Connection Arn
         */
        connectionArn?: pulumi.Input<string>;
    }
    /**
     * Code Configuration
     */
    interface ServiceCodeConfigurationArgs {
        /**
         * The basic configuration for building and running the App Runner service. Use it to quickly launch an App Runner service without providing a `apprunner.yaml` file in the source code repository (or ignoring the file if it exists).
         */
        codeConfigurationValues?: pulumi.Input<inputs.apprunner.ServiceCodeConfigurationValuesArgs>;
        /**
         * Configuration Source
         */
        configurationSource: pulumi.Input<enums.apprunner.ServiceCodeConfigurationConfigurationSource>;
    }
    /**
     * Code Configuration Values
     */
    interface ServiceCodeConfigurationValuesArgs {
        /**
         * Build Command
         */
        buildCommand?: pulumi.Input<string>;
        /**
         * Port
         */
        port?: pulumi.Input<string>;
        /**
         * Runtime
         */
        runtime: pulumi.Input<enums.apprunner.ServiceCodeConfigurationValuesRuntime>;
        /**
         * The secrets and parameters that get referenced by your service as environment variables
         */
        runtimeEnvironmentSecrets?: pulumi.Input<pulumi.Input<inputs.apprunner.ServiceKeyValuePairArgs>[]>;
        /**
         * The environment variables that are available to your running AWS App Runner service. An array of key-value pairs.
         */
        runtimeEnvironmentVariables?: pulumi.Input<pulumi.Input<inputs.apprunner.ServiceKeyValuePairArgs>[]>;
        /**
         * Start Command
         */
        startCommand?: pulumi.Input<string>;
    }
    /**
     * Source Code Repository
     */
    interface ServiceCodeRepositoryArgs {
        /**
         * Configuration for building and running the service from a source code repository.
         *
         * > `CodeConfiguration` is required only for `CreateService` request.
         */
        codeConfiguration?: pulumi.Input<inputs.apprunner.ServiceCodeConfigurationArgs>;
        /**
         * Repository Url
         */
        repositoryUrl: pulumi.Input<string>;
        /**
         * The version that should be used within the source code repository.
         */
        sourceCodeVersion: pulumi.Input<inputs.apprunner.ServiceSourceCodeVersionArgs>;
        /**
         * Source Directory
         */
        sourceDirectory?: pulumi.Input<string>;
    }
    /**
     * Network egress configuration
     */
    interface ServiceEgressConfigurationArgs {
        /**
         * Network egress type.
         */
        egressType: pulumi.Input<enums.apprunner.ServiceEgressConfigurationEgressType>;
        /**
         * The Amazon Resource Name (ARN) of the App Runner VpcConnector.
         */
        vpcConnectorArn?: pulumi.Input<string>;
    }
    /**
     * Encryption configuration (KMS key)
     */
    interface ServiceEncryptionConfigurationArgs {
        /**
         * The KMS Key
         */
        kmsKey: pulumi.Input<string>;
    }
    /**
     * Health check configuration
     */
    interface ServiceHealthCheckConfigurationArgs {
        /**
         * Health check Healthy Threshold
         */
        healthyThreshold?: pulumi.Input<number>;
        /**
         * Health check Interval
         */
        interval?: pulumi.Input<number>;
        /**
         * Health check Path
         */
        path?: pulumi.Input<string>;
        /**
         * Health Check Protocol
         */
        protocol?: pulumi.Input<enums.apprunner.ServiceHealthCheckConfigurationProtocol>;
        /**
         * Health check Timeout
         */
        timeout?: pulumi.Input<number>;
        /**
         * Health check Unhealthy Threshold
         */
        unhealthyThreshold?: pulumi.Input<number>;
    }
    /**
     * Image Configuration
     */
    interface ServiceImageConfigurationArgs {
        /**
         * Port
         */
        port?: pulumi.Input<string>;
        /**
         * The secrets and parameters that get referenced by your service as environment variables
         */
        runtimeEnvironmentSecrets?: pulumi.Input<pulumi.Input<inputs.apprunner.ServiceKeyValuePairArgs>[]>;
        /**
         * Environment variables that are available to your running App Runner service. An array of key-value pairs.
         */
        runtimeEnvironmentVariables?: pulumi.Input<pulumi.Input<inputs.apprunner.ServiceKeyValuePairArgs>[]>;
        /**
         * Start Command
         */
        startCommand?: pulumi.Input<string>;
    }
    /**
     * Image Repository
     */
    interface ServiceImageRepositoryArgs {
        /**
         * Configuration for running the identified image.
         */
        imageConfiguration?: pulumi.Input<inputs.apprunner.ServiceImageConfigurationArgs>;
        /**
         * Image Identifier
         */
        imageIdentifier: pulumi.Input<string>;
        /**
         * Image Repository Type
         */
        imageRepositoryType: pulumi.Input<enums.apprunner.ServiceImageRepositoryImageRepositoryType>;
    }
    /**
     * Network ingress configuration
     */
    interface ServiceIngressConfigurationArgs {
        /**
         * It's set to true if the Apprunner service is publicly accessible. It's set to false otherwise.
         */
        isPubliclyAccessible: pulumi.Input<boolean>;
    }
    /**
     * Instance Configuration
     */
    interface ServiceInstanceConfigurationArgs {
        /**
         * CPU
         */
        cpu?: pulumi.Input<string>;
        /**
         * Instance Role Arn
         */
        instanceRoleArn?: pulumi.Input<string>;
        /**
         * Memory
         */
        memory?: pulumi.Input<string>;
    }
    interface ServiceKeyValuePairArgs {
        /**
         * The key name string to map to a value.
         */
        name?: pulumi.Input<string>;
        /**
         * The value string to which the key name is mapped.
         */
        value?: pulumi.Input<string>;
    }
    /**
     * Network configuration
     */
    interface ServiceNetworkConfigurationArgs {
        /**
         * Network configuration settings for outbound message traffic.
         */
        egressConfiguration?: pulumi.Input<inputs.apprunner.ServiceEgressConfigurationArgs>;
        /**
         * Network configuration settings for inbound message traffic.
         */
        ingressConfiguration?: pulumi.Input<inputs.apprunner.ServiceIngressConfigurationArgs>;
        /**
         * App Runner service endpoint IP address type
         */
        ipAddressType?: pulumi.Input<enums.apprunner.ServiceNetworkConfigurationIpAddressType>;
    }
    /**
     * Service observability configuration
     */
    interface ServiceObservabilityConfigurationArgs {
        /**
         * The Amazon Resource Name (ARN) of the App Runner ObservabilityConfiguration.
         */
        observabilityConfigurationArn?: pulumi.Input<string>;
        /**
         * Observability enabled
         */
        observabilityEnabled: pulumi.Input<boolean>;
    }
    /**
     * Source Code Version
     */
    interface ServiceSourceCodeVersionArgs {
        /**
         * Source Code Version Type
         */
        type: pulumi.Input<enums.apprunner.ServiceSourceCodeVersionType>;
        /**
         * Source Code Version Value
         */
        value: pulumi.Input<string>;
    }
    /**
     * Source Code configuration
     */
    interface ServiceSourceConfigurationArgs {
        /**
         * Describes the resources that are needed to authenticate access to some source repositories.
         */
        authenticationConfiguration?: pulumi.Input<inputs.apprunner.ServiceAuthenticationConfigurationArgs>;
        /**
         * Auto Deployment enabled
         */
        autoDeploymentsEnabled?: pulumi.Input<boolean>;
        /**
         * The description of a source code repository.
         *
         * You must provide either this member or `ImageRepository` (but not both).
         */
        codeRepository?: pulumi.Input<inputs.apprunner.ServiceCodeRepositoryArgs>;
        /**
         * The description of a source image repository.
         *
         * You must provide either this member or `CodeRepository` (but not both).
         */
        imageRepository?: pulumi.Input<inputs.apprunner.ServiceImageRepositoryArgs>;
    }
    /**
     * The configuration of customer’s VPC and related VPC endpoint
     */
    interface VpcIngressConnectionIngressVpcConfigurationArgs {
        /**
         * The ID of the VPC endpoint that your App Runner service connects to.
         */
        vpcEndpointId: pulumi.Input<string>;
        /**
         * The ID of the VPC that the VPC endpoint is used in.
         */
        vpcId: pulumi.Input<string>;
    }
}
export declare namespace appstream {
    interface AppBlockBuilderAccessEndpointArgs {
        /**
         * The type of interface endpoint.
         */
        endpointType: pulumi.Input<string>;
        /**
         * The identifier (ID) of the VPC in which the interface endpoint is used.
         */
        vpceId: pulumi.Input<string>;
    }
    interface AppBlockBuilderVpcConfigArgs {
        /**
         * The identifiers of the security groups for the fleet or image builder.
         */
        securityGroupIds?: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * The identifiers of the subnets to which a network interface is attached from the fleet instance or image builder instance. Fleet instances use one or more subnets. Image builder instances use one subnet.
         */
        subnetIds?: pulumi.Input<pulumi.Input<string>[]>;
    }
    interface AppBlockS3LocationArgs {
        /**
         * The S3 bucket of the app block.
         */
        s3Bucket: pulumi.Input<string>;
        /**
         * The S3 key of the S3 object of the virtual hard disk.
         *
         * This is required when it's used by `SetupScriptDetails` and `PostSetupScriptDetails` .
         */
        s3Key?: pulumi.Input<string>;
    }
    interface AppBlockScriptDetailsArgs {
        /**
         * The parameters used in the run path for the script.
         */
        executableParameters?: pulumi.Input<string>;
        /**
         * The run path for the script.
         */
        executablePath: pulumi.Input<string>;
        /**
         * The S3 object location of the script.
         */
        scriptS3Location: pulumi.Input<inputs.appstream.AppBlockS3LocationArgs>;
        /**
         * The run timeout, in seconds, for the script.
         */
        timeoutInSeconds: pulumi.Input<number>;
    }
    interface AppBlockTag0PropertiesArgs {
        key: pulumi.Input<string>;
        value: pulumi.Input<string>;
    }
    interface AppBlockTag1PropertiesArgs {
        tagKey: pulumi.Input<string>;
        tagValue: pulumi.Input<string>;
    }
    interface ApplicationS3LocationArgs {
        /**
         * The S3 bucket of the S3 object.
         */
        s3Bucket: pulumi.Input<string>;
        /**
         * The S3 key of the S3 object.
         */
        s3Key: pulumi.Input<string>;
    }
    interface ApplicationTag0PropertiesArgs {
        key: pulumi.Input<string>;
        value: pulumi.Input<string>;
    }
    interface ApplicationTag1PropertiesArgs {
        tagKey: pulumi.Input<string>;
        tagValue: pulumi.Input<string>;
    }
    interface DirectoryConfigCertificateBasedAuthPropertiesArgs {
        /**
         * The ARN of the AWS Certificate Manager Private CA resource.
         */
        certificateAuthorityArn?: pulumi.Input<string>;
        /**
         * The status of the certificate-based authentication properties. Fallback is turned on by default when certificate-based authentication is *Enabled* . Fallback allows users to log in using their AD domain password if certificate-based authentication is unsuccessful, or to unlock a desktop lock screen. *Enabled_no_directory_login_fallback* enables certificate-based authentication, but does not allow users to log in using their AD domain password. Users will be disconnected to re-authenticate using certificates.
         */
        status?: pulumi.Input<string>;
    }
    interface DirectoryConfigServiceAccountCredentialsArgs {
        /**
         * The user name of the account. This account must have the following privileges: create computer objects, join computers to the domain, and change/reset the password on descendant computer objects for the organizational units specified.
         */
        accountName: pulumi.Input<string>;
        /**
         * The password for the account.
         */
        accountPassword: pulumi.Input<string>;
    }
    interface EntitlementAttributeArgs {
        /**
         * A supported AWS IAM SAML PrincipalTag attribute that is matched to a value when a user identity federates to an AppStream 2.0 SAML application.
         *
         * The following are supported values:
         *
         * - roles
         * - department
         * - organization
         * - groups
         * - title
         * - costCenter
         * - userType
         */
        name: pulumi.Input<string>;
        /**
         * A value that is matched to a supported SAML attribute name when a user identity federates to an AppStream 2.0 SAML application.
         */
        value: pulumi.Input<string>;
    }
    interface ImageBuilderAccessEndpointArgs {
        /**
         * The type of interface endpoint.
         */
        endpointType: pulumi.Input<string>;
        /**
         * The identifier (ID) of the VPC in which the interface endpoint is used.
         */
        vpceId: pulumi.Input<string>;
    }
    interface ImageBuilderDomainJoinInfoArgs {
        /**
         * The fully qualified name of the directory (for example, corp.example.com).
         */
        directoryName?: pulumi.Input<string>;
        /**
         * The distinguished name of the organizational unit for computer accounts.
         */
        organizationalUnitDistinguishedName?: pulumi.Input<string>;
    }
    interface ImageBuilderVpcConfigArgs {
        /**
         * The identifiers of the security groups for the image builder.
         */
        securityGroupIds?: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * The identifier of the subnet to which a network interface is attached from the image builder instance. An image builder instance can use one subnet.
         */
        subnetIds?: pulumi.Input<pulumi.Input<string>[]>;
    }
}
export declare namespace appsync {
    /**
     * An auth mode.
     */
    interface ApiAuthModeArgs {
        authType?: pulumi.Input<enums.appsync.ApiAuthenticationType>;
    }
    /**
     * An auth provider for the AppSync API.
     */
    interface ApiAuthProviderArgs {
        authType: pulumi.Input<enums.appsync.ApiAuthenticationType>;
        cognitoConfig?: pulumi.Input<inputs.appsync.ApiCognitoConfigArgs>;
        lambdaAuthorizerConfig?: pulumi.Input<inputs.appsync.ApiLambdaAuthorizerConfigArgs>;
        openIdConnectConfig?: pulumi.Input<inputs.appsync.ApiOpenIdConnectConfigArgs>;
    }
    /**
     * Optional authorization configuration for using Amazon Cognito user pools with your API endpoint.
     */
    interface ApiCognitoConfigArgs {
        appIdClientRegex?: pulumi.Input<string>;
        awsRegion: pulumi.Input<string>;
        userPoolId: pulumi.Input<string>;
    }
    /**
     * The configuration for an Event Api
     */
    interface ApiEventConfigArgs {
        /**
         * A list of authorization providers.
         */
        authProviders: pulumi.Input<pulumi.Input<inputs.appsync.ApiAuthProviderArgs>[]>;
        /**
         * A list of valid authorization modes for the Event API connections.
         */
        connectionAuthModes: pulumi.Input<pulumi.Input<inputs.appsync.ApiAuthModeArgs>[]>;
        /**
         * A list of valid authorization modes for the Event API publishing.
         */
        defaultPublishAuthModes: pulumi.Input<pulumi.Input<inputs.appsync.ApiAuthModeArgs>[]>;
        /**
         * A list of valid authorization modes for the Event API subscriptions.
         */
        defaultSubscribeAuthModes: pulumi.Input<pulumi.Input<inputs.appsync.ApiAuthModeArgs>[]>;
        /**
         * The CloudWatch Logs configuration for the Event API.
         */
        logConfig?: pulumi.Input<inputs.appsync.ApiEventLogConfigArgs>;
    }
    /**
     * The log config for the AppSync API.
     */
    interface ApiEventLogConfigArgs {
        /**
         * The IAM service role that AWS AppSync assumes to publish CloudWatch Logs in your account.
         */
        cloudWatchLogsRoleArn: pulumi.Input<string>;
        /**
         * The type of information to log for the Event API.
         */
        logLevel: pulumi.Input<enums.appsync.ApiEventLogLevel>;
    }
    /**
     * A LambdaAuthorizerConfig holds configuration on how to authorize AWS AppSync API access when using the AWS_LAMBDA authorizer mode. Be aware that an AWS AppSync API may have only one Lambda authorizer configured at a time.
     */
    interface ApiLambdaAuthorizerConfigArgs {
        authorizerResultTtlInSeconds?: pulumi.Input<number>;
        authorizerUri: pulumi.Input<string>;
        identityValidationExpression?: pulumi.Input<string>;
    }
    /**
     * The OpenID Connect configuration.
     */
    interface ApiOpenIdConnectConfigArgs {
        authTtl?: pulumi.Input<number>;
        clientId?: pulumi.Input<string>;
        iatTtl?: pulumi.Input<number>;
        issuer: pulumi.Input<string>;
    }
    /**
     * An auth mode.
     */
    interface ChannelNamespaceAuthModeArgs {
        authType?: pulumi.Input<enums.appsync.ChannelNamespaceAuthenticationType>;
    }
    interface DataSourceAuthorizationConfigArgs {
        /**
         * The authorization type that the HTTP endpoint requires.
         */
        authorizationType: pulumi.Input<string>;
        /**
         * The AWS Identity and Access Management settings.
         */
        awsIamConfig?: pulumi.Input<inputs.appsync.DataSourceAwsIamConfigArgs>;
    }
    interface DataSourceAwsIamConfigArgs {
        /**
         * The signing Region for AWS Identity and Access Management authorization.
         */
        signingRegion?: pulumi.Input<string>;
        /**
         * The signing service name for AWS Identity and Access Management authorization.
         */
        signingServiceName?: pulumi.Input<string>;
    }
    interface DataSourceDeltaSyncConfigArgs {
        /**
         * The number of minutes that an Item is stored in the data source.
         */
        baseTableTtl: pulumi.Input<string>;
        /**
         * The Delta Sync table name.
         */
        deltaSyncTableName: pulumi.Input<string>;
        /**
         * The number of minutes that a Delta Sync log entry is stored in the Delta Sync table.
         */
        deltaSyncTableTtl: pulumi.Input<string>;
    }
    interface DataSourceDynamoDbConfigArgs {
        /**
         * The AWS Region.
         */
        awsRegion: pulumi.Input<string>;
        /**
         * The DeltaSyncConfig for a versioned datasource.
         */
        deltaSyncConfig?: pulumi.Input<inputs.appsync.DataSourceDeltaSyncConfigArgs>;
        /**
         * The table name.
         */
        tableName: pulumi.Input<string>;
        /**
         * Set to TRUE to use AWS Identity and Access Management with this data source.
         */
        useCallerCredentials?: pulumi.Input<boolean>;
        /**
         * Set to TRUE to use Conflict Detection and Resolution with this data source.
         */
        versioned?: pulumi.Input<boolean>;
    }
    interface DataSourceElasticsearchConfigArgs {
        /**
         * The AWS Region.
         */
        awsRegion: pulumi.Input<string>;
        /**
         * The endpoint.
         */
        endpoint: pulumi.Input<string>;
    }
    interface DataSourceEventBridgeConfigArgs {
        /**
         * ARN for the EventBridge bus.
         */
        eventBusArn: pulumi.Input<string>;
    }
    interface DataSourceHttpConfigArgs {
        /**
         * The authorization configuration.
         */
        authorizationConfig?: pulumi.Input<inputs.appsync.DataSourceAuthorizationConfigArgs>;
        /**
         * The endpoint.
         */
        endpoint: pulumi.Input<string>;
    }
    interface DataSourceLambdaConfigArgs {
        /**
         * The ARN for the Lambda function.
         */
        lambdaFunctionArn: pulumi.Input<string>;
    }
    interface DataSourceOpenSearchServiceConfigArgs {
        /**
         * The AWS Region.
         */
        awsRegion: pulumi.Input<string>;
        /**
         * The endpoint.
         */
        endpoint: pulumi.Input<string>;
    }
    interface DataSourceRdsHttpEndpointConfigArgs {
        /**
         * AWS Region for RDS HTTP endpoint.
         */
        awsRegion: pulumi.Input<string>;
        /**
         * The ARN for database credentials stored in AWS Secrets Manager.
         */
        awsSecretStoreArn: pulumi.Input<string>;
        /**
         * Logical database name.
         */
        databaseName?: pulumi.Input<string>;
        /**
         * Amazon RDS cluster Amazon Resource Name (ARN).
         */
        dbClusterIdentifier: pulumi.Input<string>;
        /**
         * Logical schema name.
         */
        schema?: pulumi.Input<string>;
    }
    interface DataSourceRelationalDatabaseConfigArgs {
        /**
         * Information about the Amazon RDS resource.
         */
        rdsHttpEndpointConfig?: pulumi.Input<inputs.appsync.DataSourceRdsHttpEndpointConfigArgs>;
        /**
         * The type of relational data source.
         */
        relationalDatabaseSourceType: pulumi.Input<string>;
    }
    /**
     * Describes a runtime used by an AWS AppSync pipeline resolver or AWS AppSync function. Specifies the name and version of the runtime to use. Note that if a runtime is specified, code must also be specified.
     */
    interface FunctionConfigurationAppSyncRuntimeArgs {
        /**
         * The name of the runtime to use. Currently, the only allowed value is APPSYNC_JS.
         */
        name: pulumi.Input<string>;
        /**
         * The version of the runtime to use. Currently, the only allowed version is 1.0.0.
         */
        runtimeVersion: pulumi.Input<string>;
    }
    /**
     * The LambdaConflictHandlerConfig when configuring LAMBDA as the Conflict Handler.
     */
    interface FunctionConfigurationLambdaConflictHandlerConfigArgs {
        /**
         * The Amazon Resource Name (ARN) for the Lambda function to use as the Conflict Handler.
         */
        lambdaConflictHandlerArn?: pulumi.Input<string>;
    }
    /**
     * Describes a Sync configuration for a resolver. Specifies which Conflict Detection strategy and Resolution strategy to use when the resolver is invoked.
     */
    interface FunctionConfigurationSyncConfigArgs {
        /**
         * The Conflict Detection strategy to use.
         */
        conflictDetection: pulumi.Input<string>;
        /**
         * The Conflict Resolution strategy to perform in the event of a conflict.
         */
        conflictHandler?: pulumi.Input<string>;
        /**
         * The `LambdaConflictHandlerConfig` when configuring `LAMBDA` as the Conflict Handler.
         */
        lambdaConflictHandlerConfig?: pulumi.Input<inputs.appsync.FunctionConfigurationLambdaConflictHandlerConfigArgs>;
    }
    interface GraphQlApiAdditionalAuthenticationProviderArgs {
        /**
         * The authentication type for API key, AWS Identity and Access Management, OIDC, Amazon Cognito user pools, or AWS Lambda.
         */
        authenticationType: pulumi.Input<string>;
        /**
         * Configuration for AWS Lambda function authorization.
         */
        lambdaAuthorizerConfig?: pulumi.Input<inputs.appsync.GraphQlApiLambdaAuthorizerConfigArgs>;
        /**
         * The OIDC configuration.
         */
        openIdConnectConfig?: pulumi.Input<inputs.appsync.GraphQlApiOpenIdConnectConfigArgs>;
        /**
         * The Amazon Cognito user pool configuration.
         */
        userPoolConfig?: pulumi.Input<inputs.appsync.GraphQlApiCognitoUserPoolConfigArgs>;
    }
    interface GraphQlApiCognitoUserPoolConfigArgs {
        /**
         * A regular expression for validating the incoming Amazon Cognito user pool app client ID.
         */
        appIdClientRegex?: pulumi.Input<string>;
        /**
         * The AWS Region in which the user pool was created.
         */
        awsRegion?: pulumi.Input<string>;
        /**
         * The user pool ID
         */
        userPoolId?: pulumi.Input<string>;
    }
    interface GraphQlApiEnhancedMetricsConfigArgs {
        /**
         * Controls how data source metrics will be emitted to CloudWatch. Data source metrics include:
         */
        dataSourceLevelMetricsBehavior: pulumi.Input<string>;
        /**
         * Controls how operation metrics will be emitted to CloudWatch. Operation metrics include:
         */
        operationLevelMetricsConfig: pulumi.Input<string>;
        /**
         * Controls how resolver metrics will be emitted to CloudWatch. Resolver metrics include:
         */
        resolverLevelMetricsBehavior: pulumi.Input<string>;
    }
    interface GraphQlApiLambdaAuthorizerConfigArgs {
        /**
         * The number of seconds a response should be cached for.
         */
        authorizerResultTtlInSeconds?: pulumi.Input<number>;
        /**
         * The ARN of the Lambda function to be called for authorization.
         */
        authorizerUri?: pulumi.Input<string>;
        /**
         * A regular expression for validation of tokens before the Lambda function is called.
         */
        identityValidationExpression?: pulumi.Input<string>;
    }
    interface GraphQlApiLogConfigArgs {
        /**
         * The service role that AWS AppSync will assume to publish to Amazon CloudWatch Logs in your account.
         */
        cloudWatchLogsRoleArn?: pulumi.Input<string>;
        /**
         * Set to TRUE to exclude sections that contain information such as headers, context, and evaluated mapping templates, regardless of logging level.
         */
        excludeVerboseContent?: pulumi.Input<boolean>;
        /**
         * The field logging level. Values can be NONE, ERROR, INFO, DEBUG, or ALL.
         */
        fieldLogLevel?: pulumi.Input<string>;
    }
    interface GraphQlApiOpenIdConnectConfigArgs {
        /**
         * The number of milliseconds that a token is valid after being authenticated.
         */
        authTtl?: pulumi.Input<number>;
        /**
         * The client identifier of the Relying party at the OpenID identity provider.
         */
        clientId?: pulumi.Input<string>;
        /**
         * The number of milliseconds that a token is valid after it's issued to a user.
         */
        iatTtl?: pulumi.Input<number>;
        /**
         * The issuer for the OIDC configuration.
         */
        issuer?: pulumi.Input<string>;
    }
    interface GraphQlApiUserPoolConfigArgs {
        /**
         * A regular expression for validating the incoming Amazon Cognito user pool app client ID.
         */
        appIdClientRegex?: pulumi.Input<string>;
        /**
         * The AWS Region in which the user pool was created.
         */
        awsRegion?: pulumi.Input<string>;
        /**
         * The action that you want your GraphQL API to take when a request that uses Amazon Cognito user pool authentication doesn't match the Amazon Cognito user pool configuration.
         */
        defaultAction?: pulumi.Input<string>;
        /**
         * The user pool ID.
         */
        userPoolId?: pulumi.Input<string>;
    }
    /**
     * Describes a runtime used by an APSYlong resolver or APSYlong function. Specifies the name and version of the runtime to use. Note that if a runtime is specified, code must also be specified.
     */
    interface ResolverAppSyncRuntimeArgs {
        /**
         * The ``name`` of the runtime to use. Currently, the only allowed value is ``APPSYNC_JS``.
         */
        name: pulumi.Input<string>;
        /**
         * The ``version`` of the runtime to use. Currently, the only allowed version is ``1.0.0``.
         */
        runtimeVersion: pulumi.Input<string>;
    }
    /**
     * The caching configuration for a resolver that has caching activated.
     */
    interface ResolverCachingConfigArgs {
        /**
         * The caching keys for a resolver that has caching activated.
         *  Valid values are entries from the ``$context.arguments``, ``$context.source``, and ``$context.identity`` maps.
         */
        cachingKeys?: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * The TTL in seconds for a resolver that has caching activated.
         *  Valid values are 1–3,600 seconds.
         */
        ttl: pulumi.Input<number>;
    }
    /**
     * The ``LambdaConflictHandlerConfig`` when configuring LAMBDA as the Conflict Handler.
     */
    interface ResolverLambdaConflictHandlerConfigArgs {
        /**
         * The Amazon Resource Name (ARN) for the Lambda function to use as the Conflict Handler.
         */
        lambdaConflictHandlerArn?: pulumi.Input<string>;
    }
    /**
     * Use the ``PipelineConfig`` property type to specify ``PipelineConfig`` for an APSYlong resolver.
     *   ``PipelineConfig`` is a property of the [AWS::AppSync::Resolver](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-appsync-resolver.html) resource.
     */
    interface ResolverPipelineConfigArgs {
        /**
         * A list of ``Function`` objects.
         */
        functions?: pulumi.Input<pulumi.Input<string>[]>;
    }
    /**
     * Describes a Sync configuration for a resolver.
     *  Specifies which Conflict Detection strategy and Resolution strategy to use when the resolver is invoked.
     */
    interface ResolverSyncConfigArgs {
        /**
         * The Conflict Detection strategy to use.
         *   +   *VERSION*: Detect conflicts based on object versions for this resolver.
         *   +   *NONE*: Do not detect conflicts when invoking this resolver.
         */
        conflictDetection: pulumi.Input<string>;
        /**
         * The Conflict Resolution strategy to perform in the event of a conflict.
         *   +   *OPTIMISTIC_CONCURRENCY*: Resolve conflicts by rejecting mutations when versions don't match the latest version at the server.
         *   +   *AUTOMERGE*: Resolve conflicts with the Automerge conflict resolution strategy.
         *   +   *LAMBDA*: Resolve conflicts with an LAMlong function supplied in the ``LambdaConflictHandlerConfig``.
         */
        conflictHandler?: pulumi.Input<string>;
        /**
         * The ``LambdaConflictHandlerConfig`` when configuring ``LAMBDA`` as the Conflict Handler.
         */
        lambdaConflictHandlerConfig?: pulumi.Input<inputs.appsync.ResolverLambdaConflictHandlerConfigArgs>;
    }
    interface SourceApiAssociationConfigArgs {
        /**
         * Configuration of the merged behavior for the association. For example when it could be auto or has to be manual.
         */
        mergeType?: pulumi.Input<enums.appsync.SourceApiAssociationConfigMergeType>;
    }
}
export declare namespace aps {
    /**
     * Scraper metrics destination
     */
    interface ScraperDestinationArgs {
        /**
         * Configuration for Amazon Managed Prometheus metrics destination
         */
        ampConfiguration?: pulumi.Input<inputs.aps.ScraperDestinationAmpConfigurationPropertiesArgs>;
    }
    /**
     * Configuration for Amazon Managed Prometheus metrics destination
     */
    interface ScraperDestinationAmpConfigurationPropertiesArgs {
        /**
         * ARN of an Amazon Managed Prometheus workspace
         */
        workspaceArn: pulumi.Input<string>;
    }
    /**
     * Role configuration
     */
    interface ScraperRoleConfigurationArgs {
        /**
         * IAM Role in source account
         */
        sourceRoleArn?: pulumi.Input<string>;
        /**
         * IAM Role in the target account
         */
        targetRoleArn?: pulumi.Input<string>;
    }
    /**
     * Scraper configuration
     */
    interface ScraperScrapeConfigurationArgs {
        /**
         * Prometheus compatible scrape configuration in base64 encoded blob format
         */
        configurationBlob?: pulumi.Input<string>;
    }
    /**
     * Scraper metrics source
     */
    interface ScraperSourceArgs {
        /**
         * Configuration for EKS metrics source
         */
        eksConfiguration?: pulumi.Input<inputs.aps.ScraperSourceEksConfigurationPropertiesArgs>;
    }
    /**
     * Configuration for EKS metrics source
     */
    interface ScraperSourceEksConfigurationPropertiesArgs {
        /**
         * ARN of an EKS cluster
         */
        clusterArn: pulumi.Input<string>;
        /**
         * List of security group IDs
         */
        securityGroupIds?: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * List of subnet IDs
         */
        subnetIds: pulumi.Input<pulumi.Input<string>[]>;
    }
    /**
     * Workspace configuration
     */
    interface WorkspaceConfigurationArgs {
        /**
         * An array of label set and associated limits
         */
        limitsPerLabelSets?: pulumi.Input<pulumi.Input<inputs.aps.WorkspaceLimitsPerLabelSetArgs>[]>;
        /**
         * How many days that metrics are retained in the workspace
         */
        retentionPeriodInDays?: pulumi.Input<number>;
    }
    /**
     * Series label
     */
    interface WorkspaceLabelArgs {
        /**
         * Name of the label
         */
        name: pulumi.Input<string>;
        /**
         * Value of the label
         */
        value: pulumi.Input<string>;
    }
    /**
     * Label set and its associated limits
     */
    interface WorkspaceLimitsPerLabelSetArgs {
        /**
         * An array of series labels
         */
        labelSet: pulumi.Input<pulumi.Input<inputs.aps.WorkspaceLabelArgs>[]>;
        limits: pulumi.Input<inputs.aps.WorkspaceLimitsPerLabelSetEntryArgs>;
    }
    /**
     * Limits that can be applied to a label set
     */
    interface WorkspaceLimitsPerLabelSetEntryArgs {
        /**
         * The maximum number of active series that can be ingested for this label set
         */
        maxSeries?: pulumi.Input<number>;
    }
    /**
     * Logging configuration
     */
    interface WorkspaceLoggingConfigurationArgs {
        /**
         * CloudWatch log group ARN
         */
        logGroupArn?: pulumi.Input<string>;
    }
}
export declare namespace arczonalshift {
    interface ZonalAutoshiftConfigurationControlConditionArgs {
        /**
         * The Amazon Resource Name (ARN) for an Amazon CloudWatch alarm that you specify as a control condition for a practice run.
         */
        alarmIdentifier: pulumi.Input<string>;
        /**
         * The type of alarm specified for a practice run. You can only specify Amazon CloudWatch alarms for practice runs, so the only valid value is `CLOUDWATCH` .
         */
        type: pulumi.Input<string>;
    }
    interface ZonalAutoshiftConfigurationPracticeRunConfigurationArgs {
        /**
         * An array of one or more dates that you can specify when AWS does not start practice runs for a resource. Dates are in UTC.
         *
         * Specify blocked dates in the format `YYYY-MM-DD` , separated by spaces.
         */
        blockedDates?: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * An array of one or more days and times that you can specify when Route 53 ARC does not start practice runs for a resource. Days and times are in UTC.
         *
         * Specify blocked windows in the format `DAY:HH:MM-DAY:HH:MM` , separated by spaces. For example, `MON:18:30-MON:19:30 TUE:18:30-TUE:19:30` .
         */
        blockedWindows?: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * An optional alarm that you can specify that blocks practice runs when the alarm is in an `ALARM` state. When a blocking alarm goes into an `ALARM` state, it prevents practice runs from being started, and ends practice runs that are in progress.
         */
        blockingAlarms?: pulumi.Input<pulumi.Input<inputs.arczonalshift.ZonalAutoshiftConfigurationControlConditionArgs>[]>;
        /**
         * The alarm that you specify to monitor the health of your application during practice runs. When the outcome alarm goes into an `ALARM` state, the practice run is ended and the outcome is set to `FAILED` .
         */
        outcomeAlarms: pulumi.Input<pulumi.Input<inputs.arczonalshift.ZonalAutoshiftConfigurationControlConditionArgs>[]>;
    }
}
export declare namespace athena {
    interface CapacityReservationCapacityAssignmentArgs {
        workgroupNames: pulumi.Input<pulumi.Input<string>[]>;
    }
    /**
     * Assignment configuration to assign workgroups to a reservation
     */
    interface CapacityReservationCapacityAssignmentConfigurationArgs {
        /**
         * The list of assignments that make up the capacity assignment configuration.
         */
        capacityAssignments: pulumi.Input<pulumi.Input<inputs.athena.CapacityReservationCapacityAssignmentArgs>[]>;
    }
    /**
     * Indicates that an Amazon S3 canned ACL should be set to control ownership of stored query results
     */
    interface WorkGroupAclConfigurationArgs {
        /**
         * The Amazon S3 canned ACL that Athena should specify when storing query results, including data files inserted by Athena as the result of statements like CTAS or INSERT INTO. Currently the only supported canned ACL is `BUCKET_OWNER_FULL_CONTROL` . If a query runs in a workgroup and the workgroup overrides client-side settings, then the Amazon S3 canned ACL specified in the workgroup's settings is used for all queries that run in the workgroup. For more information about Amazon S3 canned ACLs, see [Canned ACL](https://docs.aws.amazon.com/AmazonS3/latest/userguide/acl-overview.html#canned-acl) in the *Amazon S3 User Guide* .
         */
        s3AclOption: pulumi.Input<enums.athena.WorkGroupS3AclOption>;
    }
    interface WorkGroupConfigurationArgs {
        /**
         * Specifies a user defined JSON string that is passed to the session engine.
         */
        additionalConfiguration?: pulumi.Input<string>;
        /**
         * The upper limit (cutoff) for the amount of bytes a single query in a workgroup is allowed to scan. No default is defined.
         *
         * > This property currently supports integer types. Support for long values is planned.
         */
        bytesScannedCutoffPerQuery?: pulumi.Input<number>;
        /**
         * Specifies the KMS key that is used to encrypt the user's data stores in Athena. This setting does not apply to Athena SQL workgroups.
         */
        customerContentEncryptionConfiguration?: pulumi.Input<inputs.athena.WorkGroupCustomerContentEncryptionConfigurationArgs>;
        /**
         * If set to "true", the settings for the workgroup override client-side settings. If set to "false", client-side settings are used. For more information, see [Override client-side settings](https://docs.aws.amazon.com/athena/latest/ug/workgroups-settings-override.html) .
         */
        enforceWorkGroupConfiguration?: pulumi.Input<boolean>;
        /**
         * The engine version that all queries running on the workgroup use.
         */
        engineVersion?: pulumi.Input<inputs.athena.WorkGroupEngineVersionArgs>;
        /**
         * Role used to access user resources in an Athena for Apache Spark session. This property applies only to Spark-enabled workgroups in Athena.
         */
        executionRole?: pulumi.Input<string>;
        /**
         * Indicates that the Amazon CloudWatch metrics are enabled for the workgroup.
         */
        publishCloudWatchMetricsEnabled?: pulumi.Input<boolean>;
        /**
         * If set to `true` , allows members assigned to a workgroup to reference Amazon S3 Requester Pays buckets in queries. If set to `false` , workgroup members cannot query data from Requester Pays buckets, and queries that retrieve data from Requester Pays buckets cause an error. The default is `false` . For more information about Requester Pays buckets, see [Requester Pays Buckets](https://docs.aws.amazon.com/AmazonS3/latest/dev/RequesterPaysBuckets.html) in the *Amazon Simple Storage Service Developer Guide* .
         */
        requesterPaysEnabled?: pulumi.Input<boolean>;
        /**
         * Specifies the location in Amazon S3 where query results are stored and the encryption option, if any, used for query results. For more information, see [Work with query results and recent queries](https://docs.aws.amazon.com/athena/latest/ug/querying.html) .
         */
        resultConfiguration?: pulumi.Input<inputs.athena.WorkGroupResultConfigurationArgs>;
    }
    /**
     * The configuration information that will be updated for this workgroup, which includes the location in Amazon S3 where query results are stored, the encryption option, if any, used for query results, whether the Amazon CloudWatch Metrics are enabled for the workgroup, whether the workgroup settings override the client-side settings, and the data usage limit for the amount of bytes scanned per query, if it is specified.
     */
    interface WorkGroupConfigurationUpdatesArgs {
        additionalConfiguration?: pulumi.Input<string>;
        bytesScannedCutoffPerQuery?: pulumi.Input<number>;
        customerContentEncryptionConfiguration?: pulumi.Input<inputs.athena.WorkGroupCustomerContentEncryptionConfigurationArgs>;
        enforceWorkGroupConfiguration?: pulumi.Input<boolean>;
        engineVersion?: pulumi.Input<inputs.athena.WorkGroupEngineVersionArgs>;
        executionRole?: pulumi.Input<string>;
        publishCloudWatchMetricsEnabled?: pulumi.Input<boolean>;
        removeBytesScannedCutoffPerQuery?: pulumi.Input<boolean>;
        removeCustomerContentEncryptionConfiguration?: pulumi.Input<boolean>;
        requesterPaysEnabled?: pulumi.Input<boolean>;
        resultConfigurationUpdates?: pulumi.Input<inputs.athena.WorkGroupResultConfigurationUpdatesArgs>;
    }
    /**
     * Indicates the KMS key for encrypting notebook content.
     */
    interface WorkGroupCustomerContentEncryptionConfigurationArgs {
        /**
         * The customer managed KMS key that is used to encrypt the user's data stores in Athena.
         */
        kmsKey: pulumi.Input<string>;
    }
    /**
     * If query results are encrypted in Amazon S3, indicates the encryption option used (for example, SSE-KMS or CSE-KMS) and key information.
     */
    interface WorkGroupEncryptionConfigurationArgs {
        /**
         * Indicates whether Amazon S3 server-side encryption with Amazon S3-managed keys ( `SSE_S3` ), server-side encryption with KMS-managed keys ( `SSE_KMS` ), or client-side encryption with KMS-managed keys ( `CSE_KMS` ) is used.
         *
         * If a query runs in a workgroup and the workgroup overrides client-side settings, then the workgroup's setting for encryption is used. It specifies whether query results must be encrypted, for all queries that run in this workgroup.
         */
        encryptionOption: pulumi.Input<enums.athena.WorkGroupEncryptionOption>;
        /**
         * For `SSE_KMS` and `CSE_KMS` , this is the KMS key ARN or ID.
         */
        kmsKey?: pulumi.Input<string>;
    }
    /**
     * The Athena engine version for running queries.
     */
    interface WorkGroupEngineVersionArgs {
        /**
         * Read only. The engine version on which the query runs. If the user requests a valid engine version other than Auto, the effective engine version is the same as the engine version that the user requested. If the user requests Auto, the effective engine version is chosen by Athena. When a request to update the engine version is made by a `CreateWorkGroup` or `UpdateWorkGroup` operation, the `EffectiveEngineVersion` field is ignored.
         */
        effectiveEngineVersion?: pulumi.Input<string>;
        /**
         * The engine version requested by the user. Possible values are determined by the output of `ListEngineVersions` , including AUTO. The default is AUTO.
         */
        selectedEngineVersion?: pulumi.Input<string>;
    }
    /**
     * The location in Amazon S3 where query results are stored and the encryption option, if any, used for query results. These are known as "client-side settings". If workgroup settings override client-side settings, then the query uses the workgroup settings.
     */
    interface WorkGroupResultConfigurationArgs {
        /**
         * Indicates that an Amazon S3 canned ACL should be set to control ownership of stored query results. Currently the only supported canned ACL is `BUCKET_OWNER_FULL_CONTROL` . This is a client-side setting. If workgroup settings override client-side settings, then the query uses the ACL configuration that is specified for the workgroup, and also uses the location for storing query results specified in the workgroup. See `EnforceWorkGroupConfiguration` .
         */
        aclConfiguration?: pulumi.Input<inputs.athena.WorkGroupAclConfigurationArgs>;
        /**
         * If query results are encrypted in Amazon S3, indicates the encryption option used (for example, `SSE_KMS` or `CSE_KMS` ) and key information. This is a client-side setting. If workgroup settings override client-side settings, then the query uses the encryption configuration that is specified for the workgroup, and also uses the location for storing query results specified in the workgroup. See `EnforceWorkGroupConfiguration` and [Override client-side settings](https://docs.aws.amazon.com/athena/latest/ug/workgroups-settings-override.html) .
         */
        encryptionConfiguration?: pulumi.Input<inputs.athena.WorkGroupEncryptionConfigurationArgs>;
        /**
         * The account ID that you expect to be the owner of the Amazon S3 bucket specified by `ResultConfiguration:OutputLocation` . If set, Athena uses the value for `ExpectedBucketOwner` when it makes Amazon S3 calls to your specified output location. If the `ExpectedBucketOwner` account ID does not match the actual owner of the Amazon S3 bucket, the call fails with a permissions error.
         *
         * This is a client-side setting. If workgroup settings override client-side settings, then the query uses the `ExpectedBucketOwner` setting that is specified for the workgroup, and also uses the location for storing query results specified in the workgroup. See `EnforceWorkGroupConfiguration` .
         */
        expectedBucketOwner?: pulumi.Input<string>;
        /**
         * The location in Amazon S3 where your query results are stored, such as `s3://path/to/query/bucket/` . To run a query, you must specify the query results location using either a client-side setting for individual queries or a location specified by the workgroup. If workgroup settings override client-side settings, then the query uses the location specified for the workgroup. If no query location is set, Athena issues an error. For more information, see [Work with query results and recent queries](https://docs.aws.amazon.com/athena/latest/ug/querying.html) and `EnforceWorkGroupConfiguration` .
         */
        outputLocation?: pulumi.Input<string>;
    }
    /**
     * The result configuration information about the queries in this workgroup that will be updated. Includes the updated results location and an updated option for encrypting query results.
     */
    interface WorkGroupResultConfigurationUpdatesArgs {
        /**
         * The ACL configuration for the query results.
         */
        aclConfiguration?: pulumi.Input<inputs.athena.WorkGroupAclConfigurationArgs>;
        /**
         * The encryption configuration for the query results.
         */
        encryptionConfiguration?: pulumi.Input<inputs.athena.WorkGroupEncryptionConfigurationArgs>;
        /**
         * The AWS account ID that you expect to be the owner of the Amazon S3 bucket specified by `ResultConfiguration$OutputLocation` . If set, Athena uses the value for `ExpectedBucketOwner` when it makes Amazon S3 calls to your specified output location. If the `ExpectedBucketOwner` AWS account ID does not match the actual owner of the Amazon S3 bucket, the call fails with a permissions error.
         *
         * If workgroup settings override client-side settings, then the query uses the `ExpectedBucketOwner` setting that is specified for the workgroup, and also uses the location for storing query results specified in the workgroup. See `WorkGroupConfiguration$EnforceWorkGroupConfiguration` and [Workgroup Settings Override Client-Side Settings](https://docs.aws.amazon.com/athena/latest/ug/workgroups-settings-override.html) .
         */
        expectedBucketOwner?: pulumi.Input<string>;
        /**
         * The location in Amazon S3 where your query results are stored, such as `s3://path/to/query/bucket/` . For more information, see [Query Results](https://docs.aws.amazon.com/athena/latest/ug/querying.html) If workgroup settings override client-side settings, then the query uses the location for the query results and the encryption configuration that are specified for the workgroup. The "workgroup settings override" is specified in EnforceWorkGroupConfiguration (true/false) in the WorkGroupConfiguration. See `EnforceWorkGroupConfiguration` .
         */
        outputLocation?: pulumi.Input<string>;
        /**
         * If set to `true` , indicates that the previously-specified ACL configuration for queries in this workgroup should be ignored and set to null. If set to `false` or not set, and a value is present in the `AclConfiguration` of `ResultConfigurationUpdates` , the `AclConfiguration` in the workgroup's `ResultConfiguration` is updated with the new value. For more information, see [Workgroup Settings Override Client-Side Settings](https://docs.aws.amazon.com/athena/latest/ug/workgroups-settings-override.html) .
         */
        removeAclConfiguration?: pulumi.Input<boolean>;
        /**
         * If set to "true", indicates that the previously-specified encryption configuration (also known as the client-side setting) for queries in this workgroup should be ignored and set to null. If set to "false" or not set, and a value is present in the EncryptionConfiguration in ResultConfigurationUpdates (the client-side setting), the EncryptionConfiguration in the workgroup's ResultConfiguration will be updated with the new value. For more information, see [Override Client-Side Settings](https://docs.aws.amazon.com/athena/latest/ug/workgroups-settings-override.html) .
         */
        removeEncryptionConfiguration?: pulumi.Input<boolean>;
        /**
         * If set to "true", removes the AWS account ID previously specified for `ResultConfiguration$ExpectedBucketOwner` . If set to "false" or not set, and a value is present in the `ExpectedBucketOwner` in `ResultConfigurationUpdates` (the client-side setting), the `ExpectedBucketOwner` in the workgroup's `ResultConfiguration` is updated with the new value. For more information, see [Workgroup Settings Override Client-Side Settings](https://docs.aws.amazon.com/athena/latest/ug/workgroups-settings-override.html) .
         */
        removeExpectedBucketOwner?: pulumi.Input<boolean>;
        /**
         * If set to "true", indicates that the previously-specified query results location (also known as a client-side setting) for queries in this workgroup should be ignored and set to null. If set to "false" or not set, and a value is present in the OutputLocation in ResultConfigurationUpdates (the client-side setting), the OutputLocation in the workgroup's ResultConfiguration will be updated with the new value. For more information, see [Override Client-Side Settings](https://docs.aws.amazon.com/athena/latest/ug/workgroups-settings-override.html) .
         */
        removeOutputLocation?: pulumi.Input<boolean>;
    }
}
export declare namespace auditmanager {
    /**
     * The AWS account associated with the assessment.
     */
    interface AssessmentAwsAccountArgs {
        /**
         * The email address that's associated with the AWS account .
         */
        emailAddress?: pulumi.Input<string>;
        /**
         * The identifier for the AWS account .
         */
        id?: pulumi.Input<string>;
        /**
         * The name of the AWS account .
         */
        name?: pulumi.Input<string>;
    }
    /**
     * An AWS service such as Amazon S3, AWS CloudTrail, and so on.
     */
    interface AssessmentAwsServiceArgs {
        /**
         * The name of the AWS service .
         */
        serviceName?: pulumi.Input<string>;
    }
    /**
     * The assignment of a control set to a delegate for review.
     */
    interface AssessmentDelegationArgs {
        /**
         * The identifier for the assessment that's associated with the delegation.
         */
        assessmentId?: pulumi.Input<string>;
        /**
         * The name of the assessment that's associated with the delegation.
         */
        assessmentName?: pulumi.Input<string>;
        /**
         * The comment that's related to the delegation.
         */
        comment?: pulumi.Input<string>;
        /**
         * The identifier for the control set that's associated with the delegation.
         */
        controlSetId?: pulumi.Input<string>;
        /**
         * The user or role that created the delegation.
         *
         * *Minimum* : `1`
         *
         * *Maximum* : `100`
         *
         * *Pattern* : `^[a-zA-Z0-9-_()\\[\\]\\s]+$`
         */
        createdBy?: pulumi.Input<string>;
        /**
         * Specifies when the delegation was created.
         */
        creationTime?: pulumi.Input<number>;
        /**
         * The unique identifier for the delegation.
         */
        id?: pulumi.Input<string>;
        /**
         * Specifies when the delegation was last updated.
         */
        lastUpdated?: pulumi.Input<number>;
        /**
         * The Amazon Resource Name (ARN) of the IAM role.
         */
        roleArn?: pulumi.Input<string>;
        /**
         * The type of customer persona.
         *
         * > In `CreateAssessment` , `roleType` can only be `PROCESS_OWNER` .
         * >
         * > In `UpdateSettings` , `roleType` can only be `PROCESS_OWNER` .
         * >
         * > In `BatchCreateDelegationByAssessment` , `roleType` can only be `RESOURCE_OWNER` .
         */
        roleType?: pulumi.Input<enums.auditmanager.AssessmentRoleType>;
        /**
         * The status of the delegation.
         */
        status?: pulumi.Input<enums.auditmanager.AssessmentDelegationStatus>;
    }
    /**
     * The destination in which evidence reports are stored for the specified assessment.
     */
    interface AssessmentReportsDestinationArgs {
        /**
         * The destination bucket where Audit Manager stores assessment reports.
         */
        destination?: pulumi.Input<string>;
        /**
         * The destination type, such as Amazon S3.
         */
        destinationType?: pulumi.Input<enums.auditmanager.AssessmentReportDestinationType>;
    }
    /**
     * The wrapper that contains AWS Audit Manager role information, such as the role type and IAM ARN.
     */
    interface AssessmentRoleArgs {
        /**
         * The Amazon Resource Name (ARN) of the IAM role.
         */
        roleArn?: pulumi.Input<string>;
        /**
         * The type of customer persona.
         *
         * > In `CreateAssessment` , `roleType` can only be `PROCESS_OWNER` .
         * >
         * > In `UpdateSettings` , `roleType` can only be `PROCESS_OWNER` .
         * >
         * > In `BatchCreateDelegationByAssessment` , `roleType` can only be `RESOURCE_OWNER` .
         */
        roleType?: pulumi.Input<enums.auditmanager.AssessmentRoleType>;
    }
    /**
     * The wrapper that contains the AWS accounts and AWS services in scope for the assessment.
     */
    interface AssessmentScopeArgs {
        /**
         * The AWS accounts included in scope.
         */
        awsAccounts?: pulumi.Input<pulumi.Input<inputs.auditmanager.AssessmentAwsAccountArgs>[]>;
        /**
         * The AWS services included in scope.
         */
        awsServices?: pulumi.Input<pulumi.Input<inputs.auditmanager.AssessmentAwsServiceArgs>[]>;
    }
}
export declare namespace autoscaling {
    /**
     * ``AcceleratorCountRequest`` is a property of the ``InstanceRequirements`` property of the [AWS::AutoScaling::AutoScalingGroup LaunchTemplateOverrides](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-autoscaling-autoscalinggroup-launchtemplateoverrides.html) property type that describes the minimum and maximum number of accelerators for an instance type.
     */
    interface AutoScalingGroupAcceleratorCountRequestArgs {
        /**
         * The maximum value.
         */
        max?: pulumi.Input<number>;
        /**
         * The minimum value.
         */
        min?: pulumi.Input<number>;
    }
    /**
     * ``AcceleratorTotalMemoryMiBRequest`` is a property of the ``InstanceRequirements`` property of the [AWS::AutoScaling::AutoScalingGroup LaunchTemplateOverrides](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-autoscaling-autoscalinggroup-launchtemplateoverrides.html) property type that describes the minimum and maximum total memory size for the accelerators for an instance type, in MiB.
     */
    interface AutoScalingGroupAcceleratorTotalMemoryMiBRequestArgs {
        /**
         * The memory maximum in MiB.
         */
        max?: pulumi.Input<number>;
        /**
         * The memory minimum in MiB.
         */
        min?: pulumi.Input<number>;
    }
    /**
     * ``AvailabilityZoneDistribution`` is a property of the [AWS::AutoScaling::AutoScalingGroup](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-autoscaling-autoscalinggroup.html) resource.
     */
    interface AutoScalingGroupAvailabilityZoneDistributionArgs {
        /**
         * If launches fail in an Availability Zone, the following strategies are available. The default is ``balanced-best-effort``.
         *   +   ``balanced-only`` - If launches fail in an Availability Zone, Auto Scaling will continue to attempt to launch in the unhealthy zone to preserve a balanced distribution.
         *   +   ``balanced-best-effort`` - If launches fail in an Availability Zone, Auto Scaling will attempt to launch in another healthy Availability Zone instead.
         */
        capacityDistributionStrategy?: pulumi.Input<enums.autoscaling.AutoScalingGroupAvailabilityZoneDistributionCapacityDistributionStrategy>;
    }
    /**
     * Describes an Availability Zone impairment policy.
     */
    interface AutoScalingGroupAvailabilityZoneImpairmentPolicyArgs {
        /**
         * Specifies the health check behavior for the impaired Availability Zone in an active zonal shift. If you select ``Replace unhealthy``, instances that appear unhealthy will be replaced in all Availability Zones. If you select ``Ignore unhealthy``, instances will not be replaced in the Availability Zone with the active zonal shift. For more information, see [Auto Scaling group zonal shift](https://docs.aws.amazon.com/autoscaling/ec2/userguide/ec2-auto-scaling-zonal-shift.html) in the *Amazon EC2 Auto Scaling User Guide*.
         */
        impairedZoneHealthCheckBehavior: pulumi.Input<enums.autoscaling.AutoScalingGroupAvailabilityZoneImpairmentPolicyImpairedZoneHealthCheckBehavior>;
        /**
         * If ``true``, enable zonal shift for your Auto Scaling group.
         */
        zonalShiftEnabled: pulumi.Input<boolean>;
    }
    /**
     * ``BaselineEbsBandwidthMbpsRequest`` is a property of the ``InstanceRequirements`` property of the [AWS::AutoScaling::AutoScalingGroup LaunchTemplateOverrides](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-autoscaling-autoscalinggroup-launchtemplateoverrides.html) property type that describes the minimum and maximum baseline bandwidth performance for an instance type, in Mbps.
     */
    interface AutoScalingGroupBaselineEbsBandwidthMbpsRequestArgs {
        /**
         * The maximum value in Mbps.
         */
        max?: pulumi.Input<number>;
        /**
         * The minimum value in Mbps.
         */
        min?: pulumi.Input<number>;
    }
    interface AutoScalingGroupBaselinePerformanceFactorsRequestArgs {
        /**
         * The CPU performance to consider, using an instance family as the baseline reference.
         */
        cpu?: pulumi.Input<inputs.autoscaling.AutoScalingGroupCpuPerformanceFactorRequestArgs>;
    }
    interface AutoScalingGroupCapacityReservationSpecificationArgs {
        /**
         * The capacity reservation preference. The following options are available:
         *
         * - `capacity-reservations-only` - Auto Scaling will only launch instances into a Capacity Reservation or Capacity Reservation resource group. If capacity isn't available, instances will fail to launch.
         * - `capacity-reservations-first` - Auto Scaling will try to launch instances into a Capacity Reservation or Capacity Reservation resource group first. If capacity isn't available, instances will run in On-Demand capacity.
         * - `none` - Auto Scaling will not launch instances into a Capacity Reservation. Instances will run in On-Demand capacity.
         * - `default` - Auto Scaling uses the Capacity Reservation preference from your launch template or an open Capacity Reservation.
         */
        capacityReservationPreference: pulumi.Input<string>;
        /**
         * Describes a target Capacity Reservation or Capacity Reservation resource group.
         */
        capacityReservationTarget?: pulumi.Input<inputs.autoscaling.AutoScalingGroupCapacityReservationTargetArgs>;
    }
    interface AutoScalingGroupCapacityReservationTargetArgs {
        /**
         * The Capacity Reservation IDs to launch instances into.
         */
        capacityReservationIds?: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * The resource group ARNs of the Capacity Reservation to launch instances into.
         */
        capacityReservationResourceGroupArns?: pulumi.Input<pulumi.Input<string>[]>;
    }
    interface AutoScalingGroupCpuPerformanceFactorRequestArgs {
        /**
         * Specify an instance family to use as the baseline reference for CPU performance. All instance types that match your specified attributes will be compared against the CPU performance of the referenced instance family, regardless of CPU manufacturer or architecture differences.
         *
         * > Currently only one instance family can be specified in the list.
         */
        references?: pulumi.Input<pulumi.Input<inputs.autoscaling.AutoScalingGroupPerformanceFactorReferenceRequestArgs>[]>;
    }
    /**
     * ``InstanceMaintenancePolicy`` is a property of the [AWS::AutoScaling::AutoScalingGroup](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-autoscaling-autoscalinggroup.html) resource.
     *  For more information, see [Instance maintenance policies](https://docs.aws.amazon.com/autoscaling/ec2/userguide/ec2-auto-scaling-instance-maintenance-policy.html) in the *Amazon EC2 Auto Scaling User Guide*.
     */
    interface AutoScalingGroupInstanceMaintenancePolicyArgs {
        /**
         * Specifies the upper threshold as a percentage of the desired capacity of the Auto Scaling group. It represents the maximum percentage of the group that can be in service and healthy, or pending, to support your workload when replacing instances. Value range is 100 to 200. To clear a previously set value, specify a value of ``-1``.
         *  Both ``MinHealthyPercentage`` and ``MaxHealthyPercentage`` must be specified, and the difference between them cannot be greater than 100. A large range increases the number of instances that can be replaced at the same time.
         */
        maxHealthyPercentage?: pulumi.Input<number>;
        /**
         * Specifies the lower threshold as a percentage of the desired capacity of the Auto Scaling group. It represents the minimum percentage of the group to keep in service, healthy, and ready to use to support your workload when replacing instances. Value range is 0 to 100. To clear a previously set value, specify a value of ``-1``.
         */
        minHealthyPercentage?: pulumi.Input<number>;
    }
    /**
     * The attributes for the instance types for a mixed instances policy. Amazon EC2 Auto Scaling uses your specified requirements to identify instance types. Then, it uses your On-Demand and Spot allocation strategies to launch instances from these instance types.
     *  When you specify multiple attributes, you get instance types that satisfy all of the specified attributes. If you specify multiple values for an attribute, you get instance types that satisfy any of the specified values.
     *  To limit the list of instance types from which Amazon EC2 Auto Scaling can identify matching instance types, you can use one of the following parameters, but not both in the same request:
     *   +   ``AllowedInstanceTypes`` - The instance types to include in the list. All other instance types are ignored, even if they match your specified attributes.
     *   +   ``ExcludedInstanceTypes`` - The instance types to exclude from the list, even if they match your specified attributes.
     *
     *   You must specify ``VCpuCount`` and ``MemoryMiB``. All other attributes are optional. Any unspecified optional attribute is set to its default.
     *   For an example template, see [Configure Amazon EC2 Auto Scaling resources](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/quickref-ec2-auto-scaling.html).
     *  For more information, see [Creating an Auto Scaling group using attribute-based instance type selection](https://docs.aws.amazon.com/autoscaling/ec2/userguide/create-asg-instance-type-requirements.html) in the *Amazon EC2 Auto Scaling User Guide*. For help determining which instance types match your attributes before you apply them to your Auto Scaling group, see [Preview instance types with specified attributes](https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/ec2-fleet-attribute-based-instance-type-selection.html#ec2fleet-get-instance-types-from-instance-requirements) in the *Amazon EC2 User Guide for Linux Instances*.
     *   ``InstanceRequirements`` is a property of the ``LaunchTemplateOverrides`` property of the [AWS::AutoScaling::AutoScalingGroup LaunchTemplate](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-autoscaling-autoscalinggroup-launchtemplate.html) property type.
     */
    interface AutoScalingGroupInstanceRequirementsArgs {
        /**
         * The minimum and maximum number of accelerators (GPUs, FPGAs, or AWS Inferentia chips) for an instance type.
         *  To exclude accelerator-enabled instance types, set ``Max`` to ``0``.
         *  Default: No minimum or maximum limits
         */
        acceleratorCount?: pulumi.Input<inputs.autoscaling.AutoScalingGroupAcceleratorCountRequestArgs>;
        /**
         * Indicates whether instance types must have accelerators by specific manufacturers.
         *   +  For instance types with NVIDIA devices, specify ``nvidia``.
         *   +  For instance types with AMD devices, specify ``amd``.
         *   +  For instance types with AWS devices, specify ``amazon-web-services``.
         *   +  For instance types with Xilinx devices, specify ``xilinx``.
         *
         *  Default: Any manufacturer
         */
        acceleratorManufacturers?: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * Lists the accelerators that must be on an instance type.
         *   +  For instance types with NVIDIA A100 GPUs, specify ``a100``.
         *   +  For instance types with NVIDIA V100 GPUs, specify ``v100``.
         *   +  For instance types with NVIDIA K80 GPUs, specify ``k80``.
         *   +  For instance types with NVIDIA T4 GPUs, specify ``t4``.
         *   +  For instance types with NVIDIA M60 GPUs, specify ``m60``.
         *   +  For instance types with AMD Radeon Pro V520 GPUs, specify ``radeon-pro-v520``.
         *   +  For instance types with Xilinx VU9P FPGAs, specify ``vu9p``.
         *
         *  Default: Any accelerator
         */
        acceleratorNames?: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * The minimum and maximum total memory size for the accelerators on an instance type, in MiB.
         *  Default: No minimum or maximum limits
         */
        acceleratorTotalMemoryMiB?: pulumi.Input<inputs.autoscaling.AutoScalingGroupAcceleratorTotalMemoryMiBRequestArgs>;
        /**
         * Lists the accelerator types that must be on an instance type.
         *   +  For instance types with GPU accelerators, specify ``gpu``.
         *   +  For instance types with FPGA accelerators, specify ``fpga``.
         *   +  For instance types with inference accelerators, specify ``inference``.
         *
         *  Default: Any accelerator type
         */
        acceleratorTypes?: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * The instance types to apply your specified attributes against. All other instance types are ignored, even if they match your specified attributes.
         *  You can use strings with one or more wild cards, represented by an asterisk (``*``), to allow an instance type, size, or generation. The following are examples: ``m5.8xlarge``, ``c5*.*``, ``m5a.*``, ``r*``, ``*3*``.
         *  For example, if you specify ``c5*``, Amazon EC2 Auto Scaling will allow the entire C5 instance family, which includes all C5a and C5n instance types. If you specify ``m5a.*``, Amazon EC2 Auto Scaling will allow all the M5a instance types, but not the M5n instance types.
         *   If you specify ``AllowedInstanceTypes``, you can't specify ``ExcludedInstanceTypes``.
         *   Default: All instance types
         */
        allowedInstanceTypes?: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * Indicates whether bare metal instance types are included, excluded, or required.
         *  Default: ``excluded``
         */
        bareMetal?: pulumi.Input<string>;
        /**
         * The minimum and maximum baseline bandwidth performance for an instance type, in Mbps. For more information, see [Amazon EBS–optimized instances](https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/ebs-optimized.html) in the *Amazon EC2 User Guide for Linux Instances*.
         *  Default: No minimum or maximum limits
         */
        baselineEbsBandwidthMbps?: pulumi.Input<inputs.autoscaling.AutoScalingGroupBaselineEbsBandwidthMbpsRequestArgs>;
        /**
         * The baseline performance factors for the instance requirements.
         */
        baselinePerformanceFactors?: pulumi.Input<inputs.autoscaling.AutoScalingGroupBaselinePerformanceFactorsRequestArgs>;
        /**
         * Indicates whether burstable performance instance types are included, excluded, or required. For more information, see [Burstable performance instances](https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/burstable-performance-instances.html) in the *Amazon EC2 User Guide for Linux Instances*.
         *  Default: ``excluded``
         */
        burstablePerformance?: pulumi.Input<string>;
        /**
         * Lists which specific CPU manufacturers to include.
         *   +  For instance types with Intel CPUs, specify ``intel``.
         *   +  For instance types with AMD CPUs, specify ``amd``.
         *   +  For instance types with AWS CPUs, specify ``amazon-web-services``.
         *
         *   Don't confuse the CPU hardware manufacturer with the CPU hardware architecture. Instances will be launched with a compatible CPU architecture based on the Amazon Machine Image (AMI) that you specify in your launch template.
         *   Default: Any manufacturer
         */
        cpuManufacturers?: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * The instance types to exclude. You can use strings with one or more wild cards, represented by an asterisk (``*``), to exclude an instance family, type, size, or generation. The following are examples: ``m5.8xlarge``, ``c5*.*``, ``m5a.*``, ``r*``, ``*3*``.
         *  For example, if you specify ``c5*``, you are excluding the entire C5 instance family, which includes all C5a and C5n instance types. If you specify ``m5a.*``, Amazon EC2 Auto Scaling will exclude all the M5a instance types, but not the M5n instance types.
         *   If you specify ``ExcludedInstanceTypes``, you can't specify ``AllowedInstanceTypes``.
         *   Default: No excluded instance types
         */
        excludedInstanceTypes?: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * Indicates whether current or previous generation instance types are included.
         *   +  For current generation instance types, specify ``current``. The current generation includes EC2 instance types currently recommended for use. This typically includes the latest two to three generations in each instance family. For more information, see [Instance types](https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/instance-types.html) in the *Amazon EC2 User Guide for Linux Instances*.
         *   +  For previous generation instance types, specify ``previous``.
         *
         *  Default: Any current or previous generation
         */
        instanceGenerations?: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * Indicates whether instance types with instance store volumes are included, excluded, or required. For more information, see [Amazon EC2 instance store](https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/InstanceStorage.html) in the *Amazon EC2 User Guide for Linux Instances*.
         *  Default: ``included``
         */
        localStorage?: pulumi.Input<string>;
        /**
         * Indicates the type of local storage that is required.
         *   +  For instance types with hard disk drive (HDD) storage, specify ``hdd``.
         *   +  For instance types with solid state drive (SSD) storage, specify ``ssd``.
         *
         *  Default: Any local storage type
         */
        localStorageTypes?: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * [Price protection] The price protection threshold for Spot Instances, as a percentage of an identified On-Demand price. The identified On-Demand price is the price of the lowest priced current generation C, M, or R instance type with your specified attributes. If no current generation C, M, or R instance type matches your attributes, then the identified price is from either the lowest priced current generation instance types or, failing that, the lowest priced previous generation instance types that match your attributes. When Amazon EC2 Auto Scaling selects instance types with your attributes, we will exclude instance types whose price exceeds your specified threshold.
         *  The parameter accepts an integer, which Amazon EC2 Auto Scaling interprets as a percentage.
         *  If you set ``DesiredCapacityType`` to ``vcpu`` or ``memory-mib``, the price protection threshold is based on the per-vCPU or per-memory price instead of the per instance price.
         *   Only one of ``SpotMaxPricePercentageOverLowestPrice`` or ``MaxSpotPriceAsPercentageOfOptimalOnDemandPrice`` can be specified. If you don't specify either, Amazon EC2 Auto Scaling will automatically apply optimal price protection to consistently select from a wide range of instance types. To indicate no price protection threshold for Spot Instances, meaning you want to consider all instance types that match your attributes, include one of these parameters and specify a high value, such as ``999999``.
         */
        maxSpotPriceAsPercentageOfOptimalOnDemandPrice?: pulumi.Input<number>;
        /**
         * The minimum and maximum amount of memory per vCPU for an instance type, in GiB.
         *  Default: No minimum or maximum limits
         */
        memoryGiBPerVCpu?: pulumi.Input<inputs.autoscaling.AutoScalingGroupMemoryGiBPerVCpuRequestArgs>;
        /**
         * The minimum and maximum instance memory size for an instance type, in MiB.
         */
        memoryMiB: pulumi.Input<inputs.autoscaling.AutoScalingGroupMemoryMiBRequestArgs>;
        /**
         * The minimum and maximum amount of network bandwidth, in gigabits per second (Gbps).
         *  Default: No minimum or maximum limits
         */
        networkBandwidthGbps?: pulumi.Input<inputs.autoscaling.AutoScalingGroupNetworkBandwidthGbpsRequestArgs>;
        /**
         * The minimum and maximum number of network interfaces for an instance type.
         *  Default: No minimum or maximum limits
         */
        networkInterfaceCount?: pulumi.Input<inputs.autoscaling.AutoScalingGroupNetworkInterfaceCountRequestArgs>;
        /**
         * [Price protection] The price protection threshold for On-Demand Instances, as a percentage higher than an identified On-Demand price. The identified On-Demand price is the price of the lowest priced current generation C, M, or R instance type with your specified attributes. If no current generation C, M, or R instance type matches your attributes, then the identified price is from either the lowest priced current generation instance types or, failing that, the lowest priced previous generation instance types that match your attributes. When Amazon EC2 Auto Scaling selects instance types with your attributes, we will exclude instance types whose price exceeds your specified threshold.
         *  The parameter accepts an integer, which Amazon EC2 Auto Scaling interprets as a percentage.
         *  To turn off price protection, specify a high value, such as ``999999``.
         *  If you set ``DesiredCapacityType`` to ``vcpu`` or ``memory-mib``, the price protection threshold is applied based on the per-vCPU or per-memory price instead of the per instance price.
         *  Default: ``20``
         */
        onDemandMaxPricePercentageOverLowestPrice?: pulumi.Input<number>;
        /**
         * Indicates whether instance types must provide On-Demand Instance hibernation support.
         *  Default: ``false``
         */
        requireHibernateSupport?: pulumi.Input<boolean>;
        /**
         * [Price protection] The price protection threshold for Spot Instances, as a percentage higher than an identified Spot price. The identified Spot price is the price of the lowest priced current generation C, M, or R instance type with your specified attributes. If no current generation C, M, or R instance type matches your attributes, then the identified price is from either the lowest priced current generation instance types or, failing that, the lowest priced previous generation instance types that match your attributes. When Amazon EC2 Auto Scaling selects instance types with your attributes, we will exclude instance types whose price exceeds your specified threshold.
         *  The parameter accepts an integer, which Amazon EC2 Auto Scaling interprets as a percentage.
         *  If you set ``DesiredCapacityType`` to ``vcpu`` or ``memory-mib``, the price protection threshold is based on the per-vCPU or per-memory price instead of the per instance price.
         *   Only one of ``SpotMaxPricePercentageOverLowestPrice`` or ``MaxSpotPriceAsPercentageOfOptimalOnDemandPrice`` can be specified. If you don't specify either, Amazon EC2 Auto Scaling will automatically apply optimal price protection to consistently select from a wide range of instance types. To indicate no price protection threshold for Spot Instances, meaning you want to consider all instance types that match your attributes, include one of these parameters and specify a high value, such as ``999999``.
         */
        spotMaxPricePercentageOverLowestPrice?: pulumi.Input<number>;
        /**
         * The minimum and maximum total local storage size for an instance type, in GB.
         *  Default: No minimum or maximum limits
         */
        totalLocalStorageGb?: pulumi.Input<inputs.autoscaling.AutoScalingGroupTotalLocalStorageGbRequestArgs>;
        /**
         * The minimum and maximum number of vCPUs for an instance type.
         */
        vCpuCount: pulumi.Input<inputs.autoscaling.AutoScalingGroupVCpuCountRequestArgs>;
    }
    /**
     * Use this structure to specify the distribution of On-Demand Instances and Spot Instances and the allocation strategies used to fulfill On-Demand and Spot capacities for a mixed instances policy.
     *  For more information, see [Auto Scaling groups with multiple instance types and purchase options](https://docs.aws.amazon.com/autoscaling/ec2/userguide/ec2-auto-scaling-mixed-instances-groups.html) in the *Amazon EC2 Auto Scaling User Guide*.
     *   ``InstancesDistribution`` is a property of the [AWS::AutoScaling::AutoScalingGroup MixedInstancesPolicy](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-autoscaling-autoscalinggroup-mixedinstancespolicy.html) property type.
     */
    interface AutoScalingGroupInstancesDistributionArgs {
        /**
         * The allocation strategy to apply to your On-Demand Instances when they are launched. Possible instance types are determined by the launch template overrides that you specify.
         *  The following lists the valid values:
         *   + lowest-price Uses price to determine which instance types are the highest priority, launching the lowest priced instance types within an Availability Zone first. This is the default value for Auto Scaling groups that specify InstanceRequirements. + prioritized You set the order of instance types for the launch template overrides from highest to lowest priority (from first to last in the list). Amazon EC2 Auto Scaling launches your highest priority instance types first. If all your On-Demand capacity cannot be fulfilled using your highest priority instance type, then Amazon EC2 Auto Scaling launches the remaining capacity using the second priority instance type, and so on. This is the default value for Auto Scaling groups that don't specify InstanceRequirements and cannot be used for groups that do.
         */
        onDemandAllocationStrategy?: pulumi.Input<string>;
        /**
         * The minimum amount of the Auto Scaling group's capacity that must be fulfilled by On-Demand Instances. This base portion is launched first as your group scales.
         *  This number has the same unit of measurement as the group's desired capacity. If you change the default unit of measurement (number of instances) by specifying weighted capacity values in your launch template overrides list, or by changing the default desired capacity type setting of the group, you must specify this number using the same unit of measurement.
         *  Default: 0
         *   An update to this setting means a gradual replacement of instances to adjust the current On-Demand Instance levels. When replacing instances, Amazon EC2 Auto Scaling launches new instances before terminating the previous ones.
         */
        onDemandBaseCapacity?: pulumi.Input<number>;
        /**
         * Controls the percentages of On-Demand Instances and Spot Instances for your additional capacity beyond ``OnDemandBaseCapacity``. Expressed as a number (for example, 20 specifies 20% On-Demand Instances, 80% Spot Instances). If set to 100, only On-Demand Instances are used.
         *  Default: 100
         *   An update to this setting means a gradual replacement of instances to adjust the current On-Demand and Spot Instance levels for your additional capacity higher than the base capacity. When replacing instances, Amazon EC2 Auto Scaling launches new instances before terminating the previous ones.
         */
        onDemandPercentageAboveBaseCapacity?: pulumi.Input<number>;
        /**
         * The allocation strategy to apply to your Spot Instances when they are launched. Possible instance types are determined by the launch template overrides that you specify.
         *  The following lists the valid values:
         *   + capacity-optimized Requests Spot Instances using pools that are optimally chosen based on the available Spot capacity. This strategy has the lowest risk of interruption. To give certain instance types a higher chance of launching first, use capacity-optimized-prioritized. + capacity-optimized-prioritized You set the order of instance types for the launch template overrides from highest to lowest priority (from first to last in the list). Amazon EC2 Auto Scaling honors the instance type priorities on a best effort basis but optimizes for capacity first. Note that if the On-Demand allocation strategy is set to prioritized, the same priority is applied when fulfilling On-Demand capacity. This is not a valid value for Auto Scaling groups that specify InstanceRequirements. + lowest-price Requests Spot Instances using the lowest priced pools within an Availability Zone, across the number of Spot pools that you specify for the SpotInstancePools property. To ensure that your desired capacity is met, you might receive Spot Instances from several pools. This is the default value, but it might lead to high interruption rates because this strategy only considers instance price and not available capacity. + price-capacity-optimized (recommended) The price and capacity optimized allocation strategy looks at both price and capacity to select the Spot Instance pools that are the least likely to be interrupted and have the lowest possible price.
         */
        spotAllocationStrategy?: pulumi.Input<string>;
        /**
         * The number of Spot Instance pools across which to allocate your Spot Instances. The Spot pools are determined from the different instance types in the overrides. Valid only when the ``SpotAllocationStrategy`` is ``lowest-price``. Value must be in the range of 1–20.
         *  Default: 2
         */
        spotInstancePools?: pulumi.Input<number>;
        /**
         * The maximum price per unit hour that you are willing to pay for a Spot Instance. If your maximum price is lower than the Spot price for the instance types that you selected, your Spot Instances are not launched. We do not recommend specifying a maximum price because it can lead to increased interruptions. When Spot Instances launch, you pay the current Spot price. To remove a maximum price that you previously set, include the property but specify an empty string ("") for the value.
         *   If you specify a maximum price, your instances will be interrupted more frequently than if you do not specify one.
         *   Valid Range: Minimum value of 0.001
         */
        spotMaxPrice?: pulumi.Input<string>;
    }
    /**
     * Use this structure to specify the launch templates and instance types (overrides) for a mixed instances policy.
     *   ``LaunchTemplate`` is a property of the [AWS::AutoScaling::AutoScalingGroup MixedInstancesPolicy](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-autoscaling-autoscalinggroup-mixedinstancespolicy.html) property type.
     */
    interface AutoScalingGroupLaunchTemplateArgs {
        /**
         * The launch template.
         */
        launchTemplateSpecification: pulumi.Input<inputs.autoscaling.AutoScalingGroupLaunchTemplateSpecificationArgs>;
        /**
         * Any properties that you specify override the same properties in the launch template.
         */
        overrides?: pulumi.Input<pulumi.Input<inputs.autoscaling.AutoScalingGroupLaunchTemplateOverridesArgs>[]>;
    }
    /**
     * Use this structure to let Amazon EC2 Auto Scaling do the following when the Auto Scaling group has a mixed instances policy:
     *   +  Override the instance type that is specified in the launch template.
     *   +  Use multiple instance types.
     *
     *  Specify the instance types that you want, or define your instance requirements instead and let Amazon EC2 Auto Scaling provision the available instance types that meet your requirements. This can provide Amazon EC2 Auto Scaling with a larger selection of instance types to choose from when fulfilling Spot and On-Demand capacities. You can view which instance types are matched before you apply the instance requirements to your Auto Scaling group.
     *  After you define your instance requirements, you don't have to keep updating these settings to get new EC2 instance types automatically. Amazon EC2 Auto Scaling uses the instance requirements of the Auto Scaling group to determine whether a new EC2 instance type can be used.
     *   ``LaunchTemplateOverrides`` is a property of the [AWS::AutoScaling::AutoScalingGroup LaunchTemplate](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-autoscaling-autoscalinggroup-launchtemplate.html) property type.
     */
    interface AutoScalingGroupLaunchTemplateOverridesArgs {
        /**
         * The instance requirements. Amazon EC2 Auto Scaling uses your specified requirements to identify instance types. Then, it uses your On-Demand and Spot allocation strategies to launch instances from these instance types.
         *  You can specify up to four separate sets of instance requirements per Auto Scaling group. This is useful for provisioning instances from different Amazon Machine Images (AMIs) in the same Auto Scaling group. To do this, create the AMIs and create a new launch template for each AMI. Then, create a compatible set of instance requirements for each launch template.
         *   If you specify ``InstanceRequirements``, you can't specify ``InstanceType``.
         */
        instanceRequirements?: pulumi.Input<inputs.autoscaling.AutoScalingGroupInstanceRequirementsArgs>;
        /**
         * The instance type, such as ``m3.xlarge``. You must specify an instance type that is supported in your requested Region and Availability Zones. For more information, see [Instance types](https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/instance-types.html) in the *Amazon EC2 User Guide for Linux Instances*.
         *  You can specify up to 40 instance types per Auto Scaling group.
         */
        instanceType?: pulumi.Input<string>;
        /**
         * Provides a launch template for the specified instance type or set of instance requirements. For example, some instance types might require a launch template with a different AMI. If not provided, Amazon EC2 Auto Scaling uses the launch template that's specified in the ``LaunchTemplate`` definition. For more information, see [Specifying a different launch template for an instance type](https://docs.aws.amazon.com/autoscaling/ec2/userguide/ec2-auto-scaling-mixed-instances-groups-launch-template-overrides.html) in the *Amazon EC2 Auto Scaling User Guide*.
         *  You can specify up to 20 launch templates per Auto Scaling group. The launch templates specified in the overrides and in the ``LaunchTemplate`` definition count towards this limit.
         */
        launchTemplateSpecification?: pulumi.Input<inputs.autoscaling.AutoScalingGroupLaunchTemplateSpecificationArgs>;
        /**
         * If you provide a list of instance types to use, you can specify the number of capacity units provided by each instance type in terms of virtual CPUs, memory, storage, throughput, or other relative performance characteristic. When a Spot or On-Demand Instance is launched, the capacity units count toward the desired capacity. Amazon EC2 Auto Scaling launches instances until the desired capacity is totally fulfilled, even if this results in an overage. For example, if there are two units remaining to fulfill capacity, and Amazon EC2 Auto Scaling can only launch an instance with a ``WeightedCapacity`` of five units, the instance is launched, and the desired capacity is exceeded by three units. For more information, see [Configure instance weighting for Amazon EC2 Auto Scaling](https://docs.aws.amazon.com/autoscaling/ec2/userguide/ec2-auto-scaling-mixed-instances-groups-instance-weighting.html) in the *Amazon EC2 Auto Scaling User Guide*. Value must be in the range of 1-999.
         *  If you specify a value for ``WeightedCapacity`` for one instance type, you must specify a value for ``WeightedCapacity`` for all of them.
         *   Every Auto Scaling group has three size parameters (``DesiredCapacity``, ``MaxSize``, and ``MinSize``). Usually, you set these sizes based on a specific number of instances. However, if you configure a mixed instances policy that defines weights for the instance types, you must specify these sizes with the same units that you use for weighting instances.
         */
        weightedCapacity?: pulumi.Input<string>;
    }
    /**
     * Specifies a launch template to use when provisioning EC2 instances for an Auto Scaling group.
     *  You must specify the following:
     *   +  The ID or the name of the launch template, but not both.
     *   +  The version of the launch template.
     *
     *   ``LaunchTemplateSpecification`` is property of the [AWS::AutoScaling::AutoScalingGroup](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-autoscaling-autoscalinggroup.html) resource. It is also a property of the [AWS::AutoScaling::AutoScalingGroup LaunchTemplate](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-autoscaling-autoscalinggroup-launchtemplate.html) and [AWS::AutoScaling::AutoScalingGroup LaunchTemplateOverrides](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-autoscaling-autoscalinggroup-launchtemplateoverrides.html) property types.
     *  For information about creating a launch template, see [AWS::EC2::LaunchTemplate](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-ec2-launchtemplate.html) and [Create a launch template for an Auto Scaling group](https://docs.aws.amazon.com/autoscaling/ec2/userguide/create-launch-template.html) in the *Amazon EC2 Auto Scaling User Guide*.
     *  For examples of launch templates, see [Create launch templates](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/quickref-ec2-launch-templates.html).
     */
    interface AutoScalingGroupLaunchTemplateSpecificationArgs {
        /**
         * The ID of the launch template.
         *  You must specify the ``LaunchTemplateID`` or the ``LaunchTemplateName``, but not both.
         */
        launchTemplateId?: pulumi.Input<string>;
        /**
         * The name of the launch template.
         *  You must specify the ``LaunchTemplateName`` or the ``LaunchTemplateID``, but not both.
         */
        launchTemplateName?: pulumi.Input<string>;
        /**
         * The version number of the launch template.
         *  Specifying ``$Latest`` or ``$Default`` for the template version number is not supported. However, you can specify ``LatestVersionNumber`` or ``DefaultVersionNumber`` using the ``Fn::GetAtt`` intrinsic function. For more information, see [Fn::GetAtt](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/intrinsic-function-reference-getatt.html).
         *   For an example of using the ``Fn::GetAtt`` function, see the [Examples](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-autoscaling-autoscalinggroup.html#aws-resource-autoscaling-autoscalinggroup--examples) section of the ``AWS::AutoScaling::AutoScalingGroup`` resource.
         */
        version: pulumi.Input<string>;
    }
    /**
     * ``LifecycleHookSpecification`` specifies a lifecycle hook for the ``LifecycleHookSpecificationList`` property of the [AWS::AutoScaling::AutoScalingGroup](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-autoscaling-autoscalinggroup.html) resource. A lifecycle hook specifies actions to perform when Amazon EC2 Auto Scaling launches or terminates instances.
     *  For more information, see [Amazon EC2 Auto Scaling lifecycle hooks](https://docs.aws.amazon.com/autoscaling/ec2/userguide/lifecycle-hooks.html) in the *Amazon EC2 Auto Scaling User Guide*. You can find a sample template snippet in the [Examples](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-as-lifecyclehook.html#aws-resource-as-lifecyclehook--examples) section of the ``AWS::AutoScaling::LifecycleHook`` resource.
     */
    interface AutoScalingGroupLifecycleHookSpecificationArgs {
        /**
         * The action the Auto Scaling group takes when the lifecycle hook timeout elapses or if an unexpected failure occurs. The default value is ``ABANDON``.
         *  Valid values: ``CONTINUE`` | ``ABANDON``
         */
        defaultResult?: pulumi.Input<string>;
        /**
         * The maximum time, in seconds, that can elapse before the lifecycle hook times out. The range is from ``30`` to ``7200`` seconds. The default value is ``3600`` seconds (1 hour).
         */
        heartbeatTimeout?: pulumi.Input<number>;
        /**
         * The name of the lifecycle hook.
         */
        lifecycleHookName: pulumi.Input<string>;
        /**
         * The lifecycle transition. For Auto Scaling groups, there are two major lifecycle transitions.
         *   +  To create a lifecycle hook for scale-out events, specify ``autoscaling:EC2_INSTANCE_LAUNCHING``.
         *   +  To create a lifecycle hook for scale-in events, specify ``autoscaling:EC2_INSTANCE_TERMINATING``.
         */
        lifecycleTransition: pulumi.Input<string>;
        /**
         * Additional information that you want to include any time Amazon EC2 Auto Scaling sends a message to the notification target.
         */
        notificationMetadata?: pulumi.Input<string>;
        /**
         * The Amazon Resource Name (ARN) of the notification target that Amazon EC2 Auto Scaling sends notifications to when an instance is in a wait state for the lifecycle hook. You can specify an Amazon SNS topic or an Amazon SQS queue.
         */
        notificationTargetArn?: pulumi.Input<string>;
        /**
         * The ARN of the IAM role that allows the Auto Scaling group to publish to the specified notification target. For information about creating this role, see [Prepare to add a lifecycle hook to your Auto Scaling group](https://docs.aws.amazon.com/autoscaling/ec2/userguide/prepare-for-lifecycle-notifications.html) in the *Amazon EC2 Auto Scaling User Guide*.
         *  Valid only if the notification target is an Amazon SNS topic or an Amazon SQS queue.
         */
        roleArn?: pulumi.Input<string>;
    }
    /**
     * ``MemoryGiBPerVCpuRequest`` is a property of the ``InstanceRequirements`` property of the [AWS::AutoScaling::AutoScalingGroup LaunchTemplateOverrides](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-autoscaling-autoscalinggroup-launchtemplateoverrides.html) property type that describes the minimum and maximum amount of memory per vCPU for an instance type, in GiB.
     */
    interface AutoScalingGroupMemoryGiBPerVCpuRequestArgs {
        /**
         * The memory maximum in GiB.
         */
        max?: pulumi.Input<number>;
        /**
         * The memory minimum in GiB.
         */
        min?: pulumi.Input<number>;
    }
    /**
     * ``MemoryMiBRequest`` is a property of the ``InstanceRequirements`` property of the [AWS::AutoScaling::AutoScalingGroup LaunchTemplateOverrides](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-autoscaling-autoscalinggroup-launchtemplateoverrides.html) property type that describes the minimum and maximum instance memory size for an instance type, in MiB.
     */
    interface AutoScalingGroupMemoryMiBRequestArgs {
        /**
         * The memory maximum in MiB.
         */
        max?: pulumi.Input<number>;
        /**
         * The memory minimum in MiB.
         */
        min?: pulumi.Input<number>;
    }
    /**
     * ``MetricsCollection`` is a property of the [AWS::AutoScaling::AutoScalingGroup](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-autoscaling-autoscalinggroup.html) resource that describes the group metrics that an Amazon EC2 Auto Scaling group sends to Amazon CloudWatch. These metrics describe the group rather than any of its instances.
     *  For more information, see [Monitor CloudWatch metrics for your Auto Scaling groups and instances](https://docs.aws.amazon.com/autoscaling/ec2/userguide/as-instance-monitoring.html) in the *Amazon EC2 Auto Scaling User Guide*. You can find a sample template snippet in the [Examples](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-autoscaling-autoscalinggroup.html#aws-resource-autoscaling-autoscalinggroup--examples) section of the ``AWS::AutoScaling::AutoScalingGroup`` resource.
     */
    interface AutoScalingGroupMetricsCollectionArgs {
        /**
         * The frequency at which Amazon EC2 Auto Scaling sends aggregated data to CloudWatch. The only valid value is ``1Minute``.
         */
        granularity: pulumi.Input<string>;
        /**
         * Identifies the metrics to enable.
         *  You can specify one or more of the following metrics:
         *   +   ``GroupMinSize``
         *   +   ``GroupMaxSize``
         *   +   ``GroupDesiredCapacity``
         *   +   ``GroupInServiceInstances``
         *   +   ``GroupPendingInstances``
         *   +   ``GroupStandbyInstances``
         *   +   ``GroupTerminatingInstances``
         *   +   ``GroupTotalInstances``
         *   +   ``GroupInServiceCapacity``
         *   +   ``GroupPendingCapacity``
         *   +   ``GroupStandbyCapacity``
         *   +   ``GroupTerminatingCapacity``
         *   +   ``GroupTotalCapacity``
         *   +   ``WarmPoolDesiredCapacity``
         *   +   ``WarmPoolWarmedCapacity``
         *   +   ``WarmPoolPendingCapacity``
         *   +   ``WarmPoolTerminatingCapacity``
         *   +   ``WarmPoolTotalCapacity``
         *   +   ``GroupAndWarmPoolDesiredCapacity``
         *   +   ``GroupAndWarmPoolTotalCapacity``
         *
         *  If you specify ``Granularity`` and don't specify any metrics, all metrics are enabled.
         *  For more information, see [Amazon CloudWatch metrics for Amazon EC2 Auto Scaling](https://docs.aws.amazon.com/autoscaling/ec2/userguide/ec2-auto-scaling-metrics.html) in the *Amazon EC2 Auto Scaling User Guide*.
         */
        metrics?: pulumi.Input<pulumi.Input<string>[]>;
    }
    /**
     * Use this structure to launch multiple instance types and On-Demand Instances and Spot Instances within a single Auto Scaling group.
     *  A mixed instances policy contains information that Amazon EC2 Auto Scaling can use to launch instances and help optimize your costs. For more information, see [Auto Scaling groups with multiple instance types and purchase options](https://docs.aws.amazon.com/autoscaling/ec2/userguide/ec2-auto-scaling-mixed-instances-groups.html) in the *Amazon EC2 Auto Scaling User Guide*.
     *  You can create a mixed instances policy for new and existing Auto Scaling groups. You must use a launch template to configure the policy. You cannot use a launch configuration.
     *  There are key differences between Spot Instances and On-Demand Instances:
     *   +  The price for Spot Instances varies based on demand
     *   +  Amazon EC2 can terminate an individual Spot Instance as the availability of, or price for, Spot Instances changes
     *
     *  When a Spot Instance is terminated, Amazon EC2 Auto Scaling group attempts to launch a replacement instance to maintain the desired capacity for the group.
     *   ``MixedInstancesPolicy`` is a property of the [AWS::AutoScaling::AutoScalingGroup](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-autoscaling-autoscalinggroup.html) resource.
     */
    interface AutoScalingGroupMixedInstancesPolicyArgs {
        /**
         * The instances distribution.
         */
        instancesDistribution?: pulumi.Input<inputs.autoscaling.AutoScalingGroupInstancesDistributionArgs>;
        /**
         * One or more launch templates and the instance types (overrides) that are used to launch EC2 instances to fulfill On-Demand and Spot capacities.
         */
        launchTemplate: pulumi.Input<inputs.autoscaling.AutoScalingGroupLaunchTemplateArgs>;
    }
    /**
     * ``NetworkBandwidthGbpsRequest`` is a property of the ``InstanceRequirements`` property of the [AWS::AutoScaling::AutoScalingGroup LaunchTemplateOverrides](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-autoscaling-autoscalinggroup-launchtemplateoverrides.html) property type that describes the minimum and maximum network bandwidth for an instance type, in Gbps.
     *   Setting the minimum bandwidth does not guarantee that your instance will achieve the minimum bandwidth. Amazon EC2 will identify instance types that support the specified minimum bandwidth, but the actual bandwidth of your instance might go below the specified minimum at times. For more information, see [Available instance bandwidth](https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/ec2-instance-network-bandwidth.html#available-instance-bandwidth) in the *Amazon EC2 User Guide for Linux Instances*.
     */
    interface AutoScalingGroupNetworkBandwidthGbpsRequestArgs {
        /**
         * The maximum amount of network bandwidth, in gigabits per second (Gbps).
         */
        max?: pulumi.Input<number>;
        /**
         * The minimum amount of network bandwidth, in gigabits per second (Gbps).
         */
        min?: pulumi.Input<number>;
    }
    /**
     * ``NetworkInterfaceCountRequest`` is a property of the ``InstanceRequirements`` property of the [AWS::AutoScaling::AutoScalingGroup LaunchTemplateOverrides](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-autoscaling-autoscalinggroup-launchtemplateoverrides.html) property type that describes the minimum and maximum number of network interfaces for an instance type.
     */
    interface AutoScalingGroupNetworkInterfaceCountRequestArgs {
        /**
         * The maximum number of network interfaces.
         */
        max?: pulumi.Input<number>;
        /**
         * The minimum number of network interfaces.
         */
        min?: pulumi.Input<number>;
    }
    /**
     * A structure that specifies an Amazon SNS notification configuration for the ``NotificationConfigurations`` property of the [AWS::AutoScaling::AutoScalingGroup](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-autoscaling-autoscalinggroup.html) resource.
     *  For an example template snippet, see [Configure Amazon EC2 Auto Scaling resources](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/quickref-ec2-auto-scaling.html).
     *  For more information, see [Get Amazon SNS notifications when your Auto Scaling group scales](https://docs.aws.amazon.com/autoscaling/ec2/userguide/ASGettingNotifications.html) in the *Amazon EC2 Auto Scaling User Guide*.
     */
    interface AutoScalingGroupNotificationConfigurationArgs {
        /**
         * A list of event types that send a notification. Event types can include any of the following types.
         *   *Allowed values*:
         *   +   ``autoscaling:EC2_INSTANCE_LAUNCH``
         *   +   ``autoscaling:EC2_INSTANCE_LAUNCH_ERROR``
         *   +   ``autoscaling:EC2_INSTANCE_TERMINATE``
         *   +   ``autoscaling:EC2_INSTANCE_TERMINATE_ERROR``
         *   +   ``autoscaling:TEST_NOTIFICATION``
         */
        notificationTypes?: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * The Amazon Resource Name (ARN) of the Amazon SNS topic.
         */
        topicArn: pulumi.Input<pulumi.Input<string>[]>;
    }
    interface AutoScalingGroupPerformanceFactorReferenceRequestArgs {
        instanceFamily?: pulumi.Input<string>;
    }
    /**
     * A structure that specifies a tag for the ``Tags`` property of [AWS::AutoScaling::AutoScalingGroup](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-autoscaling-autoscalinggroup.html) resource.
     *  For more information, see [Tag Auto Scaling groups and instances](https://docs.aws.amazon.com/autoscaling/ec2/userguide/autoscaling-tagging.html) in the *Amazon EC2 Auto Scaling User Guide*. You can find a sample template snippet in the [Examples](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-autoscaling-autoscalinggroup.html#aws-resource-autoscaling-autoscalinggroup--examples) section of the ``AWS::AutoScaling::AutoScalingGroup`` resource.
     *  CloudFormation adds the following tags to all Auto Scaling groups and associated instances:
     *   +  aws:cloudformation:stack-name
     *   +  aws:cloudformation:stack-id
     *   +  aws:cloudformation:logical-id
     */
    interface AutoScalingGroupTagPropertyArgs {
        /**
         * The tag key.
         */
        key: pulumi.Input<string>;
        /**
         * Set to ``true`` if you want CloudFormation to copy the tag to EC2 instances that are launched as part of the Auto Scaling group. Set to ``false`` if you want the tag attached only to the Auto Scaling group and not copied to any instances launched as part of the Auto Scaling group.
         */
        propagateAtLaunch: pulumi.Input<boolean>;
        /**
         * The tag value.
         */
        value: pulumi.Input<string>;
    }
    /**
     * ``TotalLocalStorageGBRequest`` is a property of the ``InstanceRequirements`` property of the [AWS::AutoScaling::AutoScalingGroup LaunchTemplateOverrides](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-autoscaling-autoscalinggroup-launchtemplateoverrides.html) property type that describes the minimum and maximum total local storage size for an instance type, in GB.
     */
    interface AutoScalingGroupTotalLocalStorageGbRequestArgs {
        /**
         * The storage maximum in GB.
         */
        max?: pulumi.Input<number>;
        /**
         * The storage minimum in GB.
         */
        min?: pulumi.Input<number>;
    }
    /**
     * Identifying information for a traffic source.
     */
    interface AutoScalingGroupTrafficSourceIdentifierArgs {
        /**
         * Identifies the traffic source.
         *  For Application Load Balancers, Gateway Load Balancers, Network Load Balancers, and VPC Lattice, this will be the Amazon Resource Name (ARN) for a target group in this account and Region. For Classic Load Balancers, this will be the name of the Classic Load Balancer in this account and Region.
         *  For example:
         *   +  Application Load Balancer ARN: ``arn:aws:elasticloadbalancing:us-west-2:123456789012:targetgroup/my-targets/1234567890123456``
         *   +  Classic Load Balancer name: ``my-classic-load-balancer``
         *   +  VPC Lattice ARN: ``arn:aws:vpc-lattice:us-west-2:123456789012:targetgroup/tg-1234567890123456``
         *
         *  To get the ARN of a target group for a Application Load Balancer, Gateway Load Balancer, or Network Load Balancer, or the name of a Classic Load Balancer, use the Elastic Load Balancing [DescribeTargetGroups](https://docs.aws.amazon.com/elasticloadbalancing/latest/APIReference/API_DescribeTargetGroups.html) and [DescribeLoadBalancers](https://docs.aws.amazon.com/elasticloadbalancing/latest/APIReference/API_DescribeLoadBalancers.html) API operations.
         *  To get the ARN of a target group for VPC Lattice, use the VPC Lattice [GetTargetGroup](https://docs.aws.amazon.com/vpc-lattice/latest/APIReference/API_GetTargetGroup.html) API operation.
         */
        identifier: pulumi.Input<string>;
        /**
         * Provides additional context for the value of ``Identifier``.
         *  The following lists the valid values:
         *   +   ``elb`` if ``Identifier`` is the name of a Classic Load Balancer.
         *   +   ``elbv2`` if ``Identifier`` is the ARN of an Application Load Balancer, Gateway Load Balancer, or Network Load Balancer target group.
         *   +   ``vpc-lattice`` if ``Identifier`` is the ARN of a VPC Lattice target group.
         *
         *  Required if the identifier is the name of a Classic Load Balancer.
         */
        type: pulumi.Input<string>;
    }
    /**
     * ``VCpuCountRequest`` is a property of the ``InstanceRequirements`` property of the [AWS::AutoScaling::AutoScalingGroup LaunchTemplateOverrides](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-autoscaling-autoscalinggroup-launchtemplateoverrides.html) property type that describes the minimum and maximum number of vCPUs for an instance type.
     */
    interface AutoScalingGroupVCpuCountRequestArgs {
        /**
         * The maximum number of vCPUs.
         */
        max?: pulumi.Input<number>;
        /**
         * The minimum number of vCPUs.
         */
        min?: pulumi.Input<number>;
    }
    /**
     * BlockDevice is a subproperty of BlockDeviceMapping that describes an Amazon EBS volume.
     */
    interface LaunchConfigurationBlockDeviceArgs {
        /**
         * Indicates whether the volume is deleted on instance termination.
         */
        deleteOnTermination?: pulumi.Input<boolean>;
        /**
         * Specifies whether the volume should be encrypted.
         */
        encrypted?: pulumi.Input<boolean>;
        /**
         * The number of input/output (I/O) operations per second (IOPS) to provision for the volume.
         */
        iops?: pulumi.Input<number>;
        /**
         * The snapshot ID of the volume to use.
         */
        snapshotId?: pulumi.Input<string>;
        /**
         * The throughput (MiBps) to provision for a gp3 volume.
         */
        throughput?: pulumi.Input<number>;
        /**
         * The volume size, in GiBs.
         */
        volumeSize?: pulumi.Input<number>;
        /**
         * The volume type.
         */
        volumeType?: pulumi.Input<string>;
    }
    /**
     * BlockDeviceMapping is a property of AWS::AutoScaling::LaunchConfiguration that describes a block device mapping for an Auto Scaling group.
     */
    interface LaunchConfigurationBlockDeviceMappingArgs {
        /**
         * The device name exposed to the EC2 instance (for example, /dev/sdh or xvdh).
         */
        deviceName: pulumi.Input<string>;
        /**
         * Parameters used to automatically set up EBS volumes when an instance is launched.
         */
        ebs?: pulumi.Input<inputs.autoscaling.LaunchConfigurationBlockDeviceArgs>;
        /**
         * Setting this value to true suppresses the specified device included in the block device mapping of the AMI.
         */
        noDevice?: pulumi.Input<boolean>;
        /**
         * The name of the virtual device.
         */
        virtualName?: pulumi.Input<string>;
    }
    /**
     * MetadataOptions is a property of AWS::AutoScaling::LaunchConfiguration that describes metadata options for the instances.
     */
    interface LaunchConfigurationMetadataOptionsArgs {
        /**
         * This parameter enables or disables the HTTP metadata endpoint on your instances.
         */
        httpEndpoint?: pulumi.Input<string>;
        /**
         * The desired HTTP PUT response hop limit for instance metadata requests.
         */
        httpPutResponseHopLimit?: pulumi.Input<number>;
        /**
         * The state of token usage for your instance metadata requests.
         */
        httpTokens?: pulumi.Input<string>;
    }
    interface ScalingPolicyCustomizedMetricSpecificationArgs {
        /**
         * The dimensions of the metric.
         *
         * Conditional: If you published your metric with dimensions, you must specify the same dimensions in your scaling policy.
         */
        dimensions?: pulumi.Input<pulumi.Input<inputs.autoscaling.ScalingPolicyMetricDimensionArgs>[]>;
        /**
         * The name of the metric. To get the exact metric name, namespace, and dimensions, inspect the [Metric](https://docs.aws.amazon.com/AmazonCloudWatch/latest/APIReference/API_Metric.html) object that is returned by a call to [ListMetrics](https://docs.aws.amazon.com/AmazonCloudWatch/latest/APIReference/API_ListMetrics.html) .
         */
        metricName?: pulumi.Input<string>;
        /**
         * The metrics to include in the target tracking scaling policy, as a metric data query. This can include both raw metric and metric math expressions.
         */
        metrics?: pulumi.Input<pulumi.Input<inputs.autoscaling.ScalingPolicyTargetTrackingMetricDataQueryArgs>[]>;
        /**
         * The namespace of the metric.
         */
        namespace?: pulumi.Input<string>;
        /**
         * The period of the metric in seconds. The default value is 60. Accepted values are 10, 30, and 60. For high resolution metric, set the value to less than 60. For more information, see [Create a target tracking policy using high-resolution metrics for faster response](https://docs.aws.amazon.com/autoscaling/ec2/userguide/policy-creating-high-resolution-metrics.html) .
         */
        period?: pulumi.Input<number>;
        /**
         * The statistic of the metric.
         */
        statistic?: pulumi.Input<string>;
        /**
         * The unit of the metric. For a complete list of the units that CloudWatch supports, see the [MetricDatum](https://docs.aws.amazon.com/AmazonCloudWatch/latest/APIReference/API_MetricDatum.html) data type in the *Amazon CloudWatch API Reference* .
         */
        unit?: pulumi.Input<string>;
    }
    interface ScalingPolicyMetricArgs {
        /**
         * The dimensions for the metric. For the list of available dimensions, see the AWS documentation available from the table in [AWS services that publish CloudWatch metrics](https://docs.aws.amazon.com/AmazonCloudWatch/latest/monitoring/aws-services-cloudwatch-metrics.html) in the *Amazon CloudWatch User Guide* .
         *
         * Conditional: If you published your metric with dimensions, you must specify the same dimensions in your scaling policy.
         */
        dimensions?: pulumi.Input<pulumi.Input<inputs.autoscaling.ScalingPolicyMetricDimensionArgs>[]>;
        /**
         * The name of the metric.
         */
        metricName: pulumi.Input<string>;
        /**
         * The namespace of the metric. For more information, see the table in [AWS services that publish CloudWatch metrics](https://docs.aws.amazon.com/AmazonCloudWatch/latest/monitoring/aws-services-cloudwatch-metrics.html) in the *Amazon CloudWatch User Guide* .
         */
        namespace: pulumi.Input<string>;
    }
    interface ScalingPolicyMetricDataQueryArgs {
        /**
         * The math expression to perform on the returned data, if this object is performing a math expression. This expression can use the `Id` of the other metrics to refer to those metrics, and can also use the `Id` of other expressions to use the result of those expressions.
         *
         * Conditional: Within each `MetricDataQuery` object, you must specify either `Expression` or `MetricStat` , but not both.
         */
        expression?: pulumi.Input<string>;
        /**
         * A short name that identifies the object's results in the response. This name must be unique among all `MetricDataQuery` objects specified for a single scaling policy. If you are performing math expressions on this set of data, this name represents that data and can serve as a variable in the mathematical expression. The valid characters are letters, numbers, and underscores. The first character must be a lowercase letter.
         */
        id: pulumi.Input<string>;
        /**
         * A human-readable label for this metric or expression. This is especially useful if this is a math expression, so that you know what the value represents.
         */
        label?: pulumi.Input<string>;
        /**
         * Information about the metric data to return.
         *
         * Conditional: Within each `MetricDataQuery` object, you must specify either `Expression` or `MetricStat` , but not both.
         */
        metricStat?: pulumi.Input<inputs.autoscaling.ScalingPolicyMetricStatArgs>;
        /**
         * Indicates whether to return the timestamps and raw data values of this metric.
         *
         * If you use any math expressions, specify `true` for this value for only the final math expression that the metric specification is based on. You must specify `false` for `ReturnData` for all the other metrics and expressions used in the metric specification.
         *
         * If you are only retrieving metrics and not performing any math expressions, do not specify anything for `ReturnData` . This sets it to its default ( `true` ).
         */
        returnData?: pulumi.Input<boolean>;
    }
    interface ScalingPolicyMetricDimensionArgs {
        /**
         * The name of the dimension.
         */
        name: pulumi.Input<string>;
        /**
         * The value of the dimension.
         */
        value: pulumi.Input<string>;
    }
    interface ScalingPolicyMetricStatArgs {
        /**
         * The CloudWatch metric to return, including the metric name, namespace, and dimensions. To get the exact metric name, namespace, and dimensions, inspect the [Metric](https://docs.aws.amazon.com/AmazonCloudWatch/latest/APIReference/API_Metric.html) object that is returned by a call to [ListMetrics](https://docs.aws.amazon.com/AmazonCloudWatch/latest/APIReference/API_ListMetrics.html) .
         */
        metric: pulumi.Input<inputs.autoscaling.ScalingPolicyMetricArgs>;
        /**
         * The statistic to return. It can include any CloudWatch statistic or extended statistic. For a list of valid values, see the table in [Statistics](https://docs.aws.amazon.com/AmazonCloudWatch/latest/monitoring/cloudwatch_concepts.html#Statistic) in the *Amazon CloudWatch User Guide* .
         *
         * The most commonly used metrics for predictive scaling are `Average` and `Sum` .
         */
        stat: pulumi.Input<string>;
        /**
         * The unit to use for the returned data points. For a complete list of the units that CloudWatch supports, see the [MetricDatum](https://docs.aws.amazon.com/AmazonCloudWatch/latest/APIReference/API_MetricDatum.html) data type in the *Amazon CloudWatch API Reference* .
         */
        unit?: pulumi.Input<string>;
    }
    interface ScalingPolicyPredefinedMetricSpecificationArgs {
        /**
         * The metric type. The following predefined metrics are available:
         *
         * - `ASGAverageCPUUtilization` - Average CPU utilization of the Auto Scaling group.
         * - `ASGAverageNetworkIn` - Average number of bytes received on all network interfaces by the Auto Scaling group.
         * - `ASGAverageNetworkOut` - Average number of bytes sent out on all network interfaces by the Auto Scaling group.
         * - `ALBRequestCountPerTarget` - Average Application Load Balancer request count per target for your Auto Scaling group.
         */
        predefinedMetricType: pulumi.Input<string>;
        /**
         * A label that uniquely identifies a specific Application Load Balancer target group from which to determine the average request count served by your Auto Scaling group. You can't specify a resource label unless the target group is attached to the Auto Scaling group.
         *
         * You create the resource label by appending the final portion of the load balancer ARN and the final portion of the target group ARN into a single value, separated by a forward slash (/). The format of the resource label is:
         *
         * `app/my-alb/778d41231b141a0f/targetgroup/my-alb-target-group/943f017f100becff` .
         *
         * Where:
         *
         * - app/<load-balancer-name>/<load-balancer-id> is the final portion of the load balancer ARN
         * - targetgroup/<target-group-name>/<target-group-id> is the final portion of the target group ARN.
         *
         * To find the ARN for an Application Load Balancer, use the [DescribeLoadBalancers](https://docs.aws.amazon.com/elasticloadbalancing/latest/APIReference/API_DescribeLoadBalancers.html) API operation. To find the ARN for the target group, use the [DescribeTargetGroups](https://docs.aws.amazon.com/elasticloadbalancing/latest/APIReference/API_DescribeTargetGroups.html) API operation.
         */
        resourceLabel?: pulumi.Input<string>;
    }
    interface ScalingPolicyPredictiveScalingConfigurationArgs {
        /**
         * Defines the behavior that should be applied if the forecast capacity approaches or exceeds the maximum capacity of the Auto Scaling group. Defaults to `HonorMaxCapacity` if not specified.
         *
         * The following are possible values:
         *
         * - `HonorMaxCapacity` - Amazon EC2 Auto Scaling can't increase the maximum capacity of the group when the forecast capacity is close to or exceeds the maximum capacity.
         * - `IncreaseMaxCapacity` - Amazon EC2 Auto Scaling can increase the maximum capacity of the group when the forecast capacity is close to or exceeds the maximum capacity. The upper limit is determined by the forecasted capacity and the value for `MaxCapacityBuffer` .
         *
         * > Use caution when allowing the maximum capacity to be automatically increased. This can lead to more instances being launched than intended if the increased maximum capacity is not monitored and managed. The increased maximum capacity then becomes the new normal maximum capacity for the Auto Scaling group until you manually update it. The maximum capacity does not automatically decrease back to the original maximum.
         */
        maxCapacityBreachBehavior?: pulumi.Input<string>;
        /**
         * The size of the capacity buffer to use when the forecast capacity is close to or exceeds the maximum capacity. The value is specified as a percentage relative to the forecast capacity. For example, if the buffer is 10, this means a 10 percent buffer, such that if the forecast capacity is 50, and the maximum capacity is 40, then the effective maximum capacity is 55.
         *
         * If set to 0, Amazon EC2 Auto Scaling may scale capacity higher than the maximum capacity to equal but not exceed forecast capacity.
         *
         * Required if the `MaxCapacityBreachBehavior` property is set to `IncreaseMaxCapacity` , and cannot be used otherwise.
         */
        maxCapacityBuffer?: pulumi.Input<number>;
        /**
         * This structure includes the metrics and target utilization to use for predictive scaling.
         *
         * This is an array, but we currently only support a single metric specification. That is, you can specify a target value and a single metric pair, or a target value and one scaling metric and one load metric.
         */
        metricSpecifications: pulumi.Input<pulumi.Input<inputs.autoscaling.ScalingPolicyPredictiveScalingMetricSpecificationArgs>[]>;
        /**
         * The predictive scaling mode. Defaults to `ForecastOnly` if not specified.
         */
        mode?: pulumi.Input<string>;
        /**
         * The amount of time, in seconds, by which the instance launch time can be advanced. For example, the forecast says to add capacity at 10:00 AM, and you choose to pre-launch instances by 5 minutes. In that case, the instances will be launched at 9:55 AM. The intention is to give resources time to be provisioned. It can take a few minutes to launch an EC2 instance. The actual amount of time required depends on several factors, such as the size of the instance and whether there are startup scripts to complete.
         *
         * The value must be less than the forecast interval duration of 3600 seconds (60 minutes). Defaults to 300 seconds if not specified.
         */
        schedulingBufferTime?: pulumi.Input<number>;
    }
    interface ScalingPolicyPredictiveScalingCustomizedCapacityMetricArgs {
        /**
         * One or more metric data queries to provide the data points for a capacity metric. Use multiple metric data queries only if you are performing a math expression on returned data.
         */
        metricDataQueries: pulumi.Input<pulumi.Input<inputs.autoscaling.ScalingPolicyMetricDataQueryArgs>[]>;
    }
    interface ScalingPolicyPredictiveScalingCustomizedLoadMetricArgs {
        /**
         * One or more metric data queries to provide the data points for a load metric. Use multiple metric data queries only if you are performing a math expression on returned data.
         */
        metricDataQueries: pulumi.Input<pulumi.Input<inputs.autoscaling.ScalingPolicyMetricDataQueryArgs>[]>;
    }
    interface ScalingPolicyPredictiveScalingCustomizedScalingMetricArgs {
        /**
         * One or more metric data queries to provide the data points for a scaling metric. Use multiple metric data queries only if you are performing a math expression on returned data.
         */
        metricDataQueries: pulumi.Input<pulumi.Input<inputs.autoscaling.ScalingPolicyMetricDataQueryArgs>[]>;
    }
    interface ScalingPolicyPredictiveScalingMetricSpecificationArgs {
        /**
         * The customized capacity metric specification.
         */
        customizedCapacityMetricSpecification?: pulumi.Input<inputs.autoscaling.ScalingPolicyPredictiveScalingCustomizedCapacityMetricArgs>;
        /**
         * The customized load metric specification.
         */
        customizedLoadMetricSpecification?: pulumi.Input<inputs.autoscaling.ScalingPolicyPredictiveScalingCustomizedLoadMetricArgs>;
        /**
         * The customized scaling metric specification.
         */
        customizedScalingMetricSpecification?: pulumi.Input<inputs.autoscaling.ScalingPolicyPredictiveScalingCustomizedScalingMetricArgs>;
        /**
         * The predefined load metric specification.
         */
        predefinedLoadMetricSpecification?: pulumi.Input<inputs.autoscaling.ScalingPolicyPredictiveScalingPredefinedLoadMetricArgs>;
        /**
         * The predefined metric pair specification from which Amazon EC2 Auto Scaling determines the appropriate scaling metric and load metric to use.
         */
        predefinedMetricPairSpecification?: pulumi.Input<inputs.autoscaling.ScalingPolicyPredictiveScalingPredefinedMetricPairArgs>;
        /**
         * The predefined scaling metric specification.
         */
        predefinedScalingMetricSpecification?: pulumi.Input<inputs.autoscaling.ScalingPolicyPredictiveScalingPredefinedScalingMetricArgs>;
        /**
         * Specifies the target utilization.
         *
         * > Some metrics are based on a count instead of a percentage, such as the request count for an Application Load Balancer or the number of messages in an SQS queue. If the scaling policy specifies one of these metrics, specify the target utilization as the optimal average request or message count per instance during any one-minute interval.
         */
        targetValue: pulumi.Input<number>;
    }
    interface ScalingPolicyPredictiveScalingPredefinedLoadMetricArgs {
        /**
         * The metric type.
         */
        predefinedMetricType: pulumi.Input<string>;
        /**
         * A label that uniquely identifies a specific Application Load Balancer target group from which to determine the request count served by your Auto Scaling group. You can't specify a resource label unless the target group is attached to the Auto Scaling group.
         *
         * You create the resource label by appending the final portion of the load balancer ARN and the final portion of the target group ARN into a single value, separated by a forward slash (/). The format of the resource label is:
         *
         * `app/my-alb/778d41231b141a0f/targetgroup/my-alb-target-group/943f017f100becff` .
         *
         * Where:
         *
         * - app/<load-balancer-name>/<load-balancer-id> is the final portion of the load balancer ARN
         * - targetgroup/<target-group-name>/<target-group-id> is the final portion of the target group ARN.
         *
         * To find the ARN for an Application Load Balancer, use the [DescribeLoadBalancers](https://docs.aws.amazon.com/elasticloadbalancing/latest/APIReference/API_DescribeLoadBalancers.html) API operation. To find the ARN for the target group, use the [DescribeTargetGroups](https://docs.aws.amazon.com/elasticloadbalancing/latest/APIReference/API_DescribeTargetGroups.html) API operation.
         */
        resourceLabel?: pulumi.Input<string>;
    }
    interface ScalingPolicyPredictiveScalingPredefinedMetricPairArgs {
        /**
         * Indicates which metrics to use. There are two different types of metrics for each metric type: one is a load metric and one is a scaling metric. For example, if the metric type is `ASGCPUUtilization` , the Auto Scaling group's total CPU metric is used as the load metric, and the average CPU metric is used for the scaling metric.
         */
        predefinedMetricType: pulumi.Input<string>;
        /**
         * A label that uniquely identifies a specific Application Load Balancer target group from which to determine the total and average request count served by your Auto Scaling group. You can't specify a resource label unless the target group is attached to the Auto Scaling group.
         *
         * You create the resource label by appending the final portion of the load balancer ARN and the final portion of the target group ARN into a single value, separated by a forward slash (/). The format of the resource label is:
         *
         * `app/my-alb/778d41231b141a0f/targetgroup/my-alb-target-group/943f017f100becff` .
         *
         * Where:
         *
         * - app/<load-balancer-name>/<load-balancer-id> is the final portion of the load balancer ARN
         * - targetgroup/<target-group-name>/<target-group-id> is the final portion of the target group ARN.
         *
         * To find the ARN for an Application Load Balancer, use the [DescribeLoadBalancers](https://docs.aws.amazon.com/elasticloadbalancing/latest/APIReference/API_DescribeLoadBalancers.html) API operation. To find the ARN for the target group, use the [DescribeTargetGroups](https://docs.aws.amazon.com/elasticloadbalancing/latest/APIReference/API_DescribeTargetGroups.html) API operation.
         */
        resourceLabel?: pulumi.Input<string>;
    }
    interface ScalingPolicyPredictiveScalingPredefinedScalingMetricArgs {
        /**
         * The metric type.
         */
        predefinedMetricType: pulumi.Input<string>;
        /**
         * A label that uniquely identifies a specific Application Load Balancer target group from which to determine the average request count served by your Auto Scaling group. You can't specify a resource label unless the target group is attached to the Auto Scaling group.
         *
         * You create the resource label by appending the final portion of the load balancer ARN and the final portion of the target group ARN into a single value, separated by a forward slash (/). The format of the resource label is:
         *
         * `app/my-alb/778d41231b141a0f/targetgroup/my-alb-target-group/943f017f100becff` .
         *
         * Where:
         *
         * - app/<load-balancer-name>/<load-balancer-id> is the final portion of the load balancer ARN
         * - targetgroup/<target-group-name>/<target-group-id> is the final portion of the target group ARN.
         *
         * To find the ARN for an Application Load Balancer, use the [DescribeLoadBalancers](https://docs.aws.amazon.com/elasticloadbalancing/latest/APIReference/API_DescribeLoadBalancers.html) API operation. To find the ARN for the target group, use the [DescribeTargetGroups](https://docs.aws.amazon.com/elasticloadbalancing/latest/APIReference/API_DescribeTargetGroups.html) API operation.
         */
        resourceLabel?: pulumi.Input<string>;
    }
    interface ScalingPolicyStepAdjustmentArgs {
        /**
         * The lower bound for the difference between the alarm threshold and the CloudWatch metric. If the metric value is above the breach threshold, the lower bound is inclusive (the metric must be greater than or equal to the threshold plus the lower bound). Otherwise, it is exclusive (the metric must be greater than the threshold plus the lower bound). A null value indicates negative infinity.
         */
        metricIntervalLowerBound?: pulumi.Input<number>;
        /**
         * The upper bound for the difference between the alarm threshold and the CloudWatch metric. If the metric value is above the breach threshold, the upper bound is exclusive (the metric must be less than the threshold plus the upper bound). Otherwise, it is inclusive (the metric must be less than or equal to the threshold plus the upper bound). A null value indicates positive infinity.
         *
         * The upper bound must be greater than the lower bound.
         */
        metricIntervalUpperBound?: pulumi.Input<number>;
        /**
         * The amount by which to scale, based on the specified adjustment type. A positive value adds to the current capacity while a negative number removes from the current capacity. For exact capacity, you must specify a non-negative value.
         */
        scalingAdjustment: pulumi.Input<number>;
    }
    interface ScalingPolicyTargetTrackingConfigurationArgs {
        /**
         * A customized metric. You must specify either a predefined metric or a customized metric.
         */
        customizedMetricSpecification?: pulumi.Input<inputs.autoscaling.ScalingPolicyCustomizedMetricSpecificationArgs>;
        /**
         * Indicates whether scaling in by the target tracking scaling policy is disabled. If scaling in is disabled, the target tracking scaling policy doesn't remove instances from the Auto Scaling group. Otherwise, the target tracking scaling policy can remove instances from the Auto Scaling group. The default is `false` .
         */
        disableScaleIn?: pulumi.Input<boolean>;
        /**
         * A predefined metric. You must specify either a predefined metric or a customized metric.
         */
        predefinedMetricSpecification?: pulumi.Input<inputs.autoscaling.ScalingPolicyPredefinedMetricSpecificationArgs>;
        /**
         * The target value for the metric.
         *
         * > Some metrics are based on a count instead of a percentage, such as the request count for an Application Load Balancer or the number of messages in an SQS queue. If the scaling policy specifies one of these metrics, specify the target utilization as the optimal average request or message count per instance during any one-minute interval.
         */
        targetValue: pulumi.Input<number>;
    }
    interface ScalingPolicyTargetTrackingMetricDataQueryArgs {
        /**
         * The math expression to perform on the returned data, if this object is performing a math expression. This expression can use the `Id` of the other metrics to refer to those metrics, and can also use the `Id` of other expressions to use the result of those expressions.
         *
         * Conditional: Within each `TargetTrackingMetricDataQuery` object, you must specify either `Expression` or `MetricStat` , but not both.
         */
        expression?: pulumi.Input<string>;
        /**
         * A short name that identifies the object's results in the response. This name must be unique among all `TargetTrackingMetricDataQuery` objects specified for a single scaling policy. If you are performing math expressions on this set of data, this name represents that data and can serve as a variable in the mathematical expression. The valid characters are letters, numbers, and underscores. The first character must be a lowercase letter.
         */
        id: pulumi.Input<string>;
        /**
         * A human-readable label for this metric or expression. This is especially useful if this is a math expression, so that you know what the value represents.
         */
        label?: pulumi.Input<string>;
        /**
         * Information about the metric data to return.
         *
         * Conditional: Within each `TargetTrackingMetricDataQuery` object, you must specify either `Expression` or `MetricStat` , but not both.
         */
        metricStat?: pulumi.Input<inputs.autoscaling.ScalingPolicyTargetTrackingMetricStatArgs>;
        /**
         * The period of the metric in seconds. The default value is 60. Accepted values are 10, 30, and 60. For high resolution metric, set the value to less than 60. For more information, see [Create a target tracking policy using high-resolution metrics for faster response](https://docs.aws.amazon.com/autoscaling/ec2/userguide/policy-creating-high-resolution-metrics.html) .
         */
        period?: pulumi.Input<number>;
        /**
         * Indicates whether to return the timestamps and raw data values of this metric.
         *
         * If you use any math expressions, specify `true` for this value for only the final math expression that the metric specification is based on. You must specify `false` for `ReturnData` for all the other metrics and expressions used in the metric specification.
         *
         * If you are only retrieving metrics and not performing any math expressions, do not specify anything for `ReturnData` . This sets it to its default ( `true` ).
         */
        returnData?: pulumi.Input<boolean>;
    }
    interface ScalingPolicyTargetTrackingMetricStatArgs {
        /**
         * The metric to use.
         */
        metric: pulumi.Input<inputs.autoscaling.ScalingPolicyMetricArgs>;
        /**
         * The period of the metric in seconds. The default value is 60. Accepted values are 10, 30, and 60. For high resolution metric, set the value to less than 60. For more information, see [Create a target tracking policy using high-resolution metrics for faster response](https://docs.aws.amazon.com/autoscaling/ec2/userguide/policy-creating-high-resolution-metrics.html) .
         */
        period?: pulumi.Input<number>;
        /**
         * The statistic to return. It can include any CloudWatch statistic or extended statistic. For a list of valid values, see the table in [Statistics](https://docs.aws.amazon.com/AmazonCloudWatch/latest/monitoring/cloudwatch_concepts.html#Statistic) in the *Amazon CloudWatch User Guide* .
         *
         * The most commonly used metric for scaling is `Average` .
         */
        stat: pulumi.Input<string>;
        /**
         * The unit to use for the returned data points. For a complete list of the units that CloudWatch supports, see the [MetricDatum](https://docs.aws.amazon.com/AmazonCloudWatch/latest/APIReference/API_MetricDatum.html) data type in the *Amazon CloudWatch API Reference* .
         */
        unit?: pulumi.Input<string>;
    }
    interface WarmPoolInstanceReusePolicyArgs {
        /**
         * Specifies whether instances in the Auto Scaling group can be returned to the warm pool on scale in.
         */
        reuseOnScaleIn?: pulumi.Input<boolean>;
    }
}
export declare namespace b2bi {
    interface CapabilityConfigurationPropertiesArgs {
        edi: pulumi.Input<inputs.b2bi.CapabilityEdiConfigurationArgs>;
    }
    interface CapabilityEdiConfigurationArgs {
        capabilityDirection?: pulumi.Input<enums.b2bi.CapabilityDirection>;
        inputLocation: pulumi.Input<inputs.b2bi.CapabilityS3LocationArgs>;
        outputLocation: pulumi.Input<inputs.b2bi.CapabilityS3LocationArgs>;
        transformerId: pulumi.Input<string>;
        type: pulumi.Input<inputs.b2bi.CapabilityEdiTypePropertiesArgs>;
    }
    interface CapabilityEdiTypePropertiesArgs {
        x12Details: pulumi.Input<inputs.b2bi.CapabilityX12DetailsArgs>;
    }
    interface CapabilityS3LocationArgs {
        bucketName?: pulumi.Input<string>;
        key?: pulumi.Input<string>;
    }
    interface CapabilityX12DetailsArgs {
        transactionSet?: pulumi.Input<enums.b2bi.CapabilityX12TransactionSet>;
        version?: pulumi.Input<enums.b2bi.CapabilityX12Version>;
    }
    interface PartnershipCapabilityOptionsArgs {
        /**
         * A structure that contains the outbound EDI options.
         */
        outboundEdi?: pulumi.Input<inputs.b2bi.PartnershipOutboundEdiOptionsPropertiesArgs>;
    }
    interface PartnershipOutboundEdiOptionsPropertiesArgs {
        x12: pulumi.Input<inputs.b2bi.PartnershipX12EnvelopeArgs>;
    }
    interface PartnershipX12DelimitersArgs {
        componentSeparator?: pulumi.Input<string>;
        dataElementSeparator?: pulumi.Input<string>;
        segmentTerminator?: pulumi.Input<string>;
    }
    interface PartnershipX12EnvelopeArgs {
        common?: pulumi.Input<inputs.b2bi.PartnershipX12OutboundEdiHeadersArgs>;
    }
    interface PartnershipX12FunctionalGroupHeadersArgs {
        applicationReceiverCode?: pulumi.Input<string>;
        applicationSenderCode?: pulumi.Input<string>;
        responsibleAgencyCode?: pulumi.Input<string>;
    }
    interface PartnershipX12InterchangeControlHeadersArgs {
        acknowledgmentRequestedCode?: pulumi.Input<string>;
        receiverId?: pulumi.Input<string>;
        receiverIdQualifier?: pulumi.Input<string>;
        repetitionSeparator?: pulumi.Input<string>;
        senderId?: pulumi.Input<string>;
        senderIdQualifier?: pulumi.Input<string>;
        usageIndicatorCode?: pulumi.Input<string>;
    }
    interface PartnershipX12OutboundEdiHeadersArgs {
        delimiters?: pulumi.Input<inputs.b2bi.PartnershipX12DelimitersArgs>;
        functionalGroupHeaders?: pulumi.Input<inputs.b2bi.PartnershipX12FunctionalGroupHeadersArgs>;
        interchangeControlHeaders?: pulumi.Input<inputs.b2bi.PartnershipX12InterchangeControlHeadersArgs>;
        validateEdi?: pulumi.Input<boolean>;
    }
    interface TransformerEdiTypePropertiesArgs {
        x12Details: pulumi.Input<inputs.b2bi.TransformerX12DetailsArgs>;
    }
    interface TransformerFormatOptionsPropertiesArgs {
        x12: pulumi.Input<inputs.b2bi.TransformerX12DetailsArgs>;
    }
    interface TransformerInputConversionArgs {
        formatOptions?: pulumi.Input<inputs.b2bi.TransformerFormatOptionsPropertiesArgs>;
        fromFormat: pulumi.Input<enums.b2bi.TransformerFromFormat>;
    }
    interface TransformerMappingArgs {
        template?: pulumi.Input<string>;
        templateLanguage: pulumi.Input<enums.b2bi.TransformerMappingTemplateLanguage>;
    }
    interface TransformerOutputConversionArgs {
        formatOptions?: pulumi.Input<inputs.b2bi.TransformerFormatOptionsPropertiesArgs>;
        toFormat: pulumi.Input<enums.b2bi.TransformerToFormat>;
    }
    interface TransformerSampleDocumentKeysArgs {
        input?: pulumi.Input<string>;
        output?: pulumi.Input<string>;
    }
    interface TransformerSampleDocumentsArgs {
        bucketName: pulumi.Input<string>;
        keys: pulumi.Input<pulumi.Input<inputs.b2bi.TransformerSampleDocumentKeysArgs>[]>;
    }
    interface TransformerX12DetailsArgs {
        transactionSet?: pulumi.Input<enums.b2bi.TransformerX12TransactionSet>;
        version?: pulumi.Input<enums.b2bi.TransformerX12Version>;
    }
}
export declare namespace backup {
    interface BackupPlanAdvancedBackupSettingResourceTypeArgs {
        /**
         * The backup option for the resource. Each option is a key-value pair. This option is only available for Windows VSS backup jobs.
         *
         * Valid values:
         *
         * Set to `"WindowsVSS":"enabled"` to enable the `WindowsVSS` backup option and create a Windows VSS backup.
         *
         * Set to `"WindowsVSS":"disabled"` to create a regular backup. The `WindowsVSS` option is not enabled by default.
         *
         * If you specify an invalid option, you get an `InvalidParameterValueException` exception.
         *
         * For more information about Windows VSS backups, see [Creating a VSS-Enabled Windows Backup](https://docs.aws.amazon.com/aws-backup/latest/devguide/windows-backups.html) .
         */
        backupOptions: any;
        /**
         * The name of a resource type. The only supported resource type is EC2.
         */
        resourceType: pulumi.Input<string>;
    }
    interface BackupPlanBackupRuleResourceTypeArgs {
        /**
         * A value in minutes after a backup job is successfully started before it must be completed or it is canceled by AWS Backup .
         */
        completionWindowMinutes?: pulumi.Input<number>;
        /**
         * An array of CopyAction objects, which contains the details of the copy operation.
         */
        copyActions?: pulumi.Input<pulumi.Input<inputs.backup.BackupPlanCopyActionResourceTypeArgs>[]>;
        /**
         * Enables continuous backup and point-in-time restores (PITR).
         */
        enableContinuousBackup?: pulumi.Input<boolean>;
        indexActions?: pulumi.Input<pulumi.Input<inputs.backup.BackupPlanIndexActionsResourceTypeArgs>[]>;
        /**
         * The lifecycle defines when a protected resource is transitioned to cold storage and when it expires. AWS Backup transitions and expires backups automatically according to the lifecycle that you define.
         */
        lifecycle?: pulumi.Input<inputs.backup.BackupPlanLifecycleResourceTypeArgs>;
        /**
         * The tags to assign to the resources.
         */
        recoveryPointTags?: pulumi.Input<{
            [key: string]: pulumi.Input<string>;
        }>;
        /**
         * A display name for a backup rule.
         */
        ruleName: pulumi.Input<string>;
        /**
         * A CRON expression specifying when AWS Backup initiates a backup job.
         */
        scheduleExpression?: pulumi.Input<string>;
        /**
         * This is the timezone in which the schedule expression is set. By default, ScheduleExpressions are in UTC. You can modify this to a specified timezone.
         */
        scheduleExpressionTimezone?: pulumi.Input<string>;
        /**
         * An optional value that specifies a period of time in minutes after a backup is scheduled before a job is canceled if it doesn't start successfully.
         *
         * If this value is included, it must be at least 60 minutes to avoid errors.
         */
        startWindowMinutes?: pulumi.Input<number>;
        /**
         * The name of a logical container where backups are stored. Backup vaults are identified by names that are unique to the account used to create them and the AWS Region where they are created. They consist of letters, numbers, and hyphens.
         */
        targetBackupVault: pulumi.Input<string>;
    }
    interface BackupPlanCopyActionResourceTypeArgs {
        /**
         * An Amazon Resource Name (ARN) that uniquely identifies the destination backup vault for the copied backup. For example, `arn:aws:backup:us-east-1:123456789012:vault:aBackupVault.`
         */
        destinationBackupVaultArn: pulumi.Input<string>;
        /**
         * Defines when a protected resource is transitioned to cold storage and when it expires. AWS Backup transitions and expires backups automatically according to the lifecycle that you define. If you do not specify a lifecycle, AWS Backup applies the lifecycle policy of the source backup to the destination backup.
         *
         * Backups transitioned to cold storage must be stored in cold storage for a minimum of 90 days.
         */
        lifecycle?: pulumi.Input<inputs.backup.BackupPlanLifecycleResourceTypeArgs>;
    }
    interface BackupPlanIndexActionsResourceTypeArgs {
        resourceTypes?: pulumi.Input<pulumi.Input<string>[]>;
    }
    interface BackupPlanLifecycleResourceTypeArgs {
        /**
         * Specifies the number of days after creation that a recovery point is deleted. Must be greater than `MoveToColdStorageAfterDays` .
         */
        deleteAfterDays?: pulumi.Input<number>;
        /**
         * Specifies the number of days after creation that a recovery point is moved to cold storage.
         */
        moveToColdStorageAfterDays?: pulumi.Input<number>;
        /**
         * If the value is true, your backup plan transitions supported resources to archive (cold) storage tier in accordance with your lifecycle settings.
         */
        optInToArchiveForSupportedResources?: pulumi.Input<boolean>;
    }
    interface BackupPlanResourceTypeArgs {
        /**
         * A list of backup options for each resource type.
         */
        advancedBackupSettings?: pulumi.Input<pulumi.Input<inputs.backup.BackupPlanAdvancedBackupSettingResourceTypeArgs>[]>;
        /**
         * The display name of a backup plan.
         */
        backupPlanName: pulumi.Input<string>;
        /**
         * An array of `BackupRule` objects, each of which specifies a scheduled task that is used to back up a selection of resources.
         */
        backupPlanRule: pulumi.Input<pulumi.Input<inputs.backup.BackupPlanBackupRuleResourceTypeArgs>[]>;
    }
    interface BackupSelectionConditionParameterArgs {
        /**
         * The key in a key-value pair. For example, in the tag `Department: Accounting` , `Department` is the key.
         */
        conditionKey?: pulumi.Input<string>;
        /**
         * The value in a key-value pair. For example, in the tag `Department: Accounting` , `Accounting` is the value.
         */
        conditionValue?: pulumi.Input<string>;
    }
    interface BackupSelectionConditionResourceTypeArgs {
        /**
         * The key in a key-value pair. For example, in `"Department": "accounting"` , `"Department"` is the key.
         */
        conditionKey: pulumi.Input<string>;
        /**
         * An operation, such as `STRINGEQUALS` , that is applied to a key-value pair used to filter resources in a selection.
         */
        conditionType: pulumi.Input<string>;
        /**
         * The value in a key-value pair. For example, in `"Department": "accounting"` , `"accounting"` is the value.
         */
        conditionValue: pulumi.Input<string>;
    }
    interface BackupSelectionResourceTypeArgs {
        /**
         * A list of conditions that you define to assign resources to your backup plans using tags. For example, `"StringEquals": { "ConditionKey": "aws:ResourceTag/CreatedByCryo", "ConditionValue": "true" },` . Condition operators are case sensitive.
         *
         * `Conditions` differs from `ListOfTags` as follows:
         *
         * - When you specify more than one condition, you only assign the resources that match ALL conditions (using AND logic).
         * - `Conditions` supports `StringEquals` , `StringLike` , `StringNotEquals` , and `StringNotLike` . `ListOfTags` only supports `StringEquals` .
         */
        conditions?: pulumi.Input<inputs.backup.BackupSelectionResourceTypeConditionsPropertiesArgs>;
        /**
         * The ARN of the IAM role that AWS Backup uses to authenticate when backing up the target resource; for example, `arn:aws:iam::123456789012:role/S3Access` .
         */
        iamRoleArn: pulumi.Input<string>;
        /**
         * A list of conditions that you define to assign resources to your backup plans using tags. For example, `"StringEquals": { "ConditionKey": "aws:ResourceTag/CreatedByCryo", "ConditionValue": "true" },` . Condition operators are case sensitive.
         *
         * `ListOfTags` differs from `Conditions` as follows:
         *
         * - When you specify more than one condition, you assign all resources that match AT LEAST ONE condition (using OR logic).
         * - `ListOfTags` only supports `StringEquals` . `Conditions` supports `StringEquals` , `StringLike` , `StringNotEquals` , and `StringNotLike` .
         */
        listOfTags?: pulumi.Input<pulumi.Input<inputs.backup.BackupSelectionConditionResourceTypeArgs>[]>;
        /**
         * A list of Amazon Resource Names (ARNs) to exclude from a backup plan. The maximum number of ARNs is 500 without wildcards, or 30 ARNs with wildcards.
         *
         * If you need to exclude many resources from a backup plan, consider a different resource selection strategy, such as assigning only one or a few resource types or refining your resource selection using tags.
         */
        notResources?: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * An array of strings that contain Amazon Resource Names (ARNs) of resources to assign to a backup plan.
         */
        resources?: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * The display name of a resource selection document.
         */
        selectionName: pulumi.Input<string>;
    }
    /**
     * A list of conditions that you define to assign resources to your backup plans using tags. For example, `"StringEquals": { "ConditionKey": "aws:ResourceTag/CreatedByCryo", "ConditionValue": "true" },` . Condition operators are case sensitive.
     *
     * `Conditions` differs from `ListOfTags` as follows:
     *
     * - When you specify more than one condition, you only assign the resources that match ALL conditions (using AND logic).
     * - `Conditions` supports `StringEquals` , `StringLike` , `StringNotEquals` , and `StringNotLike` . `ListOfTags` only supports `StringEquals` .
     */
    interface BackupSelectionResourceTypeConditionsPropertiesArgs {
        stringEquals?: pulumi.Input<pulumi.Input<inputs.backup.BackupSelectionConditionParameterArgs>[]>;
        stringLike?: pulumi.Input<pulumi.Input<inputs.backup.BackupSelectionConditionParameterArgs>[]>;
        stringNotEquals?: pulumi.Input<pulumi.Input<inputs.backup.BackupSelectionConditionParameterArgs>[]>;
        stringNotLike?: pulumi.Input<pulumi.Input<inputs.backup.BackupSelectionConditionParameterArgs>[]>;
    }
    interface BackupVaultLockConfigurationTypeArgs {
        /**
         * The AWS Backup Vault Lock configuration that specifies the number of days before the lock date. For example, setting `ChangeableForDays` to 30 on Jan. 1, 2022 at 8pm UTC will set the lock date to Jan. 31, 2022 at 8pm UTC.
         *
         * AWS Backup enforces a 72-hour cooling-off period before Vault Lock takes effect and becomes immutable. Therefore, you must set `ChangeableForDays` to 3 or greater.
         *
         * Before the lock date, you can delete Vault Lock from the vault using `DeleteBackupVaultLockConfiguration` or change the Vault Lock configuration using `PutBackupVaultLockConfiguration` . On and after the lock date, the Vault Lock becomes immutable and cannot be changed or deleted.
         *
         * If this parameter is not specified, you can delete Vault Lock from the vault using `DeleteBackupVaultLockConfiguration` or change the Vault Lock configuration using `PutBackupVaultLockConfiguration` at any time.
         */
        changeableForDays?: pulumi.Input<number>;
        /**
         * The AWS Backup Vault Lock configuration that specifies the maximum retention period that the vault retains its recovery points. This setting can be useful if, for example, your organization's policies require you to destroy certain data after retaining it for four years (1460 days).
         *
         * If this parameter is not included, Vault Lock does not enforce a maximum retention period on the recovery points in the vault. If this parameter is included without a value, Vault Lock will not enforce a maximum retention period.
         *
         * If this parameter is specified, any backup or copy job to the vault must have a lifecycle policy with a retention period equal to or shorter than the maximum retention period. If the job's retention period is longer than that maximum retention period, then the vault fails the backup or copy job, and you should either modify your lifecycle settings or use a different vault. Recovery points already saved in the vault prior to Vault Lock are not affected.
         */
        maxRetentionDays?: pulumi.Input<number>;
        /**
         * The AWS Backup Vault Lock configuration that specifies the minimum retention period that the vault retains its recovery points. This setting can be useful if, for example, your organization's policies require you to retain certain data for at least seven years (2555 days).
         *
         * If this parameter is not specified, Vault Lock will not enforce a minimum retention period.
         *
         * If this parameter is specified, any backup or copy job to the vault must have a lifecycle policy with a retention period equal to or longer than the minimum retention period. If the job's retention period is shorter than that minimum retention period, then the vault fails that backup or copy job, and you should either modify your lifecycle settings or use a different vault. Recovery points already saved in the vault prior to Vault Lock are not affected.
         */
        minRetentionDays: pulumi.Input<number>;
    }
    interface BackupVaultNotificationObjectTypeArgs {
        /**
         * An array of events that indicate the status of jobs to back up resources to the backup vault. For valid events, see [BackupVaultEvents](https://docs.aws.amazon.com/aws-backup/latest/devguide/API_PutBackupVaultNotifications.html#API_PutBackupVaultNotifications_RequestSyntax) in the *AWS Backup API Guide* .
         */
        backupVaultEvents: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * An ARN that uniquely identifies an Amazon Simple Notification Service (Amazon SNS) topic; for example, `arn:aws:sns:us-west-2:111122223333:MyTopic` .
         */
        snsTopicArn: pulumi.Input<string>;
    }
    interface FrameworkControlArgs {
        /**
         * A list of ParameterName and ParameterValue pairs.
         */
        controlInputParameters?: pulumi.Input<pulumi.Input<inputs.backup.FrameworkControlInputParameterArgs>[]>;
        /**
         * The name of a control. This name is between 1 and 256 characters.
         */
        controlName: pulumi.Input<string>;
        /**
         * The scope of a control. The control scope defines what the control will evaluate. Three examples of control scopes are: a specific backup plan, all backup plans with a specific tag, or all backup plans.
         */
        controlScope?: pulumi.Input<inputs.backup.FrameworkControlControlScopePropertiesArgs>;
    }
    /**
     * The scope of a control. The control scope defines what the control will evaluate. Three examples of control scopes are: a specific backup plan, all backup plans with a specific tag, or all backup plans.
     */
    interface FrameworkControlControlScopePropertiesArgs {
        /**
         * The ID of the only AWS resource that you want your control scope to contain.
         */
        complianceResourceIds?: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * Describes whether the control scope includes one or more types of resources, such as `EFS` or `RDS`.
         */
        complianceResourceTypes?: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * Describes whether the control scope includes resources with one or more tags. Each tag is a key-value pair.
         */
        tags?: pulumi.Input<pulumi.Input<inputs.backup.FrameworkTagArgs>[]>;
    }
    interface FrameworkControlInputParameterArgs {
        /**
         * The name of a parameter, for example, `BackupPlanFrequency` .
         */
        parameterName: pulumi.Input<string>;
        /**
         * The value of parameter, for example, `hourly` .
         */
        parameterValue: pulumi.Input<string>;
    }
    /**
     * A key-value pair to associate with a resource.
     */
    interface FrameworkTagArgs {
        /**
         * The key name of the tag. You can specify a value that is 1 to 128 Unicode characters in length and cannot be prefixed with aws:. You can use any of the following characters: the set of Unicode letters, digits, whitespace, _, ., /, =, +, and -.
         */
        key?: pulumi.Input<string>;
        /**
         * The value for the tag. You can specify a value that is 0 to 256 Unicode characters in length and cannot be prefixed with aws:. You can use any of the following characters: the set of Unicode letters, digits, whitespace, _, ., /, =, +, and -.
         */
        value?: pulumi.Input<string>;
    }
    interface LogicallyAirGappedBackupVaultNotificationObjectTypeArgs {
        /**
         * An array of events that indicate the status of jobs to back up resources to the backup vault.
         */
        backupVaultEvents: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * The Amazon Resource Name (ARN) that specifies the topic for a backup vault’s events; for example, `arn:aws:sns:us-west-2:111122223333:MyVaultTopic` .
         */
        snsTopicArn: pulumi.Input<string>;
    }
    /**
     * A structure that contains information about where and how to deliver your reports, specifically your Amazon S3 bucket name, S3 key prefix, and the formats of your reports.
     */
    interface ReportDeliveryChannelPropertiesArgs {
        /**
         * A list of the format of your reports: CSV, JSON, or both. If not specified, the default format is CSV.
         */
        formats?: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * The unique name of the S3 bucket that receives your reports.
         */
        s3BucketName: pulumi.Input<string>;
        /**
         * The prefix for where AWS Backup Audit Manager delivers your reports to Amazon S3. The prefix is this part of the following path: s3://your-bucket-name/prefix/Backup/us-west-2/year/month/day/report-name. If not specified, there is no prefix.
         */
        s3KeyPrefix?: pulumi.Input<string>;
    }
    /**
     * Identifies the report template for the report. Reports are built using a report template.
     */
    interface ReportSettingPropertiesArgs {
        /**
         * The list of AWS accounts that a report covers.
         */
        accounts?: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * The Amazon Resource Names (ARNs) of the frameworks a report covers.
         */
        frameworkArns?: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * The list of AWS organization units that a report covers.
         */
        organizationUnits?: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * The list of AWS regions that a report covers.
         */
        regions?: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * Identifies the report template for the report. Reports are built using a report template. The report templates are: `BACKUP_JOB_REPORT | COPY_JOB_REPORT | RESTORE_JOB_REPORT`
         */
        reportTemplate: pulumi.Input<string>;
    }
    interface RestoreTestingPlanRestoreTestingRecoveryPointSelectionArgs {
        /**
         * Acceptable values include "LATEST_WITHIN_WINDOW" or "RANDOM_WITHIN_WINDOW"
         */
        algorithm: pulumi.Input<enums.backup.RestoreTestingPlanRestoreTestingRecoveryPointSelectionAlgorithm>;
        /**
         * Accepted values include specific ARNs or list of selectors. Defaults to empty list if not listed.
         */
        excludeVaults?: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * Accepted values include wildcard ["*"] or by specific ARNs or ARN wilcard replacement ["arn:aws:backup:us-west-2:123456789012:backup-vault:asdf", ...] ["arn:aws:backup:*:*:backup-vault:asdf-*", ...]
         */
        includeVaults: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * These are the types of recovery points.
         *
         * Include `SNAPSHOT` to restore only snapshot recovery points; include `CONTINUOUS` to restore continuous recovery points (point in time restore / PITR); use both to restore either a snapshot or a continuous recovery point. The recovery point will be determined by the value for `Algorithm` .
         */
        recoveryPointTypes: pulumi.Input<pulumi.Input<enums.backup.RestoreTestingPlanRestoreTestingRecoveryPointType>[]>;
        /**
         * Accepted values are integers from 1 to 365.
         */
        selectionWindowDays?: pulumi.Input<number>;
    }
    interface RestoreTestingSelectionKeyValueArgs {
        /**
         * The tag key.
         */
        key: pulumi.Input<string>;
        /**
         * The tag value.
         */
        value: pulumi.Input<string>;
    }
    interface RestoreTestingSelectionProtectedResourceConditionsArgs {
        /**
         * Filters the values of your tagged resources for only those resources that you tagged with the same value. Also called "exact matching."
         */
        stringEquals?: pulumi.Input<pulumi.Input<inputs.backup.RestoreTestingSelectionKeyValueArgs>[]>;
        /**
         * Filters the values of your tagged resources for only those resources that you tagged that do not have the same value. Also called "negated matching."
         */
        stringNotEquals?: pulumi.Input<pulumi.Input<inputs.backup.RestoreTestingSelectionKeyValueArgs>[]>;
    }
}
export declare namespace backupgateway {
}
export declare namespace batch {
    interface ComputeEnvironmentComputeResourcesArgs {
        /**
         * The allocation strategy to use for the compute resource if not enough instances of the best fitting instance type can be allocated. This might be because of availability of the instance type in the Region or [Amazon EC2 service limits](https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/ec2-resource-limits.html) . For more information, see [Allocation strategies](https://docs.aws.amazon.com/batch/latest/userguide/allocation-strategies.html) in the *AWS Batch User Guide* .
         *
         * When updating a compute environment, changing the allocation strategy requires an infrastructure update of the compute environment. For more information, see [Updating compute environments](https://docs.aws.amazon.com/batch/latest/userguide/updating-compute-environments.html) in the *AWS Batch User Guide* . `BEST_FIT` is not supported when updating a compute environment.
         *
         * > This parameter isn't applicable to jobs that are running on Fargate resources, and shouldn't be specified.
         *
         * - **BEST_FIT (default)** - AWS Batch selects an instance type that best fits the needs of the jobs with a preference for the lowest-cost instance type. If additional instances of the selected instance type aren't available, AWS Batch waits for the additional instances to be available. If there aren't enough instances available, or if the user is reaching [Amazon EC2 service limits](https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/ec2-resource-limits.html) then additional jobs aren't run until the currently running jobs have completed. This allocation strategy keeps costs lower but can limit scaling. If you are using Spot Fleets with `BEST_FIT` then the Spot Fleet IAM role must be specified.
         * - **BEST_FIT_PROGRESSIVE** - AWS Batch will select additional instance types that are large enough to meet the requirements of the jobs in the queue, with a preference for instance types with a lower cost per unit vCPU. If additional instances of the previously selected instance types aren't available, AWS Batch will select new instance types.
         * - **SPOT_CAPACITY_OPTIMIZED** - AWS Batch will select one or more instance types that are large enough to meet the requirements of the jobs in the queue, with a preference for instance types that are less likely to be interrupted. This allocation strategy is only available for Spot Instance compute resources.
         * - **SPOT_PRICE_CAPACITY_OPTIMIZED** - The price and capacity optimized allocation strategy looks at both price and capacity to select the Spot Instance pools that are the least likely to be interrupted and have the lowest possible price. This allocation strategy is only available for Spot Instance compute resources.
         *
         * > We recommend that you use `SPOT_PRICE_CAPACITY_OPTIMIZED` rather than `SPOT_CAPACITY_OPTIMIZED` in most instances.
         *
         * With `BEST_FIT_PROGRESSIVE` , `SPOT_CAPACITY_OPTIMIZED` , and `SPOT_PRICE_CAPACITY_OPTIMIZED` allocation strategies using On-Demand or Spot Instances, and the `BEST_FIT` strategy using Spot Instances, AWS Batch might need to go above `maxvCpus` to meet your capacity requirements. In this event, AWS Batch never exceeds `maxvCpus` by more than a single instance.
         */
        allocationStrategy?: pulumi.Input<string>;
        /**
         * The maximum percentage that a Spot Instance price can be when compared with the On-Demand price for that instance type before instances are launched. For example, if your maximum percentage is 20%, the Spot price must be less than 20% of the current On-Demand price for that Amazon EC2 instance. You always pay the lowest (market) price and never more than your maximum percentage. For most use cases, we recommend leaving this field empty.
         *
         * When updating a compute environment, changing the bid percentage requires an infrastructure update of the compute environment. For more information, see [Updating compute environments](https://docs.aws.amazon.com/batch/latest/userguide/updating-compute-environments.html) in the *AWS Batch User Guide* .
         *
         * > This parameter isn't applicable to jobs that are running on Fargate resources. Don't specify it.
         */
        bidPercentage?: pulumi.Input<number>;
        /**
         * The desired number of vCPUS in the compute environment. AWS Batch modifies this value between the minimum and maximum values based on job queue demand.
         *
         * > This parameter isn't applicable to jobs that are running on Fargate resources. Don't specify it. > AWS Batch doesn't support changing the desired number of vCPUs of an existing compute environment. Don't specify this parameter for compute environments using Amazon EKS clusters. > When you update the `desiredvCpus` setting, the value must be between the `minvCpus` and `maxvCpus` values.
         * >
         * > Additionally, the updated `desiredvCpus` value must be greater than or equal to the current `desiredvCpus` value. For more information, see [Troubleshooting AWS Batch](https://docs.aws.amazon.com/batch/latest/userguide/troubleshooting.html#error-desired-vcpus-update) in the *AWS Batch User Guide* .
         */
        desiredvCpus?: pulumi.Input<number>;
        /**
         * Provides information used to select Amazon Machine Images (AMIs) for Amazon EC2 instances in the compute environment. If `Ec2Configuration` isn't specified, the default is `ECS_AL2` .
         *
         * When updating a compute environment, changing this setting requires an infrastructure update of the compute environment. For more information, see [Updating compute environments](https://docs.aws.amazon.com/batch/latest/userguide/updating-compute-environments.html) in the *AWS Batch User Guide* . To remove the Amazon EC2 configuration and any custom AMI ID specified in `imageIdOverride` , set this value to an empty string.
         *
         * One or two values can be provided.
         *
         * > This parameter isn't applicable to jobs that are running on Fargate resources. Don't specify it.
         */
        ec2Configuration?: pulumi.Input<pulumi.Input<inputs.batch.ComputeEnvironmentEc2ConfigurationObjectArgs>[]>;
        /**
         * The Amazon EC2 key pair that's used for instances launched in the compute environment. You can use this key pair to log in to your instances with SSH. To remove the Amazon EC2 key pair, set this value to an empty string.
         *
         * When updating a compute environment, changing the Amazon EC2 key pair requires an infrastructure update of the compute environment. For more information, see [Updating compute environments](https://docs.aws.amazon.com/batch/latest/userguide/updating-compute-environments.html) in the *AWS Batch User Guide* .
         *
         * > This parameter isn't applicable to jobs that are running on Fargate resources. Don't specify it.
         */
        ec2KeyPair?: pulumi.Input<string>;
        /**
         * The Amazon Machine Image (AMI) ID used for instances launched in the compute environment. This parameter is overridden by the `imageIdOverride` member of the `Ec2Configuration` structure. To remove the custom AMI ID and use the default AMI ID, set this value to an empty string.
         *
         * When updating a compute environment, changing the AMI ID requires an infrastructure update of the compute environment. For more information, see [Updating compute environments](https://docs.aws.amazon.com/batch/latest/userguide/updating-compute-environments.html) in the *AWS Batch User Guide* .
         *
         * > This parameter isn't applicable to jobs that are running on Fargate resources. Don't specify it. > The AMI that you choose for a compute environment must match the architecture of the instance types that you intend to use for that compute environment. For example, if your compute environment uses A1 instance types, the compute resource AMI that you choose must support ARM instances. Amazon ECS vends both x86 and ARM versions of the Amazon ECS-optimized Amazon Linux 2 AMI. For more information, see [Amazon ECS-optimized Amazon Linux 2 AMI](https://docs.aws.amazon.com/AmazonECS/latest/developerguide/ecs-optimized_AMI.html#ecs-optimized-ami-linux-variants.html) in the *Amazon Elastic Container Service Developer Guide* .
         */
        imageId?: pulumi.Input<string>;
        /**
         * The Amazon ECS instance profile applied to Amazon EC2 instances in a compute environment. Required for Amazon EC2 instances. You can specify the short name or full Amazon Resource Name (ARN) of an instance profile. For example, `*ecsInstanceRole*` or `arn:aws:iam:: *<aws_account_id>* :instance-profile/ *ecsInstanceRole*` . For more information, see [Amazon ECS instance role](https://docs.aws.amazon.com/batch/latest/userguide/instance_IAM_role.html) in the *AWS Batch User Guide* .
         *
         * When updating a compute environment, changing this setting requires an infrastructure update of the compute environment. For more information, see [Updating compute environments](https://docs.aws.amazon.com/batch/latest/userguide/updating-compute-environments.html) in the *AWS Batch User Guide* .
         *
         * > This parameter isn't applicable to jobs that are running on Fargate resources. Don't specify it.
         */
        instanceRole?: pulumi.Input<string>;
        /**
         * The instances types that can be launched. You can specify instance families to launch any instance type within those families (for example, `c5` or `p3` ), or you can specify specific sizes within a family (such as `c5.8xlarge` ). You can also choose `optimal` to select instance types (from the C4, M4, and R4 instance families) that match the demand of your job queues.
         *
         * When updating a compute environment, changing this setting requires an infrastructure update of the compute environment. For more information, see [Updating compute environments](https://docs.aws.amazon.com/batch/latest/userguide/updating-compute-environments.html) in the *AWS Batch User Guide* .
         *
         * > This parameter isn't applicable to jobs that are running on Fargate resources. Don't specify it. > When you create a compute environment, the instance types that you select for the compute environment must share the same architecture. For example, you can't mix x86 and ARM instances in the same compute environment. > Currently, `optimal` uses instance types from the C4, M4, and R4 instance families. In Regions that don't have instance types from those instance families, instance types from the C5, M5, and R5 instance families are used.
         */
        instanceTypes?: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * The launch template to use for your compute resources. Any other compute resource parameters that you specify in a [CreateComputeEnvironment](https://docs.aws.amazon.com/batch/latest/APIReference/API_CreateComputeEnvironment.html) API operation override the same parameters in the launch template. You must specify either the launch template ID or launch template name in the request, but not both. For more information, see [Launch Template Support](https://docs.aws.amazon.com/batch/latest/userguide/launch-templates.html) in the ** . Removing the launch template from a compute environment will not remove the AMI specified in the launch template. In order to update the AMI specified in a launch template, the `updateToLatestImageVersion` parameter must be set to `true` .
         *
         * When updating a compute environment, changing the launch template requires an infrastructure update of the compute environment. For more information, see [Updating compute environments](https://docs.aws.amazon.com/batch/latest/userguide/updating-compute-environments.html) in the ** .
         *
         * > This parameter isn't applicable to jobs running on Fargate resources, and shouldn't be specified.
         */
        launchTemplate?: pulumi.Input<inputs.batch.ComputeEnvironmentLaunchTemplateSpecificationArgs>;
        /**
         * The maximum number of Amazon EC2 vCPUs that an environment can reach.
         *
         * > With `BEST_FIT_PROGRESSIVE` , `SPOT_CAPACITY_OPTIMIZED` and `SPOT_PRICE_CAPACITY_OPTIMIZED` (recommended) strategies using On-Demand or Spot Instances, and the `BEST_FIT` strategy using Spot Instances, AWS Batch might need to exceed `maxvCpus` to meet your capacity requirements. In this event, AWS Batch never exceeds `maxvCpus` by more than a single instance.
         */
        maxvCpus: pulumi.Input<number>;
        /**
         * The minimum number of vCPUs that an environment should maintain (even if the compute environment is `DISABLED` ).
         *
         * > This parameter isn't applicable to jobs that are running on Fargate resources. Don't specify it.
         */
        minvCpus?: pulumi.Input<number>;
        /**
         * The Amazon EC2 placement group to associate with your compute resources. If you intend to submit multi-node parallel jobs to your compute environment, you should consider creating a cluster placement group and associate it with your compute resources. This keeps your multi-node parallel job on a logical grouping of instances within a single Availability Zone with high network flow potential. For more information, see [Placement groups](https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/placement-groups.html) in the *Amazon EC2 User Guide for Linux Instances* .
         *
         * When updating a compute environment, changing the placement group requires an infrastructure update of the compute environment. For more information, see [Updating compute environments](https://docs.aws.amazon.com/batch/latest/userguide/updating-compute-environments.html) in the *AWS Batch User Guide* .
         *
         * > This parameter isn't applicable to jobs that are running on Fargate resources. Don't specify it.
         */
        placementGroup?: pulumi.Input<string>;
        /**
         * The Amazon EC2 security groups that are associated with instances launched in the compute environment. This parameter is required for Fargate compute resources, where it can contain up to 5 security groups. For Fargate compute resources, providing an empty list is handled as if this parameter wasn't specified and no change is made. For Amazon EC2 compute resources, providing an empty list removes the security groups from the compute resource.
         *
         * When updating a compute environment, changing the Amazon EC2 security groups requires an infrastructure update of the compute environment. For more information, see [Updating compute environments](https://docs.aws.amazon.com/batch/latest/userguide/updating-compute-environments.html) in the *AWS Batch User Guide* .
         */
        securityGroupIds?: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * The Amazon Resource Name (ARN) of the Amazon EC2 Spot Fleet IAM role applied to a `SPOT` compute environment. This role is required if the allocation strategy set to `BEST_FIT` or if the allocation strategy isn't specified. For more information, see [Amazon EC2 spot fleet role](https://docs.aws.amazon.com/batch/latest/userguide/spot_fleet_IAM_role.html) in the *AWS Batch User Guide* .
         *
         * > This parameter isn't applicable to jobs that are running on Fargate resources. Don't specify it. > To tag your Spot Instances on creation, the Spot Fleet IAM role specified here must use the newer *AmazonEC2SpotFleetTaggingRole* managed policy. The previously recommended *AmazonEC2SpotFleetRole* managed policy doesn't have the required permissions to tag Spot Instances. For more information, see [Spot instances not tagged on creation](https://docs.aws.amazon.com/batch/latest/userguide/troubleshooting.html#spot-instance-no-tag) in the *AWS Batch User Guide* .
         */
        spotIamFleetRole?: pulumi.Input<string>;
        /**
         * The VPC subnets where the compute resources are launched. Fargate compute resources can contain up to 16 subnets. For Fargate compute resources, providing an empty list will be handled as if this parameter wasn't specified and no change is made. For Amazon EC2 compute resources, providing an empty list removes the VPC subnets from the compute resource. For more information, see [VPCs and subnets](https://docs.aws.amazon.com/vpc/latest/userguide/VPC_Subnets.html) in the *Amazon VPC User Guide* .
         *
         * When updating a compute environment, changing the VPC subnets requires an infrastructure update of the compute environment. For more information, see [Updating compute environments](https://docs.aws.amazon.com/batch/latest/userguide/updating-compute-environments.html) in the *AWS Batch User Guide* .
         *
         * > AWS Batch on Amazon EC2 and AWS Batch on Amazon EKS support Local Zones. For more information, see [Local Zones](https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/using-regions-availability-zones.html#concepts-local-zones) in the *Amazon EC2 User Guide for Linux Instances* , [Amazon EKS and AWS Local Zones](https://docs.aws.amazon.com/eks/latest/userguide/local-zones.html) in the *Amazon EKS User Guide* and [Amazon ECS clusters in Local Zones, Wavelength Zones, and AWS Outposts](https://docs.aws.amazon.com/AmazonECS/latest/developerguide/cluster-regions-zones.html#clusters-local-zones) in the *Amazon ECS Developer Guide* .
         * >
         * > AWS Batch on Fargate doesn't currently support Local Zones.
         */
        subnets: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * A key-value pair to associate with a resource.
         */
        tags?: pulumi.Input<{
            [key: string]: pulumi.Input<string>;
        }>;
        /**
         * The type of compute environment: `EC2` , `SPOT` , `FARGATE` , or `FARGATE_SPOT` . For more information, see [Compute environments](https://docs.aws.amazon.com/batch/latest/userguide/compute_environments.html) in the *AWS Batch User Guide* .
         *
         * If you choose `SPOT` , you must also specify an Amazon EC2 Spot Fleet role with the `spotIamFleetRole` parameter. For more information, see [Amazon EC2 spot fleet role](https://docs.aws.amazon.com/batch/latest/userguide/spot_fleet_IAM_role.html) in the *AWS Batch User Guide* .
         *
         * When updating compute environment, changing the type of a compute environment requires an infrastructure update of the compute environment. For more information, see [Updating compute environments](https://docs.aws.amazon.com/batch/latest/userguide/updating-compute-environments.html) in the *AWS Batch User Guide* .
         *
         * When updating the type of a compute environment, changing between `EC2` and `SPOT` or between `FARGATE` and `FARGATE_SPOT` will initiate an infrastructure update, but if you switch between `EC2` and `FARGATE` , AWS CloudFormation will create a new compute environment.
         */
        type: pulumi.Input<string>;
        /**
         * Specifies whether the AMI ID is updated to the latest one that's supported by AWS Batch when the compute environment has an infrastructure update. The default value is `false` .
         *
         * > An AMI ID can either be specified in the `imageId` or `imageIdOverride` parameters or be determined by the launch template that's specified in the `launchTemplate` parameter. If an AMI ID is specified any of these ways, this parameter is ignored. For more information about to update AMI IDs during an infrastructure update, see [Updating the AMI ID](https://docs.aws.amazon.com/batch/latest/userguide/updating-compute-environments.html#updating-compute-environments-ami) in the *AWS Batch User Guide* .
         *
         * When updating a compute environment, changing this setting requires an infrastructure update of the compute environment. For more information, see [Updating compute environments](https://docs.aws.amazon.com/batch/latest/userguide/updating-compute-environments.html) in the *AWS Batch User Guide* .
         */
        updateToLatestImageVersion?: pulumi.Input<boolean>;
    }
    interface ComputeEnvironmentEc2ConfigurationObjectArgs {
        /**
         * The AMI ID used for instances launched in the compute environment that match the image type. This setting overrides the `imageId` set in the `computeResource` object.
         *
         * > The AMI that you choose for a compute environment must match the architecture of the instance types that you intend to use for that compute environment. For example, if your compute environment uses A1 instance types, the compute resource AMI that you choose must support ARM instances. Amazon ECS vends both x86 and ARM versions of the Amazon ECS-optimized Amazon Linux 2 AMI. For more information, see [Amazon ECS-optimized Amazon Linux 2 AMI](https://docs.aws.amazon.com/AmazonECS/latest/developerguide/ecs-optimized_AMI.html#ecs-optimized-ami-linux-variants.html) in the *Amazon Elastic Container Service Developer Guide* .
         */
        imageIdOverride?: pulumi.Input<string>;
        /**
         * The Kubernetes version for the compute environment. If you don't specify a value, the latest version that AWS Batch supports is used.
         */
        imageKubernetesVersion?: pulumi.Input<string>;
        /**
         * The image type to match with the instance type to select an AMI. The supported values are different for `ECS` and `EKS` resources.
         *
         * - **ECS** - If the `imageIdOverride` parameter isn't specified, then a recent [Amazon ECS-optimized Amazon Linux 2 AMI](https://docs.aws.amazon.com/AmazonECS/latest/developerguide/ecs-optimized_AMI.html#al2ami) ( `ECS_AL2` ) is used. If a new image type is specified in an update, but neither an `imageId` nor a `imageIdOverride` parameter is specified, then the latest Amazon ECS optimized AMI for that image type that's supported by AWS Batch is used.
         *
         * - **ECS_AL2** - [Amazon Linux 2](https://docs.aws.amazon.com/AmazonECS/latest/developerguide/ecs-optimized_AMI.html#al2ami) : Default for all non-GPU instance families.
         * - **ECS_AL2_NVIDIA** - [Amazon Linux 2 (GPU)](https://docs.aws.amazon.com/AmazonECS/latest/developerguide/ecs-optimized_AMI.html#gpuami) : Default for all GPU instance families (for example `P4` and `G4` ) and can be used for all non AWS Graviton-based instance types.
         * - **ECS_AL2023** - [Amazon Linux 2023](https://docs.aws.amazon.com/AmazonECS/latest/developerguide/ecs-optimized_AMI.html) : AWS Batch supports Amazon Linux 2023.
         *
         * > Amazon Linux 2023 does not support `A1` instances.
         * - **ECS_AL1** - [Amazon Linux](https://docs.aws.amazon.com/AmazonECS/latest/developerguide/ecs-optimized_AMI.html#alami) . Amazon Linux has reached the end-of-life of standard support. For more information, see [Amazon Linux AMI](https://docs.aws.amazon.com/amazon-linux-ami/) .
         * - **EKS** - If the `imageIdOverride` parameter isn't specified, then a recent [Amazon EKS-optimized Amazon Linux AMI](https://docs.aws.amazon.com/eks/latest/userguide/eks-optimized-ami.html) ( `EKS_AL2` ) is used. If a new image type is specified in an update, but neither an `imageId` nor a `imageIdOverride` parameter is specified, then the latest Amazon EKS optimized AMI for that image type that AWS Batch supports is used.
         *
         * - **EKS_AL2** - [Amazon Linux 2](https://docs.aws.amazon.com/eks/latest/userguide/eks-optimized-ami.html) : Default for all non-GPU instance families.
         * - **EKS_AL2_NVIDIA** - [Amazon Linux 2 (accelerated)](https://docs.aws.amazon.com/eks/latest/userguide/eks-optimized-ami.html) : Default for all GPU instance families (for example, `P4` and `G4` ) and can be used for all non AWS Graviton-based instance types.
         */
        imageType: pulumi.Input<string>;
    }
    interface ComputeEnvironmentEksConfigurationArgs {
        /**
         * The Amazon Resource Name (ARN) of the Amazon EKS cluster. An example is `arn: *aws* :eks: *us-east-1* : *123456789012* :cluster/ *ClusterForBatch*` .
         */
        eksClusterArn: pulumi.Input<string>;
        /**
         * The namespace of the Amazon EKS cluster. AWS Batch manages pods in this namespace. The value can't left empty or null. It must be fewer than 64 characters long, can't be set to `default` , can't start with " `kube-` ," and must match this regular expression: `^[a-z0-9]([-a-z0-9]*[a-z0-9])?$` . For more information, see [Namespaces](https://docs.aws.amazon.com/https://kubernetes.io/docs/concepts/overview/working-with-objects/namespaces/) in the Kubernetes documentation.
         */
        kubernetesNamespace: pulumi.Input<string>;
    }
    interface ComputeEnvironmentLaunchTemplateSpecificationArgs {
        /**
         * The ID of the launch template.
         */
        launchTemplateId?: pulumi.Input<string>;
        /**
         * The name of the launch template.
         */
        launchTemplateName?: pulumi.Input<string>;
        /**
         * A launch template to use in place of the default launch template. You must specify either the launch template ID or launch template name in the request, but not both.
         *
         * You can specify up to ten (10) launch template overrides that are associated to unique instance types or families for each compute environment.
         *
         * > To unset all override templates for a compute environment, you can pass an empty array to the [UpdateComputeEnvironment.overrides](https://docs.aws.amazon.com/batch/latest/APIReference/API_UpdateComputeEnvironment.html) parameter, or not include the `overrides` parameter when submitting the `UpdateComputeEnvironment` API operation.
         */
        overrides?: pulumi.Input<pulumi.Input<inputs.batch.ComputeEnvironmentLaunchTemplateSpecificationOverrideArgs>[]>;
        /**
         * The version number of the launch template, `$Default` , or `$Latest` .
         *
         * If the value is `$Default` , the default version of the launch template is used. If the value is `$Latest` , the latest version of the launch template is used.
         *
         * > If the AMI ID that's used in a compute environment is from the launch template, the AMI isn't changed when the compute environment is updated. It's only changed if the `updateToLatestImageVersion` parameter for the compute environment is set to `true` . During an infrastructure update, if either `$Default` or `$Latest` is specified, AWS Batch re-evaluates the launch template version, and it might use a different version of the launch template. This is the case even if the launch template isn't specified in the update. When updating a compute environment, changing the launch template requires an infrastructure update of the compute environment. For more information, see [Updating compute environments](https://docs.aws.amazon.com/batch/latest/userguide/updating-compute-environments.html) in the *AWS Batch User Guide* .
         *
         * Default: `$Default`
         *
         * Latest: `$Latest`
         */
        version?: pulumi.Input<string>;
    }
    interface ComputeEnvironmentLaunchTemplateSpecificationOverrideArgs {
        /**
         * The ID of the launch template.
         *
         * *Note:* If you specify the `launchTemplateId` you can't specify the `launchTemplateName` as well.
         */
        launchTemplateId?: pulumi.Input<string>;
        /**
         * The name of the launch template.
         *
         * *Note:* If you specify the `launchTemplateName` you can't specify the `launchTemplateId` as well.
         */
        launchTemplateName?: pulumi.Input<string>;
        /**
         * The instance type or family that this override launch template should be applied to.
         *
         * This parameter is required when defining a launch template override.
         *
         * Information included in this parameter must meet the following requirements:
         *
         * - Must be a valid Amazon EC2 instance type or family.
         * - `optimal` isn't allowed.
         * - `targetInstanceTypes` can target only instance types and families that are included within the [`ComputeResource.instanceTypes`](https://docs.aws.amazon.com/batch/latest/APIReference/API_ComputeResource.html#Batch-Type-ComputeResource-instanceTypes) set. `targetInstanceTypes` doesn't need to include all of the instances from the `instanceType` set, but at least a subset. For example, if `ComputeResource.instanceTypes` includes `[m5, g5]` , `targetInstanceTypes` can include `[m5.2xlarge]` and `[m5.large]` but not `[c5.large]` .
         * - `targetInstanceTypes` included within the same launch template override or across launch template overrides can't overlap for the same compute environment. For example, you can't define one launch template override to target an instance family and another define an instance type within this same family.
         */
        targetInstanceTypes?: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * The version number of the launch template, `$Default` , or `$Latest` .
         *
         * If the value is `$Default` , the default version of the launch template is used. If the value is `$Latest` , the latest version of the launch template is used.
         *
         * > If the AMI ID that's used in a compute environment is from the launch template, the AMI isn't changed when the compute environment is updated. It's only changed if the `updateToLatestImageVersion` parameter for the compute environment is set to `true` . During an infrastructure update, if either `$Default` or `$Latest` is specified, AWS Batch re-evaluates the launch template version, and it might use a different version of the launch template. This is the case even if the launch template isn't specified in the update. When updating a compute environment, changing the launch template requires an infrastructure update of the compute environment. For more information, see [Updating compute environments](https://docs.aws.amazon.com/batch/latest/userguide/updating-compute-environments.html) in the *AWS Batch User Guide* .
         *
         * Default: `$Default`
         *
         * Latest: `$Latest`
         */
        version?: pulumi.Input<string>;
    }
    interface ComputeEnvironmentUpdatePolicyArgs {
        /**
         * Specifies the job timeout (in minutes) when the compute environment infrastructure is updated. The default value is 30.
         */
        jobExecutionTimeoutMinutes?: pulumi.Input<number>;
        /**
         * Specifies whether jobs are automatically terminated when the computer environment infrastructure is updated. The default value is `false` .
         */
        terminateJobsOnUpdate?: pulumi.Input<boolean>;
    }
    interface JobDefinitionConsumableResourcePropertiesArgs {
        /**
         * The list of consumable resources required by a job.
         */
        consumableResourceList: pulumi.Input<pulumi.Input<inputs.batch.JobDefinitionConsumableResourceRequirementArgs>[]>;
    }
    interface JobDefinitionConsumableResourceRequirementArgs {
        /**
         * The ARN of the consumable resource the job definition should consume.
         */
        consumableResource: pulumi.Input<string>;
        /**
         * The quantity of the consumable resource that is needed.
         */
        quantity: pulumi.Input<number>;
    }
    interface JobDefinitionContainerPropertiesArgs {
        /**
         * The command that's passed to the container. This parameter maps to `Cmd` in the [Create a container](https://docs.aws.amazon.com/https://docs.docker.com/engine/api/v1.23/#create-a-container) section of the [Docker Remote API](https://docs.aws.amazon.com/https://docs.docker.com/engine/api/v1.23/) and the `COMMAND` parameter to [docker run](https://docs.aws.amazon.com/https://docs.docker.com/engine/reference/run/) . For more information, see [https://docs.docker.com/engine/reference/builder/#cmd](https://docs.aws.amazon.com/https://docs.docker.com/engine/reference/builder/#cmd) .
         */
        command?: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * Determines whether execute command functionality is turned on for this task. If `true` , execute command functionality is turned on all the containers in the task.
         */
        enableExecuteCommand?: pulumi.Input<boolean>;
        /**
         * The environment variables to pass to a container. This parameter maps to `Env` in the [Create a container](https://docs.aws.amazon.com/https://docs.docker.com/engine/api/v1.23/#create-a-container) section of the [Docker Remote API](https://docs.aws.amazon.com/https://docs.docker.com/engine/api/v1.23/) and the `--env` option to [docker run](https://docs.aws.amazon.com/https://docs.docker.com/engine/reference/run/) .
         *
         * > We don't recommend using plaintext environment variables for sensitive information, such as credential data. > Environment variables cannot start with " `AWS_BATCH` ". This naming convention is reserved for variables that AWS Batch sets.
         */
        environment?: pulumi.Input<pulumi.Input<inputs.batch.JobDefinitionEnvironmentArgs>[]>;
        /**
         * The amount of ephemeral storage to allocate for the task. This parameter is used to expand the total amount of ephemeral storage available, beyond the default amount, for tasks hosted on AWS Fargate .
         */
        ephemeralStorage?: pulumi.Input<inputs.batch.JobDefinitionEphemeralStorageArgs>;
        /**
         * The Amazon Resource Name (ARN) of the execution role that AWS Batch can assume. For jobs that run on Fargate resources, you must provide an execution role. For more information, see [AWS Batch execution IAM role](https://docs.aws.amazon.com/batch/latest/userguide/execution-IAM-role.html) in the *AWS Batch User Guide* .
         */
        executionRoleArn?: pulumi.Input<string>;
        /**
         * The platform configuration for jobs that are running on Fargate resources. Jobs that are running on Amazon EC2 resources must not specify this parameter.
         */
        fargatePlatformConfiguration?: pulumi.Input<inputs.batch.JobDefinitionContainerPropertiesFargatePlatformConfigurationPropertiesArgs>;
        /**
         * Required. The image used to start a container. This string is passed directly to the Docker daemon. Images in the Docker Hub registry are available by default. Other repositories are specified with `*repository-url* / *image* : *tag*` . It can be 255 characters long. It can contain uppercase and lowercase letters, numbers, hyphens (-), underscores (_), colons (:), periods (.), forward slashes (/), and number signs (#). This parameter maps to `Image` in the [Create a container](https://docs.aws.amazon.com/https://docs.docker.com/engine/api/v1.23/#create-a-container) section of the [Docker Remote API](https://docs.aws.amazon.com/https://docs.docker.com/engine/api/v1.23/) and the `IMAGE` parameter of [docker run](https://docs.aws.amazon.com/https://docs.docker.com/engine/reference/run/) .
         *
         * > Docker image architecture must match the processor architecture of the compute resources that they're scheduled on. For example, ARM-based Docker images can only run on ARM-based compute resources.
         *
         * - Images in Amazon ECR Public repositories use the full `registry/repository[:tag]` or `registry/repository[@digest]` naming conventions. For example, `public.ecr.aws/ *registry_alias* / *my-web-app* : *latest*` .
         * - Images in Amazon ECR repositories use the full registry and repository URI (for example, `123456789012.dkr.ecr.<region-name>.amazonaws.com/<repository-name>` ).
         * - Images in official repositories on Docker Hub use a single name (for example, `ubuntu` or `mongo` ).
         * - Images in other repositories on Docker Hub are qualified with an organization name (for example, `amazon/amazon-ecs-agent` ).
         * - Images in other online repositories are qualified further by a domain name (for example, `quay.io/assemblyline/ubuntu` ).
         */
        image: pulumi.Input<string>;
        /**
         * The Amazon Resource Name (ARN) of the IAM role that the container can assume for AWS permissions. For more information, see [IAM roles for tasks](https://docs.aws.amazon.com/AmazonECS/latest/developerguide/task-iam-roles.html) in the *Amazon Elastic Container Service Developer Guide* .
         */
        jobRoleArn?: pulumi.Input<string>;
        /**
         * Linux-specific modifications that are applied to the container, such as details for device mappings.
         */
        linuxParameters?: pulumi.Input<inputs.batch.JobDefinitionLinuxParametersArgs>;
        /**
         * The log configuration specification for the container.
         *
         * This parameter maps to `LogConfig` in the [Create a container](https://docs.aws.amazon.com/https://docs.docker.com/engine/api/v1.23/#create-a-container) section of the [Docker Remote API](https://docs.aws.amazon.com/https://docs.docker.com/engine/api/v1.23/) and the `--log-driver` option to [docker run](https://docs.aws.amazon.com/https://docs.docker.com/engine/reference/run/) . By default, containers use the same logging driver that the Docker daemon uses. However the container might use a different logging driver than the Docker daemon by specifying a log driver with this parameter in the container definition. To use a different logging driver for a container, the log system must be configured properly on the container instance (or on a different log server for remote logging options). For more information on the options for different supported log drivers, see [Configure logging drivers](https://docs.aws.amazon.com/https://docs.docker.com/engine/admin/logging/overview/) in the Docker documentation.
         *
         * > AWS Batch currently supports a subset of the logging drivers available to the Docker daemon (shown in the [LogConfiguration](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-batch-jobdefinition-containerproperties-logconfiguration.html) data type).
         *
         * This parameter requires version 1.18 of the Docker Remote API or greater on your container instance. To check the Docker Remote API version on your container instance, log in to your container instance and run the following command: `sudo docker version | grep "Server API version"`
         *
         * > The Amazon ECS container agent running on a container instance must register the logging drivers available on that instance with the `ECS_AVAILABLE_LOGGING_DRIVERS` environment variable before containers placed on that instance can use these log configuration options. For more information, see [Amazon ECS container agent configuration](https://docs.aws.amazon.com/AmazonECS/latest/developerguide/ecs-agent-config.html) in the *Amazon Elastic Container Service Developer Guide* .
         */
        logConfiguration?: pulumi.Input<inputs.batch.JobDefinitionLogConfigurationArgs>;
        /**
         * This parameter is deprecated, use `resourceRequirements` to specify the memory requirements for the job definition. It's not supported for jobs running on Fargate resources. For jobs that run on Amazon EC2 resources, it specifies the memory hard limit (in MiB) for a container. If your container attempts to exceed the specified number, it's terminated. You must specify at least 4 MiB of memory for a job using this parameter. The memory hard limit can be specified in several places. It must be specified for each node at least once.
         */
        memory?: pulumi.Input<number>;
        /**
         * The mount points for data volumes in your container. This parameter maps to `Volumes` in the [Create a container](https://docs.aws.amazon.com/https://docs.docker.com/engine/api/v1.23/#create-a-container) section of the [Docker Remote API](https://docs.aws.amazon.com/https://docs.docker.com/engine/api/v1.23/) and the `--volume` option to [docker run](https://docs.aws.amazon.com/https://docs.docker.com/engine/reference/run/) .
         */
        mountPoints?: pulumi.Input<pulumi.Input<inputs.batch.JobDefinitionMountPointArgs>[]>;
        /**
         * The network configuration for jobs that are running on Fargate resources. Jobs that are running on Amazon EC2 resources must not specify this parameter.
         */
        networkConfiguration?: pulumi.Input<inputs.batch.JobDefinitionNetworkConfigurationArgs>;
        /**
         * When this parameter is true, the container is given elevated permissions on the host container instance (similar to the `root` user). This parameter maps to `Privileged` in the [Create a container](https://docs.aws.amazon.com/https://docs.docker.com/engine/api/v1.23/#create-a-container) section of the [Docker Remote API](https://docs.aws.amazon.com/https://docs.docker.com/engine/api/v1.23/) and the `--privileged` option to [docker run](https://docs.aws.amazon.com/https://docs.docker.com/engine/reference/run/) . The default value is false.
         *
         * > This parameter isn't applicable to jobs that are running on Fargate resources and shouldn't be provided, or specified as false.
         */
        privileged?: pulumi.Input<boolean>;
        /**
         * When this parameter is true, the container is given read-only access to its root file system. This parameter maps to `ReadonlyRootfs` in the [Create a container](https://docs.aws.amazon.com/https://docs.docker.com/engine/api/v1.23/#create-a-container) section of the [Docker Remote API](https://docs.aws.amazon.com/https://docs.docker.com/engine/api/v1.23/) and the `--read-only` option to `docker run` .
         */
        readonlyRootFilesystem?: pulumi.Input<boolean>;
        /**
         * The private repository authentication credentials to use.
         */
        repositoryCredentials?: pulumi.Input<inputs.batch.JobDefinitionRepositoryCredentialsArgs>;
        /**
         * The type and amount of resources to assign to a container. The supported resources include `GPU` , `MEMORY` , and `VCPU` .
         */
        resourceRequirements?: pulumi.Input<pulumi.Input<inputs.batch.JobDefinitionResourceRequirementArgs>[]>;
        /**
         * An object that represents the compute environment architecture for AWS Batch jobs on Fargate.
         */
        runtimePlatform?: pulumi.Input<inputs.batch.JobDefinitionRuntimePlatformArgs>;
        /**
         * The secrets for the container. For more information, see [Specifying sensitive data](https://docs.aws.amazon.com/batch/latest/userguide/specifying-sensitive-data.html) in the *AWS Batch User Guide* .
         */
        secrets?: pulumi.Input<pulumi.Input<inputs.batch.JobDefinitionSecretArgs>[]>;
        /**
         * A list of `ulimits` to set in the container. This parameter maps to `Ulimits` in the [Create a container](https://docs.aws.amazon.com/https://docs.docker.com/engine/api/v1.23/#create-a-container) section of the [Docker Remote API](https://docs.aws.amazon.com/https://docs.docker.com/engine/api/v1.23/) and the `--ulimit` option to [docker run](https://docs.aws.amazon.com/https://docs.docker.com/engine/reference/run/) .
         *
         * > This parameter isn't applicable to jobs that are running on Fargate resources and shouldn't be provided.
         */
        ulimits?: pulumi.Input<pulumi.Input<inputs.batch.JobDefinitionUlimitArgs>[]>;
        /**
         * The user name to use inside the container. This parameter maps to `User` in the [Create a container](https://docs.aws.amazon.com/https://docs.docker.com/engine/api/v1.23/#create-a-container) section of the [Docker Remote API](https://docs.aws.amazon.com/https://docs.docker.com/engine/api/v1.23/) and the `--user` option to [docker run](https://docs.aws.amazon.com/https://docs.docker.com/engine/reference/run/) .
         */
        user?: pulumi.Input<string>;
        /**
         * This parameter is deprecated, use `resourceRequirements` to specify the vCPU requirements for the job definition. It's not supported for jobs running on Fargate resources. For jobs running on Amazon EC2 resources, it specifies the number of vCPUs reserved for the job.
         *
         * Each vCPU is equivalent to 1,024 CPU shares. This parameter maps to `CpuShares` in the [Create a container](https://docs.aws.amazon.com/https://docs.docker.com/engine/api/v1.23/#create-a-container) section of the [Docker Remote API](https://docs.aws.amazon.com/https://docs.docker.com/engine/api/v1.23/) and the `--cpu-shares` option to [docker run](https://docs.aws.amazon.com/https://docs.docker.com/engine/reference/run/) . The number of vCPUs must be specified but can be specified in several places. You must specify it at least once for each node.
         */
        vcpus?: pulumi.Input<number>;
        /**
         * A list of data volumes used in a job.
         */
        volumes?: pulumi.Input<pulumi.Input<inputs.batch.JobDefinitionVolumeArgs>[]>;
    }
    /**
     * The platform configuration for jobs that are running on Fargate resources. Jobs that are running on Amazon EC2 resources must not specify this parameter.
     */
    interface JobDefinitionContainerPropertiesFargatePlatformConfigurationPropertiesArgs {
        platformVersion?: pulumi.Input<string>;
    }
    interface JobDefinitionDeviceArgs {
        /**
         * The path inside the container that's used to expose the host device. By default, the `hostPath` value is used.
         */
        containerPath?: pulumi.Input<string>;
        /**
         * The path for the device on the host container instance.
         */
        hostPath?: pulumi.Input<string>;
        /**
         * The explicit permissions to provide to the container for the device. By default, the container has permissions for `read` , `write` , and `mknod` for the device.
         */
        permissions?: pulumi.Input<pulumi.Input<string>[]>;
    }
    interface JobDefinitionEcsPropertiesArgs {
        /**
         * An object that contains the properties for the Amazon ECS task definition of a job.
         *
         * > This object is currently limited to one task element. However, the task element can run up to 10 containers.
         */
        taskProperties: pulumi.Input<pulumi.Input<inputs.batch.JobDefinitionEcsTaskPropertiesArgs>[]>;
    }
    interface JobDefinitionEcsTaskPropertiesArgs {
        /**
         * This object is a list of containers.
         */
        containers?: pulumi.Input<pulumi.Input<inputs.batch.JobDefinitionTaskContainerPropertiesArgs>[]>;
        /**
         * Determines whether execute command functionality is turned on for this task. If `true` , execute command functionality is turned on all the containers in the task.
         */
        enableExecuteCommand?: pulumi.Input<boolean>;
        /**
         * The amount of ephemeral storage to allocate for the task. This parameter is used to expand the total amount of ephemeral storage available, beyond the default amount, for tasks hosted on AWS Fargate .
         */
        ephemeralStorage?: pulumi.Input<inputs.batch.JobDefinitionEphemeralStorageArgs>;
        /**
         * The Amazon Resource Name (ARN) of the execution role that AWS Batch can assume. For jobs that run on Fargate resources, you must provide an execution role. For more information, see [AWS Batch execution IAM role](https://docs.aws.amazon.com/batch/latest/userguide/execution-IAM-role.html) in the *AWS Batch User Guide* .
         */
        executionRoleArn?: pulumi.Input<string>;
        /**
         * The IPC resource namespace to use for the containers in the task. The valid values are `host` , `task` , or `none` .
         *
         * If `host` is specified, all containers within the tasks that specified the `host` IPC mode on the same container instance share the same IPC resources with the host Amazon EC2 instance.
         *
         * If `task` is specified, all containers within the specified `task` share the same IPC resources.
         *
         * If `none` is specified, the IPC resources within the containers of a task are private, and are not shared with other containers in a task or on the container instance.
         *
         * If no value is specified, then the IPC resource namespace sharing depends on the Docker daemon setting on the container instance. For more information, see [IPC settings](https://docs.aws.amazon.com/https://docs.docker.com/engine/reference/run/#ipc-settings---ipc) in the Docker run reference.
         */
        ipcMode?: pulumi.Input<string>;
        /**
         * The network configuration for jobs that are running on Fargate resources. Jobs that are running on Amazon EC2 resources must not specify this parameter.
         */
        networkConfiguration?: pulumi.Input<inputs.batch.JobDefinitionNetworkConfigurationArgs>;
        /**
         * The process namespace to use for the containers in the task. The valid values are `host` or `task` . For example, monitoring sidecars might need `pidMode` to access information about other containers running in the same task.
         *
         * If `host` is specified, all containers within the tasks that specified the `host` PID mode on the same container instance share the process namespace with the host Amazon EC2 instance.
         *
         * If `task` is specified, all containers within the specified task share the same process namespace.
         *
         * If no value is specified, the default is a private namespace for each container. For more information, see [PID settings](https://docs.aws.amazon.com/https://docs.docker.com/engine/reference/run/#pid-settings---pid) in the Docker run reference.
         */
        pidMode?: pulumi.Input<string>;
        /**
         * The Fargate platform version where the jobs are running. A platform version is specified only for jobs that are running on Fargate resources. If one isn't specified, the `LATEST` platform version is used by default. This uses a recent, approved version of the Fargate platform for compute resources. For more information, see [AWS Fargate platform versions](https://docs.aws.amazon.com/AmazonECS/latest/developerguide/platform_versions.html) in the *Amazon Elastic Container Service Developer Guide* .
         */
        platformVersion?: pulumi.Input<string>;
        /**
         * An object that represents the compute environment architecture for AWS Batch jobs on Fargate.
         */
        runtimePlatform?: pulumi.Input<inputs.batch.JobDefinitionRuntimePlatformArgs>;
        /**
         * The Amazon Resource Name (ARN) that's associated with the Amazon ECS task.
         *
         * > This is object is comparable to [ContainerProperties:jobRoleArn](https://docs.aws.amazon.com/batch/latest/APIReference/API_ContainerProperties.html) .
         */
        taskRoleArn?: pulumi.Input<string>;
        /**
         * A list of volumes that are associated with the job.
         */
        volumes?: pulumi.Input<pulumi.Input<inputs.batch.JobDefinitionVolumeArgs>[]>;
    }
    interface JobDefinitionEfsAuthorizationConfigArgs {
        /**
         * The Amazon EFS access point ID to use. If an access point is specified, the root directory value specified in the `EFSVolumeConfiguration` must either be omitted or set to `/` which enforces the path set on the EFS access point. If an access point is used, transit encryption must be enabled in the `EFSVolumeConfiguration` . For more information, see [Working with Amazon EFS access points](https://docs.aws.amazon.com/efs/latest/ug/efs-access-points.html) in the *Amazon Elastic File System User Guide* .
         */
        accessPointId?: pulumi.Input<string>;
        /**
         * Whether or not to use the AWS Batch job IAM role defined in a job definition when mounting the Amazon EFS file system. If enabled, transit encryption must be enabled in the `EFSVolumeConfiguration` . If this parameter is omitted, the default value of `DISABLED` is used. For more information, see [Using Amazon EFS access points](https://docs.aws.amazon.com/batch/latest/userguide/efs-volumes.html#efs-volume-accesspoints) in the *AWS Batch User Guide* . EFS IAM authorization requires that `TransitEncryption` be `ENABLED` and that a `JobRoleArn` is specified.
         */
        iam?: pulumi.Input<string>;
    }
    interface JobDefinitionEfsVolumeConfigurationArgs {
        /**
         * The authorization configuration details for the Amazon EFS file system.
         */
        authorizationConfig?: pulumi.Input<inputs.batch.JobDefinitionEfsAuthorizationConfigArgs>;
        /**
         * The Amazon EFS file system ID to use.
         */
        fileSystemId: pulumi.Input<string>;
        /**
         * The directory within the Amazon EFS file system to mount as the root directory inside the host. If this parameter is omitted, the root of the Amazon EFS volume is used instead. Specifying `/` has the same effect as omitting this parameter. The maximum length is 4,096 characters.
         *
         * > If an EFS access point is specified in the `authorizationConfig` , the root directory parameter must either be omitted or set to `/` , which enforces the path set on the Amazon EFS access point.
         */
        rootDirectory?: pulumi.Input<string>;
        /**
         * Determines whether to enable encryption for Amazon EFS data in transit between the Amazon ECS host and the Amazon EFS server. Transit encryption must be enabled if Amazon EFS IAM authorization is used. If this parameter is omitted, the default value of `DISABLED` is used. For more information, see [Encrypting data in transit](https://docs.aws.amazon.com/efs/latest/ug/encryption-in-transit.html) in the *Amazon Elastic File System User Guide* .
         */
        transitEncryption?: pulumi.Input<string>;
        /**
         * The port to use when sending encrypted data between the Amazon ECS host and the Amazon EFS server. If you don't specify a transit encryption port, it uses the port selection strategy that the Amazon EFS mount helper uses. The value must be between 0 and 65,535. For more information, see [EFS mount helper](https://docs.aws.amazon.com/efs/latest/ug/efs-mount-helper.html) in the *Amazon Elastic File System User Guide* .
         */
        transitEncryptionPort?: pulumi.Input<number>;
    }
    interface JobDefinitionEksContainerArgs {
        /**
         * An array of arguments to the entrypoint. If this isn't specified, the `CMD` of the container image is used. This corresponds to the `args` member in the [Entrypoint](https://docs.aws.amazon.com/https://kubernetes.io/docs/reference/kubernetes-api/workload-resources/pod-v1/#entrypoint) portion of the [Pod](https://docs.aws.amazon.com/https://kubernetes.io/docs/reference/kubernetes-api/workload-resources/pod-v1/) in Kubernetes. Environment variable references are expanded using the container's environment.
         *
         * If the referenced environment variable doesn't exist, the reference in the command isn't changed. For example, if the reference is to " `$(NAME1)` " and the `NAME1` environment variable doesn't exist, the command string will remain " `$(NAME1)` ." `$$` is replaced with `$` , and the resulting string isn't expanded. For example, `$$(VAR_NAME)` is passed as `$(VAR_NAME)` whether or not the `VAR_NAME` environment variable exists. For more information, see [Dockerfile reference: CMD](https://docs.aws.amazon.com/https://docs.docker.com/engine/reference/builder/#cmd) and [Define a command and arguments for a pod](https://docs.aws.amazon.com/https://kubernetes.io/docs/tasks/inject-data-application/define-command-argument-container/) in the *Kubernetes documentation* .
         */
        args?: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * The entrypoint for the container. This isn't run within a shell. If this isn't specified, the `ENTRYPOINT` of the container image is used. Environment variable references are expanded using the container's environment.
         *
         * If the referenced environment variable doesn't exist, the reference in the command isn't changed. For example, if the reference is to " `$(NAME1)` " and the `NAME1` environment variable doesn't exist, the command string will remain " `$(NAME1)` ." `$$` is replaced with `$` and the resulting string isn't expanded. For example, `$$(VAR_NAME)` will be passed as `$(VAR_NAME)` whether or not the `VAR_NAME` environment variable exists. The entrypoint can't be updated. For more information, see [ENTRYPOINT](https://docs.aws.amazon.com/https://docs.docker.com/engine/reference/builder/#entrypoint) in the *Dockerfile reference* and [Define a command and arguments for a container](https://docs.aws.amazon.com/https://kubernetes.io/docs/tasks/inject-data-application/define-command-argument-container/) and [Entrypoint](https://docs.aws.amazon.com/https://kubernetes.io/docs/reference/kubernetes-api/workload-resources/pod-v1/#entrypoint) in the *Kubernetes documentation* .
         */
        command?: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * The environment variables to pass to a container.
         *
         * > Environment variables cannot start with " `AWS_BATCH` ". This naming convention is reserved for variables that AWS Batch sets.
         */
        env?: pulumi.Input<pulumi.Input<inputs.batch.JobDefinitionEksContainerEnvironmentVariableArgs>[]>;
        /**
         * The Docker image used to start the container.
         */
        image: pulumi.Input<string>;
        /**
         * The image pull policy for the container. Supported values are `Always` , `IfNotPresent` , and `Never` . This parameter defaults to `IfNotPresent` . However, if the `:latest` tag is specified, it defaults to `Always` . For more information, see [Updating images](https://docs.aws.amazon.com/https://kubernetes.io/docs/concepts/containers/images/#updating-images) in the *Kubernetes documentation* .
         */
        imagePullPolicy?: pulumi.Input<string>;
        /**
         * The name of the container. If the name isn't specified, the default name " `Default` " is used. Each container in a pod must have a unique name.
         */
        name?: pulumi.Input<string>;
        /**
         * The type and amount of resources to assign to a container. The supported resources include `memory` , `cpu` , and `nvidia.com/gpu` . For more information, see [Resource management for pods and containers](https://docs.aws.amazon.com/https://kubernetes.io/docs/concepts/configuration/manage-resources-containers/) in the *Kubernetes documentation* .
         */
        resources?: pulumi.Input<inputs.batch.JobDefinitionEksContainerResourceRequirementsArgs>;
        /**
         * The security context for a job. For more information, see [Configure a security context for a pod or container](https://docs.aws.amazon.com/https://kubernetes.io/docs/tasks/configure-pod-container/security-context/) in the *Kubernetes documentation* .
         */
        securityContext?: pulumi.Input<inputs.batch.JobDefinitionEksContainerSecurityContextArgs>;
        /**
         * The volume mounts for the container. AWS Batch supports `emptyDir` , `hostPath` , and `secret` volume types. For more information about volumes and volume mounts in Kubernetes, see [Volumes](https://docs.aws.amazon.com/https://kubernetes.io/docs/concepts/storage/volumes/) in the *Kubernetes documentation* .
         */
        volumeMounts?: pulumi.Input<pulumi.Input<inputs.batch.JobDefinitionEksContainerVolumeMountArgs>[]>;
    }
    interface JobDefinitionEksContainerEnvironmentVariableArgs {
        /**
         * The name of the environment variable.
         */
        name: pulumi.Input<string>;
        /**
         * The value of the environment variable.
         */
        value?: pulumi.Input<string>;
    }
    interface JobDefinitionEksContainerResourceRequirementsArgs {
        /**
         * The type and quantity of the resources to reserve for the container. The values vary based on the `name` that's specified. Resources can be requested using either the `limits` or the `requests` objects.
         *
         * - **memory** - The memory hard limit (in MiB) for the container, using whole integers, with a "Mi" suffix. If your container attempts to exceed the memory specified, the container is terminated. You must specify at least 4 MiB of memory for a job. `memory` can be specified in `limits` , `requests` , or both. If `memory` is specified in both places, then the value that's specified in `limits` must be equal to the value that's specified in `requests` .
         *
         * > To maximize your resource utilization, provide your jobs with as much memory as possible for the specific instance type that you are using. To learn how, see [Memory management](https://docs.aws.amazon.com/batch/latest/userguide/memory-management.html) in the *AWS Batch User Guide* .
         * - **cpu** - The number of CPUs that's reserved for the container. Values must be an even multiple of `0.25` . `cpu` can be specified in `limits` , `requests` , or both. If `cpu` is specified in both places, then the value that's specified in `limits` must be at least as large as the value that's specified in `requests` .
         * - **nvidia.com/gpu** - The number of GPUs that's reserved for the container. Values must be a whole integer. `memory` can be specified in `limits` , `requests` , or both. If `memory` is specified in both places, then the value that's specified in `limits` must be equal to the value that's specified in `requests` .
         */
        limits?: pulumi.Input<{
            [key: string]: pulumi.Input<string>;
        }>;
        /**
         * The type and quantity of the resources to request for the container. The values vary based on the `name` that's specified. Resources can be requested by using either the `limits` or the `requests` objects.
         *
         * - **memory** - The memory hard limit (in MiB) for the container, using whole integers, with a "Mi" suffix. If your container attempts to exceed the memory specified, the container is terminated. You must specify at least 4 MiB of memory for a job. `memory` can be specified in `limits` , `requests` , or both. If `memory` is specified in both, then the value that's specified in `limits` must be equal to the value that's specified in `requests` .
         *
         * > If you're trying to maximize your resource utilization by providing your jobs as much memory as possible for a particular instance type, see [Memory management](https://docs.aws.amazon.com/batch/latest/userguide/memory-management.html) in the *AWS Batch User Guide* .
         * - **cpu** - The number of CPUs that are reserved for the container. Values must be an even multiple of `0.25` . `cpu` can be specified in `limits` , `requests` , or both. If `cpu` is specified in both, then the value that's specified in `limits` must be at least as large as the value that's specified in `requests` .
         * - **nvidia.com/gpu** - The number of GPUs that are reserved for the container. Values must be a whole integer. `nvidia.com/gpu` can be specified in `limits` , `requests` , or both. If `nvidia.com/gpu` is specified in both, then the value that's specified in `limits` must be equal to the value that's specified in `requests` .
         */
        requests?: pulumi.Input<{
            [key: string]: pulumi.Input<string>;
        }>;
    }
    interface JobDefinitionEksContainerSecurityContextArgs {
        /**
         * Whether or not a container or a Kubernetes pod is allowed to gain more privileges than its parent process. The default value is `false` .
         */
        allowPrivilegeEscalation?: pulumi.Input<boolean>;
        /**
         * When this parameter is `true` , the container is given elevated permissions on the host container instance. The level of permissions are similar to the `root` user permissions. The default value is `false` . This parameter maps to `privileged` policy in the [Privileged pod security policies](https://docs.aws.amazon.com/https://kubernetes.io/docs/concepts/security/pod-security-policy/#privileged) in the *Kubernetes documentation* .
         */
        privileged?: pulumi.Input<boolean>;
        /**
         * When this parameter is `true` , the container is given read-only access to its root file system. The default value is `false` . This parameter maps to `ReadOnlyRootFilesystem` policy in the [Volumes and file systems pod security policies](https://docs.aws.amazon.com/https://kubernetes.io/docs/concepts/security/pod-security-policy/#volumes-and-file-systems) in the *Kubernetes documentation* .
         */
        readOnlyRootFilesystem?: pulumi.Input<boolean>;
        /**
         * When this parameter is specified, the container is run as the specified group ID ( `gid` ). If this parameter isn't specified, the default is the group that's specified in the image metadata. This parameter maps to `RunAsGroup` and `MustRunAs` policy in the [Users and groups pod security policies](https://docs.aws.amazon.com/https://kubernetes.io/docs/concepts/security/pod-security-policy/#users-and-groups) in the *Kubernetes documentation* .
         */
        runAsGroup?: pulumi.Input<number>;
        /**
         * When this parameter is specified, the container is run as a user with a `uid` other than 0. If this parameter isn't specified, so such rule is enforced. This parameter maps to `RunAsUser` and `MustRunAsNonRoot` policy in the [Users and groups pod security policies](https://docs.aws.amazon.com/https://kubernetes.io/docs/concepts/security/pod-security-policy/#users-and-groups) in the *Kubernetes documentation* .
         */
        runAsNonRoot?: pulumi.Input<boolean>;
        /**
         * When this parameter is specified, the container is run as the specified user ID ( `uid` ). If this parameter isn't specified, the default is the user that's specified in the image metadata. This parameter maps to `RunAsUser` and `MustRanAs` policy in the [Users and groups pod security policies](https://docs.aws.amazon.com/https://kubernetes.io/docs/concepts/security/pod-security-policy/#users-and-groups) in the *Kubernetes documentation* .
         */
        runAsUser?: pulumi.Input<number>;
    }
    interface JobDefinitionEksContainerVolumeMountArgs {
        /**
         * The path on the container where the volume is mounted.
         */
        mountPath?: pulumi.Input<string>;
        /**
         * The name the volume mount. This must match the name of one of the volumes in the pod.
         */
        name?: pulumi.Input<string>;
        /**
         * If this value is `true` , the container has read-only access to the volume. Otherwise, the container can write to the volume. The default value is `false` .
         */
        readOnly?: pulumi.Input<boolean>;
        /**
         * A sub-path inside the referenced volume instead of its root.
         */
        subPath?: pulumi.Input<string>;
    }
    interface JobDefinitionEksEmptyDirArgs {
        /**
         * The medium to store the volume. The default value is an empty string, which uses the storage of the node.
         *
         * - **""** - *(Default)* Use the disk storage of the node.
         * - **"Memory"** - Use the `tmpfs` volume that's backed by the RAM of the node. Contents of the volume are lost when the node reboots, and any storage on the volume counts against the container's memory limit.
         */
        medium?: pulumi.Input<string>;
        /**
         * The maximum size of the volume. By default, there's no maximum size defined.
         */
        sizeLimit?: pulumi.Input<string>;
    }
    interface JobDefinitionEksHostPathArgs {
        /**
         * The path of the file or directory on the host to mount into containers on the pod.
         */
        path?: pulumi.Input<string>;
    }
    interface JobDefinitionEksMetadataArgs {
        /**
         * Key-value pairs used to attach arbitrary, non-identifying metadata to Kubernetes objects. Valid annotation keys have two segments: an optional prefix and a name, separated by a slash (/).
         *
         * - The prefix is optional and must be 253 characters or less. If specified, the prefix must be a DNS subdomain− a series of DNS labels separated by dots (.), and it must end with a slash (/).
         * - The name segment is required and must be 63 characters or less. It can include alphanumeric characters ([a-z0-9A-Z]), dashes (-), underscores (_), and dots (.), but must begin and end with an alphanumeric character.
         *
         * > Annotation values must be 255 characters or less.
         *
         * Annotations can be added or modified at any time. Each resource can have multiple annotations.
         */
        annotations?: pulumi.Input<{
            [key: string]: pulumi.Input<string>;
        }>;
        /**
         * Key-value pairs used to identify, sort, and organize cube resources. Can contain up to 63 uppercase letters, lowercase letters, numbers, hyphens (-), and underscores (_). Labels can be added or modified at any time. Each resource can have multiple labels, but each key must be unique for a given object.
         */
        labels?: pulumi.Input<{
            [key: string]: pulumi.Input<string>;
        }>;
        /**
         * The namespace of the Amazon EKS cluster. In Kubernetes, namespaces provide a mechanism for isolating groups of resources within a single cluster. Names of resources need to be unique within a namespace, but not across namespaces. AWS Batch places Batch Job pods in this namespace. If this field is provided, the value can't be empty or null. It must meet the following requirements:
         *
         * - 1-63 characters long
         * - Can't be set to default
         * - Can't start with `kube`
         * - Must match the following regular expression: `^[a-z0-9]([-a-z0-9]*[a-z0-9])?$`
         *
         * For more information, see [Namespaces](https://docs.aws.amazon.com/https://kubernetes.io/docs/concepts/overview/working-with-objects/namespaces/) in the *Kubernetes documentation* . This namespace can be different from the `kubernetesNamespace` set in the compute environment's `EksConfiguration` , but must have identical role-based access control (RBAC) roles as the compute environment's `kubernetesNamespace` . For multi-node parallel jobs, the same value must be provided across all the node ranges.
         */
        namespace?: pulumi.Input<string>;
    }
    interface JobDefinitionEksPersistentVolumeClaimArgs {
        /**
         * The name of the `persistentVolumeClaim` bounded to a `persistentVolume` . For more information, see [Persistent Volume Claims](https://docs.aws.amazon.com/https://kubernetes.io/docs/concepts/storage/persistent-volumes/#persistentvolumeclaims) in the *Kubernetes documentation* .
         */
        claimName: pulumi.Input<string>;
        /**
         * An optional boolean value indicating if the mount is read only. Default is false. For more information, see [Read Only Mounts](https://docs.aws.amazon.com/https://kubernetes.io/docs/concepts/storage/volumes/#read-only-mounts) in the *Kubernetes documentation* .
         */
        readOnly?: pulumi.Input<boolean>;
    }
    interface JobDefinitionEksPodPropertiesArgs {
        /**
         * The properties of the container that's used on the Amazon EKS pod.
         *
         * > This object is limited to 10 elements.
         */
        containers?: pulumi.Input<pulumi.Input<inputs.batch.JobDefinitionEksContainerArgs>[]>;
        /**
         * The DNS policy for the pod. The default value is `ClusterFirst` . If the `hostNetwork` parameter is not specified, the default is `ClusterFirstWithHostNet` . `ClusterFirst` indicates that any DNS query that does not match the configured cluster domain suffix is forwarded to the upstream nameserver inherited from the node. For more information, see [Pod's DNS policy](https://docs.aws.amazon.com/https://kubernetes.io/docs/concepts/services-networking/dns-pod-service/#pod-s-dns-policy) in the *Kubernetes documentation* .
         *
         * Valid values: `Default` | `ClusterFirst` | `ClusterFirstWithHostNet`
         */
        dnsPolicy?: pulumi.Input<string>;
        /**
         * Indicates if the pod uses the hosts' network IP address. The default value is `true` . Setting this to `false` enables the Kubernetes pod networking model. Most AWS Batch workloads are egress-only and don't require the overhead of IP allocation for each pod for incoming connections. For more information, see [Host namespaces](https://docs.aws.amazon.com/https://kubernetes.io/docs/concepts/security/pod-security-policy/#host-namespaces) and [Pod networking](https://docs.aws.amazon.com/https://kubernetes.io/docs/concepts/workloads/pods/#pod-networking) in the *Kubernetes documentation* .
         */
        hostNetwork?: pulumi.Input<boolean>;
        /**
         * References a Kubernetes secret resource. It holds a list of secrets. These secrets help to gain access to pull an images from a private registry.
         *
         * `ImagePullSecret$name` is required when this object is used.
         */
        imagePullSecrets?: pulumi.Input<pulumi.Input<inputs.batch.JobDefinitionImagePullSecretArgs>[]>;
        /**
         * These containers run before application containers, always runs to completion, and must complete successfully before the next container starts. These containers are registered with the Amazon EKS Connector agent and persists the registration information in the Kubernetes backend data store. For more information, see [Init Containers](https://docs.aws.amazon.com/https://kubernetes.io/docs/concepts/workloads/pods/init-containers/) in the *Kubernetes documentation* .
         *
         * > This object is limited to 10 elements.
         */
        initContainers?: pulumi.Input<pulumi.Input<inputs.batch.JobDefinitionEksContainerArgs>[]>;
        /**
         * Metadata about the Kubernetes pod. For more information, see [Understanding Kubernetes Objects](https://docs.aws.amazon.com/https://kubernetes.io/docs/concepts/overview/working-with-objects/kubernetes-objects/) in the *Kubernetes documentation* .
         */
        metadata?: pulumi.Input<inputs.batch.JobDefinitionEksMetadataArgs>;
        /**
         * The name of the service account that's used to run the pod. For more information, see [Kubernetes service accounts](https://docs.aws.amazon.com/eks/latest/userguide/service-accounts.html) and [Configure a Kubernetes service account to assume an IAM role](https://docs.aws.amazon.com/eks/latest/userguide/associate-service-account-role.html) in the *Amazon EKS User Guide* and [Configure service accounts for pods](https://docs.aws.amazon.com/https://kubernetes.io/docs/tasks/configure-pod-container/configure-service-account/) in the *Kubernetes documentation* .
         */
        serviceAccountName?: pulumi.Input<string>;
        /**
         * Indicates if the processes in a container are shared, or visible, to other containers in the same pod. For more information, see [Share Process Namespace between Containers in a Pod](https://docs.aws.amazon.com/https://kubernetes.io/docs/tasks/configure-pod-container/share-process-namespace/) .
         */
        shareProcessNamespace?: pulumi.Input<boolean>;
        /**
         * Specifies the volumes for a job definition that uses Amazon EKS resources.
         */
        volumes?: pulumi.Input<pulumi.Input<inputs.batch.JobDefinitionEksVolumeArgs>[]>;
    }
    interface JobDefinitionEksPropertiesArgs {
        /**
         * The properties for the Kubernetes pod resources of a job.
         */
        podProperties?: pulumi.Input<inputs.batch.JobDefinitionEksPodPropertiesArgs>;
    }
    interface JobDefinitionEksSecretArgs {
        /**
         * Specifies whether the secret or the secret's keys must be defined.
         */
        optional?: pulumi.Input<boolean>;
        /**
         * The name of the secret. The name must be allowed as a DNS subdomain name. For more information, see [DNS subdomain names](https://docs.aws.amazon.com/https://kubernetes.io/docs/concepts/overview/working-with-objects/names/#dns-subdomain-names) in the *Kubernetes documentation* .
         */
        secretName: pulumi.Input<string>;
    }
    interface JobDefinitionEksVolumeArgs {
        /**
         * Specifies the configuration of a Kubernetes `emptyDir` volume. For more information, see [emptyDir](https://docs.aws.amazon.com/https://kubernetes.io/docs/concepts/storage/volumes/#emptydir) in the *Kubernetes documentation* .
         */
        emptyDir?: pulumi.Input<inputs.batch.JobDefinitionEksEmptyDirArgs>;
        /**
         * Specifies the configuration of a Kubernetes `hostPath` volume. For more information, see [hostPath](https://docs.aws.amazon.com/https://kubernetes.io/docs/concepts/storage/volumes/#hostpath) in the *Kubernetes documentation* .
         */
        hostPath?: pulumi.Input<inputs.batch.JobDefinitionEksHostPathArgs>;
        /**
         * The name of the volume. The name must be allowed as a DNS subdomain name. For more information, see [DNS subdomain names](https://docs.aws.amazon.com/https://kubernetes.io/docs/concepts/overview/working-with-objects/names/#dns-subdomain-names) in the *Kubernetes documentation* .
         */
        name: pulumi.Input<string>;
        /**
         * Specifies the configuration of a Kubernetes `persistentVolumeClaim` bounded to a `persistentVolume` . For more information, see [Persistent Volume Claims](https://docs.aws.amazon.com/https://kubernetes.io/docs/concepts/storage/persistent-volumes/#persistentvolumeclaims) in the *Kubernetes documentation* .
         */
        persistentVolumeClaim?: pulumi.Input<inputs.batch.JobDefinitionEksPersistentVolumeClaimArgs>;
        /**
         * Specifies the configuration of a Kubernetes `secret` volume. For more information, see [secret](https://docs.aws.amazon.com/https://kubernetes.io/docs/concepts/storage/volumes/#secret) in the *Kubernetes documentation* .
         */
        secret?: pulumi.Input<inputs.batch.JobDefinitionEksSecretArgs>;
    }
    interface JobDefinitionEnvironmentArgs {
        /**
         * The name of the environment variable.
         */
        name?: pulumi.Input<string>;
        /**
         * The value of the environment variable.
         */
        value?: pulumi.Input<string>;
    }
    interface JobDefinitionEphemeralStorageArgs {
        /**
         * The total amount, in GiB, of ephemeral storage to set for the task. The minimum supported value is `21` GiB and the maximum supported value is `200` GiB.
         */
        sizeInGiB: pulumi.Input<number>;
    }
    interface JobDefinitionEvaluateOnExitArgs {
        /**
         * Specifies the action to take if all of the specified conditions ( `onStatusReason` , `onReason` , and `onExitCode` ) are met. The values aren't case sensitive.
         */
        action: pulumi.Input<string>;
        /**
         * Contains a glob pattern to match against the decimal representation of the `ExitCode` returned for a job. The pattern can be up to 512 characters long. It can contain only numbers, and can end with an asterisk (*) so that only the start of the string needs to be an exact match.
         *
         * The string can contain up to 512 characters.
         */
        onExitCode?: pulumi.Input<string>;
        /**
         * Contains a glob pattern to match against the `Reason` returned for a job. The pattern can contain up to 512 characters. It can contain letters, numbers, periods (.), colons (:), and white space (including spaces and tabs). It can optionally end with an asterisk (*) so that only the start of the string needs to be an exact match.
         */
        onReason?: pulumi.Input<string>;
        /**
         * Contains a glob pattern to match against the `StatusReason` returned for a job. The pattern can contain up to 512 characters. It can contain letters, numbers, periods (.), colons (:), and white spaces (including spaces or tabs). It can optionally end with an asterisk (*) so that only the start of the string needs to be an exact match.
         */
        onStatusReason?: pulumi.Input<string>;
    }
    interface JobDefinitionHostArgs {
        /**
         * The path on the host container instance that's presented to the container. If this parameter is empty, then the Docker daemon has assigned a host path for you. If this parameter contains a file location, then the data volume persists at the specified location on the host container instance until you delete it manually. If the source path location doesn't exist on the host container instance, the Docker daemon creates it. If the location does exist, the contents of the source path folder are exported.
         *
         * > This parameter isn't applicable to jobs that run on Fargate resources. Don't provide this for these jobs.
         */
        sourcePath?: pulumi.Input<string>;
    }
    interface JobDefinitionImagePullSecretArgs {
        /**
         * Provides a unique identifier for the `ImagePullSecret` . This object is required when `EksPodProperties$imagePullSecrets` is used.
         */
        name?: pulumi.Input<string>;
    }
    interface JobDefinitionJobTimeoutArgs {
        /**
         * The job timeout time (in seconds) that's measured from the job attempt's `startedAt` timestamp. After this time passes, AWS Batch terminates your jobs if they aren't finished. The minimum value for the timeout is 60 seconds.
         *
         * For array jobs, the timeout applies to the child jobs, not to the parent array job.
         *
         * For multi-node parallel (MNP) jobs, the timeout applies to the whole job, not to the individual nodes.
         */
        attemptDurationSeconds?: pulumi.Input<number>;
    }
    interface JobDefinitionLinuxParametersArgs {
        /**
         * Any of the host devices to expose to the container. This parameter maps to `Devices` in the [Create a container](https://docs.aws.amazon.com/https://docs.docker.com/engine/api/v1.23/#create-a-container) section of the [Docker Remote API](https://docs.aws.amazon.com/https://docs.docker.com/engine/api/v1.23/) and the `--device` option to [docker run](https://docs.aws.amazon.com/https://docs.docker.com/engine/reference/run/) .
         *
         * > This parameter isn't applicable to jobs that are running on Fargate resources. Don't provide it for these jobs.
         */
        devices?: pulumi.Input<pulumi.Input<inputs.batch.JobDefinitionDeviceArgs>[]>;
        /**
         * If true, run an `init` process inside the container that forwards signals and reaps processes. This parameter maps to the `--init` option to [docker run](https://docs.aws.amazon.com/https://docs.docker.com/engine/reference/run/) . This parameter requires version 1.25 of the Docker Remote API or greater on your container instance. To check the Docker Remote API version on your container instance, log in to your container instance and run the following command: `sudo docker version | grep "Server API version"`
         */
        initProcessEnabled?: pulumi.Input<boolean>;
        /**
         * The total amount of swap memory (in MiB) a container can use. This parameter is translated to the `--memory-swap` option to [docker run](https://docs.aws.amazon.com/https://docs.docker.com/engine/reference/run/) where the value is the sum of the container memory plus the `maxSwap` value. For more information, see [`--memory-swap` details](https://docs.aws.amazon.com/https://docs.docker.com/config/containers/resource_constraints/#--memory-swap-details) in the Docker documentation.
         *
         * If a `maxSwap` value of `0` is specified, the container doesn't use swap. Accepted values are `0` or any positive integer. If the `maxSwap` parameter is omitted, the container doesn't use the swap configuration for the container instance on which it runs. A `maxSwap` value must be set for the `swappiness` parameter to be used.
         *
         * > This parameter isn't applicable to jobs that are running on Fargate resources. Don't provide it for these jobs.
         */
        maxSwap?: pulumi.Input<number>;
        /**
         * The value for the size (in MiB) of the `/dev/shm` volume. This parameter maps to the `--shm-size` option to [docker run](https://docs.aws.amazon.com/https://docs.docker.com/engine/reference/run/) .
         *
         * > This parameter isn't applicable to jobs that are running on Fargate resources. Don't provide it for these jobs.
         */
        sharedMemorySize?: pulumi.Input<number>;
        /**
         * You can use this parameter to tune a container's memory swappiness behavior. A `swappiness` value of `0` causes swapping to not occur unless absolutely necessary. A `swappiness` value of `100` causes pages to be swapped aggressively. Valid values are whole numbers between `0` and `100` . If the `swappiness` parameter isn't specified, a default value of `60` is used. If a value isn't specified for `maxSwap` , then this parameter is ignored. If `maxSwap` is set to 0, the container doesn't use swap. This parameter maps to the `--memory-swappiness` option to [docker run](https://docs.aws.amazon.com/https://docs.docker.com/engine/reference/run/) .
         *
         * Consider the following when you use a per-container swap configuration.
         *
         * - Swap space must be enabled and allocated on the container instance for the containers to use.
         *
         * > By default, the Amazon ECS optimized AMIs don't have swap enabled. You must enable swap on the instance to use this feature. For more information, see [Instance store swap volumes](https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/instance-store-swap-volumes.html) in the *Amazon EC2 User Guide for Linux Instances* or [How do I allocate memory to work as swap space in an Amazon EC2 instance by using a swap file?](https://docs.aws.amazon.com/premiumsupport/knowledge-center/ec2-memory-swap-file/)
         * - The swap space parameters are only supported for job definitions using EC2 resources.
         * - If the `maxSwap` and `swappiness` parameters are omitted from a job definition, each container has a default `swappiness` value of 60. Moreover, the total swap usage is limited to two times the memory reservation of the container.
         *
         * > This parameter isn't applicable to jobs that are running on Fargate resources. Don't provide it for these jobs.
         */
        swappiness?: pulumi.Input<number>;
        /**
         * The container path, mount options, and size (in MiB) of the `tmpfs` mount. This parameter maps to the `--tmpfs` option to [docker run](https://docs.aws.amazon.com/https://docs.docker.com/engine/reference/run/) .
         *
         * > This parameter isn't applicable to jobs that are running on Fargate resources. Don't provide this parameter for this resource type.
         */
        tmpfs?: pulumi.Input<pulumi.Input<inputs.batch.JobDefinitionTmpfsArgs>[]>;
    }
    interface JobDefinitionLogConfigurationArgs {
        /**
         * The log driver to use for the container. The valid values that are listed for this parameter are log drivers that the Amazon ECS container agent can communicate with by default.
         *
         * The supported log drivers are `awslogs` , `fluentd` , `gelf` , `json-file` , `journald` , `logentries` , `syslog` , and `splunk` .
         *
         * > Jobs that are running on Fargate resources are restricted to the `awslogs` and `splunk` log drivers.
         *
         * - **awsfirelens** - Specifies the firelens logging driver. For more information on configuring Firelens, see [Send Amazon ECS logs to an AWS service or AWS Partner](https://docs.aws.amazon.com//AmazonECS/latest/developerguide/using_firelens.html) in the *Amazon Elastic Container Service Developer Guide* .
         * - **awslogs** - Specifies the Amazon CloudWatch Logs logging driver. For more information, see [Using the awslogs log driver](https://docs.aws.amazon.com/batch/latest/userguide/using_awslogs.html) in the *AWS Batch User Guide* and [Amazon CloudWatch Logs logging driver](https://docs.aws.amazon.com/https://docs.docker.com/config/containers/logging/awslogs/) in the Docker documentation.
         * - **fluentd** - Specifies the Fluentd logging driver. For more information including usage and options, see [Fluentd logging driver](https://docs.aws.amazon.com/https://docs.docker.com/config/containers/logging/fluentd/) in the *Docker documentation* .
         * - **gelf** - Specifies the Graylog Extended Format (GELF) logging driver. For more information including usage and options, see [Graylog Extended Format logging driver](https://docs.aws.amazon.com/https://docs.docker.com/config/containers/logging/gelf/) in the *Docker documentation* .
         * - **journald** - Specifies the journald logging driver. For more information including usage and options, see [Journald logging driver](https://docs.aws.amazon.com/https://docs.docker.com/config/containers/logging/journald/) in the *Docker documentation* .
         * - **json-file** - Specifies the JSON file logging driver. For more information including usage and options, see [JSON File logging driver](https://docs.aws.amazon.com/https://docs.docker.com/config/containers/logging/json-file/) in the *Docker documentation* .
         * - **splunk** - Specifies the Splunk logging driver. For more information including usage and options, see [Splunk logging driver](https://docs.aws.amazon.com/https://docs.docker.com/config/containers/logging/splunk/) in the *Docker documentation* .
         * - **syslog** - Specifies the syslog logging driver. For more information including usage and options, see [Syslog logging driver](https://docs.aws.amazon.com/https://docs.docker.com/config/containers/logging/syslog/) in the *Docker documentation* .
         *
         * > If you have a custom driver that's not listed earlier that you want to work with the Amazon ECS container agent, you can fork the Amazon ECS container agent project that's [available on GitHub](https://docs.aws.amazon.com/https://github.com/aws/amazon-ecs-agent) and customize it to work with that driver. We encourage you to submit pull requests for changes that you want to have included. However, Amazon Web Services doesn't currently support running modified copies of this software.
         *
         * This parameter requires version 1.18 of the Docker Remote API or greater on your container instance. To check the Docker Remote API version on your container instance, log in to your container instance and run the following command: `sudo docker version | grep "Server API version"`
         */
        logDriver: pulumi.Input<string>;
        /**
         * The configuration options to send to the log driver. This parameter requires version 1.19 of the Docker Remote API or greater on your container instance. To check the Docker Remote API version on your container instance, log in to your container instance and run the following command: `sudo docker version | grep "Server API version"`
         */
        options?: pulumi.Input<{
            [key: string]: pulumi.Input<string>;
        }>;
        /**
         * The secrets to pass to the log configuration. For more information, see [Specifying sensitive data](https://docs.aws.amazon.com/batch/latest/userguide/specifying-sensitive-data.html) in the *AWS Batch User Guide* .
         */
        secretOptions?: pulumi.Input<pulumi.Input<inputs.batch.JobDefinitionSecretArgs>[]>;
    }
    interface JobDefinitionMountPointArgs {
        /**
         * The path on the container where the host volume is mounted.
         */
        containerPath?: pulumi.Input<string>;
        /**
         * If this value is `true` , the container has read-only access to the volume. Otherwise, the container can write to the volume. The default value is `false` .
         */
        readOnly?: pulumi.Input<boolean>;
        /**
         * The name of the volume to mount.
         */
        sourceVolume?: pulumi.Input<string>;
    }
    interface JobDefinitionMultiNodeContainerPropertiesArgs {
        /**
         * The command that's passed to the container. This parameter maps to `Cmd` in the [Create a container](https://docs.aws.amazon.com/https://docs.docker.com/engine/api/v1.23/#create-a-container) section of the [Docker Remote API](https://docs.aws.amazon.com/https://docs.docker.com/engine/api/v1.23/) and the `COMMAND` parameter to [docker run](https://docs.aws.amazon.com/https://docs.docker.com/engine/reference/run/) . For more information, see [https://docs.docker.com/engine/reference/builder/#cmd](https://docs.aws.amazon.com/https://docs.docker.com/engine/reference/builder/#cmd) .
         */
        command?: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * Determines whether execute command functionality is turned on for this task. If `true` , execute command functionality is turned on all the containers in the task.
         */
        enableExecuteCommand?: pulumi.Input<boolean>;
        /**
         * The environment variables to pass to a container. This parameter maps to `Env` in the [Create a container](https://docs.aws.amazon.com/https://docs.docker.com/engine/api/v1.23/#create-a-container) section of the [Docker Remote API](https://docs.aws.amazon.com/https://docs.docker.com/engine/api/v1.23/) and the `--env` option to [docker run](https://docs.aws.amazon.com/https://docs.docker.com/engine/reference/run/) .
         *
         * > We don't recommend using plaintext environment variables for sensitive information, such as credential data. > Environment variables cannot start with " `AWS_BATCH` ". This naming convention is reserved for variables that AWS Batch sets.
         */
        environment?: pulumi.Input<pulumi.Input<inputs.batch.JobDefinitionEnvironmentArgs>[]>;
        /**
         * The amount of ephemeral storage to allocate for the task. This parameter is used to expand the total amount of ephemeral storage available, beyond the default amount, for tasks hosted on AWS Fargate .
         */
        ephemeralStorage?: pulumi.Input<inputs.batch.JobDefinitionEphemeralStorageArgs>;
        /**
         * The Amazon Resource Name (ARN) of the execution role that AWS Batch can assume. For jobs that run on Fargate resources, you must provide an execution role. For more information, see [AWS Batch execution IAM role](https://docs.aws.amazon.com/batch/latest/userguide/execution-IAM-role.html) in the *AWS Batch User Guide* .
         */
        executionRoleArn?: pulumi.Input<string>;
        /**
         * Required. The image used to start a container. This string is passed directly to the Docker daemon. Images in the Docker Hub registry are available by default. Other repositories are specified with `*repository-url* / *image* : *tag*` . It can be 255 characters long. It can contain uppercase and lowercase letters, numbers, hyphens (-), underscores (_), colons (:), periods (.), forward slashes (/), and number signs (#). This parameter maps to `Image` in the [Create a container](https://docs.aws.amazon.com/https://docs.docker.com/engine/api/v1.23/#create-a-container) section of the [Docker Remote API](https://docs.aws.amazon.com/https://docs.docker.com/engine/api/v1.23/) and the `IMAGE` parameter of [docker run](https://docs.aws.amazon.com/https://docs.docker.com/engine/reference/run/) .
         *
         * > Docker image architecture must match the processor architecture of the compute resources that they're scheduled on. For example, ARM-based Docker images can only run on ARM-based compute resources.
         *
         * - Images in Amazon ECR Public repositories use the full `registry/repository[:tag]` or `registry/repository[@digest]` naming conventions. For example, `public.ecr.aws/ *registry_alias* / *my-web-app* : *latest*` .
         * - Images in Amazon ECR repositories use the full registry and repository URI (for example, `123456789012.dkr.ecr.<region-name>.amazonaws.com/<repository-name>` ).
         * - Images in official repositories on Docker Hub use a single name (for example, `ubuntu` or `mongo` ).
         * - Images in other repositories on Docker Hub are qualified with an organization name (for example, `amazon/amazon-ecs-agent` ).
         * - Images in other online repositories are qualified further by a domain name (for example, `quay.io/assemblyline/ubuntu` ).
         */
        image: pulumi.Input<string>;
        /**
         * The instance type to use for a multi-node parallel job. All node groups in a multi-node parallel job must use the same instance type.
         *
         * > This parameter isn't applicable to single-node container jobs or jobs that run on Fargate resources, and shouldn't be provided.
         */
        instanceType?: pulumi.Input<string>;
        /**
         * The Amazon Resource Name (ARN) of the IAM role that the container can assume for AWS permissions. For more information, see [IAM roles for tasks](https://docs.aws.amazon.com/AmazonECS/latest/developerguide/task-iam-roles.html) in the *Amazon Elastic Container Service Developer Guide* .
         */
        jobRoleArn?: pulumi.Input<string>;
        /**
         * Linux-specific modifications that are applied to the container, such as details for device mappings.
         */
        linuxParameters?: pulumi.Input<inputs.batch.JobDefinitionLinuxParametersArgs>;
        /**
         * The log configuration specification for the container.
         *
         * This parameter maps to `LogConfig` in the [Create a container](https://docs.aws.amazon.com/https://docs.docker.com/engine/api/v1.23/#create-a-container) section of the [Docker Remote API](https://docs.aws.amazon.com/https://docs.docker.com/engine/api/v1.23/) and the `--log-driver` option to [docker run](https://docs.aws.amazon.com/https://docs.docker.com/engine/reference/run/) . By default, containers use the same logging driver that the Docker daemon uses. However the container might use a different logging driver than the Docker daemon by specifying a log driver with this parameter in the container definition. To use a different logging driver for a container, the log system must be configured properly on the container instance (or on a different log server for remote logging options). For more information on the options for different supported log drivers, see [Configure logging drivers](https://docs.aws.amazon.com/https://docs.docker.com/engine/admin/logging/overview/) in the Docker documentation.
         *
         * > AWS Batch currently supports a subset of the logging drivers available to the Docker daemon (shown in the [LogConfiguration](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-batch-jobdefinition-containerproperties-logconfiguration.html) data type).
         *
         * This parameter requires version 1.18 of the Docker Remote API or greater on your container instance. To check the Docker Remote API version on your container instance, log in to your container instance and run the following command: `sudo docker version | grep "Server API version"`
         *
         * > The Amazon ECS container agent running on a container instance must register the logging drivers available on that instance with the `ECS_AVAILABLE_LOGGING_DRIVERS` environment variable before containers placed on that instance can use these log configuration options. For more information, see [Amazon ECS container agent configuration](https://docs.aws.amazon.com/AmazonECS/latest/developerguide/ecs-agent-config.html) in the *Amazon Elastic Container Service Developer Guide* .
         */
        logConfiguration?: pulumi.Input<inputs.batch.JobDefinitionLogConfigurationArgs>;
        /**
         * This parameter is deprecated, use `resourceRequirements` to specify the memory requirements for the job definition. It's not supported for jobs running on Fargate resources. For jobs that run on Amazon EC2 resources, it specifies the memory hard limit (in MiB) for a container. If your container attempts to exceed the specified number, it's terminated. You must specify at least 4 MiB of memory for a job using this parameter. The memory hard limit can be specified in several places. It must be specified for each node at least once.
         */
        memory?: pulumi.Input<number>;
        /**
         * The mount points for data volumes in your container.
         *
         * This parameter maps to `Volumes` in the [Create a container](https://docs.aws.amazon.com/https://docs.docker.com/engine/api/v1.35/#operation/ContainerCreate) section of the [Docker Remote API](https://docs.aws.amazon.com/https://docs.docker.com/engine/api/v1.35/) and the [--volume](https://docs.aws.amazon.com/) option to [docker run](https://docs.aws.amazon.com/https://docs.docker.com/engine/reference/run/#security-configuration) .
         *
         * Windows containers can mount whole directories on the same drive as `$env:ProgramData` . Windows containers can't mount directories on a different drive, and mount point can't be across drives.
         */
        mountPoints?: pulumi.Input<pulumi.Input<inputs.batch.JobDefinitionMountPointArgs>[]>;
        /**
         * When this parameter is true, the container is given elevated permissions on the host container instance (similar to the `root` user). This parameter maps to `Privileged` in the [Create a container](https://docs.aws.amazon.com/https://docs.docker.com/engine/api/v1.23/#create-a-container) section of the [Docker Remote API](https://docs.aws.amazon.com/https://docs.docker.com/engine/api/v1.23/) and the `--privileged` option to [docker run](https://docs.aws.amazon.com/https://docs.docker.com/engine/reference/run/) . The default value is false.
         *
         * > This parameter isn't applicable to jobs that are running on Fargate resources and shouldn't be provided, or specified as false.
         */
        privileged?: pulumi.Input<boolean>;
        /**
         * When this parameter is true, the container is given read-only access to its root file system. This parameter maps to `ReadonlyRootfs` in the [Create a container](https://docs.aws.amazon.com/https://docs.docker.com/engine/api/v1.23/#create-a-container) section of the [Docker Remote API](https://docs.aws.amazon.com/https://docs.docker.com/engine/api/v1.23/) and the `--read-only` option to `docker run` .
         */
        readonlyRootFilesystem?: pulumi.Input<boolean>;
        /**
         * The private repository authentication credentials to use.
         */
        repositoryCredentials?: pulumi.Input<inputs.batch.JobDefinitionRepositoryCredentialsArgs>;
        /**
         * The type and amount of resources to assign to a container. The supported resources include `GPU` , `MEMORY` , and `VCPU` .
         */
        resourceRequirements?: pulumi.Input<pulumi.Input<inputs.batch.JobDefinitionResourceRequirementArgs>[]>;
        /**
         * An object that represents the compute environment architecture for AWS Batch jobs on Fargate.
         */
        runtimePlatform?: pulumi.Input<inputs.batch.JobDefinitionRuntimePlatformArgs>;
        /**
         * The secrets for the container. For more information, see [Specifying sensitive data](https://docs.aws.amazon.com/batch/latest/userguide/specifying-sensitive-data.html) in the *AWS Batch User Guide* .
         */
        secrets?: pulumi.Input<pulumi.Input<inputs.batch.JobDefinitionSecretArgs>[]>;
        /**
         * A list of `ulimits` to set in the container. This parameter maps to `Ulimits` in the [Create a container](https://docs.aws.amazon.com/https://docs.docker.com/engine/api/v1.23/#create-a-container) section of the [Docker Remote API](https://docs.aws.amazon.com/https://docs.docker.com/engine/api/v1.23/) and the `--ulimit` option to [docker run](https://docs.aws.amazon.com/https://docs.docker.com/engine/reference/run/) .
         *
         * > This parameter isn't applicable to jobs that are running on Fargate resources and shouldn't be provided.
         */
        ulimits?: pulumi.Input<pulumi.Input<inputs.batch.JobDefinitionUlimitArgs>[]>;
        /**
         * The user name to use inside the container. This parameter maps to `User` in the [Create a container](https://docs.aws.amazon.com/https://docs.docker.com/engine/api/v1.23/#create-a-container) section of the [Docker Remote API](https://docs.aws.amazon.com/https://docs.docker.com/engine/api/v1.23/) and the `--user` option to [docker run](https://docs.aws.amazon.com/https://docs.docker.com/engine/reference/run/) .
         */
        user?: pulumi.Input<string>;
        /**
         * This parameter is deprecated, use `resourceRequirements` to specify the vCPU requirements for the job definition. It's not supported for jobs running on Fargate resources. For jobs running on Amazon EC2 resources, it specifies the number of vCPUs reserved for the job.
         *
         * Each vCPU is equivalent to 1,024 CPU shares. This parameter maps to `CpuShares` in the [Create a container](https://docs.aws.amazon.com/https://docs.docker.com/engine/api/v1.23/#create-a-container) section of the [Docker Remote API](https://docs.aws.amazon.com/https://docs.docker.com/engine/api/v1.23/) and the `--cpu-shares` option to [docker run](https://docs.aws.amazon.com/https://docs.docker.com/engine/reference/run/) . The number of vCPUs must be specified but can be specified in several places. You must specify it at least once for each node.
         */
        vcpus?: pulumi.Input<number>;
        /**
         * A list of data volumes used in a job.
         */
        volumes?: pulumi.Input<pulumi.Input<inputs.batch.JobDefinitionVolumeArgs>[]>;
    }
    interface JobDefinitionMultiNodeEcsPropertiesArgs {
        /**
         * An object that contains the properties for the Amazon ECS task definition of a job.
         *
         * > This object is currently limited to one task element. However, the task element can run up to 10 containers.
         */
        taskProperties: pulumi.Input<pulumi.Input<inputs.batch.JobDefinitionMultiNodeEcsTaskPropertiesArgs>[]>;
    }
    interface JobDefinitionMultiNodeEcsTaskPropertiesArgs {
        /**
         * This object is a list of containers.
         */
        containers?: pulumi.Input<pulumi.Input<inputs.batch.JobDefinitionTaskContainerPropertiesArgs>[]>;
        /**
         * Determines whether execute command functionality is turned on for this task. If `true` , execute command functionality is turned on all the containers in the task.
         */
        enableExecuteCommand?: pulumi.Input<boolean>;
        /**
         * The Amazon Resource Name (ARN) of the execution role that AWS Batch can assume. For jobs that run on Fargate resources, you must provide an execution role. For more information, see [AWS Batch execution IAM role](https://docs.aws.amazon.com/batch/latest/userguide/execution-IAM-role.html) in the *AWS Batch User Guide* .
         */
        executionRoleArn?: pulumi.Input<string>;
        /**
         * The IPC resource namespace to use for the containers in the task. The valid values are `host` , `task` , or `none` .
         *
         * If `host` is specified, all containers within the tasks that specified the `host` IPC mode on the same container instance share the same IPC resources with the host Amazon EC2 instance.
         *
         * If `task` is specified, all containers within the specified `task` share the same IPC resources.
         *
         * If `none` is specified, the IPC resources within the containers of a task are private, and are not shared with other containers in a task or on the container instance.
         *
         * If no value is specified, then the IPC resource namespace sharing depends on the Docker daemon setting on the container instance. For more information, see [IPC settings](https://docs.aws.amazon.com/https://docs.docker.com/engine/reference/run/#ipc-settings---ipc) in the Docker run reference.
         */
        ipcMode?: pulumi.Input<string>;
        /**
         * The process namespace to use for the containers in the task. The valid values are `host` or `task` . For example, monitoring sidecars might need `pidMode` to access information about other containers running in the same task.
         *
         * If `host` is specified, all containers within the tasks that specified the `host` PID mode on the same container instance share the process namespace with the host Amazon EC2 instance.
         *
         * If `task` is specified, all containers within the specified task share the same process namespace.
         *
         * If no value is specified, the default is a private namespace for each container. For more information, see [PID settings](https://docs.aws.amazon.com/https://docs.docker.com/engine/reference/run/#pid-settings---pid) in the Docker run reference.
         */
        pidMode?: pulumi.Input<string>;
        /**
         * The Amazon Resource Name (ARN) that's associated with the Amazon ECS task.
         *
         * > This is object is comparable to [ContainerProperties:jobRoleArn](https://docs.aws.amazon.com/batch/latest/APIReference/API_ContainerProperties.html) .
         */
        taskRoleArn?: pulumi.Input<string>;
        /**
         * A list of volumes that are associated with the job.
         */
        volumes?: pulumi.Input<pulumi.Input<inputs.batch.JobDefinitionVolumeArgs>[]>;
    }
    interface JobDefinitionNetworkConfigurationArgs {
        /**
         * Indicates whether the job has a public IP address. For a job that's running on Fargate resources in a private subnet to send outbound traffic to the internet (for example, to pull container images), the private subnet requires a NAT gateway be attached to route requests to the internet. For more information, see [Amazon ECS task networking](https://docs.aws.amazon.com/AmazonECS/latest/developerguide/task-networking.html) in the *Amazon Elastic Container Service Developer Guide* . The default value is " `DISABLED` ".
         */
        assignPublicIp?: pulumi.Input<string>;
    }
    interface JobDefinitionNodePropertiesArgs {
        /**
         * Specifies the node index for the main node of a multi-node parallel job. This node index value must be fewer than the number of nodes.
         */
        mainNode: pulumi.Input<number>;
        /**
         * A list of node ranges and their properties that are associated with a multi-node parallel job.
         */
        nodeRangeProperties: pulumi.Input<pulumi.Input<inputs.batch.JobDefinitionNodeRangePropertyArgs>[]>;
        /**
         * The number of nodes that are associated with a multi-node parallel job.
         */
        numNodes: pulumi.Input<number>;
    }
    interface JobDefinitionNodeRangePropertyArgs {
        /**
         * Contains a list of consumable resources required by a job.
         */
        consumableResourceProperties?: pulumi.Input<inputs.batch.JobDefinitionConsumableResourcePropertiesArgs>;
        /**
         * The container details for the node range.
         */
        container?: pulumi.Input<inputs.batch.JobDefinitionMultiNodeContainerPropertiesArgs>;
        /**
         * This is an object that represents the properties of the node range for a multi-node parallel job.
         */
        ecsProperties?: pulumi.Input<inputs.batch.JobDefinitionMultiNodeEcsPropertiesArgs>;
        /**
         * This is an object that represents the properties of the node range for a multi-node parallel job.
         */
        eksProperties?: pulumi.Input<inputs.batch.JobDefinitionEksPropertiesArgs>;
        /**
         * The instance types of the underlying host infrastructure of a multi-node parallel job.
         *
         * > This parameter isn't applicable to jobs that are running on Fargate resources.
         * >
         * > In addition, this list object is currently limited to one element.
         */
        instanceTypes?: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * The range of nodes, using node index values. A range of `0:3` indicates nodes with index values of `0` through `3` . If the starting range value is omitted ( `:n` ), then `0` is used to start the range. If the ending range value is omitted ( `n:` ), then the highest possible node index is used to end the range. Your accumulative node ranges must account for all nodes ( `0:n` ). You can nest node ranges (for example, `0:10` and `4:5` ). In this case, the `4:5` range properties override the `0:10` properties.
         */
        targetNodes: pulumi.Input<string>;
    }
    interface JobDefinitionRepositoryCredentialsArgs {
        /**
         * The Amazon Resource Name (ARN) of the secret containing the private repository credentials.
         */
        credentialsParameter: pulumi.Input<string>;
    }
    interface JobDefinitionResourceRequirementArgs {
        /**
         * The type of resource to assign to a container. The supported resources include `GPU` , `MEMORY` , and `VCPU` .
         */
        type?: pulumi.Input<string>;
        /**
         * The quantity of the specified resource to reserve for the container. The values vary based on the `type` specified.
         *
         * - **type="GPU"** - The number of physical GPUs to reserve for the container. Make sure that the number of GPUs reserved for all containers in a job doesn't exceed the number of available GPUs on the compute resource that the job is launched on.
         *
         * > GPUs aren't available for jobs that are running on Fargate resources.
         * - **type="MEMORY"** - The memory hard limit (in MiB) present to the container. This parameter is supported for jobs that are running on Amazon EC2 resources. If your container attempts to exceed the memory specified, the container is terminated. This parameter maps to `Memory` in the [Create a container](https://docs.aws.amazon.com/https://docs.docker.com/engine/api/v1.23/#create-a-container) section of the [Docker Remote API](https://docs.aws.amazon.com/https://docs.docker.com/engine/api/v1.23/) and the `--memory` option to [docker run](https://docs.aws.amazon.com/https://docs.docker.com/engine/reference/run/) . You must specify at least 4 MiB of memory for a job. This is required but can be specified in several places for multi-node parallel (MNP) jobs. It must be specified for each node at least once. This parameter maps to `Memory` in the [Create a container](https://docs.aws.amazon.com/https://docs.docker.com/engine/api/v1.23/#create-a-container) section of the [Docker Remote API](https://docs.aws.amazon.com/https://docs.docker.com/engine/api/v1.23/) and the `--memory` option to [docker run](https://docs.aws.amazon.com/https://docs.docker.com/engine/reference/run/) .
         *
         * > If you're trying to maximize your resource utilization by providing your jobs as much memory as possible for a particular instance type, see [Memory management](https://docs.aws.amazon.com/batch/latest/userguide/memory-management.html) in the *AWS Batch User Guide* .
         *
         * For jobs that are running on Fargate resources, then `value` is the hard limit (in MiB), and must match one of the supported values and the `VCPU` values must be one of the values supported for that memory value.
         *
         * - **value = 512** - `VCPU` = 0.25
         * - **value = 1024** - `VCPU` = 0.25 or 0.5
         * - **value = 2048** - `VCPU` = 0.25, 0.5, or 1
         * - **value = 3072** - `VCPU` = 0.5, or 1
         * - **value = 4096** - `VCPU` = 0.5, 1, or 2
         * - **value = 5120, 6144, or 7168** - `VCPU` = 1 or 2
         * - **value = 8192** - `VCPU` = 1, 2, or 4
         * - **value = 9216, 10240, 11264, 12288, 13312, 14336, or 15360** - `VCPU` = 2 or 4
         * - **value = 16384** - `VCPU` = 2, 4, or 8
         * - **value = 17408, 18432, 19456, 21504, 22528, 23552, 25600, 26624, 27648, 29696, or 30720** - `VCPU` = 4
         * - **value = 20480, 24576, or 28672** - `VCPU` = 4 or 8
         * - **value = 36864, 45056, 53248, or 61440** - `VCPU` = 8
         * - **value = 32768, 40960, 49152, or 57344** - `VCPU` = 8 or 16
         * - **value = 65536, 73728, 81920, 90112, 98304, 106496, 114688, or 122880** - `VCPU` = 16
         * - **type="VCPU"** - The number of vCPUs reserved for the container. This parameter maps to `CpuShares` in the [Create a container](https://docs.aws.amazon.com/https://docs.docker.com/engine/api/v1.23/#create-a-container) section of the [Docker Remote API](https://docs.aws.amazon.com/https://docs.docker.com/engine/api/v1.23/) and the `--cpu-shares` option to [docker run](https://docs.aws.amazon.com/https://docs.docker.com/engine/reference/run/) . Each vCPU is equivalent to 1,024 CPU shares. For Amazon EC2 resources, you must specify at least one vCPU. This is required but can be specified in several places; it must be specified for each node at least once.
         *
         * The default for the Fargate On-Demand vCPU resource count quota is 6 vCPUs. For more information about Fargate quotas, see [AWS Fargate quotas](https://docs.aws.amazon.com/general/latest/gr/ecs-service.html#service-quotas-fargate) in the *AWS General Reference* .
         *
         * For jobs that are running on Fargate resources, then `value` must match one of the supported values and the `MEMORY` values must be one of the values supported for that `VCPU` value. The supported values are 0.25, 0.5, 1, 2, 4, 8, and 16
         *
         * - **value = 0.25** - `MEMORY` = 512, 1024, or 2048
         * - **value = 0.5** - `MEMORY` = 1024, 2048, 3072, or 4096
         * - **value = 1** - `MEMORY` = 2048, 3072, 4096, 5120, 6144, 7168, or 8192
         * - **value = 2** - `MEMORY` = 4096, 5120, 6144, 7168, 8192, 9216, 10240, 11264, 12288, 13312, 14336, 15360, or 16384
         * - **value = 4** - `MEMORY` = 8192, 9216, 10240, 11264, 12288, 13312, 14336, 15360, 16384, 17408, 18432, 19456, 20480, 21504, 22528, 23552, 24576, 25600, 26624, 27648, 28672, 29696, or 30720
         * - **value = 8** - `MEMORY` = 16384, 20480, 24576, 28672, 32768, 36864, 40960, 45056, 49152, 53248, 57344, or 61440
         * - **value = 16** - `MEMORY` = 32768, 40960, 49152, 57344, 65536, 73728, 81920, 90112, 98304, 106496, 114688, or 122880
         */
        value?: pulumi.Input<string>;
    }
    interface JobDefinitionRetryStrategyArgs {
        /**
         * The number of times to move a job to the `RUNNABLE` status. You can specify between 1 and 10 attempts. If the value of `attempts` is greater than one, the job is retried on failure the same number of attempts as the value.
         */
        attempts?: pulumi.Input<number>;
        /**
         * Array of up to 5 objects that specify the conditions where jobs are retried or failed. If this parameter is specified, then the `attempts` parameter must also be specified. If none of the listed conditions match, then the job is retried.
         */
        evaluateOnExit?: pulumi.Input<pulumi.Input<inputs.batch.JobDefinitionEvaluateOnExitArgs>[]>;
    }
    interface JobDefinitionRuntimePlatformArgs {
        /**
         * The vCPU architecture. The default value is `X86_64` . Valid values are `X86_64` and `ARM64` .
         *
         * > This parameter must be set to `X86_64` for Windows containers. > Fargate Spot is not supported for `ARM64` and Windows-based containers on Fargate. A job queue will be blocked if a Fargate `ARM64` or Windows job is submitted to a job queue with only Fargate Spot compute environments. However, you can attach both `FARGATE` and `FARGATE_SPOT` compute environments to the same job queue.
         */
        cpuArchitecture?: pulumi.Input<string>;
        /**
         * The operating system for the compute environment. Valid values are: `LINUX` (default), `WINDOWS_SERVER_2019_CORE` , `WINDOWS_SERVER_2019_FULL` , `WINDOWS_SERVER_2022_CORE` , and `WINDOWS_SERVER_2022_FULL` .
         *
         * > The following parameters can’t be set for Windows containers: `linuxParameters` , `privileged` , `user` , `ulimits` , `readonlyRootFilesystem` , and `efsVolumeConfiguration` . > The AWS Batch Scheduler checks the compute environments that are attached to the job queue before registering a task definition with Fargate. In this scenario, the job queue is where the job is submitted. If the job requires a Windows container and the first compute environment is `LINUX` , the compute environment is skipped and the next compute environment is checked until a Windows-based compute environment is found. > Fargate Spot is not supported for `ARM64` and Windows-based containers on Fargate. A job queue will be blocked if a Fargate `ARM64` or Windows job is submitted to a job queue with only Fargate Spot compute environments. However, you can attach both `FARGATE` and `FARGATE_SPOT` compute environments to the same job queue.
         */
        operatingSystemFamily?: pulumi.Input<string>;
    }
    interface JobDefinitionSecretArgs {
        /**
         * The name of the secret.
         */
        name: pulumi.Input<string>;
        /**
         * The secret to expose to the container. The supported values are either the full Amazon Resource Name (ARN) of the AWS Secrets Manager secret or the full ARN of the parameter in the AWS Systems Manager Parameter Store.
         *
         * > If the AWS Systems Manager Parameter Store parameter exists in the same Region as the job you're launching, then you can use either the full Amazon Resource Name (ARN) or name of the parameter. If the parameter exists in a different Region, then the full ARN must be specified.
         */
        valueFrom: pulumi.Input<string>;
    }
    interface JobDefinitionTaskContainerDependencyArgs {
        /**
         * The dependency condition of the container. The following are the available conditions and their behavior:
         *
         * - `START` - This condition emulates the behavior of links and volumes today. It validates that a dependent container is started before permitting other containers to start.
         * - `COMPLETE` - This condition validates that a dependent container runs to completion (exits) before permitting other containers to start. This can be useful for nonessential containers that run a script and then exit. This condition can't be set on an essential container.
         * - `SUCCESS` - This condition is the same as `COMPLETE` , but it also requires that the container exits with a zero status. This condition can't be set on an essential container.
         */
        condition: pulumi.Input<string>;
        /**
         * A unique identifier for the container.
         */
        containerName: pulumi.Input<string>;
    }
    interface JobDefinitionTaskContainerPropertiesArgs {
        /**
         * The command that's passed to the container. This parameter maps to `Cmd` in the [Create a container](https://docs.aws.amazon.com/https://docs.docker.com/engine/api/v1.23/#create-a-container) section of the [Docker Remote API](https://docs.aws.amazon.com/https://docs.docker.com/engine/api/v1.23/) and the `COMMAND` parameter to [docker run](https://docs.aws.amazon.com/https://docs.docker.com/engine/reference/run/) . For more information, see [Dockerfile reference: CMD](https://docs.aws.amazon.com/https://docs.docker.com/engine/reference/builder/#cmd) .
         */
        command?: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * A list of containers that this container depends on.
         */
        dependsOn?: pulumi.Input<pulumi.Input<inputs.batch.JobDefinitionTaskContainerDependencyArgs>[]>;
        /**
         * The environment variables to pass to a container. This parameter maps to Env in the [Create a container](https://docs.aws.amazon.com/https://docs.docker.com/engine/api/v1.23/#create-a-container) section of the [Docker Remote API](https://docs.aws.amazon.com/https://docs.docker.com/engine/api/v1.23/) and the `--env` parameter to [docker run](https://docs.aws.amazon.com/https://docs.docker.com/engine/reference/run/) .
         *
         * > We don't recommend using plaintext environment variables for sensitive information, such as credential data. > Environment variables cannot start with `AWS_BATCH` . This naming convention is reserved for variables that AWS Batch sets.
         */
        environment?: pulumi.Input<pulumi.Input<inputs.batch.JobDefinitionEnvironmentArgs>[]>;
        /**
         * If the essential parameter of a container is marked as `true` , and that container fails or stops for any reason, all other containers that are part of the task are stopped. If the `essential` parameter of a container is marked as false, its failure doesn't affect the rest of the containers in a task. If this parameter is omitted, a container is assumed to be essential.
         *
         * All jobs must have at least one essential container. If you have an application that's composed of multiple containers, group containers that are used for a common purpose into components, and separate the different components into multiple task definitions. For more information, see [Application Architecture](https://docs.aws.amazon.com/AmazonECS/latest/developerguide/application_architecture.html) in the *Amazon Elastic Container Service Developer Guide* .
         */
        essential?: pulumi.Input<boolean>;
        /**
         * The FireLens configuration for the container. This is used to specify and configure a log router for container logs. For more information, see [Custom log](https://docs.aws.amazon.com/AmazonECS/latest/developerguide/using_firelens.html) routing in the *Amazon Elastic Container Service Developer Guide* .
         */
        firelensConfiguration?: pulumi.Input<inputs.batch.JobDefinitionTaskContainerPropertiesFirelensConfigurationPropertiesArgs>;
        /**
         * The image used to start a container. This string is passed directly to the Docker daemon. By default, images in the Docker Hub registry are available. Other repositories are specified with either `repository-url/image:tag` or `repository-url/image@digest` . Up to 255 letters (uppercase and lowercase), numbers, hyphens, underscores, colons, periods, forward slashes, and number signs are allowed. This parameter maps to `Image` in the [Create a container](https://docs.aws.amazon.com/https://docs.docker.com/engine/api/v1.35/#operation/ContainerCreate) section of the [Docker Remote API](https://docs.aws.amazon.com/https://docs.docker.com/engine/api/v1.35/) and the `IMAGE` parameter of the [*docker run*](https://docs.aws.amazon.com/https://docs.docker.com/engine/reference/run/#security-configuration) .
         */
        image: pulumi.Input<string>;
        /**
         * Linux-specific modifications that are applied to the container, such as Linux kernel capabilities. For more information, see [KernelCapabilities](https://docs.aws.amazon.com/AmazonECS/latest/APIReference/API_KernelCapabilities.html) .
         */
        linuxParameters?: pulumi.Input<inputs.batch.JobDefinitionLinuxParametersArgs>;
        /**
         * The log configuration specification for the container.
         *
         * This parameter maps to `LogConfig` in the [Create a container](https://docs.aws.amazon.com/https://docs.docker.com/engine/api/v1.35/#operation/ContainerCreate) section of the [Docker Remote API](https://docs.aws.amazon.com/https://docs.docker.com/engine/api/v1.35/) and the `--log-driver` option to [docker run](https://docs.aws.amazon.com/https://docs.docker.com/engine/reference/run/#security-configuration) .
         *
         * By default, containers use the same logging driver that the Docker daemon uses. However the container can use a different logging driver than the Docker daemon by specifying a log driver with this parameter in the container definition. To use a different logging driver for a container, the log system must be configured properly on the container instance (or on a different log server for remote logging options). For more information about the options for different supported log drivers, see [Configure logging drivers](https://docs.aws.amazon.com/https://docs.docker.com/engine/admin/logging/overview/) in the *Docker documentation* .
         *
         * > Amazon ECS currently supports a subset of the logging drivers available to the Docker daemon (shown in the `LogConfiguration` data type). Additional log drivers may be available in future releases of the Amazon ECS container agent.
         *
         * This parameter requires version 1.18 of the Docker Remote API or greater on your container instance. To check the Docker Remote API version on your container instance, log in to your container instance and run the following command: sudo docker version `--format '{{.Server.APIVersion}}'`
         *
         * > The Amazon ECS container agent running on a container instance must register the logging drivers available on that instance with the `ECS_AVAILABLE_LOGGING_DRIVERS` environment variable before containers placed on that instance can use these log configuration options. For more information, see [Amazon ECS container agent configuration](https://docs.aws.amazon.com/AmazonECS/latest/developerguide/ecs-agent-config.html) in the *Amazon Elastic Container Service Developer Guide* .
         */
        logConfiguration?: pulumi.Input<inputs.batch.JobDefinitionLogConfigurationArgs>;
        /**
         * The mount points for data volumes in your container.
         *
         * This parameter maps to `Volumes` in the [Create a container](https://docs.aws.amazon.com/https://docs.docker.com/engine/api/v1.35/#operation/ContainerCreate) section of the [Docker Remote API](https://docs.aws.amazon.com/https://docs.docker.com/engine/api/v1.35/) and the [--volume](https://docs.aws.amazon.com/) option to [docker run](https://docs.aws.amazon.com/https://docs.docker.com/engine/reference/run/#security-configuration) .
         *
         * Windows containers can mount whole directories on the same drive as `$env:ProgramData` . Windows containers can't mount directories on a different drive, and mount point can't be across drives.
         */
        mountPoints?: pulumi.Input<pulumi.Input<inputs.batch.JobDefinitionMountPointArgs>[]>;
        /**
         * The name of a container. The name can be used as a unique identifier to target your `dependsOn` and `Overrides` objects.
         */
        name?: pulumi.Input<string>;
        /**
         * When this parameter is `true` , the container is given elevated privileges on the host container instance (similar to the `root` user). This parameter maps to `Privileged` in the [Create a container](https://docs.aws.amazon.com/https://docs.docker.com/engine/api/v1.35/#operation/ContainerCreate) section of the [Docker Remote API](https://docs.aws.amazon.com/https://docs.docker.com/engine/api/v1.35/) and the `--privileged` option to [docker run](https://docs.aws.amazon.com/https://docs.docker.com/engine/reference/run/#security-configuration) .
         *
         * > This parameter is not supported for Windows containers or tasks run on Fargate.
         */
        privileged?: pulumi.Input<boolean>;
        /**
         * When this parameter is true, the container is given read-only access to its root file system. This parameter maps to `ReadonlyRootfs` in the [Create a container](https://docs.aws.amazon.com/https://docs.docker.com/engine/api/v1.35/#operation/ContainerCreate) section of the [Docker Remote API](https://docs.aws.amazon.com/https://docs.docker.com/engine/api/v1.35/) and the `--read-only` option to [docker run](https://docs.aws.amazon.com/https://docs.docker.com/engine/reference/run/#security-configuration) .
         *
         * > This parameter is not supported for Windows containers.
         */
        readonlyRootFilesystem?: pulumi.Input<boolean>;
        /**
         * The private repository authentication credentials to use.
         */
        repositoryCredentials?: pulumi.Input<inputs.batch.JobDefinitionRepositoryCredentialsArgs>;
        /**
         * The type and amount of a resource to assign to a container. The only supported resource is a GPU.
         */
        resourceRequirements?: pulumi.Input<pulumi.Input<inputs.batch.JobDefinitionResourceRequirementArgs>[]>;
        /**
         * The secrets to pass to the container. For more information, see [Specifying Sensitive Data](https://docs.aws.amazon.com/AmazonECS/latest/developerguide/specifying-sensitive-data.html) in the Amazon Elastic Container Service Developer Guide.
         */
        secrets?: pulumi.Input<pulumi.Input<inputs.batch.JobDefinitionSecretArgs>[]>;
        /**
         * A list of `ulimits` to set in the container. If a `ulimit` value is specified in a task definition, it overrides the default values set by Docker. This parameter maps to `Ulimits` in the [Create a container](https://docs.aws.amazon.com/https://docs.docker.com/engine/api/v1.35/#operation/ContainerCreate) section of the [Docker Remote API](https://docs.aws.amazon.com/https://docs.docker.com/engine/api/v1.35/) and the `--ulimit` option to [docker run](https://docs.aws.amazon.com/https://docs.docker.com/engine/reference/run/#security-configuration) .
         *
         * Amazon ECS tasks hosted on Fargate use the default resource limit values set by the operating system with the exception of the nofile resource limit parameter which Fargate overrides. The `nofile` resource limit sets a restriction on the number of open files that a container can use. The default `nofile` soft limit is `1024` and the default hard limit is `65535` .
         *
         * This parameter requires version 1.18 of the Docker Remote API or greater on your container instance. To check the Docker Remote API version on your container instance, log in to your container instance and run the following command: sudo docker version `--format '{{.Server.APIVersion}}'`
         *
         * > This parameter is not supported for Windows containers.
         */
        ulimits?: pulumi.Input<pulumi.Input<inputs.batch.JobDefinitionUlimitArgs>[]>;
        /**
         * The user to use inside the container. This parameter maps to User in the Create a container section of the Docker Remote API and the --user option to docker run.
         *
         * > When running tasks using the `host` network mode, don't run containers using the `root user (UID 0)` . We recommend using a non-root user for better security.
         *
         * You can specify the `user` using the following formats. If specifying a UID or GID, you must specify it as a positive integer.
         *
         * - `user`
         * - `user:group`
         * - `uid`
         * - `uid:gid`
         * - `user:gi`
         * - `uid:group`
         *
         * > This parameter is not supported for Windows containers.
         */
        user?: pulumi.Input<string>;
    }
    /**
     * The FireLens configuration for the container. This is used to specify and configure a log router for container logs. For more information, see [Custom log](https://docs.aws.amazon.com/AmazonECS/latest/developerguide/using_firelens.html) routing in the *Amazon Elastic Container Service Developer Guide* .
     */
    interface JobDefinitionTaskContainerPropertiesFirelensConfigurationPropertiesArgs {
        options?: pulumi.Input<{
            [key: string]: pulumi.Input<string>;
        }>;
        type: pulumi.Input<string>;
    }
    interface JobDefinitionTmpfsArgs {
        /**
         * The absolute file path in the container where the `tmpfs` volume is mounted.
         */
        containerPath: pulumi.Input<string>;
        /**
         * The list of `tmpfs` volume mount options.
         *
         * Valid values: " `defaults` " | " `ro` " | " `rw` " | " `suid` " | " `nosuid` " | " `dev` " | " `nodev` " | " `exec` " | " `noexec` " | " `sync` " | " `async` " | " `dirsync` " | " `remount` " | " `mand` " | " `nomand` " | " `atime` " | " `noatime` " | " `diratime` " | " `nodiratime` " | " `bind` " | " `rbind" | "unbindable" | "runbindable" | "private" | "rprivate" | "shared" | "rshared" | "slave" | "rslave" | "relatime` " | " `norelatime` " | " `strictatime` " | " `nostrictatime` " | " `mode` " | " `uid` " | " `gid` " | " `nr_inodes` " | " `nr_blocks` " | " `mpol` "
         */
        mountOptions?: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * The size (in MiB) of the `tmpfs` volume.
         */
        size: pulumi.Input<number>;
    }
    interface JobDefinitionUlimitArgs {
        /**
         * The hard limit for the `ulimit` type.
         */
        hardLimit: pulumi.Input<number>;
        /**
         * The `type` of the `ulimit` . Valid values are: `core` | `cpu` | `data` | `fsize` | `locks` | `memlock` | `msgqueue` | `nice` | `nofile` | `nproc` | `rss` | `rtprio` | `rttime` | `sigpending` | `stack` .
         */
        name: pulumi.Input<string>;
        /**
         * The soft limit for the `ulimit` type.
         */
        softLimit: pulumi.Input<number>;
    }
    interface JobDefinitionVolumeArgs {
        /**
         * This parameter is specified when you're using an Amazon Elastic File System file system for job storage. Jobs that are running on Fargate resources must specify a `platformVersion` of at least `1.4.0` .
         */
        efsVolumeConfiguration?: pulumi.Input<inputs.batch.JobDefinitionEfsVolumeConfigurationArgs>;
        /**
         * The contents of the `host` parameter determine whether your data volume persists on the host container instance and where it's stored. If the host parameter is empty, then the Docker daemon assigns a host path for your data volume. However, the data isn't guaranteed to persist after the containers that are associated with it stop running.
         *
         * > This parameter isn't applicable to jobs that are running on Fargate resources and shouldn't be provided.
         */
        host?: pulumi.Input<inputs.batch.JobDefinitionHostArgs>;
        /**
         * The name of the volume. It can be up to 255 characters long. It can contain uppercase and lowercase letters, numbers, hyphens (-), and underscores (_). This name is referenced in the `sourceVolume` parameter of container definition `mountPoints` .
         */
        name?: pulumi.Input<string>;
    }
    interface JobQueueComputeEnvironmentOrderArgs {
        /**
         * The Amazon Resource Name (ARN) of the compute environment.
         */
        computeEnvironment: pulumi.Input<string>;
        /**
         * The order of the compute environment. Compute environments are tried in ascending order. For example, if two compute environments are associated with a job queue, the compute environment with a lower `order` integer value is tried for job placement first.
         */
        order: pulumi.Input<number>;
    }
    interface JobQueueJobStateTimeLimitActionArgs {
        /**
         * The action to take when a job is at the head of the job queue in the specified state for the specified period of time. The only supported value is `CANCEL` , which will cancel the job.
         */
        action: pulumi.Input<enums.batch.JobQueueJobStateTimeLimitActionAction>;
        /**
         * The approximate amount of time, in seconds, that must pass with the job in the specified state before the action is taken. The minimum value is 600 (10 minutes) and the maximum value is 86,400 (24 hours).
         */
        maxTimeSeconds: pulumi.Input<number>;
        /**
         * The reason to log for the action being taken.
         */
        reason: pulumi.Input<string>;
        /**
         * The state of the job needed to trigger the action. The only supported value is `RUNNABLE` .
         */
        state: pulumi.Input<enums.batch.JobQueueJobStateTimeLimitActionState>;
    }
    /**
     * Fair Share Policy for the Job Queue.
     */
    interface SchedulingPolicyFairsharePolicyArgs {
        /**
         * A value used to reserve some of the available maximum vCPU for share identifiers that aren't already used.
         *
         * The reserved ratio is `( *computeReservation* /100)^ *ActiveFairShares*` where `*ActiveFairShares*` is the number of active share identifiers.
         *
         * For example, a `computeReservation` value of 50 indicates that AWS Batch reserves 50% of the maximum available vCPU if there's only one share identifier. It reserves 25% if there are two share identifiers. It reserves 12.5% if there are three share identifiers. A `computeReservation` value of 25 indicates that AWS Batch should reserve 25% of the maximum available vCPU if there's only one share identifier, 6.25% if there are two fair share identifiers, and 1.56% if there are three share identifiers.
         *
         * The minimum value is 0 and the maximum value is 99.
         */
        computeReservation?: pulumi.Input<number>;
        /**
         * The amount of time (in seconds) to use to calculate a fair-share percentage for each share identifier in use. A value of zero (0) indicates the default minimum time window (600 seconds). The maximum supported value is 604800 (1 week).
         *
         * The decay allows for more recently run jobs to have more weight than jobs that ran earlier. Consider adjusting this number if you have jobs that (on average) run longer than ten minutes, or a large difference in job count or job run times between share identifiers, and the allocation of resources doesn't meet your needs.
         */
        shareDecaySeconds?: pulumi.Input<number>;
        /**
         * List of Share Attributes
         */
        shareDistribution?: pulumi.Input<pulumi.Input<inputs.batch.SchedulingPolicyShareAttributesArgs>[]>;
    }
    interface SchedulingPolicyShareAttributesArgs {
        /**
         * A share identifier or share identifier prefix. If the string ends with an asterisk (*), this entry specifies the weight factor to use for share identifiers that start with that prefix. The list of share identifiers in a fair-share policy can't overlap. For example, you can't have one that specifies a `shareIdentifier` of `UserA*` and another that specifies a `shareIdentifier` of `UserA-1` .
         *
         * There can be no more than 500 share identifiers active in a job queue.
         *
         * The string is limited to 255 alphanumeric characters, and can be followed by an asterisk (*).
         */
        shareIdentifier?: pulumi.Input<string>;
        /**
         * The weight factor for the share identifier. The default value is 1.0. A lower value has a higher priority for compute resources. For example, jobs that use a share identifier with a weight factor of 0.125 (1/8) get 8 times the compute resources of jobs that use a share identifier with a weight factor of 1.
         *
         * The smallest supported value is 0.0001, and the largest supported value is 999.9999.
         */
        weightFactor?: pulumi.Input<number>;
    }
}
export declare namespace bedrock {
    /**
     * Contains the information of an Agent Action Group
     */
    interface AgentActionGroupArgs {
        /**
         * The Amazon Resource Name (ARN) of the Lambda function containing the business logic that is carried out upon invoking the action or the custom control method for handling the information elicited from the user.
         */
        actionGroupExecutor?: pulumi.Input<inputs.bedrock.AgentActionGroupExecutor0PropertiesArgs | inputs.bedrock.AgentActionGroupExecutor1PropertiesArgs>;
        /**
         * Name of the action group
         */
        actionGroupName: pulumi.Input<string>;
        /**
         * Specifies whether the action group is available for the agent to invoke or not when sending an [InvokeAgent](https://docs.aws.amazon.com/bedrock/latest/APIReference/API_agent-runtime_InvokeAgent.html) request.
         */
        actionGroupState?: pulumi.Input<enums.bedrock.AgentActionGroupState>;
        /**
         * Contains either details about the S3 object containing the OpenAPI schema for the action group or the JSON or YAML-formatted payload defining the schema. For more information, see [Action group OpenAPI schemas](https://docs.aws.amazon.com//bedrock/latest/userguide/agents-api-schema.html) .
         */
        apiSchema?: pulumi.Input<inputs.bedrock.AgentApiSchema0PropertiesArgs | inputs.bedrock.AgentApiSchema1PropertiesArgs>;
        /**
         * Description of action group
         */
        description?: pulumi.Input<string>;
        /**
         * Contains details about the function schema for the action group or the JSON or YAML-formatted payload defining the schema.
         */
        functionSchema?: pulumi.Input<inputs.bedrock.AgentFunctionSchemaArgs>;
        /**
         * If this field is set as `AMAZON.UserInput` , the agent can request the user for additional information when trying to complete a task. The `description` , `apiSchema` , and `actionGroupExecutor` fields must be blank for this action group.
         *
         * During orchestration, if the agent determines that it needs to invoke an API in an action group, but doesn't have enough information to complete the API request, it will invoke this action group instead and return an [Observation](https://docs.aws.amazon.com/bedrock/latest/APIReference/API_agent-runtime_Observation.html) reprompting the user for more information.
         */
        parentActionGroupSignature?: pulumi.Input<enums.bedrock.AgentActionGroupSignature>;
        /**
         * Specifies whether to allow deleting action group while it is in use.
         */
        skipResourceInUseCheckOnDelete?: pulumi.Input<boolean>;
    }
    /**
     * Type of Executors for an Action Group
     */
    interface AgentActionGroupExecutor0PropertiesArgs {
        /**
         * ARN of a Lambda.
         */
        lambda: pulumi.Input<string>;
    }
    /**
     * Type of Executors for an Action Group
     */
    interface AgentActionGroupExecutor1PropertiesArgs {
        customControl: pulumi.Input<enums.bedrock.AgentCustomControlMethod>;
    }
    /**
     * Additional Model Request Fields for Prompt Configuration
     */
    interface AgentAdditionalModelRequestFieldsArgs {
    }
    /**
     * Details about the routing configuration for an Agent alias.
     */
    interface AgentAliasRoutingConfigurationListItemArgs {
        /**
         * Agent Version.
         */
        agentVersion: pulumi.Input<string>;
    }
    /**
     * Contains information about the API Schema for the Action Group
     */
    interface AgentApiSchema0PropertiesArgs {
        s3: pulumi.Input<inputs.bedrock.AgentS3IdentifierArgs>;
    }
    /**
     * Contains information about the API Schema for the Action Group
     */
    interface AgentApiSchema1PropertiesArgs {
        /**
         * String OpenAPI Payload
         */
        payload: pulumi.Input<string>;
    }
    /**
     * Agent Collaborator
     */
    interface AgentCollaboratorArgs {
        /**
         * Agent descriptor for agent collaborator
         */
        agentDescriptor: pulumi.Input<inputs.bedrock.AgentCollaboratorAgentDescriptorPropertiesArgs>;
        /**
         * Agent collaborator instruction
         */
        collaborationInstruction: pulumi.Input<string>;
        /**
         * Agent collaborator name
         */
        collaboratorName: pulumi.Input<string>;
        /**
         * The collaborator's relay conversation history.
         */
        relayConversationHistory?: pulumi.Input<enums.bedrock.AgentRelayConversationHistory>;
    }
    /**
     * Agent descriptor for agent collaborator
     */
    interface AgentCollaboratorAgentDescriptorPropertiesArgs {
        /**
         * Alias ARN for agent descriptor
         */
        aliasArn?: pulumi.Input<string>;
    }
    /**
     * Structure for custom orchestration
     */
    interface AgentCustomOrchestrationArgs {
        /**
         * The structure of the executor invoking the actions in custom orchestration.
         */
        executor?: pulumi.Input<inputs.bedrock.AgentOrchestrationExecutorArgs>;
    }
    /**
     * Function definition
     */
    interface AgentFunctionArgs {
        /**
         * Description of function
         */
        description?: pulumi.Input<string>;
        /**
         * Name for a resource.
         */
        name: pulumi.Input<string>;
        /**
         * The parameters that the agent elicits from the user to fulfill the function.
         */
        parameters?: pulumi.Input<{
            [key: string]: pulumi.Input<inputs.bedrock.AgentParameterDetailArgs>;
        }>;
        /**
         * Contains information if user confirmation is required to invoke the function.
         */
        requireConfirmation?: pulumi.Input<enums.bedrock.AgentRequireConfirmation>;
    }
    /**
     * Schema of Functions
     */
    interface AgentFunctionSchemaArgs {
        /**
         * List of Function definitions
         */
        functions: pulumi.Input<pulumi.Input<inputs.bedrock.AgentFunctionArgs>[]>;
    }
    /**
     * Configuration for a guardrail.
     */
    interface AgentGuardrailConfigurationArgs {
        /**
         * Identifier for the guardrail, could be the id or the arn
         */
        guardrailIdentifier?: pulumi.Input<string>;
        /**
         * Version of the guardrail
         */
        guardrailVersion?: pulumi.Input<string>;
    }
    /**
     * Configuration for inference in prompt configuration
     */
    interface AgentInferenceConfigurationArgs {
        /**
         * Maximum length of output
         */
        maximumLength?: pulumi.Input<number>;
        /**
         * List of stop sequences
         */
        stopSequences?: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * Controls randomness, higher values increase diversity
         */
        temperature?: pulumi.Input<number>;
        /**
         * Sample from the k most likely next tokens
         */
        topK?: pulumi.Input<number>;
        /**
         * Cumulative probability cutoff for token selection
         */
        topP?: pulumi.Input<number>;
    }
    /**
     * Agent Knowledge Base
     */
    interface AgentKnowledgeBaseArgs {
        /**
         * Description of the Resource.
         */
        description: pulumi.Input<string>;
        /**
         * Identifier for a resource.
         */
        knowledgeBaseId: pulumi.Input<string>;
        /**
         * Specifies whether to use the knowledge base or not when sending an [InvokeAgent](https://docs.aws.amazon.com/bedrock/latest/APIReference/API_agent-runtime_InvokeAgent.html) request.
         */
        knowledgeBaseState?: pulumi.Input<enums.bedrock.AgentKnowledgeBaseState>;
    }
    /**
     * Configuration for memory storage
     */
    interface AgentMemoryConfigurationArgs {
        /**
         * The type of memory that is stored.
         */
        enabledMemoryTypes?: pulumi.Input<pulumi.Input<enums.bedrock.AgentMemoryType>[]>;
        /**
         * Contains the configuration for SESSION_SUMMARY memory type enabled for the agent.
         */
        sessionSummaryConfiguration?: pulumi.Input<inputs.bedrock.AgentSessionSummaryConfigurationArgs>;
        /**
         * Maximum number of days to store session details
         */
        storageDays?: pulumi.Input<number>;
    }
    /**
     * Types of executors for custom orchestration strategy
     */
    interface AgentOrchestrationExecutorArgs {
        /**
         * ARN of a Lambda.
         */
        lambda: pulumi.Input<string>;
    }
    /**
     * Parameter detail
     */
    interface AgentParameterDetailArgs {
        /**
         * Description of function parameter.
         */
        description?: pulumi.Input<string>;
        /**
         * Information about if a parameter is required for function call. Default to false.
         */
        required?: pulumi.Input<boolean>;
        /**
         * The data type of the parameter.
         */
        type: pulumi.Input<enums.bedrock.AgentType>;
    }
    /**
     * BasePromptConfiguration per Prompt Type.
     */
    interface AgentPromptConfigurationArgs {
        /**
         * If the Converse or ConverseStream operations support the model, `additionalModelRequestFields` contains additional inference parameters, beyond the base set of inference parameters in the `inferenceConfiguration` field.
         *
         * For more information, see [Inference request parameters and response fields for foundation models](https://docs.aws.amazon.com/bedrock/latest/userguide/model-parameters.html) .
         */
        additionalModelRequestFields?: pulumi.Input<inputs.bedrock.AgentAdditionalModelRequestFieldsArgs>;
        /**
         * Base Prompt Template.
         */
        basePromptTemplate?: pulumi.Input<string>;
        /**
         * The agent's foundation model.
         */
        foundationModel?: pulumi.Input<string>;
        /**
         * Contains inference parameters to use when the agent invokes a foundation model in the part of the agent sequence defined by the `promptType` . For more information, see [Inference parameters for foundation models](https://docs.aws.amazon.com/bedrock/latest/userguide/model-parameters.html) .
         */
        inferenceConfiguration?: pulumi.Input<inputs.bedrock.AgentInferenceConfigurationArgs>;
        /**
         * Specifies whether to override the default parser Lambda function when parsing the raw foundation model output in the part of the agent sequence defined by the `promptType` . If you set the field as `OVERRIDDEN` , the `overrideLambda` field in the [PromptOverrideConfiguration](https://docs.aws.amazon.com/bedrock/latest/APIReference/API_agent_PromptOverrideConfiguration.html) must be specified with the ARN of a Lambda function.
         */
        parserMode?: pulumi.Input<enums.bedrock.AgentCreationMode>;
        /**
         * Specifies whether to override the default prompt template for this `promptType` . Set this value to `OVERRIDDEN` to use the prompt that you provide in the `basePromptTemplate` . If you leave it as `DEFAULT` , the agent uses a default prompt template.
         */
        promptCreationMode?: pulumi.Input<enums.bedrock.AgentCreationMode>;
        /**
         * Specifies whether to allow the inline agent to carry out the step specified in the `promptType` . If you set this value to `DISABLED` , the agent skips that step. The default state for each `promptType` is as follows.
         *
         * - `PRE_PROCESSING` – `ENABLED`
         * - `ORCHESTRATION` – `ENABLED`
         * - `KNOWLEDGE_BASE_RESPONSE_GENERATION` – `ENABLED`
         * - `POST_PROCESSING` – `DISABLED`
         */
        promptState?: pulumi.Input<enums.bedrock.AgentPromptState>;
        /**
         * The step in the agent sequence that this prompt configuration applies to.
         */
        promptType?: pulumi.Input<enums.bedrock.AgentPromptType>;
    }
    /**
     * Configuration for prompt override.
     */
    interface AgentPromptOverrideConfigurationArgs {
        /**
         * ARN of a Lambda.
         */
        overrideLambda?: pulumi.Input<string>;
        /**
         * List of BasePromptConfiguration
         */
        promptConfigurations: pulumi.Input<pulumi.Input<inputs.bedrock.AgentPromptConfigurationArgs>[]>;
    }
    /**
     * The identifier for the S3 resource.
     */
    interface AgentS3IdentifierArgs {
        /**
         * A bucket in S3.
         */
        s3BucketName?: pulumi.Input<string>;
        /**
         * A object key in S3.
         */
        s3ObjectKey?: pulumi.Input<string>;
    }
    /**
     * Configuration for Session Summarization
     */
    interface AgentSessionSummaryConfigurationArgs {
        /**
         * Maximum number of Sessions to Summarize
         */
        maxRecentSessions?: pulumi.Input<number>;
    }
    /**
     * Various ways to encode a list of models in a CreateInferenceProfile request
     */
    interface ApplicationInferenceProfileInferenceProfileModelSourcePropertiesArgs {
        /**
         * Source arns for a custom inference profile to copy its regional load balancing config from. This
         * can either be a foundation model or predefined inference profile ARN.
         */
        copyFrom: pulumi.Input<string>;
    }
    interface DataAutomationProjectAudioExtractionCategoryArgs {
        /**
         * Whether generating categorical data from audio is enabled.
         */
        state: pulumi.Input<enums.bedrock.DataAutomationProjectState>;
        /**
         * The types of data to generate.
         */
        types?: pulumi.Input<pulumi.Input<enums.bedrock.DataAutomationProjectAudioExtractionCategoryType>[]>;
    }
    interface DataAutomationProjectAudioStandardExtractionArgs {
        /**
         * Settings for generating data from audio.
         */
        category: pulumi.Input<inputs.bedrock.DataAutomationProjectAudioExtractionCategoryArgs>;
    }
    interface DataAutomationProjectAudioStandardGenerativeFieldArgs {
        /**
         * Whether generating descriptions is enabled for audio.
         */
        state: pulumi.Input<enums.bedrock.DataAutomationProjectState>;
        /**
         * The types of description to generate.
         */
        types?: pulumi.Input<pulumi.Input<enums.bedrock.DataAutomationProjectAudioStandardGenerativeFieldType>[]>;
    }
    interface DataAutomationProjectAudioStandardOutputConfigurationArgs {
        /**
         * Settings for populating data fields that describe the audio.
         */
        extraction?: pulumi.Input<inputs.bedrock.DataAutomationProjectAudioStandardExtractionArgs>;
        /**
         * Whether to generate descriptions of the data.
         */
        generativeField?: pulumi.Input<inputs.bedrock.DataAutomationProjectAudioStandardGenerativeFieldArgs>;
    }
    interface DataAutomationProjectBlueprintItemArgs {
        /**
         * ARN of a Blueprint
         */
        blueprintArn: pulumi.Input<string>;
        /**
         * The blueprint's stage.
         */
        blueprintStage?: pulumi.Input<enums.bedrock.DataAutomationProjectBlueprintStage>;
        /**
         * Blueprint Version
         */
        blueprintVersion?: pulumi.Input<string>;
    }
    /**
     * Custom output configuration
     */
    interface DataAutomationProjectCustomOutputConfigurationArgs {
        /**
         * A list of blueprints.
         */
        blueprints?: pulumi.Input<pulumi.Input<inputs.bedrock.DataAutomationProjectBlueprintItemArgs>[]>;
    }
    interface DataAutomationProjectDocumentBoundingBoxArgs {
        /**
         * Whether bounding boxes are enabled for documents.
         */
        state: pulumi.Input<enums.bedrock.DataAutomationProjectState>;
    }
    interface DataAutomationProjectDocumentExtractionGranularityArgs {
        /**
         * Granularity settings for documents.
         */
        types?: pulumi.Input<pulumi.Input<enums.bedrock.DataAutomationProjectDocumentExtractionGranularityType>[]>;
    }
    interface DataAutomationProjectDocumentOutputAdditionalFileFormatArgs {
        /**
         * Whether additional file formats are enabled for a project.
         */
        state: pulumi.Input<enums.bedrock.DataAutomationProjectState>;
    }
    interface DataAutomationProjectDocumentOutputFormatArgs {
        /**
         * Output settings for additional file formats.
         */
        additionalFileFormat: pulumi.Input<inputs.bedrock.DataAutomationProjectDocumentOutputAdditionalFileFormatArgs>;
        /**
         * An output text format.
         */
        textFormat: pulumi.Input<inputs.bedrock.DataAutomationProjectDocumentOutputTextFormatArgs>;
    }
    interface DataAutomationProjectDocumentOutputTextFormatArgs {
        /**
         * The types of output text to generate.
         */
        types?: pulumi.Input<pulumi.Input<enums.bedrock.DataAutomationProjectDocumentOutputTextFormatType>[]>;
    }
    interface DataAutomationProjectDocumentOverrideConfigurationArgs {
        /**
         * Whether document splitter is enabled for a project.
         */
        splitter?: pulumi.Input<inputs.bedrock.DataAutomationProjectSplitterConfigurationArgs>;
    }
    interface DataAutomationProjectDocumentStandardExtractionArgs {
        /**
         * Whether to generate bounding boxes.
         */
        boundingBox: pulumi.Input<inputs.bedrock.DataAutomationProjectDocumentBoundingBoxArgs>;
        /**
         * Which granularities to generate data for.
         */
        granularity: pulumi.Input<inputs.bedrock.DataAutomationProjectDocumentExtractionGranularityArgs>;
    }
    interface DataAutomationProjectDocumentStandardGenerativeFieldArgs {
        /**
         * Whether generating descriptions is enabled for documents.
         */
        state: pulumi.Input<enums.bedrock.DataAutomationProjectState>;
    }
    interface DataAutomationProjectDocumentStandardOutputConfigurationArgs {
        /**
         * Settings for populating data fields that describe the document.
         */
        extraction?: pulumi.Input<inputs.bedrock.DataAutomationProjectDocumentStandardExtractionArgs>;
        /**
         * Whether to generate descriptions.
         */
        generativeField?: pulumi.Input<inputs.bedrock.DataAutomationProjectDocumentStandardGenerativeFieldArgs>;
        /**
         * The output format to generate.
         */
        outputFormat?: pulumi.Input<inputs.bedrock.DataAutomationProjectDocumentOutputFormatArgs>;
    }
    interface DataAutomationProjectImageBoundingBoxArgs {
        /**
         * Bounding box settings for a project.
         */
        state: pulumi.Input<enums.bedrock.DataAutomationProjectState>;
    }
    interface DataAutomationProjectImageExtractionCategoryArgs {
        /**
         * Whether generating categorical data from images is enabled.
         */
        state: pulumi.Input<enums.bedrock.DataAutomationProjectState>;
        /**
         * The types of data to generate.
         */
        types?: pulumi.Input<pulumi.Input<enums.bedrock.DataAutomationProjectImageExtractionCategoryType>[]>;
    }
    interface DataAutomationProjectImageStandardExtractionArgs {
        /**
         * Settings for generating bounding boxes.
         */
        boundingBox: pulumi.Input<inputs.bedrock.DataAutomationProjectImageBoundingBoxArgs>;
        /**
         * Settings for generating categorical data.
         */
        category: pulumi.Input<inputs.bedrock.DataAutomationProjectImageExtractionCategoryArgs>;
    }
    interface DataAutomationProjectImageStandardGenerativeFieldArgs {
        /**
         * Whether generating descriptions is enabled for images.
         */
        state: pulumi.Input<enums.bedrock.DataAutomationProjectState>;
        /**
         * Settings for generating descriptions of images.
         */
        types?: pulumi.Input<pulumi.Input<enums.bedrock.DataAutomationProjectImageStandardGenerativeFieldType>[]>;
    }
    interface DataAutomationProjectImageStandardOutputConfigurationArgs {
        /**
         * Settings for populating data fields that describe the image.
         */
        extraction?: pulumi.Input<inputs.bedrock.DataAutomationProjectImageStandardExtractionArgs>;
        /**
         * Whether to generate descriptions of the data.
         */
        generativeField?: pulumi.Input<inputs.bedrock.DataAutomationProjectImageStandardGenerativeFieldArgs>;
    }
    /**
     * Override configuration
     */
    interface DataAutomationProjectOverrideConfigurationArgs {
        /**
         * Additional settings for a project.
         */
        document?: pulumi.Input<inputs.bedrock.DataAutomationProjectDocumentOverrideConfigurationArgs>;
    }
    interface DataAutomationProjectSplitterConfigurationArgs {
        /**
         * Whether document splitter is enabled for a project.
         */
        state?: pulumi.Input<enums.bedrock.DataAutomationProjectState>;
    }
    /**
     * Standard output configuration
     */
    interface DataAutomationProjectStandardOutputConfigurationArgs {
        /**
         * Settings for processing audio.
         */
        audio?: pulumi.Input<inputs.bedrock.DataAutomationProjectAudioStandardOutputConfigurationArgs>;
        /**
         * Settings for processing documents.
         */
        document?: pulumi.Input<inputs.bedrock.DataAutomationProjectDocumentStandardOutputConfigurationArgs>;
        /**
         * Settings for processing images.
         */
        image?: pulumi.Input<inputs.bedrock.DataAutomationProjectImageStandardOutputConfigurationArgs>;
        /**
         * Settings for processing video.
         */
        video?: pulumi.Input<inputs.bedrock.DataAutomationProjectVideoStandardOutputConfigurationArgs>;
    }
    interface DataAutomationProjectVideoBoundingBoxArgs {
        /**
         * Whether bounding boxes are enabled for video.
         */
        state: pulumi.Input<enums.bedrock.DataAutomationProjectState>;
    }
    interface DataAutomationProjectVideoExtractionCategoryArgs {
        /**
         * Whether generating categorical data from video is enabled.
         */
        state: pulumi.Input<enums.bedrock.DataAutomationProjectState>;
        /**
         * The types of data to generate.
         */
        types?: pulumi.Input<pulumi.Input<enums.bedrock.DataAutomationProjectVideoExtractionCategoryType>[]>;
    }
    interface DataAutomationProjectVideoStandardExtractionArgs {
        /**
         * Settings for generating bounding boxes.
         */
        boundingBox: pulumi.Input<inputs.bedrock.DataAutomationProjectVideoBoundingBoxArgs>;
        /**
         * Settings for generating categorical data.
         */
        category: pulumi.Input<inputs.bedrock.DataAutomationProjectVideoExtractionCategoryArgs>;
    }
    interface DataAutomationProjectVideoStandardGenerativeFieldArgs {
        /**
         * Whether generating descriptions is enabled for video.
         */
        state: pulumi.Input<enums.bedrock.DataAutomationProjectState>;
        /**
         * The types of description to generate.
         */
        types?: pulumi.Input<pulumi.Input<enums.bedrock.DataAutomationProjectVideoStandardGenerativeFieldType>[]>;
    }
    interface DataAutomationProjectVideoStandardOutputConfigurationArgs {
        /**
         * Settings for populating data fields that describe the video.
         */
        extraction?: pulumi.Input<inputs.bedrock.DataAutomationProjectVideoStandardExtractionArgs>;
        /**
         * Whether to generate descriptions of the video.
         */
        generativeField?: pulumi.Input<inputs.bedrock.DataAutomationProjectVideoStandardGenerativeFieldArgs>;
    }
    /**
     * Settings for a Bedrock Data Automation used to parse documents for a data source.
     */
    interface DataSourceBedrockDataAutomationConfigurationArgs {
        /**
         * Specifies whether to enable parsing of multimodal data, including both text and/or images.
         */
        parsingModality?: pulumi.Input<enums.bedrock.DataSourceParsingModality>;
    }
    /**
     * Settings for a foundation model used to parse documents for a data source.
     */
    interface DataSourceBedrockFoundationModelConfigurationArgs {
        /**
         * The ARN of the foundation model to use for parsing.
         */
        modelArn: pulumi.Input<string>;
        /**
         * Specifies whether to enable parsing of multimodal data, including both text and/or images.
         */
        parsingModality?: pulumi.Input<enums.bedrock.DataSourceParsingModality>;
        /**
         * Instructions for interpreting the contents of a document.
         */
        parsingPrompt?: pulumi.Input<inputs.bedrock.DataSourceParsingPromptArgs>;
    }
    /**
     * Bedrock Foundation Model configuration to be used for Context Enrichment.
     */
    interface DataSourceBedrockFoundationModelContextEnrichmentConfigurationArgs {
        /**
         * The enrichment stategy used to provide additional context. For example, Neptune GraphRAG uses Amazon Bedrock foundation models to perform chunk entity extraction.
         */
        enrichmentStrategyConfiguration: pulumi.Input<inputs.bedrock.DataSourceEnrichmentStrategyConfigurationArgs>;
        /**
         * The Amazon Resource Name (ARN) of the model used to create vector embeddings for the knowledge base.
         */
        modelArn: pulumi.Input<string>;
    }
    /**
     * Details about how to chunk the documents in the data source. A chunk refers to an excerpt from a data source that is returned when the knowledge base that it belongs to is queried.
     */
    interface DataSourceChunkingConfigurationArgs {
        /**
         * Knowledge base can split your source data into chunks. A *chunk* refers to an excerpt from a data source that is returned when the knowledge base that it belongs to is queried. You have the following options for chunking your data. If you opt for `NONE` , then you may want to pre-process your files by splitting them up such that each file corresponds to a chunk.
         *
         * - `FIXED_SIZE` – Amazon Bedrock splits your source data into chunks of the approximate size that you set in the `fixedSizeChunkingConfiguration` .
         * - `HIERARCHICAL` – Split documents into layers of chunks where the first layer contains large chunks, and the second layer contains smaller chunks derived from the first layer.
         * - `SEMANTIC` – Split documents into chunks based on groups of similar content derived with natural language processing.
         * - `NONE` – Amazon Bedrock treats each file as one chunk. If you choose this option, you may want to pre-process your documents by splitting them into separate files.
         */
        chunkingStrategy: pulumi.Input<enums.bedrock.DataSourceChunkingStrategy>;
        /**
         * Configurations for when you choose fixed-size chunking. If you set the `chunkingStrategy` as `NONE` , exclude this field.
         */
        fixedSizeChunkingConfiguration?: pulumi.Input<inputs.bedrock.DataSourceFixedSizeChunkingConfigurationArgs>;
        /**
         * Settings for hierarchical document chunking for a data source. Hierarchical chunking splits documents into layers of chunks where the first layer contains large chunks, and the second layer contains smaller chunks derived from the first layer.
         */
        hierarchicalChunkingConfiguration?: pulumi.Input<inputs.bedrock.DataSourceHierarchicalChunkingConfigurationArgs>;
        /**
         * Settings for semantic document chunking for a data source. Semantic chunking splits a document into into smaller documents based on groups of similar content derived from the text with natural language processing.
         */
        semanticChunkingConfiguration?: pulumi.Input<inputs.bedrock.DataSourceSemanticChunkingConfigurationArgs>;
    }
    /**
     * Specifies a raw data source location to ingest.
     */
    interface DataSourceConfigurationArgs {
        /**
         * The configuration information to connect to Confluence as your data source.
         *
         * > Confluence data source connector is in preview release and is subject to change.
         */
        confluenceConfiguration?: pulumi.Input<inputs.bedrock.DataSourceConfluenceDataSourceConfigurationArgs>;
        /**
         * The configuration information to connect to Amazon S3 as your data source.
         */
        s3Configuration?: pulumi.Input<inputs.bedrock.DataSourceS3DataSourceConfigurationArgs>;
        /**
         * The configuration information to connect to Salesforce as your data source.
         *
         * > Salesforce data source connector is in preview release and is subject to change.
         */
        salesforceConfiguration?: pulumi.Input<inputs.bedrock.DataSourceSalesforceDataSourceConfigurationArgs>;
        /**
         * The configuration information to connect to SharePoint as your data source.
         *
         * > SharePoint data source connector is in preview release and is subject to change.
         */
        sharePointConfiguration?: pulumi.Input<inputs.bedrock.DataSourceSharePointDataSourceConfigurationArgs>;
        /**
         * The type of data source.
         */
        type: pulumi.Input<enums.bedrock.DataSourceType>;
        /**
         * The configuration of web URLs to crawl for your data source. You should be authorized to crawl the URLs.
         *
         * > Crawling web URLs as your data source is in preview release and is subject to change.
         */
        webConfiguration?: pulumi.Input<inputs.bedrock.DataSourceWebDataSourceConfigurationArgs>;
    }
    /**
     * The configuration of the Confluence content. For example, configuring specific types of Confluence content.
     */
    interface DataSourceConfluenceCrawlerConfigurationArgs {
        /**
         * The configuration of filtering the Confluence content. For example, configuring regular expression patterns to include or exclude certain content.
         */
        filterConfiguration?: pulumi.Input<inputs.bedrock.DataSourceCrawlFilterConfigurationArgs>;
    }
    /**
     * The configuration information to connect to Confluence as your data source.
     */
    interface DataSourceConfluenceDataSourceConfigurationArgs {
        /**
         * The configuration of the Confluence content. For example, configuring specific types of Confluence content.
         */
        crawlerConfiguration?: pulumi.Input<inputs.bedrock.DataSourceConfluenceCrawlerConfigurationArgs>;
        /**
         * The endpoint information to connect to your Confluence data source.
         */
        sourceConfiguration: pulumi.Input<inputs.bedrock.DataSourceConfluenceSourceConfigurationArgs>;
    }
    /**
     * The endpoint information to connect to your Confluence data source.
     */
    interface DataSourceConfluenceSourceConfigurationArgs {
        /**
         * The supported authentication type to authenticate and connect to your Confluence instance.
         */
        authType: pulumi.Input<enums.bedrock.DataSourceConfluenceSourceConfigurationAuthType>;
        /**
         * The Amazon Resource Name of an AWS Secrets Manager secret that stores your authentication credentials for your Confluence instance URL. For more information on the key-value pairs that must be included in your secret, depending on your authentication type, see Confluence connection configuration.
         */
        credentialsSecretArn: pulumi.Input<string>;
        /**
         * The supported host type, whether online/cloud or server/on-premises.
         */
        hostType: pulumi.Input<enums.bedrock.DataSourceConfluenceSourceConfigurationHostType>;
        /**
         * The Confluence host URL or instance URL.
         */
        hostUrl: pulumi.Input<string>;
    }
    /**
     * Additional Enrichment Configuration for example when using GraphRag.
     */
    interface DataSourceContextEnrichmentConfigurationArgs {
        /**
         * The configuration of the Amazon Bedrock foundation model used for context enrichment.
         */
        bedrockFoundationModelConfiguration?: pulumi.Input<inputs.bedrock.DataSourceBedrockFoundationModelContextEnrichmentConfigurationArgs>;
        /**
         * The method used for context enrichment. It must be Amazon Bedrock foundation models.
         */
        type: pulumi.Input<enums.bedrock.DataSourceContextEnrichmentType>;
    }
    /**
     * The type of filtering that you want to apply to certain objects or content of the data source. For example, the PATTERN type is regular expression patterns you can apply to filter your content.
     */
    interface DataSourceCrawlFilterConfigurationArgs {
        /**
         * The configuration of filtering certain objects or content types of the data source.
         */
        patternObjectFilter?: pulumi.Input<inputs.bedrock.DataSourcePatternObjectFilterConfigurationArgs>;
        /**
         * The crawl filter type.
         */
        type: pulumi.Input<enums.bedrock.DataSourceCrawlFilterConfigurationType>;
    }
    /**
     * Settings for customizing steps in the data source content ingestion pipeline.
     */
    interface DataSourceCustomTransformationConfigurationArgs {
        /**
         * An S3 bucket path for input and output objects.
         */
        intermediateStorage: pulumi.Input<inputs.bedrock.DataSourceIntermediateStorageArgs>;
        /**
         * A list of Lambda functions that process documents.
         */
        transformations: pulumi.Input<pulumi.Input<inputs.bedrock.DataSourceTransformationArgs>[]>;
    }
    /**
     * Strategy to be used when using Bedrock Foundation Model for Context Enrichment.
     */
    interface DataSourceEnrichmentStrategyConfigurationArgs {
        /**
         * The method used for the context enrichment strategy.
         */
        method: pulumi.Input<enums.bedrock.DataSourceEnrichmentStrategyMethod>;
    }
    /**
     * Configurations for when you choose fixed-size chunking. If you set the chunkingStrategy as NONE, exclude this field.
     */
    interface DataSourceFixedSizeChunkingConfigurationArgs {
        /**
         * The maximum number of tokens to include in a chunk.
         */
        maxTokens: pulumi.Input<number>;
        /**
         * The percentage of overlap between adjacent chunks of a data source.
         */
        overlapPercentage: pulumi.Input<number>;
    }
    /**
     * Configurations for when you choose hierarchical chunking. If you set the chunkingStrategy as NONE, exclude this field.
     */
    interface DataSourceHierarchicalChunkingConfigurationArgs {
        /**
         * Token settings for each layer.
         */
        levelConfigurations: pulumi.Input<pulumi.Input<inputs.bedrock.DataSourceHierarchicalChunkingLevelConfigurationArgs>[]>;
        /**
         * The number of tokens to repeat across chunks in the same layer.
         */
        overlapTokens: pulumi.Input<number>;
    }
    /**
     * Token settings for a layer in a hierarchical chunking configuration.
     */
    interface DataSourceHierarchicalChunkingLevelConfigurationArgs {
        /**
         * The maximum number of tokens that a chunk can contain in this layer.
         */
        maxTokens: pulumi.Input<number>;
    }
    /**
     * A location for storing content from data sources temporarily as it is processed by custom components in the ingestion pipeline.
     */
    interface DataSourceIntermediateStorageArgs {
        /**
         * An S3 bucket path.
         */
        s3Location: pulumi.Input<inputs.bedrock.DataSourceS3LocationArgs>;
    }
    /**
     * Settings for parsing document contents
     */
    interface DataSourceParsingConfigurationArgs {
        /**
         * If you specify `BEDROCK_DATA_AUTOMATION` as the parsing strategy for ingesting your data source, use this object to modify configurations for using the Amazon Bedrock Data Automation parser.
         */
        bedrockDataAutomationConfiguration?: pulumi.Input<inputs.bedrock.DataSourceBedrockDataAutomationConfigurationArgs>;
        /**
         * If you specify `BEDROCK_FOUNDATION_MODEL` as the parsing strategy for ingesting your data source, use this object to modify configurations for using a foundation model to parse documents.
         */
        bedrockFoundationModelConfiguration?: pulumi.Input<inputs.bedrock.DataSourceBedrockFoundationModelConfigurationArgs>;
        /**
         * The parsing strategy for the data source.
         */
        parsingStrategy: pulumi.Input<enums.bedrock.DataSourceParsingStrategy>;
    }
    /**
     * Instructions for interpreting the contents of a document.
     */
    interface DataSourceParsingPromptArgs {
        /**
         * Instructions for interpreting the contents of a document.
         */
        parsingPromptText: pulumi.Input<string>;
    }
    /**
     * The specific filters applied to your data source content. You can filter out or include certain content.
     */
    interface DataSourcePatternObjectFilterArgs {
        exclusionFilters?: pulumi.Input<pulumi.Input<string>[]>;
        inclusionFilters?: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * The supported object type or content type of the data source.
         */
        objectType: pulumi.Input<string>;
    }
    /**
     * The configuration of specific filters applied to your data source content. You can filter out or include certain content.
     */
    interface DataSourcePatternObjectFilterConfigurationArgs {
        /**
         * The configuration of specific filters applied to your data source content. You can filter out or include certain content.
         */
        filters: pulumi.Input<pulumi.Input<inputs.bedrock.DataSourcePatternObjectFilterArgs>[]>;
    }
    /**
     * The configuration information to connect to Amazon S3 as your data source.
     */
    interface DataSourceS3DataSourceConfigurationArgs {
        /**
         * The ARN of the bucket that contains the data source.
         */
        bucketArn: pulumi.Input<string>;
        /**
         * The account ID for the owner of the S3 bucket.
         */
        bucketOwnerAccountId?: pulumi.Input<string>;
        /**
         * A list of S3 prefixes that define the object containing the data sources.
         */
        inclusionPrefixes?: pulumi.Input<pulumi.Input<string>[]>;
    }
    /**
     * An Amazon S3 location.
     */
    interface DataSourceS3LocationArgs {
        /**
         * The location's URI
         */
        uri: pulumi.Input<string>;
    }
    /**
     * The configuration of filtering the Salesforce content. For example, configuring regular expression patterns to include or exclude certain content.
     */
    interface DataSourceSalesforceCrawlerConfigurationArgs {
        /**
         * The configuration of filtering the Salesforce content. For example, configuring regular expression patterns to include or exclude certain content.
         */
        filterConfiguration?: pulumi.Input<inputs.bedrock.DataSourceCrawlFilterConfigurationArgs>;
    }
    /**
     * The configuration information to connect to Salesforce as your data source.
     */
    interface DataSourceSalesforceDataSourceConfigurationArgs {
        /**
         * The configuration of the Salesforce content. For example, configuring specific types of Salesforce content.
         */
        crawlerConfiguration?: pulumi.Input<inputs.bedrock.DataSourceSalesforceCrawlerConfigurationArgs>;
        /**
         * The endpoint information to connect to your Salesforce data source.
         */
        sourceConfiguration: pulumi.Input<inputs.bedrock.DataSourceSalesforceSourceConfigurationArgs>;
    }
    /**
     * The endpoint information to connect to your Salesforce data source.
     */
    interface DataSourceSalesforceSourceConfigurationArgs {
        /**
         * The supported authentication type to authenticate and connect to your Salesforce instance.
         */
        authType: pulumi.Input<enums.bedrock.DataSourceSalesforceSourceConfigurationAuthType>;
        /**
         * The Amazon Resource Name of an AWS Secrets Manager secret that stores your authentication credentials for your Salesforce instance URL. For more information on the key-value pairs that must be included in your secret, depending on your authentication type, see Salesforce connection configuration.
         */
        credentialsSecretArn: pulumi.Input<string>;
        /**
         * The Salesforce host URL or instance URL.
         */
        hostUrl: pulumi.Input<string>;
    }
    /**
     * A seed url object.
     */
    interface DataSourceSeedUrlArgs {
        /**
         * A web url.
         */
        url: pulumi.Input<string>;
    }
    /**
     * Configurations for when you choose semantic chunking. If you set the chunkingStrategy as NONE, exclude this field.
     */
    interface DataSourceSemanticChunkingConfigurationArgs {
        /**
         * The dissimilarity threshold for splitting chunks.
         */
        breakpointPercentileThreshold: pulumi.Input<number>;
        /**
         * The buffer size.
         */
        bufferSize: pulumi.Input<number>;
        /**
         * The maximum number of tokens that a chunk can contain.
         */
        maxTokens: pulumi.Input<number>;
    }
    /**
     * Contains details about the server-side encryption for the data source.
     */
    interface DataSourceServerSideEncryptionConfigurationArgs {
        /**
         * The ARN of the AWS KMS key used to encrypt the resource.
         */
        kmsKeyArn?: pulumi.Input<string>;
    }
    /**
     * The configuration of the SharePoint content. For example, configuring specific types of SharePoint content.
     */
    interface DataSourceSharePointCrawlerConfigurationArgs {
        /**
         * The configuration of filtering the SharePoint content. For example, configuring regular expression patterns to include or exclude certain content.
         */
        filterConfiguration?: pulumi.Input<inputs.bedrock.DataSourceCrawlFilterConfigurationArgs>;
    }
    /**
     * The configuration information to connect to SharePoint as your data source.
     */
    interface DataSourceSharePointDataSourceConfigurationArgs {
        /**
         * The configuration of the SharePoint content. For example, configuring specific types of SharePoint content.
         */
        crawlerConfiguration?: pulumi.Input<inputs.bedrock.DataSourceSharePointCrawlerConfigurationArgs>;
        /**
         * The endpoint information to connect to your SharePoint data source.
         */
        sourceConfiguration: pulumi.Input<inputs.bedrock.DataSourceSharePointSourceConfigurationArgs>;
    }
    /**
     * The endpoint information to connect to your SharePoint data source.
     */
    interface DataSourceSharePointSourceConfigurationArgs {
        /**
         * The supported authentication type to authenticate and connect to your SharePoint site/sites.
         */
        authType: pulumi.Input<enums.bedrock.DataSourceSharePointSourceConfigurationAuthType>;
        /**
         * The Amazon Resource Name of an AWS Secrets Manager secret that stores your authentication credentials for your SharePoint site/sites. For more information on the key-value pairs that must be included in your secret, depending on your authentication type, see SharePoint connection configuration.
         */
        credentialsSecretArn: pulumi.Input<string>;
        /**
         * The domain of your SharePoint instance or site URL/URLs.
         */
        domain: pulumi.Input<string>;
        /**
         * The supported host type, whether online/cloud or server/on-premises.
         */
        hostType: pulumi.Input<enums.bedrock.DataSourceSharePointSourceConfigurationHostType>;
        /**
         * A list of one or more SharePoint site URLs.
         */
        siteUrls: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * The identifier of your Microsoft 365 tenant.
         */
        tenantId?: pulumi.Input<string>;
    }
    /**
     * A Lambda function that processes documents.
     */
    interface DataSourceTransformationArgs {
        /**
         * When the service applies the transformation.
         */
        stepToApply: pulumi.Input<enums.bedrock.DataSourceTransformationStepToApply>;
        /**
         * A Lambda function that processes documents.
         */
        transformationFunction: pulumi.Input<inputs.bedrock.DataSourceTransformationFunctionArgs>;
    }
    /**
     * A Lambda function that processes documents.
     */
    interface DataSourceTransformationFunctionArgs {
        /**
         * The Lambda function.
         */
        transformationLambdaConfiguration: pulumi.Input<inputs.bedrock.DataSourceTransformationLambdaConfigurationArgs>;
    }
    /**
     * A Lambda function that processes documents.
     */
    interface DataSourceTransformationLambdaConfigurationArgs {
        /**
         * The function's ARN identifier.
         */
        lambdaArn: pulumi.Input<string>;
    }
    /**
     * A url configuration.
     */
    interface DataSourceUrlConfigurationArgs {
        /**
         * One or more seed or starting point URLs.
         */
        seedUrls: pulumi.Input<pulumi.Input<inputs.bedrock.DataSourceSeedUrlArgs>[]>;
    }
    /**
     * Details about how to chunk the documents in the data source. A chunk refers to an excerpt from a data source that is returned when the knowledge base that it belongs to is queried.
     */
    interface DataSourceVectorIngestionConfigurationArgs {
        /**
         * Details about how to chunk the documents in the data source. A *chunk* refers to an excerpt from a data source that is returned when the knowledge base that it belongs to is queried.
         */
        chunkingConfiguration?: pulumi.Input<inputs.bedrock.DataSourceChunkingConfigurationArgs>;
        /**
         * The context enrichment configuration used for ingestion of the data into the vector store.
         */
        contextEnrichmentConfiguration?: pulumi.Input<inputs.bedrock.DataSourceContextEnrichmentConfigurationArgs>;
        /**
         * A custom document transformer for parsed data source documents.
         */
        customTransformationConfiguration?: pulumi.Input<inputs.bedrock.DataSourceCustomTransformationConfigurationArgs>;
        /**
         * Configurations for a parser to use for parsing documents in your data source. If you exclude this field, the default parser will be used.
         */
        parsingConfiguration?: pulumi.Input<inputs.bedrock.DataSourceParsingConfigurationArgs>;
    }
    /**
     * Configuration for the web crawler.
     */
    interface DataSourceWebCrawlerConfigurationArgs {
        /**
         * The configuration of crawl limits for the web URLs.
         */
        crawlerLimits?: pulumi.Input<inputs.bedrock.DataSourceWebCrawlerLimitsArgs>;
        /**
         * A list of one or more exclusion regular expression patterns to exclude certain URLs. If you specify an inclusion and exclusion filter/pattern and both match a URL, the exclusion filter takes precedence and the web content of the URL isn’t crawled.
         */
        exclusionFilters?: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * A list of one or more inclusion regular expression patterns to include certain URLs. If you specify an inclusion and exclusion filter/pattern and both match a URL, the exclusion filter takes precedence and the web content of the URL isn’t crawled.
         */
        inclusionFilters?: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * The scope of what is crawled for your URLs.
         *
         * You can choose to crawl only web pages that belong to the same host or primary domain. For example, only web pages that contain the seed URL "https://docs.aws.amazon.com/bedrock/latest/userguide/" and no other domains. You can choose to include sub domains in addition to the host or primary domain. For example, web pages that contain "aws.amazon.com" can also include sub domain "docs.aws.amazon.com".
         */
        scope?: pulumi.Input<enums.bedrock.DataSourceWebScopeType>;
        /**
         * The suffix that will be included in the user agent header.
         */
        userAgent?: pulumi.Input<string>;
        /**
         * The full user agent header, including UUID and suffix.
         */
        userAgentHeader?: pulumi.Input<string>;
    }
    /**
     * Limit settings for the web crawler.
     */
    interface DataSourceWebCrawlerLimitsArgs {
        /**
         * Maximum number of pages the crawler can crawl.
         */
        maxPages?: pulumi.Input<number>;
        /**
         * Rate of web URLs retrieved per minute.
         */
        rateLimit?: pulumi.Input<number>;
    }
    /**
     * Configures a web data source location.
     */
    interface DataSourceWebDataSourceConfigurationArgs {
        /**
         * The Web Crawler configuration details for the web data source.
         */
        crawlerConfiguration?: pulumi.Input<inputs.bedrock.DataSourceWebCrawlerConfigurationArgs>;
        /**
         * The source configuration details for the web data source.
         */
        sourceConfiguration: pulumi.Input<inputs.bedrock.DataSourceWebSourceConfigurationArgs>;
    }
    /**
     * A web source configuration.
     */
    interface DataSourceWebSourceConfigurationArgs {
        /**
         * The configuration of the URL/URLs.
         */
        urlConfiguration: pulumi.Input<inputs.bedrock.DataSourceUrlConfigurationArgs>;
    }
    /**
     * Agent flow node configuration
     */
    interface FlowAgentFlowNodeConfigurationArgs {
        /**
         * Arn representation of the Agent Alias.
         */
        agentAliasArn: pulumi.Input<string>;
    }
    /**
     * Details about the routing configuration for a Flow alias.
     */
    interface FlowAliasRoutingConfigurationListItemArgs {
        /**
         * Version.
         */
        flowVersion?: pulumi.Input<string>;
    }
    /**
     * Collector flow node configuration
     */
    interface FlowCollectorFlowNodeConfigurationArgs {
    }
    /**
     * Condition branch for a condition node
     */
    interface FlowConditionArgs {
        /**
         * Expression for a condition in a flow
         */
        expression?: pulumi.Input<string>;
        /**
         * Name of a condition in a flow
         */
        name: pulumi.Input<string>;
    }
    /**
     * Condition flow node configuration
     */
    interface FlowConditionFlowNodeConfigurationArgs {
        /**
         * List of conditions in a condition node
         */
        conditions: pulumi.Input<pulumi.Input<inputs.bedrock.FlowConditionArgs>[]>;
    }
    /**
     * Conditional connection configuration
     */
    interface FlowConditionalConnectionConfigurationArgs {
        /**
         * Name of a condition in a flow
         */
        condition: pulumi.Input<string>;
    }
    /**
     * Flow connection
     */
    interface FlowConnectionArgs {
        /**
         * The configuration of the connection.
         */
        configuration?: pulumi.Input<inputs.bedrock.FlowConnectionConfiguration0PropertiesArgs | inputs.bedrock.FlowConnectionConfiguration1PropertiesArgs>;
        /**
         * Name of a connection in a flow
         */
        name: pulumi.Input<string>;
        /**
         * Name of a node in a flow
         */
        source: pulumi.Input<string>;
        /**
         * Name of a node in a flow
         */
        target: pulumi.Input<string>;
        /**
         * Whether the source node that the connection begins from is a condition node ( `Conditional` ) or not ( `Data` ).
         */
        type: pulumi.Input<enums.bedrock.FlowConnectionType>;
    }
    /**
     * Connection configuration
     */
    interface FlowConnectionConfiguration0PropertiesArgs {
        data: pulumi.Input<inputs.bedrock.FlowDataConnectionConfigurationArgs>;
    }
    /**
     * Connection configuration
     */
    interface FlowConnectionConfiguration1PropertiesArgs {
        conditional: pulumi.Input<inputs.bedrock.FlowConditionalConnectionConfigurationArgs>;
    }
    /**
     * Data connection configuration
     */
    interface FlowDataConnectionConfigurationArgs {
        /**
         * Name of a node output in a flow
         */
        sourceOutput: pulumi.Input<string>;
        /**
         * Name of a node input in a flow
         */
        targetInput: pulumi.Input<string>;
    }
    /**
     * Flow definition
     */
    interface FlowDefinitionArgs {
        /**
         * List of connections
         */
        connections?: pulumi.Input<pulumi.Input<inputs.bedrock.FlowConnectionArgs>[]>;
        /**
         * List of nodes in a flow
         */
        nodes?: pulumi.Input<pulumi.Input<inputs.bedrock.FlowNodeArgs>[]>;
    }
    /**
     * Configuration for a guardrail
     */
    interface FlowGuardrailConfigurationArgs {
        /**
         * Identifier for the guardrail, could be the id or the arn
         */
        guardrailIdentifier?: pulumi.Input<string>;
        /**
         * Version of the guardrail
         */
        guardrailVersion?: pulumi.Input<string>;
    }
    /**
     * Input flow node configuration
     */
    interface FlowInputFlowNodeConfigurationArgs {
    }
    /**
     * Iterator flow node configuration
     */
    interface FlowIteratorFlowNodeConfigurationArgs {
    }
    /**
     * Knowledge base flow node configuration
     */
    interface FlowKnowledgeBaseFlowNodeConfigurationArgs {
        guardrailConfiguration?: pulumi.Input<inputs.bedrock.FlowGuardrailConfigurationArgs>;
        /**
         * Identifier of the KnowledgeBase
         */
        knowledgeBaseId: pulumi.Input<string>;
        /**
         * ARN or Id of a Bedrock Foundational Model or Inference Profile, or the ARN of a imported model, or a provisioned throughput ARN for custom models.
         */
        modelId?: pulumi.Input<string>;
    }
    /**
     * Lambda function flow node configuration
     */
    interface FlowLambdaFunctionFlowNodeConfigurationArgs {
        /**
         * ARN of a Lambda.
         */
        lambdaArn: pulumi.Input<string>;
    }
    /**
     * Lex flow node configuration
     */
    interface FlowLexFlowNodeConfigurationArgs {
        /**
         * ARN of a Lex bot alias
         */
        botAliasArn: pulumi.Input<string>;
        /**
         * Lex bot locale id
         */
        localeId: pulumi.Input<string>;
    }
    /**
     * Internal mixin for flow node
     */
    interface FlowNodeArgs {
        /**
         * Contains configurations for the node.
         */
        configuration?: pulumi.Input<inputs.bedrock.FlowNodeConfiguration0PropertiesArgs | inputs.bedrock.FlowNodeConfiguration1PropertiesArgs | inputs.bedrock.FlowNodeConfiguration2PropertiesArgs | inputs.bedrock.FlowNodeConfiguration3PropertiesArgs | inputs.bedrock.FlowNodeConfiguration4PropertiesArgs | inputs.bedrock.FlowNodeConfiguration5PropertiesArgs | inputs.bedrock.FlowNodeConfiguration6PropertiesArgs | inputs.bedrock.FlowNodeConfiguration7PropertiesArgs | inputs.bedrock.FlowNodeConfiguration8PropertiesArgs | inputs.bedrock.FlowNodeConfiguration9PropertiesArgs | inputs.bedrock.FlowNodeConfiguration10PropertiesArgs | inputs.bedrock.FlowNodeConfiguration11PropertiesArgs>;
        /**
         * List of node inputs in a flow
         */
        inputs?: pulumi.Input<pulumi.Input<inputs.bedrock.FlowNodeInputArgs>[]>;
        /**
         * Name of a node in a flow
         */
        name: pulumi.Input<string>;
        /**
         * List of node outputs in a flow
         */
        outputs?: pulumi.Input<pulumi.Input<inputs.bedrock.FlowNodeOutputArgs>[]>;
        /**
         * The type of node. This value must match the name of the key that you provide in the configuration you provide in the `FlowNodeConfiguration` field.
         */
        type: pulumi.Input<enums.bedrock.FlowNodeType>;
    }
    /**
     * Node configuration in a flow
     */
    interface FlowNodeConfiguration0PropertiesArgs {
        input: pulumi.Input<inputs.bedrock.FlowInputFlowNodeConfigurationArgs>;
    }
    /**
     * Node configuration in a flow
     */
    interface FlowNodeConfiguration10PropertiesArgs {
        collector: pulumi.Input<inputs.bedrock.FlowCollectorFlowNodeConfigurationArgs>;
    }
    /**
     * Node configuration in a flow
     */
    interface FlowNodeConfiguration11PropertiesArgs {
        retrieval: pulumi.Input<inputs.bedrock.FlowRetrievalFlowNodeConfigurationArgs>;
    }
    /**
     * Node configuration in a flow
     */
    interface FlowNodeConfiguration1PropertiesArgs {
        output: pulumi.Input<inputs.bedrock.FlowOutputFlowNodeConfigurationArgs>;
    }
    /**
     * Node configuration in a flow
     */
    interface FlowNodeConfiguration2PropertiesArgs {
        knowledgeBase: pulumi.Input<inputs.bedrock.FlowKnowledgeBaseFlowNodeConfigurationArgs>;
    }
    /**
     * Node configuration in a flow
     */
    interface FlowNodeConfiguration3PropertiesArgs {
        condition: pulumi.Input<inputs.bedrock.FlowConditionFlowNodeConfigurationArgs>;
    }
    /**
     * Node configuration in a flow
     */
    interface FlowNodeConfiguration4PropertiesArgs {
        lex: pulumi.Input<inputs.bedrock.FlowLexFlowNodeConfigurationArgs>;
    }
    /**
     * Node configuration in a flow
     */
    interface FlowNodeConfiguration5PropertiesArgs {
        prompt: pulumi.Input<inputs.bedrock.FlowPromptFlowNodeConfigurationArgs>;
    }
    /**
     * Node configuration in a flow
     */
    interface FlowNodeConfiguration6PropertiesArgs {
        lambdaFunction: pulumi.Input<inputs.bedrock.FlowLambdaFunctionFlowNodeConfigurationArgs>;
    }
    /**
     * Node configuration in a flow
     */
    interface FlowNodeConfiguration7PropertiesArgs {
        agent: pulumi.Input<inputs.bedrock.FlowAgentFlowNodeConfigurationArgs>;
    }
    /**
     * Node configuration in a flow
     */
    interface FlowNodeConfiguration8PropertiesArgs {
        storage: pulumi.Input<inputs.bedrock.FlowStorageFlowNodeConfigurationArgs>;
    }
    /**
     * Node configuration in a flow
     */
    interface FlowNodeConfiguration9PropertiesArgs {
        iterator: pulumi.Input<inputs.bedrock.FlowIteratorFlowNodeConfigurationArgs>;
    }
    /**
     * Input to a node in a flow
     */
    interface FlowNodeInputArgs {
        /**
         * Expression for a node input in a flow
         */
        expression: pulumi.Input<string>;
        /**
         * Name of a node input in a flow
         */
        name: pulumi.Input<string>;
        /**
         * The data type of the input. If the input doesn't match this type at runtime, a validation error will be thrown.
         */
        type: pulumi.Input<enums.bedrock.FlowNodeIoDataType>;
    }
    /**
     * Output of a node in a flow
     */
    interface FlowNodeOutputArgs {
        /**
         * Name of a node output in a flow
         */
        name: pulumi.Input<string>;
        /**
         * The data type of the output. If the output doesn't match this type at runtime, a validation error will be thrown.
         */
        type: pulumi.Input<enums.bedrock.FlowNodeIoDataType>;
    }
    /**
     * Output flow node configuration
     */
    interface FlowOutputFlowNodeConfigurationArgs {
    }
    /**
     * Prompt flow node configuration
     */
    interface FlowPromptFlowNodeConfigurationArgs {
        guardrailConfiguration?: pulumi.Input<inputs.bedrock.FlowGuardrailConfigurationArgs>;
        sourceConfiguration: pulumi.Input<inputs.bedrock.FlowPromptFlowNodeSourceConfiguration0PropertiesArgs | inputs.bedrock.FlowPromptFlowNodeSourceConfiguration1PropertiesArgs>;
    }
    /**
     * Inline prompt configuration for prompt node
     */
    interface FlowPromptFlowNodeInlineConfigurationArgs {
        inferenceConfiguration?: pulumi.Input<inputs.bedrock.FlowPromptInferenceConfigurationPropertiesArgs>;
        /**
         * ARN or Id of a Bedrock Foundational Model or Inference Profile, or the ARN of a imported model, or a provisioned throughput ARN for custom models.
         */
        modelId: pulumi.Input<string>;
        templateConfiguration: pulumi.Input<inputs.bedrock.FlowPromptTemplateConfigurationPropertiesArgs>;
        templateType: pulumi.Input<enums.bedrock.FlowPromptTemplateType>;
    }
    /**
     * Resource prompt configuration for prompt node
     */
    interface FlowPromptFlowNodeResourceConfigurationArgs {
        /**
         * ARN of a prompt resource possibly with a version
         */
        promptArn: pulumi.Input<string>;
    }
    /**
     * Prompt source configuration for prompt node
     */
    interface FlowPromptFlowNodeSourceConfiguration0PropertiesArgs {
        resource: pulumi.Input<inputs.bedrock.FlowPromptFlowNodeResourceConfigurationArgs>;
    }
    /**
     * Prompt source configuration for prompt node
     */
    interface FlowPromptFlowNodeSourceConfiguration1PropertiesArgs {
        inline: pulumi.Input<inputs.bedrock.FlowPromptFlowNodeInlineConfigurationArgs>;
    }
    /**
     * Model inference configuration
     */
    interface FlowPromptInferenceConfigurationPropertiesArgs {
        text: pulumi.Input<inputs.bedrock.FlowPromptModelInferenceConfigurationArgs>;
    }
    /**
     * Input variable
     */
    interface FlowPromptInputVariableArgs {
        /**
         * Name for an input variable
         */
        name?: pulumi.Input<string>;
    }
    /**
     * Prompt model inference configuration
     */
    interface FlowPromptModelInferenceConfigurationArgs {
        /**
         * Maximum length of output
         */
        maxTokens?: pulumi.Input<number>;
        /**
         * List of stop sequences
         */
        stopSequences?: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * Controls randomness, higher values increase diversity
         */
        temperature?: pulumi.Input<number>;
        /**
         * Cumulative probability cutoff for token selection
         */
        topP?: pulumi.Input<number>;
    }
    /**
     * Prompt template configuration
     */
    interface FlowPromptTemplateConfigurationPropertiesArgs {
        text: pulumi.Input<inputs.bedrock.FlowTextPromptTemplateConfigurationArgs>;
    }
    /**
     * Retrieval flow node configuration
     */
    interface FlowRetrievalFlowNodeConfigurationArgs {
        serviceConfiguration: pulumi.Input<inputs.bedrock.FlowRetrievalFlowNodeServiceConfigurationPropertiesArgs>;
    }
    /**
     * s3 Retrieval configuration for Retrieval node
     */
    interface FlowRetrievalFlowNodeS3ConfigurationArgs {
        /**
         * bucket name of an s3 that will be used for Retrieval flow node configuration
         */
        bucketName: pulumi.Input<string>;
    }
    /**
     * Retrieval service configuration for Retrieval node
     */
    interface FlowRetrievalFlowNodeServiceConfigurationPropertiesArgs {
        s3?: pulumi.Input<inputs.bedrock.FlowRetrievalFlowNodeS3ConfigurationArgs>;
    }
    /**
     * A bucket, key and optional version pointing to an S3 object containing a UTF-8 encoded JSON string Definition with the same schema as the Definition property of this resource
     */
    interface FlowS3LocationArgs {
        /**
         * A bucket in S3
         */
        bucket: pulumi.Input<string>;
        /**
         * A object key in S3
         */
        key: pulumi.Input<string>;
        /**
         * The version of the the S3 object to use
         */
        version?: pulumi.Input<string>;
    }
    /**
     * Storage flow node configuration
     */
    interface FlowStorageFlowNodeConfigurationArgs {
        serviceConfiguration: pulumi.Input<inputs.bedrock.FlowStorageFlowNodeServiceConfigurationPropertiesArgs>;
    }
    /**
     * s3 storage configuration for storage node
     */
    interface FlowStorageFlowNodeS3ConfigurationArgs {
        /**
         * bucket name of an s3 that will be used for storage flow node configuration
         */
        bucketName: pulumi.Input<string>;
    }
    /**
     * storage service configuration for storage node
     */
    interface FlowStorageFlowNodeServiceConfigurationPropertiesArgs {
        s3?: pulumi.Input<inputs.bedrock.FlowStorageFlowNodeS3ConfigurationArgs>;
    }
    /**
     * Configuration for text prompt template
     */
    interface FlowTextPromptTemplateConfigurationArgs {
        /**
         * List of input variables
         */
        inputVariables?: pulumi.Input<pulumi.Input<inputs.bedrock.FlowPromptInputVariableArgs>[]>;
        /**
         * Prompt content for String prompt template
         */
        text: pulumi.Input<string>;
    }
    /**
     * Content filter config in content policy.
     */
    interface GuardrailContentFilterConfigArgs {
        inputAction?: pulumi.Input<enums.bedrock.GuardrailContentFilterAction>;
        inputEnabled?: pulumi.Input<boolean>;
        /**
         * List of modalities
         */
        inputModalities?: pulumi.Input<pulumi.Input<enums.bedrock.GuardrailModality>[]>;
        /**
         * The strength of the content filter to apply to prompts. As you increase the filter strength, the likelihood of filtering harmful content increases and the probability of seeing harmful content in your application reduces.
         */
        inputStrength: pulumi.Input<enums.bedrock.GuardrailFilterStrength>;
        outputAction?: pulumi.Input<enums.bedrock.GuardrailContentFilterAction>;
        outputEnabled?: pulumi.Input<boolean>;
        /**
         * List of modalities
         */
        outputModalities?: pulumi.Input<pulumi.Input<enums.bedrock.GuardrailModality>[]>;
        /**
         * The strength of the content filter to apply to model responses. As you increase the filter strength, the likelihood of filtering harmful content increases and the probability of seeing harmful content in your application reduces.
         */
        outputStrength: pulumi.Input<enums.bedrock.GuardrailFilterStrength>;
        /**
         * The harmful category that the content filter is applied to.
         */
        type: pulumi.Input<enums.bedrock.GuardrailContentFilterType>;
    }
    /**
     * Content policy config for a guardrail.
     */
    interface GuardrailContentPolicyConfigArgs {
        /**
         * List of content filter configs in content policy.
         */
        filtersConfig: pulumi.Input<pulumi.Input<inputs.bedrock.GuardrailContentFilterConfigArgs>[]>;
    }
    /**
     * A config for grounding filter.
     */
    interface GuardrailContextualGroundingFilterConfigArgs {
        action?: pulumi.Input<enums.bedrock.GuardrailContextualGroundingAction>;
        enabled?: pulumi.Input<boolean>;
        /**
         * The threshold for this filter.
         */
        threshold: pulumi.Input<number>;
        /**
         * The filter details for the guardrails contextual grounding filter.
         */
        type: pulumi.Input<enums.bedrock.GuardrailContextualGroundingFilterType>;
    }
    /**
     * Contextual grounding policy config for a guardrail.
     */
    interface GuardrailContextualGroundingPolicyConfigArgs {
        /**
         * List of contextual grounding filter configs.
         */
        filtersConfig: pulumi.Input<pulumi.Input<inputs.bedrock.GuardrailContextualGroundingFilterConfigArgs>[]>;
    }
    /**
     * A managed words config.
     */
    interface GuardrailManagedWordsConfigArgs {
        inputAction?: pulumi.Input<enums.bedrock.GuardrailWordAction>;
        inputEnabled?: pulumi.Input<boolean>;
        outputAction?: pulumi.Input<enums.bedrock.GuardrailWordAction>;
        outputEnabled?: pulumi.Input<boolean>;
        /**
         * The managed word type to configure for the guardrail.
         */
        type: pulumi.Input<enums.bedrock.GuardrailManagedWordsType>;
    }
    /**
     * Pii entity configuration.
     */
    interface GuardrailPiiEntityConfigArgs {
        /**
         * Configure guardrail action when the PII entity is detected.
         */
        action: pulumi.Input<enums.bedrock.GuardrailSensitiveInformationAction>;
        inputAction?: pulumi.Input<enums.bedrock.GuardrailSensitiveInformationAction>;
        inputEnabled?: pulumi.Input<boolean>;
        outputAction?: pulumi.Input<enums.bedrock.GuardrailSensitiveInformationAction>;
        outputEnabled?: pulumi.Input<boolean>;
        /**
         * Configure guardrail type when the PII entity is detected.
         *
         * The following PIIs are used to block or mask sensitive information:
         *
         * - *General*
         *
         * - *ADDRESS*
         *
         * A physical address, such as "100 Main Street, Anytown, USA" or "Suite #12, Building 123". An address can include information such as the street, building, location, city, state, country, county, zip code, precinct, and neighborhood.
         * - *AGE*
         *
         * An individual's age, including the quantity and unit of time. For example, in the phrase "I am 40 years old," Guardrails recognizes "40 years" as an age.
         * - *NAME*
         *
         * An individual's name. This entity type does not include titles, such as Dr., Mr., Mrs., or Miss. guardrails doesn't apply this entity type to names that are part of organizations or addresses. For example, guardrails recognizes the "John Doe Organization" as an organization, and it recognizes "Jane Doe Street" as an address.
         * - *EMAIL*
         *
         * An email address, such as *marymajor@email.com* .
         * - *PHONE*
         *
         * A phone number. This entity type also includes fax and pager numbers.
         * - *USERNAME*
         *
         * A user name that identifies an account, such as a login name, screen name, nick name, or handle.
         * - *PASSWORD*
         *
         * An alphanumeric string that is used as a password, such as "* *very20special#pass** ".
         * - *DRIVER_ID*
         *
         * The number assigned to a driver's license, which is an official document permitting an individual to operate one or more motorized vehicles on a public road. A driver's license number consists of alphanumeric characters.
         * - *LICENSE_PLATE*
         *
         * A license plate for a vehicle is issued by the state or country where the vehicle is registered. The format for passenger vehicles is typically five to eight digits, consisting of upper-case letters and numbers. The format varies depending on the location of the issuing state or country.
         * - *VEHICLE_IDENTIFICATION_NUMBER*
         *
         * A Vehicle Identification Number (VIN) uniquely identifies a vehicle. VIN content and format are defined in the *ISO 3779* specification. Each country has specific codes and formats for VINs.
         * - *Finance*
         *
         * - *CREDIT_DEBIT_CARD_CVV*
         *
         * A three-digit card verification code (CVV) that is present on VISA, MasterCard, and Discover credit and debit cards. For American Express credit or debit cards, the CVV is a four-digit numeric code.
         * - *CREDIT_DEBIT_CARD_EXPIRY*
         *
         * The expiration date for a credit or debit card. This number is usually four digits long and is often formatted as *month/year* or *MM/YY* . Guardrails recognizes expiration dates such as *01/21* , *01/2021* , and *Jan 2021* .
         * - *CREDIT_DEBIT_CARD_NUMBER*
         *
         * The number for a credit or debit card. These numbers can vary from 13 to 16 digits in length. However, Amazon Comprehend also recognizes credit or debit card numbers when only the last four digits are present.
         * - *PIN*
         *
         * A four-digit personal identification number (PIN) with which you can access your bank account.
         * - *INTERNATIONAL_BANK_ACCOUNT_NUMBER*
         *
         * An International Bank Account Number has specific formats in each country. For more information, see [www.iban.com/structure](https://docs.aws.amazon.com/https://www.iban.com/structure) .
         * - *SWIFT_CODE*
         *
         * A SWIFT code is a standard format of Bank Identifier Code (BIC) used to specify a particular bank or branch. Banks use these codes for money transfers such as international wire transfers.
         *
         * SWIFT codes consist of eight or 11 characters. The 11-digit codes refer to specific branches, while eight-digit codes (or 11-digit codes ending in 'XXX') refer to the head or primary office.
         * - *IT*
         *
         * - *IP_ADDRESS*
         *
         * An IPv4 address, such as *198.51.100.0* .
         * - *MAC_ADDRESS*
         *
         * A *media access control* (MAC) address is a unique identifier assigned to a network interface controller (NIC).
         * - *URL*
         *
         * A web address, such as *www.example.com* .
         * - *AWS_ACCESS_KEY*
         *
         * A unique identifier that's associated with a secret access key; you use the access key ID and secret access key to sign programmatic AWS requests cryptographically.
         * - *AWS_SECRET_KEY*
         *
         * A unique identifier that's associated with an access key. You use the access key ID and secret access key to sign programmatic AWS requests cryptographically.
         * - *USA specific*
         *
         * - *US_BANK_ACCOUNT_NUMBER*
         *
         * A US bank account number, which is typically 10 to 12 digits long.
         * - *US_BANK_ROUTING_NUMBER*
         *
         * A US bank account routing number. These are typically nine digits long,
         * - *US_INDIVIDUAL_TAX_IDENTIFICATION_NUMBER*
         *
         * A US Individual Taxpayer Identification Number (ITIN) is a nine-digit number that starts with a "9" and contain a "7" or "8" as the fourth digit. An ITIN can be formatted with a space or a dash after the third and forth digits.
         * - *US_PASSPORT_NUMBER*
         *
         * A US passport number. Passport numbers range from six to nine alphanumeric characters.
         * - *US_SOCIAL_SECURITY_NUMBER*
         *
         * A US Social Security Number (SSN) is a nine-digit number that is issued to US citizens, permanent residents, and temporary working residents.
         * - *Canada specific*
         *
         * - *CA_HEALTH_NUMBER*
         *
         * A Canadian Health Service Number is a 10-digit unique identifier, required for individuals to access healthcare benefits.
         * - *CA_SOCIAL_INSURANCE_NUMBER*
         *
         * A Canadian Social Insurance Number (SIN) is a nine-digit unique identifier, required for individuals to access government programs and benefits.
         *
         * The SIN is formatted as three groups of three digits, such as *123-456-789* . A SIN can be validated through a simple check-digit process called the [Luhn algorithm](https://docs.aws.amazon.com/https://www.wikipedia.org/wiki/Luhn_algorithm) .
         * - *UK Specific*
         *
         * - *UK_NATIONAL_HEALTH_SERVICE_NUMBER*
         *
         * A UK National Health Service Number is a 10-17 digit number, such as *485 777 3456* . The current system formats the 10-digit number with spaces after the third and sixth digits. The final digit is an error-detecting checksum.
         * - *UK_NATIONAL_INSURANCE_NUMBER*
         *
         * A UK National Insurance Number (NINO) provides individuals with access to National Insurance (social security) benefits. It is also used for some purposes in the UK tax system.
         *
         * The number is nine digits long and starts with two letters, followed by six numbers and one letter. A NINO can be formatted with a space or a dash after the two letters and after the second, forth, and sixth digits.
         * - *UK_UNIQUE_TAXPAYER_REFERENCE_NUMBER*
         *
         * A UK Unique Taxpayer Reference (UTR) is a 10-digit number that identifies a taxpayer or a business.
         * - *Custom*
         *
         * - *Regex filter* - You can use a regular expressions to define patterns for a guardrail to recognize and act upon such as serial number, booking ID etc..
         */
        type: pulumi.Input<enums.bedrock.GuardrailPiiEntityType>;
    }
    /**
     * A regex configuration.
     */
    interface GuardrailRegexConfigArgs {
        /**
         * The guardrail action to configure when matching regular expression is detected.
         */
        action: pulumi.Input<enums.bedrock.GuardrailSensitiveInformationAction>;
        /**
         * The regex description.
         */
        description?: pulumi.Input<string>;
        inputAction?: pulumi.Input<enums.bedrock.GuardrailSensitiveInformationAction>;
        inputEnabled?: pulumi.Input<boolean>;
        /**
         * The regex name.
         */
        name: pulumi.Input<string>;
        outputAction?: pulumi.Input<enums.bedrock.GuardrailSensitiveInformationAction>;
        outputEnabled?: pulumi.Input<boolean>;
        /**
         * The regex pattern.
         */
        pattern: pulumi.Input<string>;
    }
    /**
     * Sensitive information policy config for a guardrail.
     */
    interface GuardrailSensitiveInformationPolicyConfigArgs {
        /**
         * List of entities.
         */
        piiEntitiesConfig?: pulumi.Input<pulumi.Input<inputs.bedrock.GuardrailPiiEntityConfigArgs>[]>;
        /**
         * List of regex.
         */
        regexesConfig?: pulumi.Input<pulumi.Input<inputs.bedrock.GuardrailRegexConfigArgs>[]>;
    }
    /**
     * Topic config in topic policy.
     */
    interface GuardrailTopicConfigArgs {
        /**
         * Definition of topic in topic policy
         */
        definition: pulumi.Input<string>;
        /**
         * List of text examples
         */
        examples?: pulumi.Input<pulumi.Input<string>[]>;
        inputAction?: pulumi.Input<enums.bedrock.GuardrailTopicAction>;
        inputEnabled?: pulumi.Input<boolean>;
        /**
         * Name of topic in topic policy
         */
        name: pulumi.Input<string>;
        outputAction?: pulumi.Input<enums.bedrock.GuardrailTopicAction>;
        outputEnabled?: pulumi.Input<boolean>;
        /**
         * Specifies to deny the topic.
         */
        type: pulumi.Input<enums.bedrock.GuardrailTopicType>;
    }
    /**
     * Topic policy config for a guardrail.
     */
    interface GuardrailTopicPolicyConfigArgs {
        /**
         * List of topic configs in topic policy.
         */
        topicsConfig: pulumi.Input<pulumi.Input<inputs.bedrock.GuardrailTopicConfigArgs>[]>;
    }
    /**
     * A custom word config.
     */
    interface GuardrailWordConfigArgs {
        inputAction?: pulumi.Input<enums.bedrock.GuardrailWordAction>;
        inputEnabled?: pulumi.Input<boolean>;
        outputAction?: pulumi.Input<enums.bedrock.GuardrailWordAction>;
        outputEnabled?: pulumi.Input<boolean>;
        /**
         * The custom word text.
         */
        text: pulumi.Input<string>;
    }
    /**
     * Word policy config for a guardrail.
     */
    interface GuardrailWordPolicyConfigArgs {
        /**
         * A config for the list of managed words.
         */
        managedWordListsConfig?: pulumi.Input<pulumi.Input<inputs.bedrock.GuardrailManagedWordsConfigArgs>[]>;
        /**
         * List of custom word configs.
         */
        wordsConfig?: pulumi.Input<pulumi.Input<inputs.bedrock.GuardrailWordConfigArgs>[]>;
    }
    /**
     * The vector configuration details for the Bedrock embeddings model.
     */
    interface KnowledgeBaseBedrockEmbeddingModelConfigurationArgs {
        /**
         * The dimensions details for the vector configuration used on the Bedrock embeddings model.
         */
        dimensions?: pulumi.Input<number>;
        /**
         * The data type for the vectors when using a model to convert text into vector embeddings.
         */
        embeddingDataType?: pulumi.Input<enums.bedrock.KnowledgeBaseBedrockEmbeddingModelConfigurationEmbeddingDataType>;
    }
    /**
     * Contains details about the embeddings model used for the knowledge base.
     */
    interface KnowledgeBaseConfigurationArgs {
        /**
         * Settings for an Amazon Kendra knowledge base.
         */
        kendraKnowledgeBaseConfiguration?: pulumi.Input<inputs.bedrock.KnowledgeBaseKendraKnowledgeBaseConfigurationArgs>;
        /**
         * Specifies configurations for a knowledge base connected to an SQL database.
         */
        sqlKnowledgeBaseConfiguration?: pulumi.Input<inputs.bedrock.KnowledgeBaseSqlKnowledgeBaseConfigurationArgs>;
        /**
         * The type of data that the data source is converted into for the knowledge base.
         */
        type: pulumi.Input<enums.bedrock.KnowledgeBaseType>;
        /**
         * Contains details about the model that's used to convert the data source into vector embeddings.
         */
        vectorKnowledgeBaseConfiguration?: pulumi.Input<inputs.bedrock.KnowledgeBaseVectorKnowledgeBaseConfigurationArgs>;
    }
    /**
     * Curated query or question and answer pair
     */
    interface KnowledgeBaseCuratedQueryArgs {
        naturalLanguage: pulumi.Input<string>;
        sql: pulumi.Input<string>;
    }
    /**
     * The embeddings model configuration details for the vector model used in Knowledge Base.
     */
    interface KnowledgeBaseEmbeddingModelConfigurationArgs {
        /**
         * The vector configuration details on the Bedrock embeddings model.
         */
        bedrockEmbeddingModelConfiguration?: pulumi.Input<inputs.bedrock.KnowledgeBaseBedrockEmbeddingModelConfigurationArgs>;
    }
    /**
     * Configurations for a Kendra knowledge base
     */
    interface KnowledgeBaseKendraKnowledgeBaseConfigurationArgs {
        /**
         * The ARN of the Amazon Kendra index.
         */
        kendraIndexArn: pulumi.Input<string>;
    }
    /**
     * Contains the storage configuration of the knowledge base in MongoDb Atlas Cloud.
     */
    interface KnowledgeBaseMongoDbAtlasConfigurationArgs {
        /**
         * Name of the collection within MongoDB Atlas.
         */
        collectionName: pulumi.Input<string>;
        /**
         * The ARN of the secret that you created in AWS Secrets Manager that is linked to your Amazon Mongo database.
         */
        credentialsSecretArn: pulumi.Input<string>;
        /**
         * Name of the database within MongoDB Atlas.
         */
        databaseName: pulumi.Input<string>;
        /**
         * MongoDB Atlas endpoint.
         */
        endpoint: pulumi.Input<string>;
        /**
         * MongoDB Atlas endpoint service name.
         */
        endpointServiceName?: pulumi.Input<string>;
        /**
         * Contains the names of the fields to which to map information about the vector store.
         */
        fieldMapping: pulumi.Input<inputs.bedrock.KnowledgeBaseMongoDbAtlasFieldMappingArgs>;
        /**
         * Name of a MongoDB Atlas text index.
         */
        textIndexName?: pulumi.Input<string>;
        /**
         * Name of a MongoDB Atlas index.
         */
        vectorIndexName: pulumi.Input<string>;
    }
    /**
     * Contains the names of the fields to which to map information about the vector store.
     */
    interface KnowledgeBaseMongoDbAtlasFieldMappingArgs {
        /**
         * The name of the field in which Amazon Bedrock stores metadata about the vector store.
         */
        metadataField: pulumi.Input<string>;
        /**
         * The name of the field in which Amazon Bedrock stores the raw text from your data. The text is split according to the chunking strategy you choose.
         */
        textField: pulumi.Input<string>;
        /**
         * The name of the field in which Amazon Bedrock stores the vector embeddings for your data sources.
         */
        vectorField: pulumi.Input<string>;
    }
    /**
     * Contains the configurations to use Neptune Analytics as Vector Store.
     */
    interface KnowledgeBaseNeptuneAnalyticsConfigurationArgs {
        /**
         * Contains the names of the fields to which to map information about the vector store.
         */
        fieldMapping: pulumi.Input<inputs.bedrock.KnowledgeBaseNeptuneAnalyticsFieldMappingArgs>;
        /**
         * ARN for Neptune Analytics graph database.
         */
        graphArn: pulumi.Input<string>;
    }
    /**
     * A mapping of Bedrock Knowledge Base fields to Neptune Analytics fields.
     */
    interface KnowledgeBaseNeptuneAnalyticsFieldMappingArgs {
        /**
         * The name of the field in which Amazon Bedrock stores metadata about the vector store.
         */
        metadataField: pulumi.Input<string>;
        /**
         * The name of the field in which Amazon Bedrock stores the raw text from your data. The text is split according to the chunking strategy you choose.
         */
        textField: pulumi.Input<string>;
    }
    /**
     * Contains the storage configuration of the knowledge base in Amazon OpenSearch Service.
     */
    interface KnowledgeBaseOpenSearchManagedClusterConfigurationArgs {
        /**
         * The Amazon Resource Name (ARN) of the OpenSearch domain.
         */
        domainArn: pulumi.Input<string>;
        /**
         * The endpoint URL the OpenSearch domain.
         */
        domainEndpoint: pulumi.Input<string>;
        /**
         * Contains the names of the fields to which to map information about the vector store.
         */
        fieldMapping: pulumi.Input<inputs.bedrock.KnowledgeBaseOpenSearchManagedClusterFieldMappingArgs>;
        /**
         * The name of the vector store.
         */
        vectorIndexName: pulumi.Input<string>;
    }
    /**
     * A mapping of Bedrock Knowledge Base fields to OpenSearch Managed Cluster field names
     */
    interface KnowledgeBaseOpenSearchManagedClusterFieldMappingArgs {
        /**
         * The name of the field in which Amazon Bedrock stores metadata about the vector store.
         */
        metadataField: pulumi.Input<string>;
        /**
         * The name of the field in which Amazon Bedrock stores the raw text from your data. The text is split according to the chunking strategy you choose.
         */
        textField: pulumi.Input<string>;
        /**
         * The name of the field in which Amazon Bedrock stores the vector embeddings for your data sources.
         */
        vectorField: pulumi.Input<string>;
    }
    /**
     * Contains the storage configuration of the knowledge base in Amazon OpenSearch Service.
     */
    interface KnowledgeBaseOpenSearchServerlessConfigurationArgs {
        /**
         * The ARN of the OpenSearch Service vector store.
         */
        collectionArn: pulumi.Input<string>;
        /**
         * Contains the names of the fields to which to map information about the vector store.
         */
        fieldMapping: pulumi.Input<inputs.bedrock.KnowledgeBaseOpenSearchServerlessFieldMappingArgs>;
        /**
         * The name of the vector store.
         */
        vectorIndexName: pulumi.Input<string>;
    }
    /**
     * A mapping of Bedrock Knowledge Base fields to OpenSearch Serverless field names
     */
    interface KnowledgeBaseOpenSearchServerlessFieldMappingArgs {
        /**
         * The name of the field in which Amazon Bedrock stores metadata about the vector store.
         */
        metadataField: pulumi.Input<string>;
        /**
         * The name of the field in which Amazon Bedrock stores the raw text from your data. The text is split according to the chunking strategy you choose.
         */
        textField: pulumi.Input<string>;
        /**
         * The name of the field in which Amazon Bedrock stores the vector embeddings for your data sources.
         */
        vectorField: pulumi.Input<string>;
    }
    /**
     * Contains the storage configuration of the knowledge base in Pinecone.
     */
    interface KnowledgeBasePineconeConfigurationArgs {
        /**
         * The endpoint URL for your index management page.
         */
        connectionString: pulumi.Input<string>;
        /**
         * The ARN of the secret that you created in AWS Secrets Manager that is linked to your Pinecone API key.
         */
        credentialsSecretArn: pulumi.Input<string>;
        /**
         * Contains the names of the fields to which to map information about the vector store.
         */
        fieldMapping: pulumi.Input<inputs.bedrock.KnowledgeBasePineconeFieldMappingArgs>;
        /**
         * The namespace to be used to write new data to your database.
         */
        namespace?: pulumi.Input<string>;
    }
    /**
     * Contains the names of the fields to which to map information about the vector store.
     */
    interface KnowledgeBasePineconeFieldMappingArgs {
        /**
         * The name of the field in which Amazon Bedrock stores metadata about the vector store.
         */
        metadataField: pulumi.Input<string>;
        /**
         * The name of the field in which Amazon Bedrock stores the raw text from your data. The text is split according to the chunking strategy you choose.
         */
        textField: pulumi.Input<string>;
    }
    /**
     * Redshift query generation column
     */
    interface KnowledgeBaseQueryGenerationColumnArgs {
        description?: pulumi.Input<string>;
        inclusion?: pulumi.Input<enums.bedrock.KnowledgeBaseInclusionType>;
        name?: pulumi.Input<string>;
    }
    /**
     * Configurations for generating Redshift engine queries
     */
    interface KnowledgeBaseQueryGenerationConfigurationArgs {
        /**
         * The time after which query generation will time out.
         */
        executionTimeoutSeconds?: pulumi.Input<number>;
        /**
         * Specifies configurations for context to use during query generation.
         */
        generationContext?: pulumi.Input<inputs.bedrock.KnowledgeBaseQueryGenerationContextArgs>;
    }
    /**
     * Context used to improve query generation
     */
    interface KnowledgeBaseQueryGenerationContextArgs {
        /**
         * An array of objects, each of which defines information about example queries to help the query engine generate appropriate SQL queries.
         */
        curatedQueries?: pulumi.Input<pulumi.Input<inputs.bedrock.KnowledgeBaseCuratedQueryArgs>[]>;
        /**
         * An array of objects, each of which defines information about a table in the database.
         */
        tables?: pulumi.Input<pulumi.Input<inputs.bedrock.KnowledgeBaseQueryGenerationTableArgs>[]>;
    }
    /**
     * Tables used for Redshift query generation context
     */
    interface KnowledgeBaseQueryGenerationTableArgs {
        columns?: pulumi.Input<pulumi.Input<inputs.bedrock.KnowledgeBaseQueryGenerationColumnArgs>[]>;
        description?: pulumi.Input<string>;
        inclusion?: pulumi.Input<enums.bedrock.KnowledgeBaseInclusionType>;
        name: pulumi.Input<string>;
    }
    /**
     * Contains details about the storage configuration of the knowledge base in Amazon RDS. For more information, see Create a vector index in Amazon RDS.
     */
    interface KnowledgeBaseRdsConfigurationArgs {
        /**
         * The ARN of the secret that you created in AWS Secrets Manager that is linked to your Amazon RDS database.
         */
        credentialsSecretArn: pulumi.Input<string>;
        /**
         * The name of your Amazon RDS database.
         */
        databaseName: pulumi.Input<string>;
        /**
         * Contains the names of the fields to which to map information about the vector store.
         */
        fieldMapping: pulumi.Input<inputs.bedrock.KnowledgeBaseRdsFieldMappingArgs>;
        /**
         * The ARN of the vector store.
         */
        resourceArn: pulumi.Input<string>;
        /**
         * The name of the table in the database.
         */
        tableName: pulumi.Input<string>;
    }
    /**
     * Contains the names of the fields to which to map information about the vector store.
     */
    interface KnowledgeBaseRdsFieldMappingArgs {
        /**
         * The name of the field in which Amazon Bedrock stores custom metadata about the vector store.
         */
        customMetadataField?: pulumi.Input<string>;
        /**
         * The name of the field in which Amazon Bedrock stores metadata about the vector store.
         */
        metadataField: pulumi.Input<string>;
        /**
         * The name of the field in which Amazon Bedrock stores the ID for each entry.
         */
        primaryKeyField: pulumi.Input<string>;
        /**
         * The name of the field in which Amazon Bedrock stores the raw text from your data. The text is split according to the chunking strategy you choose.
         */
        textField: pulumi.Input<string>;
        /**
         * The name of the field in which Amazon Bedrock stores the vector embeddings for your data sources.
         */
        vectorField: pulumi.Input<string>;
    }
    /**
     * Configurations for a Redshift knowledge base
     */
    interface KnowledgeBaseRedshiftConfigurationArgs {
        /**
         * Specifies configurations for an Amazon Redshift query engine.
         */
        queryEngineConfiguration: pulumi.Input<inputs.bedrock.KnowledgeBaseRedshiftQueryEngineConfigurationArgs>;
        /**
         * Specifies configurations for generating queries.
         */
        queryGenerationConfiguration?: pulumi.Input<inputs.bedrock.KnowledgeBaseQueryGenerationConfigurationArgs>;
        /**
         * Specifies configurations for Amazon Redshift database storage.
         */
        storageConfigurations: pulumi.Input<pulumi.Input<inputs.bedrock.KnowledgeBaseRedshiftQueryEngineStorageConfigurationArgs>[]>;
    }
    /**
     * Configurations for Redshift query engine provisioned auth setup
     */
    interface KnowledgeBaseRedshiftProvisionedAuthConfigurationArgs {
        /**
         * Redshift database user
         */
        databaseUser?: pulumi.Input<string>;
        /**
         * The type of authentication to use.
         */
        type: pulumi.Input<enums.bedrock.KnowledgeBaseRedshiftProvisionedAuthType>;
        /**
         * The ARN of an Secrets Manager secret for authentication.
         */
        usernamePasswordSecretArn?: pulumi.Input<string>;
    }
    /**
     * Configurations for provisioned Redshift query engine
     */
    interface KnowledgeBaseRedshiftProvisionedConfigurationArgs {
        /**
         * Specifies configurations for authentication to Amazon Redshift.
         */
        authConfiguration: pulumi.Input<inputs.bedrock.KnowledgeBaseRedshiftProvisionedAuthConfigurationArgs>;
        /**
         * The ID of the Amazon Redshift cluster.
         */
        clusterIdentifier: pulumi.Input<string>;
    }
    /**
     * Configurations for Redshift query engine AWS Data Catalog backed storage
     */
    interface KnowledgeBaseRedshiftQueryEngineAwsDataCatalogStorageConfigurationArgs {
        tableNames: pulumi.Input<pulumi.Input<string>[]>;
    }
    /**
     * Configurations for Redshift query engine
     */
    interface KnowledgeBaseRedshiftQueryEngineConfigurationArgs {
        /**
         * Specifies configurations for a provisioned Amazon Redshift query engine.
         */
        provisionedConfiguration?: pulumi.Input<inputs.bedrock.KnowledgeBaseRedshiftProvisionedConfigurationArgs>;
        /**
         * Specifies configurations for a serverless Amazon Redshift query engine.
         */
        serverlessConfiguration?: pulumi.Input<inputs.bedrock.KnowledgeBaseRedshiftServerlessConfigurationArgs>;
        /**
         * The type of query engine.
         */
        type: pulumi.Input<enums.bedrock.KnowledgeBaseRedshiftQueryEngineType>;
    }
    /**
     * Configurations for Redshift query engine Redshift backed storage
     */
    interface KnowledgeBaseRedshiftQueryEngineRedshiftStorageConfigurationArgs {
        databaseName: pulumi.Input<string>;
    }
    /**
     * Configurations for available Redshift query engine storage types
     */
    interface KnowledgeBaseRedshiftQueryEngineStorageConfigurationArgs {
        awsDataCatalogConfiguration?: pulumi.Input<inputs.bedrock.KnowledgeBaseRedshiftQueryEngineAwsDataCatalogStorageConfigurationArgs>;
        redshiftConfiguration?: pulumi.Input<inputs.bedrock.KnowledgeBaseRedshiftQueryEngineRedshiftStorageConfigurationArgs>;
        type: pulumi.Input<enums.bedrock.KnowledgeBaseRedshiftQueryEngineStorageType>;
    }
    /**
     * Configurations for Redshift query engine serverless auth setup
     */
    interface KnowledgeBaseRedshiftServerlessAuthConfigurationArgs {
        /**
         * The type of authentication to use.
         */
        type: pulumi.Input<enums.bedrock.KnowledgeBaseRedshiftServerlessAuthType>;
        /**
         * The ARN of an Secrets Manager secret for authentication.
         */
        usernamePasswordSecretArn?: pulumi.Input<string>;
    }
    /**
     * Configurations for serverless Redshift query engine
     */
    interface KnowledgeBaseRedshiftServerlessConfigurationArgs {
        /**
         * Specifies configurations for authentication to an Amazon Redshift provisioned data warehouse.
         */
        authConfiguration: pulumi.Input<inputs.bedrock.KnowledgeBaseRedshiftServerlessAuthConfigurationArgs>;
        /**
         * The ARN of the Amazon Redshift workgroup.
         */
        workgroupArn: pulumi.Input<string>;
    }
    /**
     * An Amazon S3 location.
     */
    interface KnowledgeBaseS3LocationArgs {
        /**
         * The location's URI
         */
        uri: pulumi.Input<string>;
    }
    /**
     * Configurations for a SQL knowledge base
     */
    interface KnowledgeBaseSqlKnowledgeBaseConfigurationArgs {
        /**
         * Specifies configurations for a knowledge base connected to an Amazon Redshift database.
         */
        redshiftConfiguration?: pulumi.Input<inputs.bedrock.KnowledgeBaseRedshiftConfigurationArgs>;
        /**
         * The type of SQL database to connect to the knowledge base.
         */
        type: pulumi.Input<enums.bedrock.KnowledgeBaseQueryEngineType>;
    }
    /**
     * The vector store service in which the knowledge base is stored.
     */
    interface KnowledgeBaseStorageConfigurationArgs {
        /**
         * Contains the storage configuration of the knowledge base in MongoDB Atlas.
         */
        mongoDbAtlasConfiguration?: pulumi.Input<inputs.bedrock.KnowledgeBaseMongoDbAtlasConfigurationArgs>;
        /**
         * Contains details about the Neptune Analytics configuration of the knowledge base in Amazon Neptune. For more information, see [Create a vector index in Amazon Neptune Analytics.](https://docs.aws.amazon.com/bedrock/latest/userguide/knowledge-base-setup-neptune.html) .
         */
        neptuneAnalyticsConfiguration?: pulumi.Input<inputs.bedrock.KnowledgeBaseNeptuneAnalyticsConfigurationArgs>;
        /**
         * Contains details about the storage configuration of the knowledge base in OpenSearch Managed Cluster. For more information, see [Create a vector index in Amazon OpenSearch Service](https://docs.aws.amazon.com/bedrock/latest/userguide/knowledge-base-setup-osm.html) .
         */
        opensearchManagedClusterConfiguration?: pulumi.Input<inputs.bedrock.KnowledgeBaseOpenSearchManagedClusterConfigurationArgs>;
        /**
         * Contains the storage configuration of the knowledge base in Amazon OpenSearch Service.
         */
        opensearchServerlessConfiguration?: pulumi.Input<inputs.bedrock.KnowledgeBaseOpenSearchServerlessConfigurationArgs>;
        /**
         * Contains the storage configuration of the knowledge base in Pinecone.
         */
        pineconeConfiguration?: pulumi.Input<inputs.bedrock.KnowledgeBasePineconeConfigurationArgs>;
        /**
         * Contains details about the storage configuration of the knowledge base in Amazon RDS. For more information, see [Create a vector index in Amazon RDS](https://docs.aws.amazon.com/bedrock/latest/userguide/knowledge-base-setup-rds.html) .
         */
        rdsConfiguration?: pulumi.Input<inputs.bedrock.KnowledgeBaseRdsConfigurationArgs>;
        /**
         * The vector store service in which the knowledge base is stored.
         */
        type: pulumi.Input<enums.bedrock.KnowledgeBaseStorageType>;
    }
    /**
     * Configurations for supplemental data storage.
     */
    interface KnowledgeBaseSupplementalDataStorageConfigurationArgs {
        supplementalDataStorageLocations: pulumi.Input<pulumi.Input<inputs.bedrock.KnowledgeBaseSupplementalDataStorageLocationArgs>[]>;
    }
    /**
     * Supplemental data storage location.
     */
    interface KnowledgeBaseSupplementalDataStorageLocationArgs {
        s3Location?: pulumi.Input<inputs.bedrock.KnowledgeBaseS3LocationArgs>;
        supplementalDataStorageLocationType: pulumi.Input<enums.bedrock.KnowledgeBaseSupplementalDataStorageLocationType>;
    }
    /**
     * Contains details about the model used to create vector embeddings for the knowledge base.
     */
    interface KnowledgeBaseVectorKnowledgeBaseConfigurationArgs {
        /**
         * The ARN of the model used to create vector embeddings for the knowledge base.
         */
        embeddingModelArn: pulumi.Input<string>;
        /**
         * The embeddings model configuration details for the vector model used in Knowledge Base.
         */
        embeddingModelConfiguration?: pulumi.Input<inputs.bedrock.KnowledgeBaseEmbeddingModelConfigurationArgs>;
        /**
         * If you include multimodal data from your data source, use this object to specify configurations for the storage location of the images extracted from your documents. These images can be retrieved and returned to the end user. They can also be used in generation when using [RetrieveAndGenerate](https://docs.aws.amazon.com/bedrock/latest/APIReference/API_agent-runtime_RetrieveAndGenerate.html) .
         */
        supplementalDataStorageConfiguration?: pulumi.Input<inputs.bedrock.KnowledgeBaseSupplementalDataStorageConfigurationArgs>;
    }
    /**
     * Contains model-specific configurations
     */
    interface PromptAdditionalModelRequestFieldsArgs {
    }
    /**
     * Target Agent to invoke with Prompt
     */
    interface PromptAgentResourceArgs {
        /**
         * Arn representation of the Agent Alias.
         */
        agentIdentifier: pulumi.Input<string>;
    }
    /**
     * Any Tool choice
     */
    interface PromptAnyToolChoiceArgs {
    }
    /**
     * Auto Tool choice
     */
    interface PromptAutoToolChoiceArgs {
    }
    /**
     * CachePointBlock
     */
    interface PromptCachePointBlockArgs {
        type: pulumi.Input<enums.bedrock.PromptCachePointType>;
    }
    /**
     * Configuration for chat prompt template
     */
    interface PromptChatPromptTemplateConfigurationArgs {
        /**
         * List of input variables
         */
        inputVariables?: pulumi.Input<pulumi.Input<inputs.bedrock.PromptInputVariableArgs>[]>;
        /**
         * List of messages for chat prompt template
         */
        messages: pulumi.Input<pulumi.Input<inputs.bedrock.PromptMessageArgs>[]>;
        /**
         * Configuration for chat prompt template
         */
        system?: pulumi.Input<pulumi.Input<inputs.bedrock.PromptSystemContentBlock0PropertiesArgs | inputs.bedrock.PromptSystemContentBlock1PropertiesArgs>[]>;
        toolConfiguration?: pulumi.Input<inputs.bedrock.PromptToolConfigurationArgs>;
    }
    /**
     * Configuration for chat prompt template
     */
    interface PromptContentBlock0PropertiesArgs {
        /**
         * Configuration for chat prompt template
         */
        text: pulumi.Input<string>;
    }
    /**
     * Configuration for chat prompt template
     */
    interface PromptContentBlock1PropertiesArgs {
        cachePoint: pulumi.Input<inputs.bedrock.PromptCachePointBlockArgs>;
    }
    /**
     * Target resource to invoke with Prompt
     */
    interface PromptGenAiResourcePropertiesArgs {
        agent: pulumi.Input<inputs.bedrock.PromptAgentResourceArgs>;
    }
    /**
     * Model inference configuration
     */
    interface PromptInferenceConfigurationPropertiesArgs {
        text: pulumi.Input<inputs.bedrock.PromptModelInferenceConfigurationArgs>;
    }
    /**
     * Input variable
     */
    interface PromptInputVariableArgs {
        /**
         * Name for an input variable
         */
        name?: pulumi.Input<string>;
    }
    /**
     * Chat prompt Message
     */
    interface PromptMessageArgs {
        /**
         * List of Content Blocks
         */
        content: pulumi.Input<pulumi.Input<inputs.bedrock.PromptContentBlock0PropertiesArgs | inputs.bedrock.PromptContentBlock1PropertiesArgs>[]>;
        role: pulumi.Input<enums.bedrock.PromptConversationRole>;
    }
    /**
     * Contains a key-value pair that defines a metadata tag and value to attach to a prompt variant.
     */
    interface PromptMetadataEntryArgs {
        key: pulumi.Input<string>;
        value: pulumi.Input<string>;
    }
    /**
     * Prompt model inference configuration
     */
    interface PromptModelInferenceConfigurationArgs {
        /**
         * Maximum length of output
         */
        maxTokens?: pulumi.Input<number>;
        /**
         * List of stop sequences
         */
        stopSequences?: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * Controls randomness, higher values increase diversity
         */
        temperature?: pulumi.Input<number>;
        /**
         * Cumulative probability cutoff for token selection
         */
        topP?: pulumi.Input<number>;
    }
    /**
     * Specific Tool choice
     */
    interface PromptSpecificToolChoiceArgs {
        /**
         * Tool name
         */
        name: pulumi.Input<string>;
    }
    /**
     * Configuration for chat prompt template
     */
    interface PromptSystemContentBlock0PropertiesArgs {
        /**
         * Configuration for chat prompt template
         */
        text: pulumi.Input<string>;
    }
    /**
     * Configuration for chat prompt template
     */
    interface PromptSystemContentBlock1PropertiesArgs {
        cachePoint: pulumi.Input<inputs.bedrock.PromptCachePointBlockArgs>;
    }
    /**
     * Prompt template configuration
     */
    interface PromptTemplateConfiguration0PropertiesArgs {
        text: pulumi.Input<inputs.bedrock.PromptTextPromptTemplateConfigurationArgs>;
    }
    /**
     * Prompt template configuration
     */
    interface PromptTemplateConfiguration1PropertiesArgs {
        chat: pulumi.Input<inputs.bedrock.PromptChatPromptTemplateConfigurationArgs>;
    }
    /**
     * Configuration for text prompt template
     */
    interface PromptTextPromptTemplateConfigurationArgs {
        cachePoint?: pulumi.Input<inputs.bedrock.PromptCachePointBlockArgs>;
        /**
         * List of input variables
         */
        inputVariables?: pulumi.Input<pulumi.Input<inputs.bedrock.PromptInputVariableArgs>[]>;
        /**
         * Prompt content for String prompt template
         */
        text?: pulumi.Input<string>;
        textS3Location?: pulumi.Input<inputs.bedrock.PromptTextS3LocationArgs>;
    }
    /**
     * The identifier for the S3 resource.
     */
    interface PromptTextS3LocationArgs {
        /**
         * A bucket in S3
         */
        bucket: pulumi.Input<string>;
        /**
         * A object key in S3
         */
        key: pulumi.Input<string>;
        /**
         * The version of the the S3 object to use
         */
        version?: pulumi.Input<string>;
    }
    /**
     * Tool details
     */
    interface PromptTool0PropertiesArgs {
        toolSpec: pulumi.Input<inputs.bedrock.PromptToolSpecificationArgs>;
    }
    /**
     * Tool details
     */
    interface PromptTool1PropertiesArgs {
        cachePoint: pulumi.Input<inputs.bedrock.PromptCachePointBlockArgs>;
    }
    /**
     * Tool choice
     */
    interface PromptToolChoice0PropertiesArgs {
        auto: pulumi.Input<inputs.bedrock.PromptAutoToolChoiceArgs>;
    }
    /**
     * Tool choice
     */
    interface PromptToolChoice1PropertiesArgs {
        any: pulumi.Input<inputs.bedrock.PromptAnyToolChoiceArgs>;
    }
    /**
     * Tool choice
     */
    interface PromptToolChoice2PropertiesArgs {
        tool: pulumi.Input<inputs.bedrock.PromptSpecificToolChoiceArgs>;
    }
    /**
     * Tool configuration
     */
    interface PromptToolConfigurationArgs {
        toolChoice?: pulumi.Input<inputs.bedrock.PromptToolChoice0PropertiesArgs | inputs.bedrock.PromptToolChoice1PropertiesArgs | inputs.bedrock.PromptToolChoice2PropertiesArgs>;
        /**
         * List of Tools
         */
        tools: pulumi.Input<pulumi.Input<inputs.bedrock.PromptTool0PropertiesArgs | inputs.bedrock.PromptTool1PropertiesArgs>[]>;
    }
    /**
     * Tool input schema json
     */
    interface PromptToolInputSchemaPropertiesArgs {
        json: any;
    }
    /**
     * Tool specification
     */
    interface PromptToolSpecificationArgs {
        description?: pulumi.Input<string>;
        inputSchema: pulumi.Input<inputs.bedrock.PromptToolInputSchemaPropertiesArgs>;
        /**
         * Tool name
         */
        name: pulumi.Input<string>;
    }
    /**
     * Prompt variant
     */
    interface PromptVariantArgs {
        /**
         * Contains model-specific inference configurations that aren't in the `inferenceConfiguration` field. To see model-specific inference parameters, see [Inference request parameters and response fields for foundation models](https://docs.aws.amazon.com/bedrock/latest/userguide/model-parameters.html) .
         */
        additionalModelRequestFields?: pulumi.Input<inputs.bedrock.PromptAdditionalModelRequestFieldsArgs>;
        /**
         * Specifies a generative AI resource with which to use the prompt.
         */
        genAiResource?: pulumi.Input<inputs.bedrock.PromptGenAiResourcePropertiesArgs>;
        /**
         * Contains inference configurations for the prompt variant.
         */
        inferenceConfiguration?: pulumi.Input<inputs.bedrock.PromptInferenceConfigurationPropertiesArgs>;
        /**
         * An array of objects, each containing a key-value pair that defines a metadata tag and value to attach to a prompt variant.
         */
        metadata?: pulumi.Input<pulumi.Input<inputs.bedrock.PromptMetadataEntryArgs>[]>;
        /**
         * ARN or Id of a Bedrock Foundational Model or Inference Profile, or the ARN of a imported model, or a provisioned throughput ARN for custom models.
         */
        modelId?: pulumi.Input<string>;
        /**
         * Name for a variant.
         */
        name: pulumi.Input<string>;
        /**
         * Contains configurations for the prompt template.
         */
        templateConfiguration: pulumi.Input<inputs.bedrock.PromptTemplateConfiguration0PropertiesArgs | inputs.bedrock.PromptTemplateConfiguration1PropertiesArgs>;
        /**
         * The type of prompt template to use.
         */
        templateType: pulumi.Input<enums.bedrock.PromptTemplateType>;
    }
}
export declare namespace budgets {
    interface BudgetsActionActionThresholdArgs {
        /**
         * The type of threshold for a notification.
         */
        type: pulumi.Input<enums.budgets.BudgetsActionActionThresholdType>;
        /**
         * The threshold of a notification.
         */
        value: pulumi.Input<number>;
    }
    interface BudgetsActionDefinitionArgs {
        /**
         * The AWS Identity and Access Management ( IAM ) action definition details.
         */
        iamActionDefinition?: pulumi.Input<inputs.budgets.BudgetsActionIamActionDefinitionArgs>;
        /**
         * The service control policies (SCP) action definition details.
         */
        scpActionDefinition?: pulumi.Input<inputs.budgets.BudgetsActionScpActionDefinitionArgs>;
        /**
         * The Amazon EC2 Systems Manager ( SSM ) action definition details.
         */
        ssmActionDefinition?: pulumi.Input<inputs.budgets.BudgetsActionSsmActionDefinitionArgs>;
    }
    interface BudgetsActionIamActionDefinitionArgs {
        /**
         * A list of groups to be attached. There must be at least one group.
         */
        groups?: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * The Amazon Resource Name (ARN) of the policy to be attached.
         */
        policyArn: pulumi.Input<string>;
        /**
         * A list of roles to be attached. There must be at least one role.
         */
        roles?: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * A list of users to be attached. There must be at least one user.
         */
        users?: pulumi.Input<pulumi.Input<string>[]>;
    }
    interface BudgetsActionScpActionDefinitionArgs {
        /**
         * The policy ID attached.
         */
        policyId: pulumi.Input<string>;
        /**
         * A list of target IDs.
         */
        targetIds: pulumi.Input<pulumi.Input<string>[]>;
    }
    interface BudgetsActionSsmActionDefinitionArgs {
        /**
         * The EC2 and RDS instance IDs.
         */
        instanceIds: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * The Region to run the ( SSM ) document.
         */
        region: pulumi.Input<string>;
        /**
         * The action subType.
         */
        subtype: pulumi.Input<enums.budgets.BudgetsActionSsmActionDefinitionSubtype>;
    }
    interface BudgetsActionSubscriberArgs {
        /**
         * The address that AWS sends budget notifications to, either an SNS topic or an email.
         *
         * When you create a subscriber, the value of `Address` can't contain line breaks.
         */
        address: pulumi.Input<string>;
        /**
         * The type of notification that AWS sends to a subscriber.
         */
        type: pulumi.Input<enums.budgets.BudgetsActionSubscriberType>;
    }
}
export declare namespace cassandra {
    interface KeyspaceReplicationSpecificationArgs {
        /**
         * Specifies the AWS Regions that the keyspace is replicated in. You must specify at least two Regions, including the Region that the keyspace is being created in.
         *
         * To specify a Region [that's disabled by default](https://docs.aws.amazon.com/accounts/latest/reference/manage-acct-regions.html#rande-manage-enable) , you must first enable the Region. For more information, see [Multi-Region replication in AWS Regions disabled by default](https://docs.aws.amazon.com/keyspaces/latest/devguide/multiRegion-replication_how-it-works.html#howitworks_mrr_opt_in) in the *Amazon Keyspaces Developer Guide* .
         */
        regionList?: pulumi.Input<pulumi.Input<enums.cassandra.KeyspaceRegionListItem>[]>;
        /**
         * The options are:
         *
         * - `SINGLE_REGION` (optional)
         * - `MULTI_REGION`
         *
         * If no value is specified, the default is `SINGLE_REGION` . If `MULTI_REGION` is specified, `RegionList` is required.
         */
        replicationStrategy?: pulumi.Input<enums.cassandra.KeyspaceReplicationSpecificationReplicationStrategy>;
    }
    /**
     * Represents configuration for auto scaling.
     */
    interface TableAutoScalingSettingArgs {
        /**
         * This optional parameter enables auto scaling for the table if set to `false` .
         */
        autoScalingDisabled?: pulumi.Input<boolean>;
        /**
         * Manage costs by specifying the maximum amount of throughput to provision. The value must be between 1 and the max throughput per second quota for your account (40,000 by default).
         */
        maximumUnits?: pulumi.Input<number>;
        /**
         * The minimum level of throughput the table should always be ready to support. The value must be between 1 and the max throughput per second quota for your account (40,000 by default).
         */
        minimumUnits?: pulumi.Input<number>;
        /**
         * Amazon Keyspaces supports the `target tracking` auto scaling policy. With this policy, Amazon Keyspaces auto scaling ensures that the table's ratio of consumed to provisioned capacity stays at or near the target value that you specify. You define the target value as a percentage between 20 and 90.
         */
        scalingPolicy?: pulumi.Input<inputs.cassandra.TableScalingPolicyArgs>;
    }
    /**
     * Represents the read and write settings used for AutoScaling.
     */
    interface TableAutoScalingSpecificationArgs {
        /**
         * The auto scaling settings for the table's read capacity.
         */
        readCapacityAutoScaling?: pulumi.Input<inputs.cassandra.TableAutoScalingSettingArgs>;
        /**
         * The auto scaling settings for the table's write capacity.
         */
        writeCapacityAutoScaling?: pulumi.Input<inputs.cassandra.TableAutoScalingSettingArgs>;
    }
    interface TableBillingModeArgs {
        /**
         * The billing mode for the table:
         *
         * - On-demand mode - `ON_DEMAND`
         * - Provisioned mode - `PROVISIONED`
         *
         * > If you choose `PROVISIONED` mode, then you also need to specify provisioned throughput (read and write capacity) for the table.
         *
         * Valid values: `ON_DEMAND` | `PROVISIONED`
         */
        mode: pulumi.Input<enums.cassandra.TableMode>;
        /**
         * The provisioned read capacity and write capacity for the table. For more information, see [Provisioned throughput capacity mode](https://docs.aws.amazon.com/keyspaces/latest/devguide/ReadWriteCapacityMode.html#ReadWriteCapacityMode.Provisioned) in the *Amazon Keyspaces Developer Guide* .
         */
        provisionedThroughput?: pulumi.Input<inputs.cassandra.TableProvisionedThroughputArgs>;
    }
    interface TableClusteringKeyColumnArgs {
        /**
         * The name and data type of this clustering key column.
         */
        column: pulumi.Input<inputs.cassandra.TableColumnArgs>;
        /**
         * The order in which this column's data is stored:
         *
         * - `ASC` (default) - The column's data is stored in ascending order.
         * - `DESC` - The column's data is stored in descending order.
         */
        orderBy?: pulumi.Input<enums.cassandra.TableClusteringKeyColumnOrderBy>;
    }
    interface TableColumnArgs {
        /**
         * The name of the column. For more information, see [Identifiers](https://docs.aws.amazon.com/keyspaces/latest/devguide/cql.elements.html#cql.elements.identifier) in the *Amazon Keyspaces Developer Guide* .
         */
        columnName: pulumi.Input<string>;
        /**
         * The data type of the column. For more information, see [Data types](https://docs.aws.amazon.com/keyspaces/latest/devguide/cql.elements.html#cql.data-types) in the *Amazon Keyspaces Developer Guide* .
         */
        columnType: pulumi.Input<string>;
    }
    /**
     * Represents the settings used to enable server-side encryption
     */
    interface TableEncryptionSpecificationArgs {
        /**
         * The encryption at rest options for the table.
         *
         * - *AWS owned key* (default) - `AWS_OWNED_KMS_KEY`
         * - *Customer managed key* - `CUSTOMER_MANAGED_KMS_KEY`
         *
         * > If you choose `CUSTOMER_MANAGED_KMS_KEY` , a `kms_key_identifier` in the format of a key ARN is required.
         *
         * Valid values: `CUSTOMER_MANAGED_KMS_KEY` | `AWS_OWNED_KMS_KEY` .
         */
        encryptionType: pulumi.Input<enums.cassandra.TableEncryptionType>;
        /**
         * Requires a `kms_key_identifier` in the format of a key ARN.
         */
        kmsKeyIdentifier?: pulumi.Input<string>;
    }
    /**
     * Throughput for the specified table, which consists of values for ReadCapacityUnits and WriteCapacityUnits
     */
    interface TableProvisionedThroughputArgs {
        /**
         * The amount of read capacity that's provisioned for the table. For more information, see [Read/write capacity mode](https://docs.aws.amazon.com/keyspaces/latest/devguide/ReadWriteCapacityMode.html) in the *Amazon Keyspaces Developer Guide* .
         */
        readCapacityUnits: pulumi.Input<number>;
        /**
         * The amount of write capacity that's provisioned for the table. For more information, see [Read/write capacity mode](https://docs.aws.amazon.com/keyspaces/latest/devguide/ReadWriteCapacityMode.html) in the *Amazon Keyspaces Developer Guide* .
         */
        writeCapacityUnits: pulumi.Input<number>;
    }
    /**
     * Represents replica specifications.
     */
    interface TableReplicaSpecificationArgs {
        /**
         * The read capacity auto scaling settings for the multi-Region table in the specified AWS Region.
         */
        readCapacityAutoScaling?: pulumi.Input<inputs.cassandra.TableAutoScalingSettingArgs>;
        /**
         * The provisioned read capacity units for the multi-Region table in the specified AWS Region.
         */
        readCapacityUnits?: pulumi.Input<number>;
        /**
         * The AWS Region.
         */
        region: pulumi.Input<string>;
    }
    /**
     * Represents scaling policy.
     */
    interface TableScalingPolicyArgs {
        /**
         * The auto scaling policy that scales a table based on the ratio of consumed to provisioned capacity.
         */
        targetTrackingScalingPolicyConfiguration?: pulumi.Input<inputs.cassandra.TableTargetTrackingScalingPolicyConfigurationArgs>;
    }
    /**
     * Represents configuration for target tracking scaling policy.
     */
    interface TableTargetTrackingScalingPolicyConfigurationArgs {
        /**
         * Specifies if `scale-in` is enabled.
         *
         * When auto scaling automatically decreases capacity for a table, the table *scales in* . When scaling policies are set, they can't scale in the table lower than its minimum capacity.
         */
        disableScaleIn?: pulumi.Input<boolean>;
        /**
         * Specifies a `scale-in` cool down period.
         *
         * A cooldown period in seconds between scaling activities that lets the table stabilize before another scaling activity starts.
         */
        scaleInCooldown?: pulumi.Input<number>;
        /**
         * Specifies a scale out cool down period.
         *
         * A cooldown period in seconds between scaling activities that lets the table stabilize before another scaling activity starts.
         */
        scaleOutCooldown?: pulumi.Input<number>;
        /**
         * Specifies the target value for the target tracking auto scaling policy.
         *
         * Amazon Keyspaces auto scaling scales up capacity automatically when traffic exceeds this target utilization rate, and then back down when it falls below the target. This ensures that the ratio of consumed capacity to provisioned capacity stays at or near this value. You define `targetValue` as a percentage. An `integer` between 20 and 90.
         */
        targetValue: pulumi.Input<number>;
    }
    interface TypeFieldArgs {
        /**
         * The name of the field.
         */
        fieldName: pulumi.Input<string>;
        /**
         * The data type of the field. This can be any Cassandra data type or another user-defined type.
         */
        fieldType: pulumi.Input<string>;
    }
}
export declare namespace ce {
    /**
     * A key-value pair to associate with a resource.
     */
    interface AnomalyMonitorResourceTagArgs {
        /**
         * The key name for the tag.
         */
        key: pulumi.Input<string>;
        /**
         * The value for the tag.
         */
        value: pulumi.Input<string>;
    }
    /**
     * A key-value pair to associate with a resource.
     */
    interface AnomalySubscriptionResourceTagArgs {
        /**
         * The key name for the tag.
         */
        key: pulumi.Input<string>;
        /**
         * The value for the tag.
         */
        value: pulumi.Input<string>;
    }
    interface AnomalySubscriptionSubscriberArgs {
        /**
         * The email address or SNS Topic Amazon Resource Name (ARN), depending on the `Type` .
         */
        address: pulumi.Input<string>;
        /**
         * Indicates if the subscriber accepts the notifications.
         */
        status?: pulumi.Input<enums.ce.AnomalySubscriptionSubscriberStatus>;
        /**
         * The notification delivery channel.
         */
        type: pulumi.Input<enums.ce.AnomalySubscriptionSubscriberType>;
    }
}
export declare namespace certificatemanager {
    interface AccountExpiryEventsConfigurationArgs {
        /**
         * This option specifies the number of days prior to certificate expiration when ACM starts generating `EventBridge` events. ACM sends one event per day per certificate until the certificate expires. By default, accounts receive events starting 45 days before certificate expiration.
         */
        daysBeforeExpiry?: pulumi.Input<number>;
    }
}
export declare namespace chatbot {
    interface CustomActionAttachmentArgs {
        /**
         * The text of the button that appears on the notification.
         */
        buttonText?: pulumi.Input<string>;
        /**
         * The criteria for when a button should be shown based on values in the notification.
         */
        criteria?: pulumi.Input<pulumi.Input<inputs.chatbot.CustomActionAttachmentCriteriaArgs>[]>;
        /**
         * The type of notification that the custom action should be attached to.
         */
        notificationType?: pulumi.Input<string>;
        /**
         * The variables to extract from the notification.
         */
        variables?: pulumi.Input<{
            [key: string]: pulumi.Input<string>;
        }>;
    }
    interface CustomActionAttachmentCriteriaArgs {
        /**
         * The operation to perform on the named variable.
         */
        operator: pulumi.Input<enums.chatbot.CustomActionAttachmentCriteriaOperator>;
        /**
         * A value that is compared with the actual value of the variable based on the behavior of the operator.
         */
        value?: pulumi.Input<string>;
        /**
         * The name of the variable to operate on.
         */
        variableName: pulumi.Input<string>;
    }
    interface CustomActionDefinitionArgs {
        /**
         * The command string to run which may include variables by prefixing with a dollar sign ($).
         */
        commandText: pulumi.Input<string>;
    }
}
export declare namespace cleanrooms {
    interface AnalysisTemplateAnalysisParameterArgs {
        /**
         * Optional. The default value that is applied in the analysis template. The member who can query can override this value in the query editor.
         */
        defaultValue?: pulumi.Input<string>;
        /**
         * The name of the parameter. The name must use only alphanumeric, underscore (_), or hyphen (-) characters but cannot start or end with a hyphen.
         */
        name: pulumi.Input<string>;
        /**
         * The type of parameter.
         */
        type: pulumi.Input<enums.cleanrooms.AnalysisTemplateAnalysisParameterType>;
    }
    interface AnalysisTemplateAnalysisSchemaArgs {
        /**
         * The tables referenced in the analysis schema.
         */
        referencedTables: pulumi.Input<pulumi.Input<string>[]>;
    }
    interface AnalysisTemplateAnalysisSource0PropertiesArgs {
        text: pulumi.Input<string>;
    }
    interface AnalysisTemplateAnalysisSource1PropertiesArgs {
        artifacts: pulumi.Input<inputs.cleanrooms.AnalysisTemplateArtifactsArgs>;
    }
    interface AnalysisTemplateAnalysisSourceMetadataPropertiesArgs {
        artifacts: pulumi.Input<inputs.cleanrooms.AnalysisTemplateArtifactMetadataArgs>;
    }
    interface AnalysisTemplateArtifactArgs {
        location: pulumi.Input<inputs.cleanrooms.AnalysisTemplateS3LocationArgs>;
    }
    interface AnalysisTemplateArtifactMetadataArgs {
        additionalArtifactHashes?: pulumi.Input<pulumi.Input<inputs.cleanrooms.AnalysisTemplateHashArgs>[]>;
        entryPointHash: pulumi.Input<inputs.cleanrooms.AnalysisTemplateHashArgs>;
    }
    interface AnalysisTemplateArtifactsArgs {
        additionalArtifacts?: pulumi.Input<pulumi.Input<inputs.cleanrooms.AnalysisTemplateArtifactArgs>[]>;
        entryPoint: pulumi.Input<inputs.cleanrooms.AnalysisTemplateArtifactArgs>;
        roleArn: pulumi.Input<string>;
    }
    interface AnalysisTemplateHashArgs {
        sha256?: pulumi.Input<string>;
    }
    interface AnalysisTemplateS3LocationArgs {
        bucket: pulumi.Input<string>;
        key: pulumi.Input<string>;
    }
    interface CollaborationDataEncryptionMetadataArgs {
        /**
         * Indicates whether encrypted tables can contain cleartext data ( `TRUE` ) or are to cryptographically process every column ( `FALSE` ).
         */
        allowCleartext: pulumi.Input<boolean>;
        /**
         * Indicates whether Fingerprint columns can contain duplicate entries ( `TRUE` ) or are to contain only non-repeated values ( `FALSE` ).
         */
        allowDuplicates: pulumi.Input<boolean>;
        /**
         * Indicates whether Fingerprint columns can be joined on any other Fingerprint column with a different name ( `TRUE` ) or can only be joined on Fingerprint columns of the same name ( `FALSE` ).
         */
        allowJoinsOnColumnsWithDifferentNames: pulumi.Input<boolean>;
        /**
         * Indicates whether NULL values are to be copied as NULL to encrypted tables ( `TRUE` ) or cryptographically processed ( `FALSE` ).
         */
        preserveNulls: pulumi.Input<boolean>;
    }
    interface CollaborationJobComputePaymentConfigArgs {
        /**
         * Indicates whether the collaboration creator has configured the collaboration member to pay for query and job compute costs ( `TRUE` ) or has not configured the collaboration member to pay for query and job compute costs ( `FALSE` ).
         *
         * Exactly one member can be configured to pay for query and job compute costs. An error is returned if the collaboration creator sets a `TRUE` value for more than one member in the collaboration.
         *
         * An error is returned if the collaboration creator sets a `FALSE` value for the member who can run queries and jobs.
         */
        isResponsible: pulumi.Input<boolean>;
    }
    interface CollaborationMemberSpecificationArgs {
        /**
         * The identifier used to reference members of the collaboration. Currently only supports AWS account ID.
         */
        accountId: pulumi.Input<string>;
        /**
         * The member's display name.
         */
        displayName: pulumi.Input<string>;
        /**
         * The abilities granted to the collaboration member.
         *
         * *Allowed Values* : `CAN_QUERY` | `CAN_RECEIVE_RESULTS`
         */
        memberAbilities: pulumi.Input<pulumi.Input<enums.cleanrooms.CollaborationMemberAbility>[]>;
        /**
         * The ML abilities granted to the collaboration member.
         */
        mlMemberAbilities?: pulumi.Input<inputs.cleanrooms.CollaborationMlMemberAbilitiesArgs>;
        /**
         * The collaboration member's payment responsibilities set by the collaboration creator.
         *
         * If the collaboration creator hasn't speciﬁed anyone as the member paying for query compute costs, then the member who can query is the default payer.
         */
        paymentConfiguration?: pulumi.Input<inputs.cleanrooms.CollaborationPaymentConfigurationArgs>;
    }
    interface CollaborationMlMemberAbilitiesArgs {
        /**
         * The custom ML member abilities for a collaboration member.
         */
        customMlMemberAbilities: pulumi.Input<pulumi.Input<enums.cleanrooms.CollaborationCustomMlMemberAbility>[]>;
    }
    interface CollaborationMlPaymentConfigArgs {
        /**
         * The payment responsibilities accepted by the member for model inference.
         */
        modelInference?: pulumi.Input<inputs.cleanrooms.CollaborationModelInferencePaymentConfigArgs>;
        /**
         * The payment responsibilities accepted by the member for model training.
         */
        modelTraining?: pulumi.Input<inputs.cleanrooms.CollaborationModelTrainingPaymentConfigArgs>;
    }
    interface CollaborationModelInferencePaymentConfigArgs {
        /**
         * Indicates whether the collaboration creator has configured the collaboration member to pay for model inference costs ( `TRUE` ) or has not configured the collaboration member to pay for model inference costs ( `FALSE` ).
         *
         * Exactly one member can be configured to pay for model inference costs. An error is returned if the collaboration creator sets a `TRUE` value for more than one member in the collaboration.
         *
         * If the collaboration creator hasn't specified anyone as the member paying for model inference costs, then the member who can query is the default payer. An error is returned if the collaboration creator sets a `FALSE` value for the member who can query.
         */
        isResponsible: pulumi.Input<boolean>;
    }
    interface CollaborationModelTrainingPaymentConfigArgs {
        /**
         * Indicates whether the collaboration creator has configured the collaboration member to pay for model training costs ( `TRUE` ) or has not configured the collaboration member to pay for model training costs ( `FALSE` ).
         *
         * Exactly one member can be configured to pay for model training costs. An error is returned if the collaboration creator sets a `TRUE` value for more than one member in the collaboration.
         *
         * If the collaboration creator hasn't specified anyone as the member paying for model training costs, then the member who can query is the default payer. An error is returned if the collaboration creator sets a `FALSE` value for the member who can query.
         */
        isResponsible: pulumi.Input<boolean>;
    }
    interface CollaborationPaymentConfigurationArgs {
        /**
         * The compute configuration for the job.
         */
        jobCompute?: pulumi.Input<inputs.cleanrooms.CollaborationJobComputePaymentConfigArgs>;
        /**
         * An object representing the collaboration member's machine learning payment responsibilities set by the collaboration creator.
         */
        machineLearning?: pulumi.Input<inputs.cleanrooms.CollaborationMlPaymentConfigArgs>;
        /**
         * The collaboration member's payment responsibilities set by the collaboration creator for query compute costs.
         */
        queryCompute: pulumi.Input<inputs.cleanrooms.CollaborationQueryComputePaymentConfigArgs>;
    }
    interface CollaborationQueryComputePaymentConfigArgs {
        /**
         * Indicates whether the collaboration creator has configured the collaboration member to pay for query compute costs ( `TRUE` ) or has not configured the collaboration member to pay for query compute costs ( `FALSE` ).
         *
         * Exactly one member can be configured to pay for query compute costs. An error is returned if the collaboration creator sets a `TRUE` value for more than one member in the collaboration.
         *
         * If the collaboration creator hasn't specified anyone as the member paying for query compute costs, then the member who can query is the default payer. An error is returned if the collaboration creator sets a `FALSE` value for the member who can query.
         */
        isResponsible: pulumi.Input<boolean>;
    }
    interface ConfiguredTableAggregateColumnArgs {
        columnNames: pulumi.Input<pulumi.Input<string>[]>;
        function: pulumi.Input<enums.cleanrooms.ConfiguredTableAggregateFunctionName>;
    }
    interface ConfiguredTableAggregationConstraintArgs {
        columnName: pulumi.Input<string>;
        minimum: pulumi.Input<number>;
        type: pulumi.Input<enums.cleanrooms.ConfiguredTableAggregationType>;
    }
    interface ConfiguredTableAnalysisRuleArgs {
        /**
         * A policy that describes the associated data usage limitations.
         */
        policy: pulumi.Input<inputs.cleanrooms.ConfiguredTableAnalysisRulePolicyArgs>;
        /**
         * The type of analysis rule.
         */
        type: pulumi.Input<enums.cleanrooms.ConfiguredTableAnalysisRuleType>;
    }
    interface ConfiguredTableAnalysisRuleAggregationArgs {
        additionalAnalyses?: pulumi.Input<enums.cleanrooms.ConfiguredTableAdditionalAnalyses>;
        aggregateColumns: pulumi.Input<pulumi.Input<inputs.cleanrooms.ConfiguredTableAggregateColumnArgs>[]>;
        allowedJoinOperators?: pulumi.Input<pulumi.Input<enums.cleanrooms.ConfiguredTableJoinOperator>[]>;
        dimensionColumns: pulumi.Input<pulumi.Input<string>[]>;
        joinColumns: pulumi.Input<pulumi.Input<string>[]>;
        joinRequired?: pulumi.Input<enums.cleanrooms.ConfiguredTableJoinRequiredOption>;
        outputConstraints: pulumi.Input<pulumi.Input<inputs.cleanrooms.ConfiguredTableAggregationConstraintArgs>[]>;
        scalarFunctions: pulumi.Input<pulumi.Input<enums.cleanrooms.ConfiguredTableScalarFunctions>[]>;
    }
    interface ConfiguredTableAnalysisRuleCustomArgs {
        additionalAnalyses?: pulumi.Input<enums.cleanrooms.ConfiguredTableAdditionalAnalyses>;
        allowedAnalyses: pulumi.Input<pulumi.Input<string>[]>;
        allowedAnalysisProviders?: pulumi.Input<pulumi.Input<string>[]>;
        differentialPrivacy?: pulumi.Input<inputs.cleanrooms.ConfiguredTableDifferentialPrivacyArgs>;
        disallowedOutputColumns?: pulumi.Input<pulumi.Input<string>[]>;
    }
    interface ConfiguredTableAnalysisRuleListArgs {
        additionalAnalyses?: pulumi.Input<enums.cleanrooms.ConfiguredTableAdditionalAnalyses>;
        allowedJoinOperators?: pulumi.Input<pulumi.Input<enums.cleanrooms.ConfiguredTableJoinOperator>[]>;
        joinColumns: pulumi.Input<pulumi.Input<string>[]>;
        listColumns: pulumi.Input<pulumi.Input<string>[]>;
    }
    interface ConfiguredTableAnalysisRulePolicyArgs {
        /**
         * Controls on the query specifications that can be run on a configured table.
         */
        v1: pulumi.Input<inputs.cleanrooms.ConfiguredTableAnalysisRulePolicyV10PropertiesArgs | inputs.cleanrooms.ConfiguredTableAnalysisRulePolicyV11PropertiesArgs | inputs.cleanrooms.ConfiguredTableAnalysisRulePolicyV12PropertiesArgs>;
    }
    interface ConfiguredTableAnalysisRulePolicyV10PropertiesArgs {
        list: pulumi.Input<inputs.cleanrooms.ConfiguredTableAnalysisRuleListArgs>;
    }
    interface ConfiguredTableAnalysisRulePolicyV11PropertiesArgs {
        aggregation: pulumi.Input<inputs.cleanrooms.ConfiguredTableAnalysisRuleAggregationArgs>;
    }
    interface ConfiguredTableAnalysisRulePolicyV12PropertiesArgs {
        custom: pulumi.Input<inputs.cleanrooms.ConfiguredTableAnalysisRuleCustomArgs>;
    }
    interface ConfiguredTableAssociationAnalysisRuleArgs {
        /**
         * The policy of the configured table association analysis rule.
         */
        policy: pulumi.Input<inputs.cleanrooms.ConfiguredTableAssociationAnalysisRulePolicyArgs>;
        /**
         * The type of the configured table association analysis rule.
         */
        type: pulumi.Input<enums.cleanrooms.ConfiguredTableAssociationAnalysisRuleType>;
    }
    interface ConfiguredTableAssociationAnalysisRuleAggregationArgs {
        allowedAdditionalAnalyses?: pulumi.Input<pulumi.Input<string>[]>;
        allowedResultReceivers?: pulumi.Input<pulumi.Input<string>[]>;
    }
    interface ConfiguredTableAssociationAnalysisRuleCustomArgs {
        allowedAdditionalAnalyses?: pulumi.Input<pulumi.Input<string>[]>;
        allowedResultReceivers?: pulumi.Input<pulumi.Input<string>[]>;
    }
    interface ConfiguredTableAssociationAnalysisRuleListArgs {
        allowedAdditionalAnalyses?: pulumi.Input<pulumi.Input<string>[]>;
        allowedResultReceivers?: pulumi.Input<pulumi.Input<string>[]>;
    }
    interface ConfiguredTableAssociationAnalysisRulePolicyArgs {
        /**
         * The policy for the configured table association analysis rule.
         */
        v1: pulumi.Input<inputs.cleanrooms.ConfiguredTableAssociationAnalysisRulePolicyV10PropertiesArgs | inputs.cleanrooms.ConfiguredTableAssociationAnalysisRulePolicyV11PropertiesArgs | inputs.cleanrooms.ConfiguredTableAssociationAnalysisRulePolicyV12PropertiesArgs>;
    }
    interface ConfiguredTableAssociationAnalysisRulePolicyV10PropertiesArgs {
        list: pulumi.Input<inputs.cleanrooms.ConfiguredTableAssociationAnalysisRuleListArgs>;
    }
    interface ConfiguredTableAssociationAnalysisRulePolicyV11PropertiesArgs {
        aggregation: pulumi.Input<inputs.cleanrooms.ConfiguredTableAssociationAnalysisRuleAggregationArgs>;
    }
    interface ConfiguredTableAssociationAnalysisRulePolicyV12PropertiesArgs {
        custom: pulumi.Input<inputs.cleanrooms.ConfiguredTableAssociationAnalysisRuleCustomArgs>;
    }
    interface ConfiguredTableAthenaTableReferenceArgs {
        databaseName: pulumi.Input<string>;
        outputLocation?: pulumi.Input<string>;
        tableName: pulumi.Input<string>;
        workGroup: pulumi.Input<string>;
    }
    interface ConfiguredTableDifferentialPrivacyArgs {
        columns: pulumi.Input<pulumi.Input<inputs.cleanrooms.ConfiguredTableDifferentialPrivacyColumnArgs>[]>;
    }
    interface ConfiguredTableDifferentialPrivacyColumnArgs {
        name: pulumi.Input<string>;
    }
    interface ConfiguredTableGlueTableReferenceArgs {
        databaseName: pulumi.Input<string>;
        tableName: pulumi.Input<string>;
    }
    interface ConfiguredTableSnowflakeTableReferenceArgs {
        accountIdentifier: pulumi.Input<string>;
        databaseName: pulumi.Input<string>;
        schemaName: pulumi.Input<string>;
        secretArn: pulumi.Input<string>;
        tableName: pulumi.Input<string>;
        tableSchema: pulumi.Input<inputs.cleanrooms.ConfiguredTableSnowflakeTableSchemaPropertiesArgs>;
    }
    interface ConfiguredTableSnowflakeTableSchemaPropertiesArgs {
        v1: pulumi.Input<pulumi.Input<inputs.cleanrooms.ConfiguredTableSnowflakeTableSchemaV1Args>[]>;
    }
    interface ConfiguredTableSnowflakeTableSchemaV1Args {
        columnName: pulumi.Input<string>;
        columnType: pulumi.Input<string>;
    }
    interface ConfiguredTableTableReference0PropertiesArgs {
        glue: pulumi.Input<inputs.cleanrooms.ConfiguredTableGlueTableReferenceArgs>;
    }
    interface ConfiguredTableTableReference1PropertiesArgs {
        snowflake: pulumi.Input<inputs.cleanrooms.ConfiguredTableSnowflakeTableReferenceArgs>;
    }
    interface ConfiguredTableTableReference2PropertiesArgs {
        athena: pulumi.Input<inputs.cleanrooms.ConfiguredTableAthenaTableReferenceArgs>;
    }
    interface IdMappingTableInputReferenceConfigArgs {
        /**
         * The Amazon Resource Name (ARN) of the referenced resource in AWS Entity Resolution . Valid values are ID mapping workflow ARNs.
         */
        inputReferenceArn: pulumi.Input<string>;
        /**
         * When `TRUE` , AWS Clean Rooms manages permissions for the ID mapping table resource.
         *
         * When `FALSE` , the resource owner manages permissions for the ID mapping table resource.
         */
        manageResourcePolicies: pulumi.Input<boolean>;
    }
    interface IdNamespaceAssociationIdMappingConfigArgs {
        /**
         * An indicator as to whether you can use your column as a dimension column in the ID mapping table ( `TRUE` ) or not ( `FALSE` ).
         *
         * Default is `FALSE` .
         */
        allowUseAsDimensionColumn: pulumi.Input<boolean>;
    }
    interface IdNamespaceAssociationInputReferenceConfigArgs {
        /**
         * The Amazon Resource Name (ARN) of the AWS Entity Resolution resource that is being associated to the collaboration. Valid resource ARNs are from the ID namespaces that you own.
         */
        inputReferenceArn: pulumi.Input<string>;
        /**
         * When `TRUE` , AWS Clean Rooms manages permissions for the ID namespace association resource.
         *
         * When `FALSE` , the resource owner manages permissions for the ID namespace association resource.
         */
        manageResourcePolicies: pulumi.Input<boolean>;
    }
    interface MembershipJobComputePaymentConfigArgs {
        /**
         * Indicates whether the collaboration member has accepted to pay for job compute costs ( `TRUE` ) or has not accepted to pay for query and job compute costs ( `FALSE` ).
         *
         * There is only one member who pays for queries and jobs.
         *
         * An error message is returned for the following reasons:
         *
         * - If you set the value to `FALSE` but you are responsible to pay for query and job compute costs.
         * - If you set the value to `TRUE` but you are not responsible to pay for query and job compute costs.
         */
        isResponsible: pulumi.Input<boolean>;
    }
    interface MembershipMlPaymentConfigArgs {
        /**
         * The payment responsibilities accepted by the member for model inference.
         */
        modelInference?: pulumi.Input<inputs.cleanrooms.MembershipModelInferencePaymentConfigArgs>;
        /**
         * The payment responsibilities accepted by the member for model training.
         */
        modelTraining?: pulumi.Input<inputs.cleanrooms.MembershipModelTrainingPaymentConfigArgs>;
    }
    interface MembershipModelInferencePaymentConfigArgs {
        /**
         * Indicates whether the collaboration member has accepted to pay for model inference costs ( `TRUE` ) or has not accepted to pay for model inference costs ( `FALSE` ).
         *
         * If the collaboration creator has not specified anyone to pay for model inference costs, then the member who can query is the default payer.
         *
         * An error message is returned for the following reasons:
         *
         * - If you set the value to `FALSE` but you are responsible to pay for model inference costs.
         * - If you set the value to `TRUE` but you are not responsible to pay for model inference costs.
         */
        isResponsible: pulumi.Input<boolean>;
    }
    interface MembershipModelTrainingPaymentConfigArgs {
        /**
         * Indicates whether the collaboration member has accepted to pay for model training costs ( `TRUE` ) or has not accepted to pay for model training costs ( `FALSE` ).
         *
         * If the collaboration creator has not specified anyone to pay for model training costs, then the member who can query is the default payer.
         *
         * An error message is returned for the following reasons:
         *
         * - If you set the value to `FALSE` but you are responsible to pay for model training costs.
         * - If you set the value to `TRUE` but you are not responsible to pay for model training costs.
         */
        isResponsible: pulumi.Input<boolean>;
    }
    interface MembershipPaymentConfigurationArgs {
        /**
         * The payment responsibilities accepted by the collaboration member for job compute costs.
         */
        jobCompute?: pulumi.Input<inputs.cleanrooms.MembershipJobComputePaymentConfigArgs>;
        /**
         * The payment responsibilities accepted by the collaboration member for machine learning costs.
         */
        machineLearning?: pulumi.Input<inputs.cleanrooms.MembershipMlPaymentConfigArgs>;
        /**
         * The payment responsibilities accepted by the collaboration member for query compute costs.
         */
        queryCompute: pulumi.Input<inputs.cleanrooms.MembershipQueryComputePaymentConfigArgs>;
    }
    interface MembershipProtectedJobOutputConfigurationArgs {
        /**
         * Contains the configuration to write the job results to S3.
         */
        s3: pulumi.Input<inputs.cleanrooms.MembershipProtectedJobS3OutputConfigurationInputArgs>;
    }
    interface MembershipProtectedJobResultConfigurationArgs {
        /**
         * The output configuration for a protected job result.
         */
        outputConfiguration: pulumi.Input<inputs.cleanrooms.MembershipProtectedJobOutputConfigurationArgs>;
        /**
         * The unique ARN for an IAM role that is used by AWS Clean Rooms to write protected job results to the result location, given by the member who can receive results.
         */
        roleArn: pulumi.Input<string>;
    }
    interface MembershipProtectedJobS3OutputConfigurationInputArgs {
        /**
         * The S3 bucket for job output.
         */
        bucket: pulumi.Input<string>;
        /**
         * The S3 prefix to unload the protected job results.
         */
        keyPrefix?: pulumi.Input<string>;
    }
    interface MembershipProtectedQueryOutputConfigurationArgs {
        /**
         * Required configuration for a protected query with an `s3` output type.
         */
        s3: pulumi.Input<inputs.cleanrooms.MembershipProtectedQueryS3OutputConfigurationArgs>;
    }
    interface MembershipProtectedQueryResultConfigurationArgs {
        /**
         * Configuration for protected query results.
         */
        outputConfiguration: pulumi.Input<inputs.cleanrooms.MembershipProtectedQueryOutputConfigurationArgs>;
        /**
         * The unique ARN for an IAM role that is used by AWS Clean Rooms to write protected query results to the result location, given by the member who can receive results.
         */
        roleArn?: pulumi.Input<string>;
    }
    interface MembershipProtectedQueryS3OutputConfigurationArgs {
        /**
         * The S3 bucket to unload the protected query results.
         */
        bucket: pulumi.Input<string>;
        /**
         * The S3 prefix to unload the protected query results.
         */
        keyPrefix?: pulumi.Input<string>;
        /**
         * Intended file format of the result.
         */
        resultFormat: pulumi.Input<enums.cleanrooms.MembershipResultFormat>;
        /**
         * Indicates whether files should be output as a single file ( `TRUE` ) or output as multiple files ( `FALSE` ). This parameter is only supported for analyses with the Spark analytics engine.
         */
        singleFileOutput?: pulumi.Input<boolean>;
    }
    interface MembershipQueryComputePaymentConfigArgs {
        /**
         * Indicates whether the collaboration member has accepted to pay for query compute costs ( `TRUE` ) or has not accepted to pay for query compute costs ( `FALSE` ).
         *
         * If the collaboration creator has not specified anyone to pay for query compute costs, then the member who can query is the default payer.
         *
         * An error message is returned for the following reasons:
         *
         * - If you set the value to `FALSE` but you are responsible to pay for query compute costs.
         * - If you set the value to `TRUE` but you are not responsible to pay for query compute costs.
         */
        isResponsible: pulumi.Input<boolean>;
    }
    /**
     * Specifies the epsilon and noise parameters for the privacy budget template.
     */
    interface ParametersPropertiesArgs {
        /**
         * The epsilon value that you want to use.
         */
        epsilon: pulumi.Input<number>;
        /**
         * Noise added per query is measured in terms of the number of users whose contributions you want to obscure. This value governs the rate at which the privacy budget is depleted.
         */
        usersNoisePerQuery: pulumi.Input<number>;
    }
}
export declare namespace cleanroomsml {
    interface TrainingDatasetColumnSchemaArgs {
        /**
         * The name of a column.
         */
        columnName: pulumi.Input<string>;
        /**
         * The data type of column.
         */
        columnTypes: pulumi.Input<pulumi.Input<enums.cleanroomsml.TrainingDatasetColumnType>[]>;
    }
    interface TrainingDatasetDataSourceArgs {
        /**
         * A GlueDataSource object that defines the catalog ID, database name, and table name for the training data.
         */
        glueDataSource: pulumi.Input<inputs.cleanroomsml.TrainingDatasetGlueDataSourceArgs>;
    }
    interface TrainingDatasetDatasetArgs {
        /**
         * A DatasetInputConfig object that defines the data source and schema mapping.
         */
        inputConfig: pulumi.Input<inputs.cleanroomsml.TrainingDatasetDatasetInputConfigArgs>;
        /**
         * What type of information is found in the dataset.
         */
        type: pulumi.Input<enums.cleanroomsml.TrainingDatasetDatasetType>;
    }
    interface TrainingDatasetDatasetInputConfigArgs {
        /**
         * A DataSource object that specifies the Glue data source for the training data.
         */
        dataSource: pulumi.Input<inputs.cleanroomsml.TrainingDatasetDataSourceArgs>;
        /**
         * The schema information for the training data.
         */
        schema: pulumi.Input<pulumi.Input<inputs.cleanroomsml.TrainingDatasetColumnSchemaArgs>[]>;
    }
    interface TrainingDatasetGlueDataSourceArgs {
        /**
         * The Glue catalog that contains the training data.
         */
        catalogId?: pulumi.Input<string>;
        /**
         * The Glue database that contains the training data.
         */
        databaseName: pulumi.Input<string>;
        /**
         * The Glue table that contains the training data.
         */
        tableName: pulumi.Input<string>;
    }
}
export declare namespace cloudformation {
    /**
     * S3 Source Location for the Guard files.
     */
    interface GuardHookS3LocationArgs {
        /**
         * S3 uri of Guard files.
         */
        uri: pulumi.Input<string>;
        /**
         * S3 object version
         */
        versionId?: pulumi.Input<string>;
    }
    interface HookVersionLoggingConfigArgs {
        /**
         * The Amazon CloudWatch log group to which CloudFormation sends error logging information when invoking the type's handlers.
         */
        logGroupName?: pulumi.Input<string>;
        /**
         * The ARN of the role that CloudFormation should assume when sending log entries to CloudWatch logs.
         */
        logRoleArn?: pulumi.Input<string>;
    }
    /**
     * Hook targets are the destination where hooks will be invoked against.
     */
    interface LambdaHookHookTargetArgs {
        action: pulumi.Input<enums.cloudformation.LambdaHookAction>;
        invocationPoint: pulumi.Input<enums.cloudformation.LambdaHookInvocationPoint>;
        targetName: pulumi.Input<string>;
    }
    /**
     * Describes whether StackSets performs non-conflicting operations concurrently and queues conflicting operations.
     */
    interface ManagedExecutionPropertiesArgs {
        /**
         * When `true` , StackSets performs non-conflicting operations concurrently and queues conflicting operations. After conflicting operations finish, StackSets starts queued operations in request order.
         *
         * > If there are already running or queued operations, StackSets queues all incoming operations even if they are non-conflicting.
         * >
         * > You can't modify your stack set's execution configuration while there are running or queued operations for that stack set.
         *
         * When `false` (default), StackSets performs one operation at a time in request order.
         */
        active?: pulumi.Input<boolean>;
    }
    /**
     * Specifies the S3 location of your input parameters.
     */
    interface OptionsPropertiesArgs {
        /**
         * Specifies the S3 location where your input parameters are located.
         */
        inputParams?: pulumi.Input<inputs.cloudformation.GuardHookS3LocationArgs>;
    }
    interface ResourceVersionLoggingConfigArgs {
        /**
         * The Amazon CloudWatch log group to which CloudFormation sends error logging information when invoking the type's handlers.
         */
        logGroupName?: pulumi.Input<string>;
        /**
         * The ARN of the role that CloudFormation should assume when sending log entries to CloudWatch logs.
         */
        logRoleArn?: pulumi.Input<string>;
    }
    /**
     * Filters to allow hooks to target specific stack attributes
     */
    interface StackFiltersPropertiesArgs {
        /**
         * Attribute to specify the filtering behavior. ANY will make the Hook pass if one filter matches. ALL will make the Hook pass if all filters match
         */
        filteringCriteria: pulumi.Input<enums.cloudformation.LambdaHookStackFiltersPropertiesFilteringCriteria>;
        /**
         * List of stack names as filters
         */
        stackNames?: pulumi.Input<inputs.cloudformation.StackFiltersPropertiesStackNamesPropertiesArgs>;
        /**
         * List of stack roles that are performing the stack operations.
         */
        stackRoles?: pulumi.Input<inputs.cloudformation.StackFiltersPropertiesStackRolesPropertiesArgs>;
    }
    /**
     * List of stack names as filters
     */
    interface StackFiltersPropertiesStackNamesPropertiesArgs {
        /**
         * List of stack names that the hook is going to be excluded from
         */
        exclude?: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * List of stack names that the hook is going to target
         */
        include?: pulumi.Input<pulumi.Input<string>[]>;
    }
    /**
     * List of stack roles that are performing the stack operations.
     */
    interface StackFiltersPropertiesStackRolesPropertiesArgs {
        /**
         * List of stack roles that the hook is going to be excluded from
         */
        exclude?: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * List of stack roles that the hook is going to target
         */
        include?: pulumi.Input<pulumi.Input<string>[]>;
    }
    interface StackSetAutoDeploymentArgs {
        /**
         * If set to true, StackSets automatically deploys additional stack instances to AWS Organizations accounts that are added to a target organization or organizational unit (OU) in the specified Regions. If an account is removed from a target organization or OU, StackSets deletes stack instances from the account in the specified Regions.
         */
        enabled?: pulumi.Input<boolean>;
        /**
         * If set to true, stack resources are retained when an account is removed from a target organization or OU. If set to false, stack resources are deleted. Specify only if Enabled is set to True.
         */
        retainStacksOnAccountRemoval?: pulumi.Input<boolean>;
    }
    /**
     *  The AWS OrganizationalUnitIds or Accounts for which to create stack instances in the specified Regions.
     */
    interface StackSetDeploymentTargetsArgs {
        /**
         * The filter type you want to apply on organizational units and accounts.
         */
        accountFilterType?: pulumi.Input<enums.cloudformation.StackSetDeploymentTargetsAccountFilterType>;
        /**
         * AWS accounts that you want to create stack instances in the specified Region(s) for.
         */
        accounts?: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * Returns the value of the AccountsUrl property.
         */
        accountsUrl?: pulumi.Input<string>;
        /**
         * The organization root ID or organizational unit (OU) IDs to which StackSets deploys.
         */
        organizationalUnitIds?: pulumi.Input<pulumi.Input<string>[]>;
    }
    /**
     * The user-specified preferences for how AWS CloudFormation performs a stack set operation.
     */
    interface StackSetOperationPreferencesArgs {
        /**
         * Specifies how the concurrency level behaves during the operation execution.
         *
         * - `STRICT_FAILURE_TOLERANCE` : This option dynamically lowers the concurrency level to ensure the number of failed accounts never exceeds the value of `FailureToleranceCount` +1. The initial actual concurrency is set to the lower of either the value of the `MaxConcurrentCount` , or the value of `FailureToleranceCount` +1. The actual concurrency is then reduced proportionally by the number of failures. This is the default behavior.
         *
         * If failure tolerance or Maximum concurrent accounts are set to percentages, the behavior is similar.
         * - `SOFT_FAILURE_TOLERANCE` : This option decouples `FailureToleranceCount` from the actual concurrency. This allows stack set operations to run at the concurrency level set by the `MaxConcurrentCount` value, or `MaxConcurrentPercentage` , regardless of the number of failures.
         */
        concurrencyMode?: pulumi.Input<enums.cloudformation.StackSetConcurrencyMode>;
        /**
         * The number of accounts, per Region, for which this operation can fail before CloudFormation stops the operation in that Region. If the operation is stopped in a Region, CloudFormation doesn't attempt the operation in any subsequent Regions.
         *
         * Conditional: You must specify either `FailureToleranceCount` or `FailureTolerancePercentage` (but not both).
         */
        failureToleranceCount?: pulumi.Input<number>;
        /**
         * The percentage of accounts, per Region, for which this stack operation can fail before CloudFormation stops the operation in that Region. If the operation is stopped in a Region, CloudFormation doesn't attempt the operation in any subsequent Regions.
         *
         * When calculating the number of accounts based on the specified percentage, CloudFormation rounds *down* to the next whole number.
         *
         * Conditional: You must specify either `FailureToleranceCount` or `FailureTolerancePercentage` , but not both.
         */
        failureTolerancePercentage?: pulumi.Input<number>;
        /**
         * The maximum number of accounts in which to perform this operation at one time. This is dependent on the value of `FailureToleranceCount` . `MaxConcurrentCount` is at most one more than the `FailureToleranceCount` .
         *
         * Note that this setting lets you specify the *maximum* for operations. For large deployments, under certain circumstances the actual number of accounts acted upon concurrently may be lower due to service throttling.
         *
         * Conditional: You must specify either `MaxConcurrentCount` or `MaxConcurrentPercentage` , but not both.
         */
        maxConcurrentCount?: pulumi.Input<number>;
        /**
         * The maximum percentage of accounts in which to perform this operation at one time.
         *
         * When calculating the number of accounts based on the specified percentage, CloudFormation rounds down to the next whole number. This is true except in cases where rounding down would result is zero. In this case, CloudFormation sets the number as one instead.
         *
         * Note that this setting lets you specify the *maximum* for operations. For large deployments, under certain circumstances the actual number of accounts acted upon concurrently may be lower due to service throttling.
         *
         * Conditional: You must specify either `MaxConcurrentCount` or `MaxConcurrentPercentage` , but not both.
         */
        maxConcurrentPercentage?: pulumi.Input<number>;
        /**
         * The concurrency type of deploying StackSets operations in Regions, could be in parallel or one Region at a time.
         */
        regionConcurrencyType?: pulumi.Input<enums.cloudformation.StackSetRegionConcurrencyType>;
        /**
         * The order of the Regions where you want to perform the stack operation.
         */
        regionOrder?: pulumi.Input<pulumi.Input<string>[]>;
    }
    interface StackSetParameterArgs {
        /**
         * The key associated with the parameter. If you don't specify a key and value for a particular parameter, AWS CloudFormation uses the default value that is specified in your template.
         */
        parameterKey: pulumi.Input<string>;
        /**
         * The input value associated with the parameter.
         */
        parameterValue: pulumi.Input<string>;
    }
    /**
     * Stack instances in some specific accounts and Regions.
     */
    interface StackSetStackInstancesArgs {
        /**
         * The AWS `OrganizationalUnitIds` or `Accounts` for which to create stack instances in the specified Regions.
         */
        deploymentTargets: pulumi.Input<inputs.cloudformation.StackSetDeploymentTargetsArgs>;
        /**
         * A list of stack set parameters whose values you want to override in the selected stack instances.
         */
        parameterOverrides?: pulumi.Input<pulumi.Input<inputs.cloudformation.StackSetParameterArgs>[]>;
        /**
         * The names of one or more Regions where you want to create stack instances using the specified AWS account(s).
         */
        regions: pulumi.Input<pulumi.Input<string>[]>;
    }
    /**
     * Attribute to specify which targets should invoke the hook
     */
    interface TargetFilters0PropertiesArgs {
        /**
         * List of actions that the hook is going to target
         */
        actions?: pulumi.Input<pulumi.Input<enums.cloudformation.LambdaHookAction>[]>;
        /**
         * List of invocation points that the hook is going to target
         */
        invocationPoints?: pulumi.Input<pulumi.Input<enums.cloudformation.LambdaHookInvocationPoint>[]>;
        /**
         * List of type names that the hook is going to target
         */
        targetNames?: pulumi.Input<pulumi.Input<string>[]>;
    }
    /**
     * Attribute to specify which targets should invoke the hook
     */
    interface TargetFilters1PropertiesArgs {
        /**
         * List of hook targets
         */
        targets: pulumi.Input<pulumi.Input<inputs.cloudformation.LambdaHookHookTargetArgs>[]>;
    }
    interface TypeActivationLoggingConfigArgs {
        /**
         * The Amazon CloudWatch log group to which CloudFormation sends error logging information when invoking the type's handlers.
         */
        logGroupName?: pulumi.Input<string>;
        /**
         * The ARN of the role that CloudFormation should assume when sending log entries to CloudWatch logs.
         */
        logRoleArn?: pulumi.Input<string>;
    }
}
export declare namespace cloudfront {
    /**
     * A cache policy configuration.
     *  This configuration determines the following:
     *   +  The values that CloudFront includes in the cache key. These values can include HTTP headers, cookies, and URL query strings. CloudFront uses the cache key to find an object in its cache that it can return to the viewer.
     *   +  The default, minimum, and maximum time to live (TTL) values that you want objects to stay in the CloudFront cache.
     *
     *  The headers, cookies, and query strings that are included in the cache key are also included in requests that CloudFront sends to the origin. CloudFront sends a request when it can't find a valid object in its cache that matches the request's cache key. If you want to send values to the origin but *not* include them in the cache key, use ``OriginRequestPolicy``.
     */
    interface CachePolicyConfigArgs {
        /**
         * A comment to describe the cache policy. The comment cannot be longer than 128 characters.
         */
        comment?: pulumi.Input<string>;
        /**
         * The default amount of time, in seconds, that you want objects to stay in the CloudFront cache before CloudFront sends another request to the origin to see if the object has been updated. CloudFront uses this value as the object's time to live (TTL) only when the origin does *not* send ``Cache-Control`` or ``Expires`` headers with the object. For more information, see [Managing How Long Content Stays in an Edge Cache (Expiration)](https://docs.aws.amazon.com/AmazonCloudFront/latest/DeveloperGuide/Expiration.html) in the *Amazon CloudFront Developer Guide*.
         *  The default value for this field is 86400 seconds (one day). If the value of ``MinTTL`` is more than 86400 seconds, then the default value for this field is the same as the value of ``MinTTL``.
         */
        defaultTtl: pulumi.Input<number>;
        /**
         * The maximum amount of time, in seconds, that objects stay in the CloudFront cache before CloudFront sends another request to the origin to see if the object has been updated. CloudFront uses this value only when the origin sends ``Cache-Control`` or ``Expires`` headers with the object. For more information, see [Managing How Long Content Stays in an Edge Cache (Expiration)](https://docs.aws.amazon.com/AmazonCloudFront/latest/DeveloperGuide/Expiration.html) in the *Amazon CloudFront Developer Guide*.
         *  The default value for this field is 31536000 seconds (one year). If the value of ``MinTTL`` or ``DefaultTTL`` is more than 31536000 seconds, then the default value for this field is the same as the value of ``DefaultTTL``.
         */
        maxTtl: pulumi.Input<number>;
        /**
         * The minimum amount of time, in seconds, that you want objects to stay in the CloudFront cache before CloudFront sends another request to the origin to see if the object has been updated. For more information, see [Managing How Long Content Stays in an Edge Cache (Expiration)](https://docs.aws.amazon.com/AmazonCloudFront/latest/DeveloperGuide/Expiration.html) in the *Amazon CloudFront Developer Guide*.
         */
        minTtl: pulumi.Input<number>;
        /**
         * A unique name to identify the cache policy.
         */
        name: pulumi.Input<string>;
        /**
         * The HTTP headers, cookies, and URL query strings to include in the cache key. The values included in the cache key are also included in requests that CloudFront sends to the origin.
         */
        parametersInCacheKeyAndForwardedToOrigin: pulumi.Input<inputs.cloudfront.CachePolicyParametersInCacheKeyAndForwardedToOriginArgs>;
    }
    /**
     * An object that determines whether any cookies in viewer requests (and if so, which cookies) are included in the cache key and in requests that CloudFront sends to the origin.
     */
    interface CachePolicyCookiesConfigArgs {
        /**
         * Determines whether any cookies in viewer requests are included in the cache key and in requests that CloudFront sends to the origin. Valid values are:
         *   +   ``none`` – No cookies in viewer requests are included in the cache key or in requests that CloudFront sends to the origin. Even when this field is set to ``none``, any cookies that are listed in an ``OriginRequestPolicy`` *are* included in origin requests.
         *   +   ``whitelist`` – Only the cookies in viewer requests that are listed in the ``CookieNames`` type are included in the cache key and in requests that CloudFront sends to the origin.
         *   +   ``allExcept`` – All cookies in viewer requests are included in the cache key and in requests that CloudFront sends to the origin, *except* for those that are listed in the ``CookieNames`` type, which are not included.
         *   +   ``all`` – All cookies in viewer requests are included in the cache key and in requests that CloudFront sends to the origin.
         */
        cookieBehavior: pulumi.Input<string>;
        /**
         * Contains a list of cookie names.
         */
        cookies?: pulumi.Input<pulumi.Input<string>[]>;
    }
    /**
     * An object that determines whether any HTTP headers (and if so, which headers) are included in the cache key and in requests that CloudFront sends to the origin.
     */
    interface CachePolicyHeadersConfigArgs {
        /**
         * Determines whether any HTTP headers are included in the cache key and in requests that CloudFront sends to the origin. Valid values are:
         *   +   ``none`` – No HTTP headers are included in the cache key or in requests that CloudFront sends to the origin. Even when this field is set to ``none``, any headers that are listed in an ``OriginRequestPolicy`` *are* included in origin requests.
         *   +   ``whitelist`` – Only the HTTP headers that are listed in the ``Headers`` type are included in the cache key and in requests that CloudFront sends to the origin.
         */
        headerBehavior: pulumi.Input<string>;
        /**
         * Contains a list of HTTP header names.
         */
        headers?: pulumi.Input<pulumi.Input<string>[]>;
    }
    /**
     * This object determines the values that CloudFront includes in the cache key. These values can include HTTP headers, cookies, and URL query strings. CloudFront uses the cache key to find an object in its cache that it can return to the viewer.
     *  The headers, cookies, and query strings that are included in the cache key are also included in requests that CloudFront sends to the origin. CloudFront sends a request when it can't find an object in its cache that matches the request's cache key. If you want to send values to the origin but *not* include them in the cache key, use ``OriginRequestPolicy``.
     */
    interface CachePolicyParametersInCacheKeyAndForwardedToOriginArgs {
        /**
         * An object that determines whether any cookies in viewer requests (and if so, which cookies) are included in the cache key and in requests that CloudFront sends to the origin.
         */
        cookiesConfig: pulumi.Input<inputs.cloudfront.CachePolicyCookiesConfigArgs>;
        /**
         * A flag that can affect whether the ``Accept-Encoding`` HTTP header is included in the cache key and included in requests that CloudFront sends to the origin.
         *  This field is related to the ``EnableAcceptEncodingGzip`` field. If one or both of these fields is ``true`` *and* the viewer request includes the ``Accept-Encoding`` header, then CloudFront does the following:
         *   +  Normalizes the value of the viewer's ``Accept-Encoding`` header
         *   +  Includes the normalized header in the cache key
         *   +  Includes the normalized header in the request to the origin, if a request is necessary
         *
         *  For more information, see [Compression support](https://docs.aws.amazon.com/AmazonCloudFront/latest/DeveloperGuide/controlling-the-cache-key.html#cache-policy-compressed-objects) in the *Amazon CloudFront Developer Guide*.
         *  If you set this value to ``true``, and this cache behavior also has an origin request policy attached, do not include the ``Accept-Encoding`` header in the origin request policy. CloudFront always includes the ``Accept-Encoding`` header in origin requests when the value of this field is ``true``, so including this header in an origin request policy has no effect.
         *  If both of these fields are ``false``, then CloudFront treats the ``Accept-Encoding`` header the same as any other HTTP header in the viewer request. By default, it's not included in the cache key and it's not included in origin requests. In this case, you can manually add ``Accept-Encoding`` to the headers whitelist like any other HTTP header.
         */
        enableAcceptEncodingBrotli?: pulumi.Input<boolean>;
        /**
         * A flag that can affect whether the ``Accept-Encoding`` HTTP header is included in the cache key and included in requests that CloudFront sends to the origin.
         *  This field is related to the ``EnableAcceptEncodingBrotli`` field. If one or both of these fields is ``true`` *and* the viewer request includes the ``Accept-Encoding`` header, then CloudFront does the following:
         *   +  Normalizes the value of the viewer's ``Accept-Encoding`` header
         *   +  Includes the normalized header in the cache key
         *   +  Includes the normalized header in the request to the origin, if a request is necessary
         *
         *  For more information, see [Compression support](https://docs.aws.amazon.com/AmazonCloudFront/latest/DeveloperGuide/controlling-the-cache-key.html#cache-policy-compressed-objects) in the *Amazon CloudFront Developer Guide*.
         *  If you set this value to ``true``, and this cache behavior also has an origin request policy attached, do not include the ``Accept-Encoding`` header in the origin request policy. CloudFront always includes the ``Accept-Encoding`` header in origin requests when the value of this field is ``true``, so including this header in an origin request policy has no effect.
         *  If both of these fields are ``false``, then CloudFront treats the ``Accept-Encoding`` header the same as any other HTTP header in the viewer request. By default, it's not included in the cache key and it's not included in origin requests. In this case, you can manually add ``Accept-Encoding`` to the headers whitelist like any other HTTP header.
         */
        enableAcceptEncodingGzip: pulumi.Input<boolean>;
        /**
         * An object that determines whether any HTTP headers (and if so, which headers) are included in the cache key and in requests that CloudFront sends to the origin.
         */
        headersConfig: pulumi.Input<inputs.cloudfront.CachePolicyHeadersConfigArgs>;
        /**
         * An object that determines whether any URL query strings in viewer requests (and if so, which query strings) are included in the cache key and in requests that CloudFront sends to the origin.
         */
        queryStringsConfig: pulumi.Input<inputs.cloudfront.CachePolicyQueryStringsConfigArgs>;
    }
    /**
     * An object that determines whether any URL query strings in viewer requests (and if so, which query strings) are included in the cache key and in requests that CloudFront sends to the origin.
     */
    interface CachePolicyQueryStringsConfigArgs {
        /**
         * Determines whether any URL query strings in viewer requests are included in the cache key and in requests that CloudFront sends to the origin. Valid values are:
         *   +   ``none`` – No query strings in viewer requests are included in the cache key or in requests that CloudFront sends to the origin. Even when this field is set to ``none``, any query strings that are listed in an ``OriginRequestPolicy`` *are* included in origin requests.
         *   +   ``whitelist`` – Only the query strings in viewer requests that are listed in the ``QueryStringNames`` type are included in the cache key and in requests that CloudFront sends to the origin.
         *   +   ``allExcept`` – All query strings in viewer requests are included in the cache key and in requests that CloudFront sends to the origin, *except* those that are listed in the ``QueryStringNames`` type, which are not included.
         *   +   ``all`` – All query strings in viewer requests are included in the cache key and in requests that CloudFront sends to the origin.
         */
        queryStringBehavior: pulumi.Input<string>;
        /**
         * Contains a list of query string names.
         */
        queryStrings?: pulumi.Input<pulumi.Input<string>[]>;
    }
    /**
     * Origin access identity configuration. Send a ``GET`` request to the ``/CloudFront API version/CloudFront/identity ID/config`` resource.
     */
    interface CloudFrontOriginAccessIdentityConfigArgs {
        /**
         * A comment to describe the origin access identity. The comment cannot be longer than 128 characters.
         */
        comment: pulumi.Input<string>;
    }
    /**
     * Contains the configuration for a continuous deployment policy.
     */
    interface ContinuousDeploymentPolicyConfigArgs {
        /**
         * A Boolean that indicates whether this continuous deployment policy is enabled (in effect). When this value is ``true``, this policy is enabled and in effect. When this value is ``false``, this policy is not enabled and has no effect.
         */
        enabled: pulumi.Input<boolean>;
        /**
         * This configuration determines which HTTP requests are sent to the staging distribution. If the HTTP request contains a header and value that matches what you specify here, the request is sent to the staging distribution. Otherwise the request is sent to the primary distribution.
         */
        singleHeaderPolicyConfig?: pulumi.Input<inputs.cloudfront.ContinuousDeploymentPolicyConfigSingleHeaderPolicyConfigPropertiesArgs>;
        /**
         * This configuration determines the percentage of HTTP requests that are sent to the staging distribution.
         */
        singleWeightPolicyConfig?: pulumi.Input<inputs.cloudfront.ContinuousDeploymentPolicyConfigSingleWeightPolicyConfigPropertiesArgs>;
        /**
         * The CloudFront domain name of the staging distribution. For example: ``d111111abcdef8.cloudfront.net``.
         */
        stagingDistributionDnsNames: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * Contains the parameters for routing production traffic from your primary to staging distributions.
         */
        trafficConfig?: pulumi.Input<inputs.cloudfront.ContinuousDeploymentPolicyTrafficConfigArgs>;
        /**
         * The type of traffic configuration.
         */
        type?: pulumi.Input<enums.cloudfront.ContinuousDeploymentPolicyConfigType>;
    }
    /**
     * This configuration determines which HTTP requests are sent to the staging distribution. If the HTTP request contains a header and value that matches what you specify here, the request is sent to the staging distribution. Otherwise the request is sent to the primary distribution.
     */
    interface ContinuousDeploymentPolicyConfigSingleHeaderPolicyConfigPropertiesArgs {
        header: pulumi.Input<string>;
        value: pulumi.Input<string>;
    }
    /**
     * This configuration determines the percentage of HTTP requests that are sent to the staging distribution.
     */
    interface ContinuousDeploymentPolicyConfigSingleWeightPolicyConfigPropertiesArgs {
        sessionStickinessConfig?: pulumi.Input<inputs.cloudfront.ContinuousDeploymentPolicySessionStickinessConfigArgs>;
        weight: pulumi.Input<number>;
    }
    /**
     * Session stickiness provides the ability to define multiple requests from a single viewer as a single session. This prevents the potentially inconsistent experience of sending some of a given user's requests to your staging distribution, while others are sent to your primary distribution. Define the session duration using TTL values.
     */
    interface ContinuousDeploymentPolicySessionStickinessConfigArgs {
        /**
         * The amount of time after which you want sessions to cease if no requests are received. Allowed values are 300–3600 seconds (5–60 minutes).
         */
        idleTtl: pulumi.Input<number>;
        /**
         * The maximum amount of time to consider requests from the viewer as being part of the same session. Allowed values are 300–3600 seconds (5–60 minutes).
         */
        maximumTtl: pulumi.Input<number>;
    }
    /**
     * Determines which HTTP requests are sent to the staging distribution.
     */
    interface ContinuousDeploymentPolicySingleHeaderConfigArgs {
        /**
         * The request header name that you want CloudFront to send to your staging distribution. The header must contain the prefix ``aws-cf-cd-``.
         */
        header: pulumi.Input<string>;
        /**
         * The request header value.
         */
        value: pulumi.Input<string>;
    }
    /**
     * This configuration determines the percentage of HTTP requests that are sent to the staging distribution.
     */
    interface ContinuousDeploymentPolicySingleWeightConfigArgs {
        /**
         * Session stickiness provides the ability to define multiple requests from a single viewer as a single session. This prevents the potentially inconsistent experience of sending some of a given user's requests to your staging distribution, while others are sent to your primary distribution. Define the session duration using TTL values.
         */
        sessionStickinessConfig?: pulumi.Input<inputs.cloudfront.ContinuousDeploymentPolicySessionStickinessConfigArgs>;
        /**
         * The percentage of traffic to send to a staging distribution, expressed as a decimal number between 0 and 0.15. For example, a value of 0.10 means 10% of traffic is sent to the staging distribution.
         */
        weight: pulumi.Input<number>;
    }
    /**
     * The traffic configuration of your continuous deployment.
     */
    interface ContinuousDeploymentPolicyTrafficConfigArgs {
        /**
         * Determines which HTTP requests are sent to the staging distribution.
         */
        singleHeaderConfig?: pulumi.Input<inputs.cloudfront.ContinuousDeploymentPolicySingleHeaderConfigArgs>;
        /**
         * Contains the percentage of traffic to send to the staging distribution.
         */
        singleWeightConfig?: pulumi.Input<inputs.cloudfront.ContinuousDeploymentPolicySingleWeightConfigArgs>;
        /**
         * The type of traffic configuration.
         */
        type: pulumi.Input<enums.cloudfront.ContinuousDeploymentPolicyTrafficConfigType>;
    }
    /**
     * A complex type that describes how CloudFront processes requests.
     *  You must create at least as many cache behaviors (including the default cache behavior) as you have origins if you want CloudFront to serve objects from all of the origins. Each cache behavior specifies the one origin from which you want CloudFront to get objects. If you have two origins and only the default cache behavior, the default cache behavior will cause CloudFront to get objects from one of the origins, but the other origin is never used.
     *  For the current quota (formerly known as limit) on the number of cache behaviors that you can add to a distribution, see [Quotas](https://docs.aws.amazon.com/AmazonCloudFront/latest/DeveloperGuide/cloudfront-limits.html) in the *Amazon CloudFront Developer Guide*.
     *  If you don't want to specify any cache behaviors, include only an empty ``CacheBehaviors`` element. Don't specify an empty individual ``CacheBehavior`` element, because this is invalid. For more information, see [CacheBehaviors](https://docs.aws.amazon.com/cloudfront/latest/APIReference/API_CacheBehaviors.html).
     *  To delete all cache behaviors in an existing distribution, update the distribution configuration and include only an empty ``CacheBehaviors`` element.
     *  To add, change, or remove one or more cache behaviors, update the distribution configuration and specify all of the cache behaviors that you want to include in the updated distribution.
     *  For more information about cache behaviors, see [Cache Behavior Settings](https://docs.aws.amazon.com/AmazonCloudFront/latest/DeveloperGuide/distribution-web-values-specify.html#DownloadDistValuesCacheBehavior) in the *Amazon CloudFront Developer Guide*.
     */
    interface DistributionCacheBehaviorArgs {
        /**
         * A complex type that controls which HTTP methods CloudFront processes and forwards to your Amazon S3 bucket or your custom origin. There are three choices:
         *   +  CloudFront forwards only ``GET`` and ``HEAD`` requests.
         *   +  CloudFront forwards only ``GET``, ``HEAD``, and ``OPTIONS`` requests.
         *   +  CloudFront forwards ``GET, HEAD, OPTIONS, PUT, PATCH, POST``, and ``DELETE`` requests.
         *
         *  If you pick the third choice, you may need to restrict access to your Amazon S3 bucket or to your custom origin so users can't perform operations that you don't want them to. For example, you might not want users to have permissions to delete objects from your origin.
         */
        allowedMethods?: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * The unique identifier of the cache policy that is attached to this cache behavior. For more information, see [Creating cache policies](https://docs.aws.amazon.com/AmazonCloudFront/latest/DeveloperGuide/controlling-the-cache-key.html#cache-key-create-cache-policy) or [Using the managed cache policies](https://docs.aws.amazon.com/AmazonCloudFront/latest/DeveloperGuide/using-managed-cache-policies.html) in the *Amazon CloudFront Developer Guide*.
         *  A ``CacheBehavior`` must include either a ``CachePolicyId`` or ``ForwardedValues``. We recommend that you use a ``CachePolicyId``.
         */
        cachePolicyId?: pulumi.Input<string>;
        /**
         * A complex type that controls whether CloudFront caches the response to requests using the specified HTTP methods. There are two choices:
         *   +  CloudFront caches responses to ``GET`` and ``HEAD`` requests.
         *   +  CloudFront caches responses to ``GET``, ``HEAD``, and ``OPTIONS`` requests.
         *
         *  If you pick the second choice for your Amazon S3 Origin, you may need to forward Access-Control-Request-Method, Access-Control-Request-Headers, and Origin headers for the responses to be cached correctly.
         */
        cachedMethods?: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * Whether you want CloudFront to automatically compress certain files for this cache behavior. If so, specify true; if not, specify false. For more information, see [Serving Compressed Files](https://docs.aws.amazon.com/AmazonCloudFront/latest/DeveloperGuide/ServingCompressedFiles.html) in the *Amazon CloudFront Developer Guide*.
         */
        compress?: pulumi.Input<boolean>;
        /**
         * This field is deprecated. We recommend that you use the ``DefaultTTL`` field in a cache policy instead of this field. For more information, see [Creating cache policies](https://docs.aws.amazon.com/AmazonCloudFront/latest/DeveloperGuide/controlling-the-cache-key.html#cache-key-create-cache-policy) or [Using the managed cache policies](https://docs.aws.amazon.com/AmazonCloudFront/latest/DeveloperGuide/using-managed-cache-policies.html) in the *Amazon CloudFront Developer Guide*.
         *  The default amount of time that you want objects to stay in CloudFront caches before CloudFront forwards another request to your origin to determine whether the object has been updated. The value that you specify applies only when your origin does not add HTTP headers such as ``Cache-Control max-age``, ``Cache-Control s-maxage``, and ``Expires`` to objects. For more information, see [Managing How Long Content Stays in an Edge Cache (Expiration)](https://docs.aws.amazon.com/AmazonCloudFront/latest/DeveloperGuide/Expiration.html) in the *Amazon CloudFront Developer Guide*.
         */
        defaultTtl?: pulumi.Input<number>;
        /**
         * The value of ``ID`` for the field-level encryption configuration that you want CloudFront to use for encrypting specific fields of data for this cache behavior.
         */
        fieldLevelEncryptionId?: pulumi.Input<string>;
        /**
         * This field is deprecated. We recommend that you use a cache policy or an origin request policy instead of this field. For more information, see [Working with policies](https://docs.aws.amazon.com/AmazonCloudFront/latest/DeveloperGuide/working-with-policies.html) in the *Amazon CloudFront Developer Guide*.
         *  If you want to include values in the cache key, use a cache policy. For more information, see [Creating cache policies](https://docs.aws.amazon.com/AmazonCloudFront/latest/DeveloperGuide/controlling-the-cache-key.html#cache-key-create-cache-policy) or [Using the managed cache policies](https://docs.aws.amazon.com/AmazonCloudFront/latest/DeveloperGuide/using-managed-cache-policies.html) in the *Amazon CloudFront Developer Guide*.
         *  If you want to send values to the origin but not include them in the cache key, use an origin request policy. For more information, see [Creating origin request policies](https://docs.aws.amazon.com/AmazonCloudFront/latest/DeveloperGuide/controlling-origin-requests.html#origin-request-create-origin-request-policy) or [Using the managed origin request policies](https://docs.aws.amazon.com/AmazonCloudFront/latest/DeveloperGuide/using-managed-origin-request-policies.html) in the *Amazon CloudFront Developer Guide*.
         *  A ``CacheBehavior`` must include either a ``CachePolicyId`` or ``ForwardedValues``. We recommend that you use a ``CachePolicyId``.
         *  A complex type that specifies how CloudFront handles query strings, cookies, and HTTP headers.
         */
        forwardedValues?: pulumi.Input<inputs.cloudfront.DistributionForwardedValuesArgs>;
        /**
         * A list of CloudFront functions that are associated with this cache behavior. CloudFront functions must be published to the ``LIVE`` stage to associate them with a cache behavior.
         */
        functionAssociations?: pulumi.Input<pulumi.Input<inputs.cloudfront.DistributionFunctionAssociationArgs>[]>;
        /**
         * The gRPC configuration for your cache behavior.
         */
        grpcConfig?: pulumi.Input<inputs.cloudfront.DistributionGrpcConfigArgs>;
        /**
         * A complex type that contains zero or more Lambda@Edge function associations for a cache behavior.
         */
        lambdaFunctionAssociations?: pulumi.Input<pulumi.Input<inputs.cloudfront.DistributionLambdaFunctionAssociationArgs>[]>;
        /**
         * This field is deprecated. We recommend that you use the ``MaxTTL`` field in a cache policy instead of this field. For more information, see [Creating cache policies](https://docs.aws.amazon.com/AmazonCloudFront/latest/DeveloperGuide/controlling-the-cache-key.html#cache-key-create-cache-policy) or [Using the managed cache policies](https://docs.aws.amazon.com/AmazonCloudFront/latest/DeveloperGuide/using-managed-cache-policies.html) in the *Amazon CloudFront Developer Guide*.
         *  The maximum amount of time that you want objects to stay in CloudFront caches before CloudFront forwards another request to your origin to determine whether the object has been updated. The value that you specify applies only when your origin adds HTTP headers such as ``Cache-Control max-age``, ``Cache-Control s-maxage``, and ``Expires`` to objects. For more information, see [Managing How Long Content Stays in an Edge Cache (Expiration)](https://docs.aws.amazon.com/AmazonCloudFront/latest/DeveloperGuide/Expiration.html) in the *Amazon CloudFront Developer Guide*.
         */
        maxTtl?: pulumi.Input<number>;
        /**
         * This field is deprecated. We recommend that you use the ``MinTTL`` field in a cache policy instead of this field. For more information, see [Creating cache policies](https://docs.aws.amazon.com/AmazonCloudFront/latest/DeveloperGuide/controlling-the-cache-key.html#cache-key-create-cache-policy) or [Using the managed cache policies](https://docs.aws.amazon.com/AmazonCloudFront/latest/DeveloperGuide/using-managed-cache-policies.html) in the *Amazon CloudFront Developer Guide*.
         *  The minimum amount of time that you want objects to stay in CloudFront caches before CloudFront forwards another request to your origin to determine whether the object has been updated. For more information, see [Managing How Long Content Stays in an Edge Cache (Expiration)](https://docs.aws.amazon.com/AmazonCloudFront/latest/DeveloperGuide/Expiration.html) in the *Amazon CloudFront Developer Guide*.
         *  You must specify ``0`` for ``MinTTL`` if you configure CloudFront to forward all headers to your origin (under ``Headers``, if you specify ``1`` for ``Quantity`` and ``*`` for ``Name``).
         */
        minTtl?: pulumi.Input<number>;
        /**
         * The unique identifier of the origin request policy that is attached to this cache behavior. For more information, see [Creating origin request policies](https://docs.aws.amazon.com/AmazonCloudFront/latest/DeveloperGuide/controlling-origin-requests.html#origin-request-create-origin-request-policy) or [Using the managed origin request policies](https://docs.aws.amazon.com/AmazonCloudFront/latest/DeveloperGuide/using-managed-origin-request-policies.html) in the *Amazon CloudFront Developer Guide*.
         */
        originRequestPolicyId?: pulumi.Input<string>;
        /**
         * The pattern (for example, ``images/*.jpg``) that specifies which requests to apply the behavior to. When CloudFront receives a viewer request, the requested path is compared with path patterns in the order in which cache behaviors are listed in the distribution.
         *   You can optionally include a slash (``/``) at the beginning of the path pattern. For example, ``/images/*.jpg``. CloudFront behavior is the same with or without the leading ``/``.
         *   The path pattern for the default cache behavior is ``*`` and cannot be changed. If the request for an object does not match the path pattern for any cache behaviors, CloudFront applies the behavior in the default cache behavior.
         *  For more information, see [Path Pattern](https://docs.aws.amazon.com/AmazonCloudFront/latest/DeveloperGuide/distribution-web-values-specify.html#DownloadDistValuesPathPattern) in the *Amazon CloudFront Developer Guide*.
         */
        pathPattern: pulumi.Input<string>;
        /**
         * The Amazon Resource Name (ARN) of the real-time log configuration that is attached to this cache behavior. For more information, see [Real-time logs](https://docs.aws.amazon.com/AmazonCloudFront/latest/DeveloperGuide/real-time-logs.html) in the *Amazon CloudFront Developer Guide*.
         */
        realtimeLogConfigArn?: pulumi.Input<string>;
        /**
         * The identifier for a response headers policy.
         */
        responseHeadersPolicyId?: pulumi.Input<string>;
        /**
         * Indicates whether you want to distribute media files in the Microsoft Smooth Streaming format using the origin that is associated with this cache behavior. If so, specify ``true``; if not, specify ``false``. If you specify ``true`` for ``SmoothStreaming``, you can still distribute other content using this cache behavior if the content matches the value of ``PathPattern``.
         */
        smoothStreaming?: pulumi.Input<boolean>;
        /**
         * The value of ``ID`` for the origin that you want CloudFront to route requests to when they match this cache behavior.
         */
        targetOriginId: pulumi.Input<string>;
        /**
         * A list of key groups that CloudFront can use to validate signed URLs or signed cookies.
         *  When a cache behavior contains trusted key groups, CloudFront requires signed URLs or signed cookies for all requests that match the cache behavior. The URLs or cookies must be signed with a private key whose corresponding public key is in the key group. The signed URL or cookie contains information about which public key CloudFront should use to verify the signature. For more information, see [Serving private content](https://docs.aws.amazon.com/AmazonCloudFront/latest/DeveloperGuide/PrivateContent.html) in the *Amazon CloudFront Developer Guide*.
         */
        trustedKeyGroups?: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * We recommend using ``TrustedKeyGroups`` instead of ``TrustedSigners``.
         *   A list of AWS-account IDs whose public keys CloudFront can use to validate signed URLs or signed cookies.
         *  When a cache behavior contains trusted signers, CloudFront requires signed URLs or signed cookies for all requests that match the cache behavior. The URLs or cookies must be signed with the private key of a CloudFront key pair in the trusted signer's AWS-account. The signed URL or cookie contains information about which public key CloudFront should use to verify the signature. For more information, see [Serving private content](https://docs.aws.amazon.com/AmazonCloudFront/latest/DeveloperGuide/PrivateContent.html) in the *Amazon CloudFront Developer Guide*.
         */
        trustedSigners?: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * The protocol that viewers can use to access the files in the origin specified by ``TargetOriginId`` when a request matches the path pattern in ``PathPattern``. You can specify the following options:
         *   +   ``allow-all``: Viewers can use HTTP or HTTPS.
         *   +   ``redirect-to-https``: If a viewer submits an HTTP request, CloudFront returns an HTTP status code of 301 (Moved Permanently) to the viewer along with the HTTPS URL. The viewer then resubmits the request using the new URL.
         *   +   ``https-only``: If a viewer sends an HTTP request, CloudFront returns an HTTP status code of 403 (Forbidden).
         *
         *  For more information about requiring the HTTPS protocol, see [Requiring HTTPS Between Viewers and CloudFront](https://docs.aws.amazon.com/AmazonCloudFront/latest/DeveloperGuide/using-https-viewers-to-cloudfront.html) in the *Amazon CloudFront Developer Guide*.
         *   The only way to guarantee that viewers retrieve an object that was fetched from the origin using HTTPS is never to use any other protocol to fetch the object. If you have recently changed from HTTP to HTTPS, we recommend that you clear your objects' cache because cached objects are protocol agnostic. That means that an edge location will return an object from the cache regardless of whether the current request protocol matches the protocol used previously. For more information, see [Managing Cache Expiration](https://docs.aws.amazon.com/AmazonCloudFront/latest/DeveloperGuide/Expiration.html) in the *Amazon CloudFront Developer Guide*.
         */
        viewerProtocolPolicy: pulumi.Input<string>;
    }
    /**
     * A distribution configuration.
     */
    interface DistributionConfigArgs {
        /**
         * A complex type that contains information about CNAMEs (alternate domain names), if any, for this distribution.
         */
        aliases?: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * ID of the Anycast static IP list that is associated with the distribution.
         */
        anycastIpListId?: pulumi.Input<string>;
        /**
         * A complex type that contains zero or more ``CacheBehavior`` elements.
         */
        cacheBehaviors?: pulumi.Input<pulumi.Input<inputs.cloudfront.DistributionCacheBehaviorArgs>[]>;
        /**
         * An alias for the CF distribution's domain name.
         *   This property is legacy. We recommend that you use [Aliases](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-cloudfront-distribution-distributionconfig.html#cfn-cloudfront-distribution-distributionconfig-aliases) instead.
         */
        cnames?: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * A comment to describe the distribution. The comment cannot be longer than 128 characters.
         */
        comment?: pulumi.Input<string>;
        /**
         * The identifier of a continuous deployment policy. For more information, see ``CreateContinuousDeploymentPolicy``.
         */
        continuousDeploymentPolicyId?: pulumi.Input<string>;
        /**
         * A complex type that controls the following:
         *   +  Whether CloudFront replaces HTTP status codes in the 4xx and 5xx range with custom error messages before returning the response to the viewer.
         *   +  How long CloudFront caches HTTP status codes in the 4xx and 5xx range.
         *
         *  For more information about custom error pages, see [Customizing Error Responses](https://docs.aws.amazon.com/AmazonCloudFront/latest/DeveloperGuide/custom-error-pages.html) in the *Amazon CloudFront Developer Guide*.
         */
        customErrorResponses?: pulumi.Input<pulumi.Input<inputs.cloudfront.DistributionCustomErrorResponseArgs>[]>;
        /**
         * The user-defined HTTP server that serves as the origin for content that CF distributes.
         *   This property is legacy. We recommend that you use [Origin](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-cloudfront-distribution-origin.html) instead.
         */
        customOrigin?: pulumi.Input<inputs.cloudfront.DistributionLegacyCustomOriginArgs>;
        /**
         * A complex type that describes the default cache behavior if you don't specify a ``CacheBehavior`` element or if files don't match any of the values of ``PathPattern`` in ``CacheBehavior`` elements. You must create exactly one default cache behavior.
         */
        defaultCacheBehavior: pulumi.Input<inputs.cloudfront.DistributionDefaultCacheBehaviorArgs>;
        /**
         * When a viewer requests the root URL for your distribution, the default root object is the object that you want CloudFront to request from your origin. For example, if your root URL is ``https://www.example.com``, you can specify CloudFront to return the ``index.html`` file as the default root object. You can specify a default root object so that viewers see a specific file or object, instead of another object in your distribution (for example, ``https://www.example.com/product-description.html``). A default root object avoids exposing the contents of your distribution.
         *  You can specify the object name or a path to the object name (for example, ``index.html`` or ``exampleFolderName/index.html``). Your string can't begin with a forward slash (``/``). Only specify the object name or the path to the object.
         *  If you don't want to specify a default root object when you create a distribution, include an empty ``DefaultRootObject`` element.
         *  To delete the default root object from an existing distribution, update the distribution configuration and include an empty ``DefaultRootObject`` element.
         *  To replace the default root object, update the distribution configuration and specify the new object.
         *  For more information about the default root object, see [Specify a default root object](https://docs.aws.amazon.com/AmazonCloudFront/latest/DeveloperGuide/DefaultRootObject.html) in the *Amazon CloudFront Developer Guide*.
         */
        defaultRootObject?: pulumi.Input<string>;
        /**
         * From this field, you can enable or disable the selected distribution.
         */
        enabled: pulumi.Input<boolean>;
        /**
         * (Optional) Specify the HTTP version(s) that you want viewers to use to communicate with CF. The default value for new distributions is ``http1.1``.
         *  For viewers and CF to use HTTP/2, viewers must support TLSv1.2 or later, and must support Server Name Indication (SNI).
         *  For viewers and CF to use HTTP/3, viewers must support TLSv1.3 and Server Name Indication (SNI). CF supports HTTP/3 connection migration to allow the viewer to switch networks without losing connection. For more information about connection migration, see [Connection Migration](https://docs.aws.amazon.com/https://www.rfc-editor.org/rfc/rfc9000.html#name-connection-migration) at RFC 9000. For more information about supported TLSv1.3 ciphers, see [Supported protocols and ciphers between viewers and CloudFront](https://docs.aws.amazon.com/AmazonCloudFront/latest/DeveloperGuide/secure-connections-supported-viewer-protocols-ciphers.html).
         */
        httpVersion?: pulumi.Input<string>;
        /**
         * If you want CloudFront to respond to IPv6 DNS requests with an IPv6 address for your distribution, specify ``true``. If you specify ``false``, CloudFront responds to IPv6 DNS requests with the DNS response code ``NOERROR`` and with no IP addresses. This allows viewers to submit a second request, for an IPv4 address for your distribution.
         *  In general, you should enable IPv6 if you have users on IPv6 networks who want to access your content. However, if you're using signed URLs or signed cookies to restrict access to your content, and if you're using a custom policy that includes the ``IpAddress`` parameter to restrict the IP addresses that can access your content, don't enable IPv6. If you want to restrict access to some content by IP address and not restrict access to other content (or restrict access but not by IP address), you can create two distributions. For more information, see [Creating a Signed URL Using a Custom Policy](https://docs.aws.amazon.com/AmazonCloudFront/latest/DeveloperGuide/private-content-creating-signed-url-custom-policy.html) in the *Amazon CloudFront Developer Guide*.
         *  If you're using an R53AWSIntlong alias resource record set to route traffic to your CloudFront distribution, you need to create a second alias resource record set when both of the following are true:
         *   +  You enable IPv6 for the distribution
         *   +  You're using alternate domain names in the URLs for your objects
         *
         *  For more information, see [Routing Traffic to an Amazon CloudFront Web Distribution by Using Your Domain Name](https://docs.aws.amazon.com/Route53/latest/DeveloperGuide/routing-to-cloudfront-distribution.html) in the *Developer Guide*.
         *  If you created a CNAME resource record set, either with R53AWSIntlong or with another DNS service, you don't need to make any changes. A CNAME record will route traffic to your distribution regardless of the IP address format of the viewer request.
         */
        ipv6Enabled?: pulumi.Input<boolean>;
        /**
         * A complex type that controls whether access logs are written for the distribution.
         *  For more information about logging, see [Access Logs](https://docs.aws.amazon.com/AmazonCloudFront/latest/DeveloperGuide/AccessLogs.html) in the *Amazon CloudFront Developer Guide*.
         */
        logging?: pulumi.Input<inputs.cloudfront.DistributionLoggingArgs>;
        /**
         * A complex type that contains information about origin groups for this distribution.
         *  Specify a value for either the ``Origins`` or ``OriginGroups`` property.
         */
        originGroups?: pulumi.Input<inputs.cloudfront.DistributionOriginGroupsArgs>;
        /**
         * A complex type that contains information about origins for this distribution.
         *  Specify a value for either the ``Origins`` or ``OriginGroups`` property.
         */
        origins?: pulumi.Input<pulumi.Input<inputs.cloudfront.DistributionOriginArgs>[]>;
        /**
         * The price class that corresponds with the maximum price that you want to pay for CloudFront service. If you specify ``PriceClass_All``, CloudFront responds to requests for your objects from all CloudFront edge locations.
         *  If you specify a price class other than ``PriceClass_All``, CloudFront serves your objects from the CloudFront edge location that has the lowest latency among the edge locations in your price class. Viewers who are in or near regions that are excluded from your specified price class may encounter slower performance.
         *  For more information about price classes, see [Choosing the Price Class for a CloudFront Distribution](https://docs.aws.amazon.com/AmazonCloudFront/latest/DeveloperGuide/PriceClass.html) in the *Amazon CloudFront Developer Guide*. For information about CloudFront pricing, including how price classes (such as Price Class 100) map to CloudFront regions, see [Amazon CloudFront Pricing](https://docs.aws.amazon.com/cloudfront/pricing/).
         */
        priceClass?: pulumi.Input<string>;
        /**
         * A complex type that identifies ways in which you want to restrict distribution of your content.
         */
        restrictions?: pulumi.Input<inputs.cloudfront.DistributionRestrictionsArgs>;
        /**
         * The origin as an S3 bucket.
         *   This property is legacy. We recommend that you use [Origin](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-cloudfront-distribution-origin.html) instead.
         */
        s3Origin?: pulumi.Input<inputs.cloudfront.DistributionLegacyS3OriginArgs>;
        /**
         * A Boolean that indicates whether this is a staging distribution. When this value is ``true``, this is a staging distribution. When this value is ``false``, this is not a staging distribution.
         */
        staging?: pulumi.Input<boolean>;
        /**
         * A complex type that determines the distribution's SSL/TLS configuration for communicating with viewers.
         */
        viewerCertificate?: pulumi.Input<inputs.cloudfront.DistributionViewerCertificateArgs>;
        /**
         * A unique identifier that specifies the WAF web ACL, if any, to associate with this distribution. To specify a web ACL created using the latest version of WAF, use the ACL ARN, for example ``arn:aws:wafv2:us-east-1:123456789012:global/webacl/ExampleWebACL/a1b2c3d4-5678-90ab-cdef-EXAMPLE11111``. To specify a web ACL created using WAF Classic, use the ACL ID, for example ``a1b2c3d4-5678-90ab-cdef-EXAMPLE11111``.
         *   WAF is a web application firewall that lets you monitor the HTTP and HTTPS requests that are forwarded to CloudFront, and lets you control access to your content. Based on conditions that you specify, such as the IP addresses that requests originate from or the values of query strings, CloudFront responds to requests either with the requested content or with an HTTP 403 status code (Forbidden). You can also configure CloudFront to return a custom error page when a request is blocked. For more information about WAF, see the [Developer Guide](https://docs.aws.amazon.com/waf/latest/developerguide/what-is-aws-waf.html).
         */
        webAclId?: pulumi.Input<string>;
    }
    /**
     * This field is deprecated. We recommend that you use a cache policy or an origin request policy instead of this field.
     *  If you want to include cookies in the cache key, use a cache policy. For more information, see [Creating cache policies](https://docs.aws.amazon.com/AmazonCloudFront/latest/DeveloperGuide/controlling-the-cache-key.html#cache-key-create-cache-policy) in the *Amazon CloudFront Developer Guide*.
     *  If you want to send cookies to the origin but not include them in the cache key, use an origin request policy. For more information, see [Creating origin request policies](https://docs.aws.amazon.com/AmazonCloudFront/latest/DeveloperGuide/controlling-origin-requests.html#origin-request-create-origin-request-policy) in the *Amazon CloudFront Developer Guide*.
     *  A complex type that specifies whether you want CloudFront to forward cookies to the origin and, if so, which ones. For more information about forwarding cookies to the origin, see [How CloudFront Forwards, Caches, and Logs Cookies](https://docs.aws.amazon.com/AmazonCloudFront/latest/DeveloperGuide/Cookies.html) in the *Amazon CloudFront Developer Guide*.
     */
    interface DistributionCookiesArgs {
        /**
         * This field is deprecated. We recommend that you use a cache policy or an origin request policy instead of this field.
         *  If you want to include cookies in the cache key, use a cache policy. For more information, see [Creating cache policies](https://docs.aws.amazon.com/AmazonCloudFront/latest/DeveloperGuide/controlling-the-cache-key.html#cache-key-create-cache-policy) in the *Amazon CloudFront Developer Guide*.
         *  If you want to send cookies to the origin but not include them in the cache key, use origin request policy. For more information, see [Creating origin request policies](https://docs.aws.amazon.com/AmazonCloudFront/latest/DeveloperGuide/controlling-origin-requests.html#origin-request-create-origin-request-policy) in the *Amazon CloudFront Developer Guide*.
         *  Specifies which cookies to forward to the origin for this cache behavior: all, none, or the list of cookies specified in the ``WhitelistedNames`` complex type.
         *  Amazon S3 doesn't process cookies. When the cache behavior is forwarding requests to an Amazon S3 origin, specify none for the ``Forward`` element.
         */
        forward: pulumi.Input<string>;
        /**
         * This field is deprecated. We recommend that you use a cache policy or an origin request policy instead of this field.
         *  If you want to include cookies in the cache key, use a cache policy. For more information, see [Creating cache policies](https://docs.aws.amazon.com/AmazonCloudFront/latest/DeveloperGuide/controlling-the-cache-key.html#cache-key-create-cache-policy) in the *Amazon CloudFront Developer Guide*.
         *  If you want to send cookies to the origin but not include them in the cache key, use an origin request policy. For more information, see [Creating origin request policies](https://docs.aws.amazon.com/AmazonCloudFront/latest/DeveloperGuide/controlling-origin-requests.html#origin-request-create-origin-request-policy) in the *Amazon CloudFront Developer Guide*.
         *  Required if you specify ``whitelist`` for the value of ``Forward``. A complex type that specifies how many different cookies you want CloudFront to forward to the origin for this cache behavior and, if you want to forward selected cookies, the names of those cookies.
         *  If you specify ``all`` or ``none`` for the value of ``Forward``, omit ``WhitelistedNames``. If you change the value of ``Forward`` from ``whitelist`` to ``all`` or ``none`` and you don't delete the ``WhitelistedNames`` element and its child elements, CloudFront deletes them automatically.
         *  For the current limit on the number of cookie names that you can whitelist for each cache behavior, see [CloudFront Limits](https://docs.aws.amazon.com/general/latest/gr/xrefaws_service_limits.html#limits_cloudfront) in the *General Reference*.
         */
        whitelistedNames?: pulumi.Input<pulumi.Input<string>[]>;
    }
    /**
     * A complex type that controls:
     *   +  Whether CloudFront replaces HTTP status codes in the 4xx and 5xx range with custom error messages before returning the response to the viewer.
     *   +  How long CloudFront caches HTTP status codes in the 4xx and 5xx range.
     *
     *  For more information about custom error pages, see [Customizing Error Responses](https://docs.aws.amazon.com/AmazonCloudFront/latest/DeveloperGuide/custom-error-pages.html) in the *Amazon CloudFront Developer Guide*.
     */
    interface DistributionCustomErrorResponseArgs {
        /**
         * The minimum amount of time, in seconds, that you want CloudFront to cache the HTTP status code specified in ``ErrorCode``. When this time period has elapsed, CloudFront queries your origin to see whether the problem that caused the error has been resolved and the requested object is now available.
         *  For more information, see [Customizing Error Responses](https://docs.aws.amazon.com/AmazonCloudFront/latest/DeveloperGuide/custom-error-pages.html) in the *Amazon CloudFront Developer Guide*.
         */
        errorCachingMinTtl?: pulumi.Input<number>;
        /**
         * The HTTP status code for which you want to specify a custom error page and/or a caching duration.
         */
        errorCode: pulumi.Input<number>;
        /**
         * The HTTP status code that you want CloudFront to return to the viewer along with the custom error page. There are a variety of reasons that you might want CloudFront to return a status code different from the status code that your origin returned to CloudFront, for example:
         *   +  Some Internet devices (some firewalls and corporate proxies, for example) intercept HTTP 4xx and 5xx and prevent the response from being returned to the viewer. If you substitute ``200``, the response typically won't be intercepted.
         *   +  If you don't care about distinguishing among different client errors or server errors, you can specify ``400`` or ``500`` as the ``ResponseCode`` for all 4xx or 5xx errors.
         *   +  You might want to return a ``200`` status code (OK) and static website so your customers don't know that your website is down.
         *
         *  If you specify a value for ``ResponseCode``, you must also specify a value for ``ResponsePagePath``.
         */
        responseCode?: pulumi.Input<number>;
        /**
         * The path to the custom error page that you want CloudFront to return to a viewer when your origin returns the HTTP status code specified by ``ErrorCode``, for example, ``/4xx-errors/403-forbidden.html``. If you want to store your objects and your custom error pages in different locations, your distribution must include a cache behavior for which the following is true:
         *   +  The value of ``PathPattern`` matches the path to your custom error messages. For example, suppose you saved custom error pages for 4xx errors in an Amazon S3 bucket in a directory named ``/4xx-errors``. Your distribution must include a cache behavior for which the path pattern routes requests for your custom error pages to that location, for example, ``/4xx-errors/*``.
         *   +  The value of ``TargetOriginId`` specifies the value of the ``ID`` element for the origin that contains your custom error pages.
         *
         *  If you specify a value for ``ResponsePagePath``, you must also specify a value for ``ResponseCode``.
         *  We recommend that you store custom error pages in an Amazon S3 bucket. If you store custom error pages on an HTTP server and the server starts to return 5xx errors, CloudFront can't get the files that you want to return to viewers because the origin server is unavailable.
         */
        responsePagePath?: pulumi.Input<string>;
    }
    /**
     * A custom origin. A custom origin is any origin that is *not* an Amazon S3 bucket, with one exception. An Amazon S3 bucket that is [configured with static website hosting](https://docs.aws.amazon.com/AmazonS3/latest/dev/WebsiteHosting.html) *is* a custom origin.
     */
    interface DistributionCustomOriginConfigArgs {
        /**
         * The HTTP port that CloudFront uses to connect to the origin. Specify the HTTP port that the origin listens on.
         */
        httpPort?: pulumi.Input<number>;
        /**
         * The HTTPS port that CloudFront uses to connect to the origin. Specify the HTTPS port that the origin listens on.
         */
        httpsPort?: pulumi.Input<number>;
        /**
         * Specifies how long, in seconds, CloudFront persists its connection to the origin. The minimum timeout is 1 second, the maximum is 60 seconds, and the default (if you don't specify otherwise) is 5 seconds.
         *  For more information, see [Keep-alive timeout (custom origins only)](https://docs.aws.amazon.com/AmazonCloudFront/latest/DeveloperGuide/distribution-web-values-specify.html#DownloadDistValuesOriginKeepaliveTimeout) in the *Amazon CloudFront Developer Guide*.
         */
        originKeepaliveTimeout?: pulumi.Input<number>;
        /**
         * Specifies the protocol (HTTP or HTTPS) that CloudFront uses to connect to the origin. Valid values are:
         *   +   ``http-only`` – CloudFront always uses HTTP to connect to the origin.
         *   +   ``match-viewer`` – CloudFront connects to the origin using the same protocol that the viewer used to connect to CloudFront.
         *   +   ``https-only`` – CloudFront always uses HTTPS to connect to the origin.
         */
        originProtocolPolicy: pulumi.Input<string>;
        /**
         * Specifies how long, in seconds, CloudFront waits for a response from the origin. This is also known as the *origin response timeout*. The minimum timeout is 1 second, the maximum is 60 seconds, and the default (if you don't specify otherwise) is 30 seconds.
         *  For more information, see [Response timeout (custom origins only)](https://docs.aws.amazon.com/AmazonCloudFront/latest/DeveloperGuide/distribution-web-values-specify.html#DownloadDistValuesOriginResponseTimeout) in the *Amazon CloudFront Developer Guide*.
         */
        originReadTimeout?: pulumi.Input<number>;
        /**
         * Specifies the minimum SSL/TLS protocol that CloudFront uses when connecting to your origin over HTTPS. Valid values include ``SSLv3``, ``TLSv1``, ``TLSv1.1``, and ``TLSv1.2``.
         *  For more information, see [Minimum Origin SSL Protocol](https://docs.aws.amazon.com/AmazonCloudFront/latest/DeveloperGuide/distribution-web-values-specify.html#DownloadDistValuesOriginSSLProtocols) in the *Amazon CloudFront Developer Guide*.
         */
        originSslProtocols?: pulumi.Input<pulumi.Input<string>[]>;
    }
    /**
     * A complex type that describes the default cache behavior if you don't specify a ``CacheBehavior`` element or if request URLs don't match any of the values of ``PathPattern`` in ``CacheBehavior`` elements. You must create exactly one default cache behavior.
     */
    interface DistributionDefaultCacheBehaviorArgs {
        /**
         * A complex type that controls which HTTP methods CloudFront processes and forwards to your Amazon S3 bucket or your custom origin. There are three choices:
         *   +  CloudFront forwards only ``GET`` and ``HEAD`` requests.
         *   +  CloudFront forwards only ``GET``, ``HEAD``, and ``OPTIONS`` requests.
         *   +  CloudFront forwards ``GET, HEAD, OPTIONS, PUT, PATCH, POST``, and ``DELETE`` requests.
         *
         *  If you pick the third choice, you may need to restrict access to your Amazon S3 bucket or to your custom origin so users can't perform operations that you don't want them to. For example, you might not want users to have permissions to delete objects from your origin.
         */
        allowedMethods?: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * The unique identifier of the cache policy that is attached to the default cache behavior. For more information, see [Creating cache policies](https://docs.aws.amazon.com/AmazonCloudFront/latest/DeveloperGuide/controlling-the-cache-key.html#cache-key-create-cache-policy) or [Using the managed cache policies](https://docs.aws.amazon.com/AmazonCloudFront/latest/DeveloperGuide/using-managed-cache-policies.html) in the *Amazon CloudFront Developer Guide*.
         *  A ``DefaultCacheBehavior`` must include either a ``CachePolicyId`` or ``ForwardedValues``. We recommend that you use a ``CachePolicyId``.
         */
        cachePolicyId?: pulumi.Input<string>;
        /**
         * A complex type that controls whether CloudFront caches the response to requests using the specified HTTP methods. There are two choices:
         *   +  CloudFront caches responses to ``GET`` and ``HEAD`` requests.
         *   +  CloudFront caches responses to ``GET``, ``HEAD``, and ``OPTIONS`` requests.
         *
         *  If you pick the second choice for your Amazon S3 Origin, you may need to forward Access-Control-Request-Method, Access-Control-Request-Headers, and Origin headers for the responses to be cached correctly.
         */
        cachedMethods?: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * Whether you want CloudFront to automatically compress certain files for this cache behavior. If so, specify ``true``; if not, specify ``false``. For more information, see [Serving Compressed Files](https://docs.aws.amazon.com/AmazonCloudFront/latest/DeveloperGuide/ServingCompressedFiles.html) in the *Amazon CloudFront Developer Guide*.
         */
        compress?: pulumi.Input<boolean>;
        /**
         * This field is deprecated. We recommend that you use the ``DefaultTTL`` field in a cache policy instead of this field. For more information, see [Creating cache policies](https://docs.aws.amazon.com/AmazonCloudFront/latest/DeveloperGuide/controlling-the-cache-key.html#cache-key-create-cache-policy) or [Using the managed cache policies](https://docs.aws.amazon.com/AmazonCloudFront/latest/DeveloperGuide/using-managed-cache-policies.html) in the *Amazon CloudFront Developer Guide*.
         *  The default amount of time that you want objects to stay in CloudFront caches before CloudFront forwards another request to your origin to determine whether the object has been updated. The value that you specify applies only when your origin does not add HTTP headers such as ``Cache-Control max-age``, ``Cache-Control s-maxage``, and ``Expires`` to objects. For more information, see [Managing How Long Content Stays in an Edge Cache (Expiration)](https://docs.aws.amazon.com/AmazonCloudFront/latest/DeveloperGuide/Expiration.html) in the *Amazon CloudFront Developer Guide*.
         */
        defaultTtl?: pulumi.Input<number>;
        /**
         * The value of ``ID`` for the field-level encryption configuration that you want CloudFront to use for encrypting specific fields of data for the default cache behavior.
         */
        fieldLevelEncryptionId?: pulumi.Input<string>;
        /**
         * This field is deprecated. We recommend that you use a cache policy or an origin request policy instead of this field. For more information, see [Working with policies](https://docs.aws.amazon.com/AmazonCloudFront/latest/DeveloperGuide/working-with-policies.html) in the *Amazon CloudFront Developer Guide*.
         *  If you want to include values in the cache key, use a cache policy. For more information, see [Creating cache policies](https://docs.aws.amazon.com/AmazonCloudFront/latest/DeveloperGuide/controlling-the-cache-key.html#cache-key-create-cache-policy) or [Using the managed cache policies](https://docs.aws.amazon.com/AmazonCloudFront/latest/DeveloperGuide/using-managed-cache-policies.html) in the *Amazon CloudFront Developer Guide*.
         *  If you want to send values to the origin but not include them in the cache key, use an origin request policy. For more information, see [Creating origin request policies](https://docs.aws.amazon.com/AmazonCloudFront/latest/DeveloperGuide/controlling-origin-requests.html#origin-request-create-origin-request-policy) or [Using the managed origin request policies](https://docs.aws.amazon.com/AmazonCloudFront/latest/DeveloperGuide/using-managed-origin-request-policies.html) in the *Amazon CloudFront Developer Guide*.
         *  A ``DefaultCacheBehavior`` must include either a ``CachePolicyId`` or ``ForwardedValues``. We recommend that you use a ``CachePolicyId``.
         *  A complex type that specifies how CloudFront handles query strings, cookies, and HTTP headers.
         */
        forwardedValues?: pulumi.Input<inputs.cloudfront.DistributionForwardedValuesArgs>;
        /**
         * A list of CloudFront functions that are associated with this cache behavior. Your functions must be published to the ``LIVE`` stage to associate them with a cache behavior.
         */
        functionAssociations?: pulumi.Input<pulumi.Input<inputs.cloudfront.DistributionFunctionAssociationArgs>[]>;
        /**
         * The gRPC configuration for your cache behavior.
         */
        grpcConfig?: pulumi.Input<inputs.cloudfront.DistributionGrpcConfigArgs>;
        /**
         * A complex type that contains zero or more Lambda@Edge function associations for a cache behavior.
         */
        lambdaFunctionAssociations?: pulumi.Input<pulumi.Input<inputs.cloudfront.DistributionLambdaFunctionAssociationArgs>[]>;
        /**
         * This field is deprecated. We recommend that you use the ``MaxTTL`` field in a cache policy instead of this field. For more information, see [Creating cache policies](https://docs.aws.amazon.com/AmazonCloudFront/latest/DeveloperGuide/controlling-the-cache-key.html#cache-key-create-cache-policy) or [Using the managed cache policies](https://docs.aws.amazon.com/AmazonCloudFront/latest/DeveloperGuide/using-managed-cache-policies.html) in the *Amazon CloudFront Developer Guide*.
         *  The maximum amount of time that you want objects to stay in CloudFront caches before CloudFront forwards another request to your origin to determine whether the object has been updated. The value that you specify applies only when your origin adds HTTP headers such as ``Cache-Control max-age``, ``Cache-Control s-maxage``, and ``Expires`` to objects. For more information, see [Managing How Long Content Stays in an Edge Cache (Expiration)](https://docs.aws.amazon.com/AmazonCloudFront/latest/DeveloperGuide/Expiration.html) in the *Amazon CloudFront Developer Guide*.
         */
        maxTtl?: pulumi.Input<number>;
        /**
         * This field is deprecated. We recommend that you use the ``MinTTL`` field in a cache policy instead of this field. For more information, see [Creating cache policies](https://docs.aws.amazon.com/AmazonCloudFront/latest/DeveloperGuide/controlling-the-cache-key.html#cache-key-create-cache-policy) or [Using the managed cache policies](https://docs.aws.amazon.com/AmazonCloudFront/latest/DeveloperGuide/using-managed-cache-policies.html) in the *Amazon CloudFront Developer Guide*.
         *  The minimum amount of time that you want objects to stay in CloudFront caches before CloudFront forwards another request to your origin to determine whether the object has been updated. For more information, see [Managing How Long Content Stays in an Edge Cache (Expiration)](https://docs.aws.amazon.com/AmazonCloudFront/latest/DeveloperGuide/Expiration.html) in the *Amazon CloudFront Developer Guide*.
         *  You must specify ``0`` for ``MinTTL`` if you configure CloudFront to forward all headers to your origin (under ``Headers``, if you specify ``1`` for ``Quantity`` and ``*`` for ``Name``).
         */
        minTtl?: pulumi.Input<number>;
        /**
         * The unique identifier of the origin request policy that is attached to the default cache behavior. For more information, see [Creating origin request policies](https://docs.aws.amazon.com/AmazonCloudFront/latest/DeveloperGuide/controlling-origin-requests.html#origin-request-create-origin-request-policy) or [Using the managed origin request policies](https://docs.aws.amazon.com/AmazonCloudFront/latest/DeveloperGuide/using-managed-origin-request-policies.html) in the *Amazon CloudFront Developer Guide*.
         */
        originRequestPolicyId?: pulumi.Input<string>;
        /**
         * The Amazon Resource Name (ARN) of the real-time log configuration that is attached to this cache behavior. For more information, see [Real-time logs](https://docs.aws.amazon.com/AmazonCloudFront/latest/DeveloperGuide/real-time-logs.html) in the *Amazon CloudFront Developer Guide*.
         */
        realtimeLogConfigArn?: pulumi.Input<string>;
        /**
         * The identifier for a response headers policy.
         */
        responseHeadersPolicyId?: pulumi.Input<string>;
        /**
         * Indicates whether you want to distribute media files in the Microsoft Smooth Streaming format using the origin that is associated with this cache behavior. If so, specify ``true``; if not, specify ``false``. If you specify ``true`` for ``SmoothStreaming``, you can still distribute other content using this cache behavior if the content matches the value of ``PathPattern``.
         */
        smoothStreaming?: pulumi.Input<boolean>;
        /**
         * The value of ``ID`` for the origin that you want CloudFront to route requests to when they use the default cache behavior.
         */
        targetOriginId: pulumi.Input<string>;
        /**
         * A list of key groups that CloudFront can use to validate signed URLs or signed cookies.
         *  When a cache behavior contains trusted key groups, CloudFront requires signed URLs or signed cookies for all requests that match the cache behavior. The URLs or cookies must be signed with a private key whose corresponding public key is in the key group. The signed URL or cookie contains information about which public key CloudFront should use to verify the signature. For more information, see [Serving private content](https://docs.aws.amazon.com/AmazonCloudFront/latest/DeveloperGuide/PrivateContent.html) in the *Amazon CloudFront Developer Guide*.
         */
        trustedKeyGroups?: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * We recommend using ``TrustedKeyGroups`` instead of ``TrustedSigners``.
         *   A list of AWS-account IDs whose public keys CloudFront can use to validate signed URLs or signed cookies.
         *  When a cache behavior contains trusted signers, CloudFront requires signed URLs or signed cookies for all requests that match the cache behavior. The URLs or cookies must be signed with the private key of a CloudFront key pair in a trusted signer's AWS-account. The signed URL or cookie contains information about which public key CloudFront should use to verify the signature. For more information, see [Serving private content](https://docs.aws.amazon.com/AmazonCloudFront/latest/DeveloperGuide/PrivateContent.html) in the *Amazon CloudFront Developer Guide*.
         */
        trustedSigners?: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * The protocol that viewers can use to access the files in the origin specified by ``TargetOriginId`` when a request matches the path pattern in ``PathPattern``. You can specify the following options:
         *   +   ``allow-all``: Viewers can use HTTP or HTTPS.
         *   +   ``redirect-to-https``: If a viewer submits an HTTP request, CloudFront returns an HTTP status code of 301 (Moved Permanently) to the viewer along with the HTTPS URL. The viewer then resubmits the request using the new URL.
         *   +   ``https-only``: If a viewer sends an HTTP request, CloudFront returns an HTTP status code of 403 (Forbidden).
         *
         *  For more information about requiring the HTTPS protocol, see [Requiring HTTPS Between Viewers and CloudFront](https://docs.aws.amazon.com/AmazonCloudFront/latest/DeveloperGuide/using-https-viewers-to-cloudfront.html) in the *Amazon CloudFront Developer Guide*.
         *   The only way to guarantee that viewers retrieve an object that was fetched from the origin using HTTPS is never to use any other protocol to fetch the object. If you have recently changed from HTTP to HTTPS, we recommend that you clear your objects' cache because cached objects are protocol agnostic. That means that an edge location will return an object from the cache regardless of whether the current request protocol matches the protocol used previously. For more information, see [Managing Cache Expiration](https://docs.aws.amazon.com/AmazonCloudFront/latest/DeveloperGuide/Expiration.html) in the *Amazon CloudFront Developer Guide*.
         */
        viewerProtocolPolicy: pulumi.Input<string>;
    }
    /**
     * This field is deprecated. We recommend that you use a cache policy or an origin request policy instead of this field.
     *  If you want to include values in the cache key, use a cache policy. For more information, see [Creating cache policies](https://docs.aws.amazon.com/AmazonCloudFront/latest/DeveloperGuide/controlling-the-cache-key.html#cache-key-create-cache-policy) in the *Amazon CloudFront Developer Guide*.
     *  If you want to send values to the origin but not include them in the cache key, use an origin request policy. For more information, see [Creating origin request policies](https://docs.aws.amazon.com/AmazonCloudFront/latest/DeveloperGuide/controlling-origin-requests.html#origin-request-create-origin-request-policy) in the *Amazon CloudFront Developer Guide*.
     *  A complex type that specifies how CloudFront handles query strings, cookies, and HTTP headers.
     */
    interface DistributionForwardedValuesArgs {
        /**
         * This field is deprecated. We recommend that you use a cache policy or an origin request policy instead of this field.
         *  If you want to include cookies in the cache key, use a cache policy. For more information, see [Creating cache policies](https://docs.aws.amazon.com/AmazonCloudFront/latest/DeveloperGuide/controlling-the-cache-key.html#cache-key-create-cache-policy) in the *Amazon CloudFront Developer Guide*.
         *  If you want to send cookies to the origin but not include them in the cache key, use an origin request policy. For more information, see [Creating origin request policies](https://docs.aws.amazon.com/AmazonCloudFront/latest/DeveloperGuide/controlling-origin-requests.html#origin-request-create-origin-request-policy) in the *Amazon CloudFront Developer Guide*.
         *  A complex type that specifies whether you want CloudFront to forward cookies to the origin and, if so, which ones. For more information about forwarding cookies to the origin, see [How CloudFront Forwards, Caches, and Logs Cookies](https://docs.aws.amazon.com/AmazonCloudFront/latest/DeveloperGuide/Cookies.html) in the *Amazon CloudFront Developer Guide*.
         */
        cookies?: pulumi.Input<inputs.cloudfront.DistributionCookiesArgs>;
        /**
         * This field is deprecated. We recommend that you use a cache policy or an origin request policy instead of this field.
         *  If you want to include headers in the cache key, use a cache policy. For more information, see [Creating cache policies](https://docs.aws.amazon.com/AmazonCloudFront/latest/DeveloperGuide/controlling-the-cache-key.html#cache-key-create-cache-policy) in the *Amazon CloudFront Developer Guide*.
         *  If you want to send headers to the origin but not include them in the cache key, use an origin request policy. For more information, see [Creating origin request policies](https://docs.aws.amazon.com/AmazonCloudFront/latest/DeveloperGuide/controlling-origin-requests.html#origin-request-create-origin-request-policy) in the *Amazon CloudFront Developer Guide*.
         *  A complex type that specifies the ``Headers``, if any, that you want CloudFront to forward to the origin for this cache behavior (whitelisted headers). For the headers that you specify, CloudFront also caches separate versions of a specified object that is based on the header values in viewer requests.
         *  For more information, see [Caching Content Based on Request Headers](https://docs.aws.amazon.com/AmazonCloudFront/latest/DeveloperGuide/header-caching.html) in the *Amazon CloudFront Developer Guide*.
         */
        headers?: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * This field is deprecated. We recommend that you use a cache policy or an origin request policy instead of this field.
         *  If you want to include query strings in the cache key, use a cache policy. For more information, see [Creating cache policies](https://docs.aws.amazon.com/AmazonCloudFront/latest/DeveloperGuide/controlling-the-cache-key.html#cache-key-create-cache-policy) in the *Amazon CloudFront Developer Guide*.
         *  If you want to send query strings to the origin but not include them in the cache key, use an origin request policy. For more information, see [Creating origin request policies](https://docs.aws.amazon.com/AmazonCloudFront/latest/DeveloperGuide/controlling-origin-requests.html#origin-request-create-origin-request-policy) in the *Amazon CloudFront Developer Guide*.
         *  Indicates whether you want CloudFront to forward query strings to the origin that is associated with this cache behavior and cache based on the query string parameters. CloudFront behavior depends on the value of ``QueryString`` and on the values that you specify for ``QueryStringCacheKeys``, if any:
         *  If you specify true for ``QueryString`` and you don't specify any values for ``QueryStringCacheKeys``, CloudFront forwards all query string parameters to the origin and caches based on all query string parameters. Depending on how many query string parameters and values you have, this can adversely affect performance because CloudFront must forward more requests to the origin.
         *  If you specify true for ``QueryString`` and you specify one or more values for ``QueryStringCacheKeys``, CloudFront forwards all query string parameters to the origin, but it only caches based on the query string parameters that you specify.
         *  If you specify false for ``QueryString``, CloudFront doesn't forward any query string parameters to the origin, and doesn't cache based on query string parameters.
         *  For more information, see [Configuring CloudFront to Cache Based on Query String Parameters](https://docs.aws.amazon.com/AmazonCloudFront/latest/DeveloperGuide/QueryStringParameters.html) in the *Amazon CloudFront Developer Guide*.
         */
        queryString: pulumi.Input<boolean>;
        /**
         * This field is deprecated. We recommend that you use a cache policy or an origin request policy instead of this field.
         *  If you want to include query strings in the cache key, use a cache policy. For more information, see [Creating cache policies](https://docs.aws.amazon.com/AmazonCloudFront/latest/DeveloperGuide/controlling-the-cache-key.html#cache-key-create-cache-policy) in the *Amazon CloudFront Developer Guide*.
         *  If you want to send query strings to the origin but not include them in the cache key, use an origin request policy. For more information, see [Creating origin request policies](https://docs.aws.amazon.com/AmazonCloudFront/latest/DeveloperGuide/controlling-origin-requests.html#origin-request-create-origin-request-policy) in the *Amazon CloudFront Developer Guide*.
         *  A complex type that contains information about the query string parameters that you want CloudFront to use for caching for this cache behavior.
         */
        queryStringCacheKeys?: pulumi.Input<pulumi.Input<string>[]>;
    }
    /**
     * A CloudFront function that is associated with a cache behavior in a CloudFront distribution.
     */
    interface DistributionFunctionAssociationArgs {
        /**
         * The event type of the function, either ``viewer-request`` or ``viewer-response``. You cannot use origin-facing event types (``origin-request`` and ``origin-response``) with a CloudFront function.
         */
        eventType?: pulumi.Input<string>;
        /**
         * The Amazon Resource Name (ARN) of the function.
         */
        functionArn?: pulumi.Input<string>;
    }
    /**
     * A complex type that controls the countries in which your content is distributed. CF determines the location of your users using ``MaxMind`` GeoIP databases. To disable geo restriction, remove the [Restrictions](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-cloudfront-distribution-distributionconfig.html#cfn-cloudfront-distribution-distributionconfig-restrictions) property from your stack template.
     */
    interface DistributionGeoRestrictionArgs {
        /**
         * A complex type that contains a ``Location`` element for each country in which you want CloudFront either to distribute your content (``whitelist``) or not distribute your content (``blacklist``).
         *  The ``Location`` element is a two-letter, uppercase country code for a country that you want to include in your ``blacklist`` or ``whitelist``. Include one ``Location`` element for each country.
         *  CloudFront and ``MaxMind`` both use ``ISO 3166`` country codes. For the current list of countries and the corresponding codes, see ``ISO 3166-1-alpha-2`` code on the *International Organization for Standardization* website. You can also refer to the country list on the CloudFront console, which includes both country names and codes.
         */
        locations?: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * The method that you want to use to restrict distribution of your content by country:
         *   +   ``none``: No geo restriction is enabled, meaning access to content is not restricted by client geo location.
         *   +   ``blacklist``: The ``Location`` elements specify the countries in which you don't want CloudFront to distribute your content.
         *   +   ``whitelist``: The ``Location`` elements specify the countries in which you want CloudFront to distribute your content.
         */
        restrictionType: pulumi.Input<string>;
    }
    /**
     * Amazon CloudFront supports gRPC, an open-source remote procedure call (RPC) framework built on HTTP/2. gRPC offers bi-directional streaming and binary protocol that buffers payloads, making it suitable for applications that require low latency communications.
     *  To enable your distribution to handle gRPC requests, you must include HTTP/2 as one of the supported ``HTTP`` versions and allow ``HTTP`` methods, including ``POST``.
     *  For more information, see [Using gRPC with CloudFront distributions](https://docs.aws.amazon.com/AmazonCloudFront/latest/DeveloperGuide/distribution-using-grpc.html) in the *Amazon CloudFront Developer Guide*.
     */
    interface DistributionGrpcConfigArgs {
        /**
         * Enables your CloudFront distribution to receive gRPC requests and to proxy them directly to your origins.
         */
        enabled: pulumi.Input<boolean>;
    }
    /**
     * A complex type that contains a Lambda@Edge function association.
     */
    interface DistributionLambdaFunctionAssociationArgs {
        /**
         * Specifies the event type that triggers a Lambda@Edge function invocation. You can specify the following values:
         *   +   ``viewer-request``: The function executes when CloudFront receives a request from a viewer and before it checks to see whether the requested object is in the edge cache.
         *   +   ``origin-request``: The function executes only when CloudFront sends a request to your origin. When the requested object is in the edge cache, the function doesn't execute.
         *   +   ``origin-response``: The function executes after CloudFront receives a response from the origin and before it caches the object in the response. When the requested object is in the edge cache, the function doesn't execute.
         *   +   ``viewer-response``: The function executes before CloudFront returns the requested object to the viewer. The function executes regardless of whether the object was already in the edge cache.
         *  If the origin returns an HTTP status code other than HTTP 200 (OK), the function doesn't execute.
         */
        eventType?: pulumi.Input<string>;
        /**
         * A flag that allows a Lambda@Edge function to have read access to the body content. For more information, see [Accessing the Request Body by Choosing the Include Body Option](https://docs.aws.amazon.com/AmazonCloudFront/latest/DeveloperGuide/lambda-include-body-access.html) in the Amazon CloudFront Developer Guide.
         */
        includeBody?: pulumi.Input<boolean>;
        /**
         * The ARN of the Lambda@Edge function. You must specify the ARN of a function version; you can't specify an alias or $LATEST.
         */
        lambdaFunctionArn?: pulumi.Input<string>;
    }
    /**
     * A custom origin. A custom origin is any origin that is *not* an S3 bucket, with one exception. An S3 bucket that is [configured with static website hosting](https://docs.aws.amazon.com/AmazonS3/latest/dev/WebsiteHosting.html) *is* a custom origin.
     *   This property is legacy. We recommend that you use [Origin](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-cloudfront-distribution-origin.html) instead.
     */
    interface DistributionLegacyCustomOriginArgs {
        /**
         * The domain name assigned to your CF distribution.
         */
        dnsName: pulumi.Input<string>;
        /**
         * The HTTP port that CF uses to connect to the origin. Specify the HTTP port that the origin listens on.
         */
        httpPort?: pulumi.Input<number>;
        /**
         * The HTTPS port that CF uses to connect to the origin. Specify the HTTPS port that the origin listens on.
         */
        httpsPort?: pulumi.Input<number>;
        /**
         * Specifies the protocol (HTTP or HTTPS) that CF uses to connect to the origin.
         */
        originProtocolPolicy: pulumi.Input<string>;
        /**
         * The minimum SSL/TLS protocol version that CF uses when communicating with your origin server over HTTPs.
         *  For more information, see [Minimum Origin SSL Protocol](https://docs.aws.amazon.com/AmazonCloudFront/latest/DeveloperGuide/distribution-web-values-specify.html#DownloadDistValuesOriginSSLProtocols) in the *Developer Guide*.
         */
        originSslProtocols: pulumi.Input<pulumi.Input<string>[]>;
    }
    /**
     * The origin as an S3 bucket.
     *   This property is legacy. We recommend that you use [Origin](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-cloudfront-distribution-origin.html) instead.
     */
    interface DistributionLegacyS3OriginArgs {
        /**
         * The domain name assigned to your CF distribution.
         */
        dnsName: pulumi.Input<string>;
        /**
         * The CF origin access identity to associate with the distribution. Use an origin access identity to configure the distribution so that end users can only access objects in an S3 through CF.
         *   This property is legacy. We recommend that you use [OriginAccessControl](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-cloudfront-originaccesscontrol.html) instead.
         */
        originAccessIdentity?: pulumi.Input<string>;
    }
    /**
     * A complex type that specifies whether access logs are written for the distribution.
     *   If you already enabled standard logging (legacy) and you want to enable standard logging (v2) to send your access logs to Amazon S3, we recommend that you specify a *different* Amazon S3 bucket or use a *separate path* in the same bucket (for example, use a log prefix or partitioning). This helps you keep track of which log files are associated with which logging subscription and prevents log files from overwriting each other. For more information, see [Standard logging (access logs)](https://docs.aws.amazon.com/AmazonCloudFront/latest/DeveloperGuide/AccessLogs.html) in the *Amazon CloudFront Developer Guide*.
     */
    interface DistributionLoggingArgs {
        /**
         * The Amazon S3 bucket to store the access logs in, for example, ``amzn-s3-demo-bucket.s3.amazonaws.com``.
         */
        bucket?: pulumi.Input<string>;
        /**
         * Specifies whether you want CloudFront to include cookies in access logs, specify ``true`` for ``IncludeCookies``. If you choose to include cookies in logs, CloudFront logs all cookies regardless of how you configure the cache behaviors for this distribution. If you don't want to include cookies when you create a distribution or if you want to disable include cookies for an existing distribution, specify ``false`` for ``IncludeCookies``.
         */
        includeCookies?: pulumi.Input<boolean>;
        /**
         * An optional string that you want CloudFront to prefix to the access log ``filenames`` for this distribution, for example, ``myprefix/``. If you want to enable logging, but you don't want to specify a prefix, you still must include an empty ``Prefix`` element in the ``Logging`` element.
         */
        prefix?: pulumi.Input<string>;
    }
    /**
     * An origin.
     *  An origin is the location where content is stored, and from which CloudFront gets content to serve to viewers. To specify an origin:
     *   +  Use ``S3OriginConfig`` to specify an Amazon S3 bucket that is not configured with static website hosting.
     *   +  Use ``VpcOriginConfig`` to specify a VPC origin.
     *   +  Use ``CustomOriginConfig`` to specify all other kinds of origins, including:
     *   +  An Amazon S3 bucket that is configured with static website hosting
     *   +  An Elastic Load Balancing load balancer
     *   +  An EMPlong endpoint
     *   +  An EMSlong container
     *   +  Any other HTTP server, running on an Amazon EC2 instance or any other kind of host
     *
     *
     *  For the current maximum number of origins that you can specify per distribution, see [General Quotas on Web Distributions](https://docs.aws.amazon.com/AmazonCloudFront/latest/DeveloperGuide/cloudfront-limits.html#limits-web-distributions) in the *Amazon CloudFront Developer Guide* (quotas were formerly referred to as limits).
     */
    interface DistributionOriginArgs {
        /**
         * The number of times that CloudFront attempts to connect to the origin. The minimum number is 1, the maximum is 3, and the default (if you don't specify otherwise) is 3.
         *  For a custom origin (including an Amazon S3 bucket that's configured with static website hosting), this value also specifies the number of times that CloudFront attempts to get a response from the origin, in the case of an [Origin Response Timeout](https://docs.aws.amazon.com/AmazonCloudFront/latest/DeveloperGuide/distribution-web-values-specify.html#DownloadDistValuesOriginResponseTimeout).
         *  For more information, see [Origin Connection Attempts](https://docs.aws.amazon.com/AmazonCloudFront/latest/DeveloperGuide/distribution-web-values-specify.html#origin-connection-attempts) in the *Amazon CloudFront Developer Guide*.
         */
        connectionAttempts?: pulumi.Input<number>;
        /**
         * The number of seconds that CloudFront waits when trying to establish a connection to the origin. The minimum timeout is 1 second, the maximum is 10 seconds, and the default (if you don't specify otherwise) is 10 seconds.
         *  For more information, see [Origin Connection Timeout](https://docs.aws.amazon.com/AmazonCloudFront/latest/DeveloperGuide/distribution-web-values-specify.html#origin-connection-timeout) in the *Amazon CloudFront Developer Guide*.
         */
        connectionTimeout?: pulumi.Input<number>;
        /**
         * Use this type to specify an origin that is not an Amazon S3 bucket, with one exception. If the Amazon S3 bucket is configured with static website hosting, use this type. If the Amazon S3 bucket is not configured with static website hosting, use the ``S3OriginConfig`` type instead.
         */
        customOriginConfig?: pulumi.Input<inputs.cloudfront.DistributionCustomOriginConfigArgs>;
        /**
         * The domain name for the origin.
         *  For more information, see [Origin Domain Name](https://docs.aws.amazon.com/AmazonCloudFront/latest/DeveloperGuide/distribution-web-values-specify.html#DownloadDistValuesDomainName) in the *Amazon CloudFront Developer Guide*.
         */
        domainName: pulumi.Input<string>;
        /**
         * A unique identifier for the origin. This value must be unique within the distribution.
         *  Use this value to specify the ``TargetOriginId`` in a ``CacheBehavior`` or ``DefaultCacheBehavior``.
         */
        id: pulumi.Input<string>;
        /**
         * The unique identifier of an origin access control for this origin.
         *  For more information, see [Restricting access to an Amazon S3 origin](https://docs.aws.amazon.com/AmazonCloudFront/latest/DeveloperGuide/private-content-restricting-access-to-s3.html) in the *Amazon CloudFront Developer Guide*.
         */
        originAccessControlId?: pulumi.Input<string>;
        /**
         * A list of HTTP header names and values that CloudFront adds to the requests that it sends to the origin.
         *  For more information, see [Adding Custom Headers to Origin Requests](https://docs.aws.amazon.com/AmazonCloudFront/latest/DeveloperGuide/add-origin-custom-headers.html) in the *Amazon CloudFront Developer Guide*.
         */
        originCustomHeaders?: pulumi.Input<pulumi.Input<inputs.cloudfront.DistributionOriginCustomHeaderArgs>[]>;
        /**
         * An optional path that CloudFront appends to the origin domain name when CloudFront requests content from the origin.
         *  For more information, see [Origin Path](https://docs.aws.amazon.com/AmazonCloudFront/latest/DeveloperGuide/distribution-web-values-specify.html#DownloadDistValuesOriginPath) in the *Amazon CloudFront Developer Guide*.
         */
        originPath?: pulumi.Input<string>;
        /**
         * CloudFront Origin Shield. Using Origin Shield can help reduce the load on your origin.
         *  For more information, see [Using Origin Shield](https://docs.aws.amazon.com/AmazonCloudFront/latest/DeveloperGuide/origin-shield.html) in the *Amazon CloudFront Developer Guide*.
         */
        originShield?: pulumi.Input<inputs.cloudfront.DistributionOriginShieldArgs>;
        /**
         * Use this type to specify an origin that is an Amazon S3 bucket that is not configured with static website hosting. To specify any other type of origin, including an Amazon S3 bucket that is configured with static website hosting, use the ``CustomOriginConfig`` type instead.
         */
        s3OriginConfig?: pulumi.Input<inputs.cloudfront.DistributionS3OriginConfigArgs>;
        /**
         * The VPC origin configuration.
         */
        vpcOriginConfig?: pulumi.Input<inputs.cloudfront.DistributionVpcOriginConfigArgs>;
    }
    /**
     * A complex type that contains ``HeaderName`` and ``HeaderValue`` elements, if any, for this distribution.
     */
    interface DistributionOriginCustomHeaderArgs {
        /**
         * The name of a header that you want CloudFront to send to your origin. For more information, see [Adding Custom Headers to Origin Requests](https://docs.aws.amazon.com/AmazonCloudFront/latest/DeveloperGuide/forward-custom-headers.html) in the *Amazon CloudFront Developer Guide*.
         */
        headerName: pulumi.Input<string>;
        /**
         * The value for the header that you specified in the ``HeaderName`` field.
         */
        headerValue: pulumi.Input<string>;
    }
    /**
     * An origin group includes two origins (a primary origin and a secondary origin to failover to) and a failover criteria that you specify. You create an origin group to support origin failover in CloudFront. When you create or update a distribution, you can specify the origin group instead of a single origin, and CloudFront will failover from the primary origin to the secondary origin under the failover conditions that you've chosen.
     *  Optionally, you can choose selection criteria for your origin group to specify how your origins are selected when your distribution routes viewer requests.
     */
    interface DistributionOriginGroupArgs {
        /**
         * A complex type that contains information about the failover criteria for an origin group.
         */
        failoverCriteria: pulumi.Input<inputs.cloudfront.DistributionOriginGroupFailoverCriteriaArgs>;
        /**
         * The origin group's ID.
         */
        id: pulumi.Input<string>;
        /**
         * A complex type that contains information about the origins in an origin group.
         */
        members: pulumi.Input<inputs.cloudfront.DistributionOriginGroupMembersArgs>;
        /**
         * The selection criteria for the origin group. For more information, see [Create an origin group](https://docs.aws.amazon.com/AmazonCloudFront/latest/DeveloperGuide/high_availability_origin_failover.html#concept_origin_groups.creating) in the *Amazon CloudFront Developer Guide*.
         */
        selectionCriteria?: pulumi.Input<enums.cloudfront.DistributionOriginGroupSelectionCriteria>;
    }
    /**
     * A complex data type that includes information about the failover criteria for an origin group, including the status codes for which CloudFront will failover from the primary origin to the second origin.
     */
    interface DistributionOriginGroupFailoverCriteriaArgs {
        /**
         * The status codes that, when returned from the primary origin, will trigger CloudFront to failover to the second origin.
         */
        statusCodes: pulumi.Input<inputs.cloudfront.DistributionStatusCodesArgs>;
    }
    /**
     * An origin in an origin group.
     */
    interface DistributionOriginGroupMemberArgs {
        /**
         * The ID for an origin in an origin group.
         */
        originId: pulumi.Input<string>;
    }
    /**
     * A complex data type for the origins included in an origin group.
     */
    interface DistributionOriginGroupMembersArgs {
        /**
         * Items (origins) in an origin group.
         */
        items: pulumi.Input<pulumi.Input<inputs.cloudfront.DistributionOriginGroupMemberArgs>[]>;
        /**
         * The number of origins in an origin group.
         */
        quantity: pulumi.Input<number>;
    }
    /**
     * A complex data type for the origin groups specified for a distribution.
     */
    interface DistributionOriginGroupsArgs {
        /**
         * The items (origin groups) in a distribution.
         */
        items?: pulumi.Input<pulumi.Input<inputs.cloudfront.DistributionOriginGroupArgs>[]>;
        /**
         * The number of origin groups.
         */
        quantity: pulumi.Input<number>;
    }
    /**
     * CloudFront Origin Shield.
     *  Using Origin Shield can help reduce the load on your origin. For more information, see [Using Origin Shield](https://docs.aws.amazon.com/AmazonCloudFront/latest/DeveloperGuide/origin-shield.html) in the *Amazon CloudFront Developer Guide*.
     */
    interface DistributionOriginShieldArgs {
        /**
         * A flag that specifies whether Origin Shield is enabled.
         *  When it's enabled, CloudFront routes all requests through Origin Shield, which can help protect your origin. When it's disabled, CloudFront might send requests directly to your origin from multiple edge locations or regional edge caches.
         */
        enabled?: pulumi.Input<boolean>;
        /**
         * The AWS-Region for Origin Shield.
         *  Specify the AWS-Region that has the lowest latency to your origin. To specify a region, use the region code, not the region name. For example, specify the US East (Ohio) region as ``us-east-2``.
         *  When you enable CloudFront Origin Shield, you must specify the AWS-Region for Origin Shield. For the list of AWS-Regions that you can specify, and for help choosing the best Region for your origin, see [Choosing the for Origin Shield](https://docs.aws.amazon.com/AmazonCloudFront/latest/DeveloperGuide/origin-shield.html#choose-origin-shield-region) in the *Amazon CloudFront Developer Guide*.
         */
        originShieldRegion?: pulumi.Input<string>;
    }
    /**
     * A complex type that identifies ways in which you want to restrict distribution of your content.
     */
    interface DistributionRestrictionsArgs {
        /**
         * A complex type that controls the countries in which your content is distributed. CF determines the location of your users using ``MaxMind`` GeoIP databases. To disable geo restriction, remove the [Restrictions](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-cloudfront-distribution-distributionconfig.html#cfn-cloudfront-distribution-distributionconfig-restrictions) property from your stack template.
         */
        geoRestriction: pulumi.Input<inputs.cloudfront.DistributionGeoRestrictionArgs>;
    }
    /**
     * A complex type that contains information about the Amazon S3 origin. If the origin is a custom origin or an S3 bucket that is configured as a website endpoint, use the ``CustomOriginConfig`` element instead.
     */
    interface DistributionS3OriginConfigArgs {
        /**
         * If you're using origin access control (OAC) instead of origin access identity, specify an empty ``OriginAccessIdentity`` element. For more information, see [Restricting access to an](https://docs.aws.amazon.com/AmazonCloudFront/latest/DeveloperGuide/private-content-restricting-access-to-origin.html) in the *Amazon CloudFront Developer Guide*.
         *   The CloudFront origin access identity to associate with the origin. Use an origin access identity to configure the origin so that viewers can *only* access objects in an Amazon S3 bucket through CloudFront. The format of the value is:
         *   ``origin-access-identity/cloudfront/ID-of-origin-access-identity``
         *  The ``ID-of-origin-access-identity`` is the value that CloudFront returned in the ``ID`` element when you created the origin access identity.
         *  If you want viewers to be able to access objects using either the CloudFront URL or the Amazon S3 URL, specify an empty ``OriginAccessIdentity`` element.
         *  To delete the origin access identity from an existing distribution, update the distribution configuration and include an empty ``OriginAccessIdentity`` element.
         *  To replace the origin access identity, update the distribution configuration and specify the new origin access identity.
         *  For more information about the origin access identity, see [Serving Private Content through CloudFront](https://docs.aws.amazon.com/AmazonCloudFront/latest/DeveloperGuide/PrivateContent.html) in the *Amazon CloudFront Developer Guide*.
         */
        originAccessIdentity?: pulumi.Input<string>;
    }
    /**
     * A complex data type for the status codes that you specify that, when returned by a primary origin, trigger CloudFront to failover to a second origin.
     */
    interface DistributionStatusCodesArgs {
        /**
         * The items (status codes) for an origin group.
         */
        items: pulumi.Input<pulumi.Input<number>[]>;
        /**
         * The number of status codes.
         */
        quantity: pulumi.Input<number>;
    }
    /**
     * A complex type that determines the distribution's SSL/TLS configuration for communicating with viewers.
     *  If the distribution doesn't use ``Aliases`` (also known as alternate domain names or CNAMEs)—that is, if the distribution uses the CloudFront domain name such as ``d111111abcdef8.cloudfront.net``—set ``CloudFrontDefaultCertificate`` to ``true`` and leave all other fields empty.
     *  If the distribution uses ``Aliases`` (alternate domain names or CNAMEs), use the fields in this type to specify the following settings:
     *   +  Which viewers the distribution accepts HTTPS connections from: only viewers that support [server name indication (SNI)](https://docs.aws.amazon.com/https://en.wikipedia.org/wiki/Server_Name_Indication) (recommended), or all viewers including those that don't support SNI.
     *   +  To accept HTTPS connections from only viewers that support SNI, set ``SSLSupportMethod`` to ``sni-only``. This is recommended. Most browsers and clients support SNI. (In CloudFormation, the field name is ``SslSupportMethod``. Note the different capitalization.)
     *   +  To accept HTTPS connections from all viewers, including those that don't support SNI, set ``SSLSupportMethod`` to ``vip``. This is not recommended, and results in additional monthly charges from CloudFront. (In CloudFormation, the field name is ``SslSupportMethod``. Note the different capitalization.)
     *
     *   +  The minimum SSL/TLS protocol version that the distribution can use to communicate with viewers. To specify a minimum version, choose a value for ``MinimumProtocolVersion``. For more information, see [Security Policy](https://docs.aws.amazon.com/AmazonCloudFront/latest/DeveloperGuide/distribution-web-values-specify.html#DownloadDistValues-security-policy) in the *Amazon CloudFront Developer Guide*.
     *   +  The location of the SSL/TLS certificate, [(ACM)](https://docs.aws.amazon.com/acm/latest/userguide/acm-overview.html) (recommended) or [(IAM)](https://docs.aws.amazon.com/IAM/latest/UserGuide/id_credentials_server-certs.html). You specify the location by setting a value in one of the following fields (not both):
     *   +   ``ACMCertificateArn`` (In CloudFormation, this field name is ``AcmCertificateArn``. Note the different capitalization.)
     *   +   ``IAMCertificateId`` (In CloudFormation, this field name is ``IamCertificateId``. Note the different capitalization.)
     *
     *
     *  All distributions support HTTPS connections from viewers. To require viewers to use HTTPS only, or to redirect them from HTTP to HTTPS, use ``ViewerProtocolPolicy`` in the ``CacheBehavior`` or ``DefaultCacheBehavior``. To specify how CloudFront should use SSL/TLS to communicate with your custom origin, use ``CustomOriginConfig``.
     *  For more information, see [Using HTTPS with CloudFront](https://docs.aws.amazon.com/AmazonCloudFront/latest/DeveloperGuide/using-https.html) and [Using Alternate Domain Names and HTTPS](https://docs.aws.amazon.com/AmazonCloudFront/latest/DeveloperGuide/using-https-alternate-domain-names.html) in the *Amazon CloudFront Developer Guide*.
     */
    interface DistributionViewerCertificateArgs {
        /**
         * In CloudFormation, this field name is ``AcmCertificateArn``. Note the different capitalization.
         *   If the distribution uses ``Aliases`` (alternate domain names or CNAMEs) and the SSL/TLS certificate is stored in [(ACM)](https://docs.aws.amazon.com/acm/latest/userguide/acm-overview.html), provide the Amazon Resource Name (ARN) of the ACM certificate. CloudFront only supports ACM certificates in the US East (N. Virginia) Region (``us-east-1``).
         *  If you specify an ACM certificate ARN, you must also specify values for ``MinimumProtocolVersion`` and ``SSLSupportMethod``. (In CloudFormation, the field name is ``SslSupportMethod``. Note the different capitalization.)
         */
        acmCertificateArn?: pulumi.Input<string>;
        /**
         * If the distribution uses the CloudFront domain name such as ``d111111abcdef8.cloudfront.net``, set this field to ``true``.
         *  If the distribution uses ``Aliases`` (alternate domain names or CNAMEs), omit this field and specify values for the following fields:
         *   +   ``AcmCertificateArn`` or ``IamCertificateId`` (specify a value for one, not both)
         *   +   ``MinimumProtocolVersion``
         *   +   ``SslSupportMethod``
         */
        cloudFrontDefaultCertificate?: pulumi.Input<boolean>;
        /**
         * In CloudFormation, this field name is ``IamCertificateId``. Note the different capitalization.
         *   If the distribution uses ``Aliases`` (alternate domain names or CNAMEs) and the SSL/TLS certificate is stored in [(IAM)](https://docs.aws.amazon.com/IAM/latest/UserGuide/id_credentials_server-certs.html), provide the ID of the IAM certificate.
         *  If you specify an IAM certificate ID, you must also specify values for ``MinimumProtocolVersion`` and ``SSLSupportMethod``. (In CloudFormation, the field name is ``SslSupportMethod``. Note the different capitalization.)
         */
        iamCertificateId?: pulumi.Input<string>;
        /**
         * If the distribution uses ``Aliases`` (alternate domain names or CNAMEs), specify the security policy that you want CloudFront to use for HTTPS connections with viewers. The security policy determines two settings:
         *   +  The minimum SSL/TLS protocol that CloudFront can use to communicate with viewers.
         *   +  The ciphers that CloudFront can use to encrypt the content that it returns to viewers.
         *
         *  For more information, see [Security Policy](https://docs.aws.amazon.com/AmazonCloudFront/latest/DeveloperGuide/distribution-web-values-specify.html#DownloadDistValues-security-policy) and [Supported Protocols and Ciphers Between Viewers and CloudFront](https://docs.aws.amazon.com/AmazonCloudFront/latest/DeveloperGuide/secure-connections-supported-viewer-protocols-ciphers.html#secure-connections-supported-ciphers) in the *Amazon CloudFront Developer Guide*.
         *   On the CloudFront console, this setting is called *Security Policy*.
         *   When you're using SNI only (you set ``SSLSupportMethod`` to ``sni-only``), you must specify ``TLSv1`` or higher. (In CloudFormation, the field name is ``SslSupportMethod``. Note the different capitalization.)
         *  If the distribution uses the CloudFront domain name such as ``d111111abcdef8.cloudfront.net`` (you set ``CloudFrontDefaultCertificate`` to ``true``), CloudFront automatically sets the security policy to ``TLSv1`` regardless of the value that you set here.
         */
        minimumProtocolVersion?: pulumi.Input<string>;
        /**
         * In CloudFormation, this field name is ``SslSupportMethod``. Note the different capitalization.
         *   If the distribution uses ``Aliases`` (alternate domain names or CNAMEs), specify which viewers the distribution accepts HTTPS connections from.
         *   +   ``sni-only`` – The distribution accepts HTTPS connections from only viewers that support [server name indication (SNI)](https://docs.aws.amazon.com/https://en.wikipedia.org/wiki/Server_Name_Indication). This is recommended. Most browsers and clients support SNI.
         *   +   ``vip`` – The distribution accepts HTTPS connections from all viewers including those that don't support SNI. This is not recommended, and results in additional monthly charges from CloudFront.
         *   +   ``static-ip`` - Do not specify this value unless your distribution has been enabled for this feature by the CloudFront team. If you have a use case that requires static IP addresses for a distribution, contact CloudFront through the [Center](https://docs.aws.amazon.com/support/home).
         *
         *  If the distribution uses the CloudFront domain name such as ``d111111abcdef8.cloudfront.net``, don't set a value for this field.
         */
        sslSupportMethod?: pulumi.Input<string>;
    }
    /**
     * An Amazon CloudFront VPC origin configuration.
     */
    interface DistributionVpcOriginConfigArgs {
        /**
         * Specifies how long, in seconds, CloudFront persists its connection to the origin. The minimum timeout is 1 second, the maximum is 60 seconds, and the default (if you don't specify otherwise) is 5 seconds.
         *  For more information, see [Keep-alive timeout (custom origins only)](https://docs.aws.amazon.com/AmazonCloudFront/latest/DeveloperGuide/distribution-web-values-specify.html#DownloadDistValuesOriginKeepaliveTimeout) in the *Amazon CloudFront Developer Guide*.
         */
        originKeepaliveTimeout?: pulumi.Input<number>;
        /**
         * Specifies how long, in seconds, CloudFront waits for a response from the origin. This is also known as the *origin response timeout*. The minimum timeout is 1 second, the maximum is 60 seconds, and the default (if you don't specify otherwise) is 30 seconds.
         *  For more information, see [Response timeout (custom origins only)](https://docs.aws.amazon.com/AmazonCloudFront/latest/DeveloperGuide/distribution-web-values-specify.html#DownloadDistValuesOriginResponseTimeout) in the *Amazon CloudFront Developer Guide*.
         */
        originReadTimeout?: pulumi.Input<number>;
        /**
         * The VPC origin ID.
         */
        vpcOriginId: pulumi.Input<string>;
    }
    /**
     * Contains configuration information about a CloudFront function.
     */
    interface FunctionConfigArgs {
        /**
         * A comment to describe the function.
         */
        comment: pulumi.Input<string>;
        /**
         * The configuration for the key value store associations.
         */
        keyValueStoreAssociations?: pulumi.Input<pulumi.Input<inputs.cloudfront.FunctionKeyValueStoreAssociationArgs>[]>;
        /**
         * The function's runtime environment version.
         */
        runtime: pulumi.Input<string>;
    }
    /**
     * The key value store association.
     */
    interface FunctionKeyValueStoreAssociationArgs {
        /**
         * The Amazon Resource Name (ARN) of the key value store association.
         */
        keyValueStoreArn: pulumi.Input<string>;
    }
    /**
     * Contains metadata about a CloudFront function.
     */
    interface FunctionMetadataArgs {
        /**
         * The Amazon Resource Name (ARN) of the function. The ARN uniquely identifies the function.
         */
        functionArn?: pulumi.Input<string>;
    }
    /**
     * A key group configuration.
     *  A key group contains a list of public keys that you can use with [CloudFront signed URLs and signed cookies](https://docs.aws.amazon.com/AmazonCloudFront/latest/DeveloperGuide/PrivateContent.html).
     */
    interface KeyGroupConfigArgs {
        /**
         * A comment to describe the key group. The comment cannot be longer than 128 characters.
         */
        comment?: pulumi.Input<string>;
        /**
         * A list of the identifiers of the public keys in the key group.
         */
        items: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * A name to identify the key group.
         */
        name: pulumi.Input<string>;
    }
    /**
     * The import source for the key value store.
     */
    interface KeyValueStoreImportSourceArgs {
        /**
         * The Amazon Resource Name (ARN) of the import source for the key value store.
         */
        sourceArn: pulumi.Input<string>;
        /**
         * The source type of the import source for the key value store.
         */
        sourceType: pulumi.Input<string>;
    }
    /**
     * A monitoring subscription. This structure contains information about whether additional CloudWatch metrics are enabled for a given CloudFront distribution.
     */
    interface MonitoringSubscriptionArgs {
        /**
         * A subscription configuration for additional CloudWatch metrics.
         */
        realtimeMetricsSubscriptionConfig?: pulumi.Input<inputs.cloudfront.MonitoringSubscriptionRealtimeMetricsSubscriptionConfigArgs>;
    }
    /**
     * A subscription configuration for additional CloudWatch metrics.
     */
    interface MonitoringSubscriptionRealtimeMetricsSubscriptionConfigArgs {
        /**
         * A flag that indicates whether additional CloudWatch metrics are enabled for a given CloudFront distribution.
         */
        realtimeMetricsSubscriptionStatus: pulumi.Input<enums.cloudfront.MonitoringSubscriptionRealtimeMetricsSubscriptionConfigRealtimeMetricsSubscriptionStatus>;
    }
    /**
     * Creates a new origin access control in CloudFront. After you create an origin access control, you can add it to an origin in a CloudFront distribution so that CloudFront sends authenticated (signed) requests to the origin.
     *  This makes it possible to block public access to the origin, allowing viewers (users) to access the origin's content only through CloudFront.
     *  For more information about using a CloudFront origin access control, see [Restricting access to an origin](https://docs.aws.amazon.com/AmazonCloudFront/latest/DeveloperGuide/private-content-restricting-access-to-origin.html) in the *Amazon CloudFront Developer Guide*.
     */
    interface OriginAccessControlConfigArgs {
        /**
         * A description of the origin access control.
         */
        description?: pulumi.Input<string>;
        /**
         * A name to identify the origin access control. You can specify up to 64 characters.
         */
        name: pulumi.Input<string>;
        /**
         * The type of origin that this origin access control is for.
         */
        originAccessControlOriginType: pulumi.Input<string>;
        /**
         * Specifies which requests CloudFront signs (adds authentication information to). Specify ``always`` for the most common use case. For more information, see [origin access control advanced settings](https://docs.aws.amazon.com/AmazonCloudFront/latest/DeveloperGuide/private-content-restricting-access-to-s3.html#oac-advanced-settings) in the *Amazon CloudFront Developer Guide*.
         *  This field can have one of the following values:
         *   +   ``always`` – CloudFront signs all origin requests, overwriting the ``Authorization`` header from the viewer request if one exists.
         *   +   ``never`` – CloudFront doesn't sign any origin requests. This value turns off origin access control for all origins in all distributions that use this origin access control.
         *   +   ``no-override`` – If the viewer request doesn't contain the ``Authorization`` header, then CloudFront signs the origin request. If the viewer request contains the ``Authorization`` header, then CloudFront doesn't sign the origin request and instead passes along the ``Authorization`` header from the viewer request. *WARNING: To pass along the Authorization header from the viewer request, you must add the Authorization header to a cache policy for all cache behaviors that use origins associated with this origin access control.*
         */
        signingBehavior: pulumi.Input<string>;
        /**
         * The signing protocol of the origin access control, which determines how CloudFront signs (authenticates) requests. The only valid value is ``sigv4``.
         */
        signingProtocol: pulumi.Input<string>;
    }
    /**
     * An origin request policy configuration.
     *  This configuration determines the values that CloudFront includes in requests that it sends to the origin. Each request that CloudFront sends to the origin includes the following:
     *   +  The request body and the URL path (without the domain name) from the viewer request.
     *   +  The headers that CloudFront automatically includes in every origin request, including ``Host``, ``User-Agent``, and ``X-Amz-Cf-Id``.
     *   +  All HTTP headers, cookies, and URL query strings that are specified in the cache policy or the origin request policy. These can include items from the viewer request and, in the case of headers, additional ones that are added by CloudFront.
     *
     *  CloudFront sends a request when it can't find an object in its cache that matches the request. If you want to send values to the origin and also include them in the cache key, use ``CachePolicy``.
     */
    interface OriginRequestPolicyConfigArgs {
        /**
         * A comment to describe the origin request policy. The comment cannot be longer than 128 characters.
         */
        comment?: pulumi.Input<string>;
        /**
         * The cookies from viewer requests to include in origin requests.
         */
        cookiesConfig: pulumi.Input<inputs.cloudfront.OriginRequestPolicyCookiesConfigArgs>;
        /**
         * The HTTP headers to include in origin requests. These can include headers from viewer requests and additional headers added by CloudFront.
         */
        headersConfig: pulumi.Input<inputs.cloudfront.OriginRequestPolicyHeadersConfigArgs>;
        /**
         * A unique name to identify the origin request policy.
         */
        name: pulumi.Input<string>;
        /**
         * The URL query strings from viewer requests to include in origin requests.
         */
        queryStringsConfig: pulumi.Input<inputs.cloudfront.OriginRequestPolicyQueryStringsConfigArgs>;
    }
    /**
     * An object that determines whether any cookies in viewer requests (and if so, which cookies) are included in requests that CloudFront sends to the origin.
     */
    interface OriginRequestPolicyCookiesConfigArgs {
        /**
         * Determines whether cookies in viewer requests are included in requests that CloudFront sends to the origin. Valid values are:
         *   +   ``none`` – No cookies in viewer requests are included in requests that CloudFront sends to the origin. Even when this field is set to ``none``, any cookies that are listed in a ``CachePolicy`` *are* included in origin requests.
         *   +   ``whitelist`` – Only the cookies in viewer requests that are listed in the ``CookieNames`` type are included in requests that CloudFront sends to the origin.
         *   +   ``all`` – All cookies in viewer requests are included in requests that CloudFront sends to the origin.
         *   +   ``allExcept`` – All cookies in viewer requests are included in requests that CloudFront sends to the origin, *except* for those listed in the ``CookieNames`` type, which are not included.
         */
        cookieBehavior: pulumi.Input<string>;
        /**
         * Contains a list of cookie names.
         */
        cookies?: pulumi.Input<pulumi.Input<string>[]>;
    }
    /**
     * An object that determines whether any HTTP headers (and if so, which headers) are included in requests that CloudFront sends to the origin.
     */
    interface OriginRequestPolicyHeadersConfigArgs {
        /**
         * Determines whether any HTTP headers are included in requests that CloudFront sends to the origin. Valid values are:
         *   +   ``none`` – No HTTP headers in viewer requests are included in requests that CloudFront sends to the origin. Even when this field is set to ``none``, any headers that are listed in a ``CachePolicy`` *are* included in origin requests.
         *   +   ``whitelist`` – Only the HTTP headers that are listed in the ``Headers`` type are included in requests that CloudFront sends to the origin.
         *   +   ``allViewer`` – All HTTP headers in viewer requests are included in requests that CloudFront sends to the origin.
         *   +   ``allViewerAndWhitelistCloudFront`` – All HTTP headers in viewer requests and the additional CloudFront headers that are listed in the ``Headers`` type are included in requests that CloudFront sends to the origin. The additional headers are added by CloudFront.
         *   +   ``allExcept`` – All HTTP headers in viewer requests are included in requests that CloudFront sends to the origin, *except* for those listed in the ``Headers`` type, which are not included.
         */
        headerBehavior: pulumi.Input<string>;
        /**
         * Contains a list of HTTP header names.
         */
        headers?: pulumi.Input<pulumi.Input<string>[]>;
    }
    /**
     * An object that determines whether any URL query strings in viewer requests (and if so, which query strings) are included in requests that CloudFront sends to the origin.
     */
    interface OriginRequestPolicyQueryStringsConfigArgs {
        /**
         * Determines whether any URL query strings in viewer requests are included in requests that CloudFront sends to the origin. Valid values are:
         *   +   ``none`` – No query strings in viewer requests are included in requests that CloudFront sends to the origin. Even when this field is set to ``none``, any query strings that are listed in a ``CachePolicy`` *are* included in origin requests.
         *   +   ``whitelist`` – Only the query strings in viewer requests that are listed in the ``QueryStringNames`` type are included in requests that CloudFront sends to the origin.
         *   +   ``all`` – All query strings in viewer requests are included in requests that CloudFront sends to the origin.
         *   +   ``allExcept`` – All query strings in viewer requests are included in requests that CloudFront sends to the origin, *except* for those listed in the ``QueryStringNames`` type, which are not included.
         */
        queryStringBehavior: pulumi.Input<string>;
        /**
         * Contains a list of query string names.
         */
        queryStrings?: pulumi.Input<pulumi.Input<string>[]>;
    }
    /**
     * Configuration information about a public key that you can use with [signed URLs and signed cookies](https://docs.aws.amazon.com/AmazonCloudFront/latest/DeveloperGuide/PrivateContent.html), or with [field-level encryption](https://docs.aws.amazon.com/AmazonCloudFront/latest/DeveloperGuide/field-level-encryption.html).
     */
    interface PublicKeyConfigArgs {
        /**
         * A string included in the request to help make sure that the request can't be replayed.
         */
        callerReference: pulumi.Input<string>;
        /**
         * A comment to describe the public key. The comment cannot be longer than 128 characters.
         */
        comment?: pulumi.Input<string>;
        /**
         * The public key that you can use with [signed URLs and signed cookies](https://docs.aws.amazon.com/AmazonCloudFront/latest/DeveloperGuide/PrivateContent.html), or with [field-level encryption](https://docs.aws.amazon.com/AmazonCloudFront/latest/DeveloperGuide/field-level-encryption.html).
         */
        encodedKey: pulumi.Input<string>;
        /**
         * A name to help identify the public key.
         */
        name: pulumi.Input<string>;
    }
    /**
     * Contains information about the Amazon Kinesis data stream where you are sending real-time log data in a real-time log configuration.
     */
    interface RealtimeLogConfigEndPointArgs {
        /**
         * Contains information about the Amazon Kinesis data stream where you are sending real-time log data.
         */
        kinesisStreamConfig: pulumi.Input<inputs.cloudfront.RealtimeLogConfigKinesisStreamConfigArgs>;
        /**
         * The type of data stream where you are sending real-time log data. The only valid value is ``Kinesis``.
         */
        streamType: pulumi.Input<string>;
    }
    /**
     * Contains information about the Amazon Kinesis data stream where you are sending real-time log data.
     */
    interface RealtimeLogConfigKinesisStreamConfigArgs {
        /**
         * The Amazon Resource Name (ARN) of an IAMlong (IAM) role that CloudFront can use to send real-time log data to your Kinesis data stream.
         *  For more information the IAM role, see [Real-time log configuration IAM role](https://docs.aws.amazon.com/AmazonCloudFront/latest/DeveloperGuide/real-time-logs.html#understand-real-time-log-config-iam-role) in the *Amazon CloudFront Developer Guide*.
         */
        roleArn: pulumi.Input<string>;
        /**
         * The Amazon Resource Name (ARN) of the Kinesis data stream where you are sending real-time log data.
         */
        streamArn: pulumi.Input<string>;
    }
    /**
     * A list of HTTP header names that CloudFront includes as values for the ``Access-Control-Allow-Headers`` HTTP response header.
     *  For more information about the ``Access-Control-Allow-Headers`` HTTP response header, see [Access-Control-Allow-Headers](https://docs.aws.amazon.com/https://developer.mozilla.org/en-US/docs/Web/HTTP/Headers/Access-Control-Allow-Headers) in the MDN Web Docs.
     */
    interface ResponseHeadersPolicyAccessControlAllowHeadersArgs {
        /**
         * The list of HTTP header names. You can specify ``*`` to allow all headers.
         */
        items: pulumi.Input<pulumi.Input<string>[]>;
    }
    /**
     * A list of HTTP methods that CloudFront includes as values for the ``Access-Control-Allow-Methods`` HTTP response header.
     *  For more information about the ``Access-Control-Allow-Methods`` HTTP response header, see [Access-Control-Allow-Methods](https://docs.aws.amazon.com/https://developer.mozilla.org/en-US/docs/Web/HTTP/Headers/Access-Control-Allow-Methods) in the MDN Web Docs.
     */
    interface ResponseHeadersPolicyAccessControlAllowMethodsArgs {
        /**
         * The list of HTTP methods. Valid values are:
         *   +   ``GET``
         *   +   ``DELETE``
         *   +   ``HEAD``
         *   +   ``OPTIONS``
         *   +   ``PATCH``
         *   +   ``POST``
         *   +   ``PUT``
         *   +   ``ALL``
         *
         *   ``ALL`` is a special value that includes all of the listed HTTP methods.
         */
        items: pulumi.Input<pulumi.Input<string>[]>;
    }
    /**
     * A list of origins (domain names) that CloudFront can use as the value for the ``Access-Control-Allow-Origin`` HTTP response header.
     *  For more information about the ``Access-Control-Allow-Origin`` HTTP response header, see [Access-Control-Allow-Origin](https://docs.aws.amazon.com/https://developer.mozilla.org/en-US/docs/Web/HTTP/Headers/Access-Control-Allow-Origin) in the MDN Web Docs.
     */
    interface ResponseHeadersPolicyAccessControlAllowOriginsArgs {
        /**
         * The list of origins (domain names). You can specify ``*`` to allow all origins.
         */
        items: pulumi.Input<pulumi.Input<string>[]>;
    }
    /**
     * A list of HTTP headers that CloudFront includes as values for the ``Access-Control-Expose-Headers`` HTTP response header.
     *  For more information about the ``Access-Control-Expose-Headers`` HTTP response header, see [Access-Control-Expose-Headers](https://docs.aws.amazon.com/https://developer.mozilla.org/en-US/docs/Web/HTTP/Headers/Access-Control-Expose-Headers) in the MDN Web Docs.
     */
    interface ResponseHeadersPolicyAccessControlExposeHeadersArgs {
        /**
         * The list of HTTP headers. You can specify ``*`` to expose all headers.
         */
        items: pulumi.Input<pulumi.Input<string>[]>;
    }
    /**
     * A response headers policy configuration.
     *  A response headers policy configuration contains metadata about the response headers policy, and configurations for sets of HTTP response headers.
     */
    interface ResponseHeadersPolicyConfigArgs {
        /**
         * A comment to describe the response headers policy.
         *  The comment cannot be longer than 128 characters.
         */
        comment?: pulumi.Input<string>;
        /**
         * A configuration for a set of HTTP response headers that are used for cross-origin resource sharing (CORS).
         */
        corsConfig?: pulumi.Input<inputs.cloudfront.ResponseHeadersPolicyCorsConfigArgs>;
        /**
         * A configuration for a set of custom HTTP response headers.
         */
        customHeadersConfig?: pulumi.Input<inputs.cloudfront.ResponseHeadersPolicyCustomHeadersConfigArgs>;
        /**
         * A name to identify the response headers policy.
         *  The name must be unique for response headers policies in this AWS-account.
         */
        name: pulumi.Input<string>;
        /**
         * A configuration for a set of HTTP headers to remove from the HTTP response.
         */
        removeHeadersConfig?: pulumi.Input<inputs.cloudfront.ResponseHeadersPolicyRemoveHeadersConfigArgs>;
        /**
         * A configuration for a set of security-related HTTP response headers.
         */
        securityHeadersConfig?: pulumi.Input<inputs.cloudfront.ResponseHeadersPolicySecurityHeadersConfigArgs>;
        /**
         * A configuration for enabling the ``Server-Timing`` header in HTTP responses sent from CloudFront.
         */
        serverTimingHeadersConfig?: pulumi.Input<inputs.cloudfront.ResponseHeadersPolicyServerTimingHeadersConfigArgs>;
    }
    /**
     * The policy directives and their values that CloudFront includes as values for the ``Content-Security-Policy`` HTTP response header.
     *  For more information about the ``Content-Security-Policy`` HTTP response header, see [Content-Security-Policy](https://docs.aws.amazon.com/https://developer.mozilla.org/en-US/docs/Web/HTTP/Headers/Content-Security-Policy) in the MDN Web Docs.
     */
    interface ResponseHeadersPolicyContentSecurityPolicyArgs {
        /**
         * The policy directives and their values that CloudFront includes as values for the ``Content-Security-Policy`` HTTP response header.
         *  For more information about the ``Content-Security-Policy`` HTTP response header, see [Content-Security-Policy](https://docs.aws.amazon.com/https://developer.mozilla.org/en-US/docs/Web/HTTP/Headers/Content-Security-Policy) in the MDN Web Docs.
         */
        contentSecurityPolicy: pulumi.Input<string>;
        /**
         * A Boolean that determines whether CloudFront overrides the ``Content-Security-Policy`` HTTP response header received from the origin with the one specified in this response headers policy.
         */
        override: pulumi.Input<boolean>;
    }
    /**
     * Determines whether CloudFront includes the ``X-Content-Type-Options`` HTTP response header with its value set to ``nosniff``.
     *  For more information about the ``X-Content-Type-Options`` HTTP response header, see [X-Content-Type-Options](https://docs.aws.amazon.com/https://developer.mozilla.org/en-US/docs/Web/HTTP/Headers/X-Content-Type-Options) in the MDN Web Docs.
     */
    interface ResponseHeadersPolicyContentTypeOptionsArgs {
        /**
         * A Boolean that determines whether CloudFront overrides the ``X-Content-Type-Options`` HTTP response header received from the origin with the one specified in this response headers policy.
         */
        override: pulumi.Input<boolean>;
    }
    /**
     * A configuration for a set of HTTP response headers that are used for cross-origin resource sharing (CORS). CloudFront adds these headers to HTTP responses that it sends for CORS requests that match a cache behavior associated with this response headers policy.
     *  For more information about CORS, see [Cross-Origin Resource Sharing (CORS)](https://docs.aws.amazon.com/https://developer.mozilla.org/en-US/docs/Web/HTTP/CORS) in the MDN Web Docs.
     */
    interface ResponseHeadersPolicyCorsConfigArgs {
        /**
         * A Boolean that CloudFront uses as the value for the ``Access-Control-Allow-Credentials`` HTTP response header.
         *  For more information about the ``Access-Control-Allow-Credentials`` HTTP response header, see [Access-Control-Allow-Credentials](https://docs.aws.amazon.com/https://developer.mozilla.org/en-US/docs/Web/HTTP/Headers/Access-Control-Allow-Credentials) in the MDN Web Docs.
         */
        accessControlAllowCredentials: pulumi.Input<boolean>;
        /**
         * A list of HTTP header names that CloudFront includes as values for the ``Access-Control-Allow-Headers`` HTTP response header.
         *  For more information about the ``Access-Control-Allow-Headers`` HTTP response header, see [Access-Control-Allow-Headers](https://docs.aws.amazon.com/https://developer.mozilla.org/en-US/docs/Web/HTTP/Headers/Access-Control-Allow-Headers) in the MDN Web Docs.
         */
        accessControlAllowHeaders: pulumi.Input<inputs.cloudfront.ResponseHeadersPolicyAccessControlAllowHeadersArgs>;
        /**
         * A list of HTTP methods that CloudFront includes as values for the ``Access-Control-Allow-Methods`` HTTP response header.
         *  For more information about the ``Access-Control-Allow-Methods`` HTTP response header, see [Access-Control-Allow-Methods](https://docs.aws.amazon.com/https://developer.mozilla.org/en-US/docs/Web/HTTP/Headers/Access-Control-Allow-Methods) in the MDN Web Docs.
         */
        accessControlAllowMethods: pulumi.Input<inputs.cloudfront.ResponseHeadersPolicyAccessControlAllowMethodsArgs>;
        /**
         * A list of origins (domain names) that CloudFront can use as the value for the ``Access-Control-Allow-Origin`` HTTP response header.
         *  For more information about the ``Access-Control-Allow-Origin`` HTTP response header, see [Access-Control-Allow-Origin](https://docs.aws.amazon.com/https://developer.mozilla.org/en-US/docs/Web/HTTP/Headers/Access-Control-Allow-Origin) in the MDN Web Docs.
         */
        accessControlAllowOrigins: pulumi.Input<inputs.cloudfront.ResponseHeadersPolicyAccessControlAllowOriginsArgs>;
        /**
         * A list of HTTP headers that CloudFront includes as values for the ``Access-Control-Expose-Headers`` HTTP response header.
         *  For more information about the ``Access-Control-Expose-Headers`` HTTP response header, see [Access-Control-Expose-Headers](https://docs.aws.amazon.com/https://developer.mozilla.org/en-US/docs/Web/HTTP/Headers/Access-Control-Expose-Headers) in the MDN Web Docs.
         */
        accessControlExposeHeaders?: pulumi.Input<inputs.cloudfront.ResponseHeadersPolicyAccessControlExposeHeadersArgs>;
        /**
         * A number that CloudFront uses as the value for the ``Access-Control-Max-Age`` HTTP response header.
         *  For more information about the ``Access-Control-Max-Age`` HTTP response header, see [Access-Control-Max-Age](https://docs.aws.amazon.com/https://developer.mozilla.org/en-US/docs/Web/HTTP/Headers/Access-Control-Max-Age) in the MDN Web Docs.
         */
        accessControlMaxAgeSec?: pulumi.Input<number>;
        /**
         * A Boolean that determines whether CloudFront overrides HTTP response headers received from the origin with the ones specified in this response headers policy.
         */
        originOverride: pulumi.Input<boolean>;
    }
    /**
     * An HTTP response header name and its value. CloudFront includes this header in HTTP responses that it sends for requests that match a cache behavior that's associated with this response headers policy.
     */
    interface ResponseHeadersPolicyCustomHeaderArgs {
        /**
         * The HTTP response header name.
         */
        header: pulumi.Input<string>;
        /**
         * A Boolean that determines whether CloudFront overrides a response header with the same name received from the origin with the header specified here.
         */
        override: pulumi.Input<boolean>;
        /**
         * The value for the HTTP response header.
         */
        value: pulumi.Input<string>;
    }
    /**
     * A list of HTTP response header names and their values. CloudFront includes these headers in HTTP responses that it sends for requests that match a cache behavior that's associated with this response headers policy.
     */
    interface ResponseHeadersPolicyCustomHeadersConfigArgs {
        /**
         * The list of HTTP response headers and their values.
         */
        items: pulumi.Input<pulumi.Input<inputs.cloudfront.ResponseHeadersPolicyCustomHeaderArgs>[]>;
    }
    /**
     * Determines whether CloudFront includes the ``X-Frame-Options`` HTTP response header and the header's value.
     *  For more information about the ``X-Frame-Options`` HTTP response header, see [X-Frame-Options](https://docs.aws.amazon.com/https://developer.mozilla.org/en-US/docs/Web/HTTP/Headers/X-Frame-Options) in the MDN Web Docs.
     */
    interface ResponseHeadersPolicyFrameOptionsArgs {
        /**
         * The value of the ``X-Frame-Options`` HTTP response header. Valid values are ``DENY`` and ``SAMEORIGIN``.
         *  For more information about these values, see [X-Frame-Options](https://docs.aws.amazon.com/https://developer.mozilla.org/en-US/docs/Web/HTTP/Headers/X-Frame-Options) in the MDN Web Docs.
         */
        frameOption: pulumi.Input<string>;
        /**
         * A Boolean that determines whether CloudFront overrides the ``X-Frame-Options`` HTTP response header received from the origin with the one specified in this response headers policy.
         */
        override: pulumi.Input<boolean>;
    }
    /**
     * Determines whether CloudFront includes the ``Referrer-Policy`` HTTP response header and the header's value.
     *  For more information about the ``Referrer-Policy`` HTTP response header, see [Referrer-Policy](https://docs.aws.amazon.com/https://developer.mozilla.org/en-US/docs/Web/HTTP/Headers/Referrer-Policy) in the MDN Web Docs.
     */
    interface ResponseHeadersPolicyReferrerPolicyArgs {
        /**
         * A Boolean that determines whether CloudFront overrides the ``Referrer-Policy`` HTTP response header received from the origin with the one specified in this response headers policy.
         */
        override: pulumi.Input<boolean>;
        /**
         * Determines whether CloudFront includes the ``Referrer-Policy`` HTTP response header and the header's value.
         *  For more information about the ``Referrer-Policy`` HTTP response header, see [Referrer-Policy](https://docs.aws.amazon.com/https://developer.mozilla.org/en-US/docs/Web/HTTP/Headers/Referrer-Policy) in the MDN Web Docs.
         */
        referrerPolicy: pulumi.Input<string>;
    }
    /**
     * The name of an HTTP header that CloudFront removes from HTTP responses to requests that match the cache behavior that this response headers policy is attached to.
     */
    interface ResponseHeadersPolicyRemoveHeaderArgs {
        /**
         * The HTTP header name.
         */
        header: pulumi.Input<string>;
    }
    /**
     * A list of HTTP header names that CloudFront removes from HTTP responses to requests that match the cache behavior that this response headers policy is attached to.
     */
    interface ResponseHeadersPolicyRemoveHeadersConfigArgs {
        /**
         * The list of HTTP header names.
         */
        items: pulumi.Input<pulumi.Input<inputs.cloudfront.ResponseHeadersPolicyRemoveHeaderArgs>[]>;
    }
    /**
     * A configuration for a set of security-related HTTP response headers. CloudFront adds these headers to HTTP responses that it sends for requests that match a cache behavior associated with this response headers policy.
     */
    interface ResponseHeadersPolicySecurityHeadersConfigArgs {
        /**
         * The policy directives and their values that CloudFront includes as values for the ``Content-Security-Policy`` HTTP response header.
         *  For more information about the ``Content-Security-Policy`` HTTP response header, see [Content-Security-Policy](https://docs.aws.amazon.com/https://developer.mozilla.org/en-US/docs/Web/HTTP/Headers/Content-Security-Policy) in the MDN Web Docs.
         */
        contentSecurityPolicy?: pulumi.Input<inputs.cloudfront.ResponseHeadersPolicyContentSecurityPolicyArgs>;
        /**
         * Determines whether CloudFront includes the ``X-Content-Type-Options`` HTTP response header with its value set to ``nosniff``.
         *  For more information about the ``X-Content-Type-Options`` HTTP response header, see [X-Content-Type-Options](https://docs.aws.amazon.com/https://developer.mozilla.org/en-US/docs/Web/HTTP/Headers/X-Content-Type-Options) in the MDN Web Docs.
         */
        contentTypeOptions?: pulumi.Input<inputs.cloudfront.ResponseHeadersPolicyContentTypeOptionsArgs>;
        /**
         * Determines whether CloudFront includes the ``X-Frame-Options`` HTTP response header and the header's value.
         *  For more information about the ``X-Frame-Options`` HTTP response header, see [X-Frame-Options](https://docs.aws.amazon.com/https://developer.mozilla.org/en-US/docs/Web/HTTP/Headers/X-Frame-Options) in the MDN Web Docs.
         */
        frameOptions?: pulumi.Input<inputs.cloudfront.ResponseHeadersPolicyFrameOptionsArgs>;
        /**
         * Determines whether CloudFront includes the ``Referrer-Policy`` HTTP response header and the header's value.
         *  For more information about the ``Referrer-Policy`` HTTP response header, see [Referrer-Policy](https://docs.aws.amazon.com/https://developer.mozilla.org/en-US/docs/Web/HTTP/Headers/Referrer-Policy) in the MDN Web Docs.
         */
        referrerPolicy?: pulumi.Input<inputs.cloudfront.ResponseHeadersPolicyReferrerPolicyArgs>;
        /**
         * Determines whether CloudFront includes the ``Strict-Transport-Security`` HTTP response header and the header's value.
         *  For more information about the ``Strict-Transport-Security`` HTTP response header, see [Security headers](https://docs.aws.amazon.com/AmazonCloudFront/latest/DeveloperGuide/understanding-response-headers-policies.html#understanding-response-headers-policies-security) in the *Amazon CloudFront Developer Guide* and [Strict-Transport-Security](https://docs.aws.amazon.com/https://developer.mozilla.org/en-US/docs/Web/HTTP/Headers/Strict-Transport-Security) in the MDN Web Docs.
         */
        strictTransportSecurity?: pulumi.Input<inputs.cloudfront.ResponseHeadersPolicyStrictTransportSecurityArgs>;
        /**
         * Determines whether CloudFront includes the ``X-XSS-Protection`` HTTP response header and the header's value.
         *  For more information about the ``X-XSS-Protection`` HTTP response header, see [X-XSS-Protection](https://docs.aws.amazon.com/https://developer.mozilla.org/en-US/docs/Web/HTTP/Headers/X-XSS-Protection) in the MDN Web Docs.
         */
        xssProtection?: pulumi.Input<inputs.cloudfront.ResponseHeadersPolicyXssProtectionArgs>;
    }
    /**
     * A configuration for enabling the ``Server-Timing`` header in HTTP responses sent from CloudFront.
     */
    interface ResponseHeadersPolicyServerTimingHeadersConfigArgs {
        /**
         * A Boolean that determines whether CloudFront adds the ``Server-Timing`` header to HTTP responses that it sends in response to requests that match a cache behavior that's associated with this response headers policy.
         */
        enabled: pulumi.Input<boolean>;
        /**
         * A number 0–100 (inclusive) that specifies the percentage of responses that you want CloudFront to add the ``Server-Timing`` header to. When you set the sampling rate to 100, CloudFront adds the ``Server-Timing`` header to the HTTP response for every request that matches the cache behavior that this response headers policy is attached to. When you set it to 50, CloudFront adds the header to 50% of the responses for requests that match the cache behavior. You can set the sampling rate to any number 0–100 with up to four decimal places.
         */
        samplingRate?: pulumi.Input<number>;
    }
    /**
     * Determines whether CloudFront includes the ``Strict-Transport-Security`` HTTP response header and the header's value.
     *  For more information about the ``Strict-Transport-Security`` HTTP response header, see [Strict-Transport-Security](https://docs.aws.amazon.com/https://developer.mozilla.org/en-US/docs/Web/HTTP/Headers/Strict-Transport-Security) in the MDN Web Docs.
     */
    interface ResponseHeadersPolicyStrictTransportSecurityArgs {
        /**
         * A number that CloudFront uses as the value for the ``max-age`` directive in the ``Strict-Transport-Security`` HTTP response header.
         */
        accessControlMaxAgeSec: pulumi.Input<number>;
        /**
         * A Boolean that determines whether CloudFront includes the ``includeSubDomains`` directive in the ``Strict-Transport-Security`` HTTP response header.
         */
        includeSubdomains?: pulumi.Input<boolean>;
        /**
         * A Boolean that determines whether CloudFront overrides the ``Strict-Transport-Security`` HTTP response header received from the origin with the one specified in this response headers policy.
         */
        override: pulumi.Input<boolean>;
        /**
         * A Boolean that determines whether CloudFront includes the ``preload`` directive in the ``Strict-Transport-Security`` HTTP response header.
         */
        preload?: pulumi.Input<boolean>;
    }
    /**
     * Determines whether CloudFront includes the ``X-XSS-Protection`` HTTP response header and the header's value.
     *  For more information about the ``X-XSS-Protection`` HTTP response header, see [X-XSS-Protection](https://docs.aws.amazon.com/https://developer.mozilla.org/en-US/docs/Web/HTTP/Headers/X-XSS-Protection) in the MDN Web Docs.
     */
    interface ResponseHeadersPolicyXssProtectionArgs {
        /**
         * A Boolean that determines whether CloudFront includes the ``mode=block`` directive in the ``X-XSS-Protection`` header.
         *  For more information about this directive, see [X-XSS-Protection](https://docs.aws.amazon.com/https://developer.mozilla.org/en-US/docs/Web/HTTP/Headers/X-XSS-Protection) in the MDN Web Docs.
         */
        modeBlock?: pulumi.Input<boolean>;
        /**
         * A Boolean that determines whether CloudFront overrides the ``X-XSS-Protection`` HTTP response header received from the origin with the one specified in this response headers policy.
         */
        override: pulumi.Input<boolean>;
        /**
         * A Boolean that determines the value of the ``X-XSS-Protection`` HTTP response header. When this setting is ``true``, the value of the ``X-XSS-Protection`` header is ``1``. When this setting is ``false``, the value of the ``X-XSS-Protection`` header is ``0``.
         *  For more information about these settings, see [X-XSS-Protection](https://docs.aws.amazon.com/https://developer.mozilla.org/en-US/docs/Web/HTTP/Headers/X-XSS-Protection) in the MDN Web Docs.
         */
        protection: pulumi.Input<boolean>;
        /**
         * A reporting URI, which CloudFront uses as the value of the ``report`` directive in the ``X-XSS-Protection`` header.
         *  You cannot specify a ``ReportUri`` when ``ModeBlock`` is ``true``.
         *  For more information about using a reporting URL, see [X-XSS-Protection](https://docs.aws.amazon.com/https://developer.mozilla.org/en-US/docs/Web/HTTP/Headers/X-XSS-Protection) in the MDN Web Docs.
         */
        reportUri?: pulumi.Input<string>;
    }
    /**
     * An Amazon CloudFront VPC origin endpoint configuration.
     */
    interface VpcOriginEndpointConfigArgs {
        /**
         * The ARN of the CloudFront VPC origin endpoint configuration.
         */
        arn: pulumi.Input<string>;
        /**
         * The HTTP port for the CloudFront VPC origin endpoint configuration. The default value is ``80``.
         */
        httpPort?: pulumi.Input<number>;
        /**
         * The HTTPS port of the CloudFront VPC origin endpoint configuration. The default value is ``443``.
         */
        httpsPort?: pulumi.Input<number>;
        /**
         * The name of the CloudFront VPC origin endpoint configuration.
         */
        name: pulumi.Input<string>;
        /**
         * The origin protocol policy for the CloudFront VPC origin endpoint configuration.
         */
        originProtocolPolicy?: pulumi.Input<string>;
        originSslProtocols?: pulumi.Input<pulumi.Input<string>[]>;
    }
}
export declare namespace cloudtrail {
    /**
     * The resource that receives events arriving from a channel.
     */
    interface ChannelDestinationArgs {
        /**
         * The ARN of a resource that receives events from a channel.
         */
        location: pulumi.Input<string>;
        /**
         * The type of destination for events arriving from a channel.
         */
        type: pulumi.Input<enums.cloudtrail.ChannelDestinationType>;
    }
    /**
     * Configures the automatic refresh schedule for the dashboard. Includes the frequency unit (DAYS or HOURS) and value, as well as the status (ENABLED or DISABLED) of the refresh schedule.
     */
    interface DashboardRefreshScheduleArgs {
        /**
         * The frequency at which you want the dashboard refreshed.
         */
        frequency?: pulumi.Input<inputs.cloudtrail.DashboardRefreshScheduleFrequencyPropertiesArgs>;
        /**
         * The status of the schedule. Supported values are ENABLED and DISABLED.
         */
        status?: pulumi.Input<enums.cloudtrail.DashboardRefreshScheduleStatus>;
        /**
         * StartTime of the automatic schedule refresh.
         */
        timeOfDay?: pulumi.Input<string>;
    }
    /**
     * The frequency at which you want the dashboard refreshed.
     */
    interface DashboardRefreshScheduleFrequencyPropertiesArgs {
        /**
         * The frequency unit. Supported values are HOURS and DAYS.
         */
        unit: pulumi.Input<enums.cloudtrail.DashboardRefreshScheduleFrequencyPropertiesUnit>;
        /**
         * The frequency value.
         */
        value: pulumi.Input<number>;
    }
    /**
     * The dashboard widget
     */
    interface DashboardWidgetArgs {
        /**
         * The placeholder keys in the QueryStatement. For example: $StartTime$, $EndTime$, $Period$.
         */
        queryParameters?: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * The SQL query statement on one or more event data stores.
         */
        queryStatement: pulumi.Input<string>;
        /**
         * The view properties of the widget.
         */
        viewProperties?: pulumi.Input<{
            [key: string]: pulumi.Input<string>;
        }>;
    }
    /**
     * Advanced event selectors let you create fine-grained selectors for the following AWS CloudTrail event record ﬁelds. They help you control costs by logging only those events that are important to you.
     */
    interface EventDataStoreAdvancedEventSelectorArgs {
        /**
         * Contains all selector statements in an advanced event selector.
         */
        fieldSelectors: pulumi.Input<pulumi.Input<inputs.cloudtrail.EventDataStoreAdvancedFieldSelectorArgs>[]>;
        /**
         * An optional, descriptive name for an advanced event selector, such as "Log data events for only two S3 buckets".
         */
        name?: pulumi.Input<string>;
    }
    /**
     * A single selector statement in an advanced event selector.
     */
    interface EventDataStoreAdvancedFieldSelectorArgs {
        /**
         * An operator that includes events that match the last few characters of the event record field specified as the value of Field.
         */
        endsWith?: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * An operator that includes events that match the exact value of the event record field specified as the value of Field. This is the only valid operator that you can use with the readOnly, eventCategory, and resources.type fields.
         */
        equals?: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * A field in an event record on which to filter events to be logged. Supported fields include readOnly, eventCategory, eventSource (for management events), eventName, resources.type, and resources.ARN.
         */
        field: pulumi.Input<string>;
        /**
         * An operator that excludes events that match the last few characters of the event record field specified as the value of Field.
         */
        notEndsWith?: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * An operator that excludes events that match the exact value of the event record field specified as the value of Field.
         */
        notEquals?: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * An operator that excludes events that match the first few characters of the event record field specified as the value of Field.
         */
        notStartsWith?: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * An operator that includes events that match the first few characters of the event record field specified as the value of Field.
         */
        startsWith?: pulumi.Input<pulumi.Input<string>[]>;
    }
    /**
     * A string that contains Insights types that are logged on an event data store.
     */
    interface EventDataStoreInsightSelectorArgs {
        /**
         * The type of Insights to log on an event data store.
         */
        insightType?: pulumi.Input<string>;
    }
    /**
     * Advanced event selectors let you create fine-grained selectors for the following AWS CloudTrail event record ﬁelds. They help you control costs by logging only those events that are important to you.
     */
    interface TrailAdvancedEventSelectorArgs {
        /**
         * Contains all selector statements in an advanced event selector.
         */
        fieldSelectors: pulumi.Input<pulumi.Input<inputs.cloudtrail.TrailAdvancedFieldSelectorArgs>[]>;
        /**
         * An optional, descriptive name for an advanced event selector, such as "Log data events for only two S3 buckets".
         */
        name?: pulumi.Input<string>;
    }
    /**
     * A single selector statement in an advanced event selector.
     */
    interface TrailAdvancedFieldSelectorArgs {
        /**
         * An operator that includes events that match the last few characters of the event record field specified as the value of Field.
         */
        endsWith?: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * An operator that includes events that match the exact value of the event record field specified as the value of Field. This is the only valid operator that you can use with the readOnly, eventCategory, and resources.type fields.
         */
        equals?: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * A field in an event record on which to filter events to be logged. Supported fields include readOnly, eventCategory, eventSource (for management events), eventName, resources.type, and resources.ARN.
         */
        field: pulumi.Input<string>;
        /**
         * An operator that excludes events that match the last few characters of the event record field specified as the value of Field.
         */
        notEndsWith?: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * An operator that excludes events that match the exact value of the event record field specified as the value of Field.
         */
        notEquals?: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * An operator that excludes events that match the first few characters of the event record field specified as the value of Field.
         */
        notStartsWith?: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * An operator that includes events that match the first few characters of the event record field specified as the value of Field.
         */
        startsWith?: pulumi.Input<pulumi.Input<string>[]>;
    }
    /**
     * CloudTrail supports data event logging for Amazon S3 objects and AWS Lambda functions. You can specify up to 250 resources for an individual event selector, but the total number of data resources cannot exceed 250 across all event selectors in a trail. This limit does not apply if you configure resource logging for all data events.
     */
    interface TrailDataResourceArgs {
        /**
         * The resource type in which you want to log data events. You can specify AWS::S3::Object or AWS::Lambda::Function resources.
         */
        type: pulumi.Input<string>;
        /**
         * An array of Amazon Resource Name (ARN) strings or partial ARN strings for the specified objects.
         */
        values?: pulumi.Input<pulumi.Input<string>[]>;
    }
    /**
     * The type of email sending events to publish to the event destination.
     */
    interface TrailEventSelectorArgs {
        /**
         * CloudTrail supports data event logging for Amazon S3 objects in standard S3 buckets, AWS Lambda functions, and Amazon DynamoDB tables with basic event selectors. You can specify up to 250 resources for an individual event selector, but the total number of data resources cannot exceed 250 across all event selectors in a trail. This limit does not apply if you configure resource logging for all data events.
         *
         * For more information, see [Data Events](https://docs.aws.amazon.com/awscloudtrail/latest/userguide/logging-data-events-with-cloudtrail.html) and [Limits in AWS CloudTrail](https://docs.aws.amazon.com/awscloudtrail/latest/userguide/WhatIsCloudTrail-Limits.html) in the *AWS CloudTrail User Guide* .
         *
         * > To log data events for all other resource types including objects stored in [directory buckets](https://docs.aws.amazon.com/AmazonS3/latest/userguide/directory-buckets-overview.html) , you must use [AdvancedEventSelectors](https://docs.aws.amazon.com/awscloudtrail/latest/APIReference/API_AdvancedEventSelector.html) . You must also use `AdvancedEventSelectors` if you want to filter on the `eventName` field.
         */
        dataResources?: pulumi.Input<pulumi.Input<inputs.cloudtrail.TrailDataResourceArgs>[]>;
        /**
         * An optional list of service event sources from which you do not want management events to be logged on your trail. In this release, the list can be empty (disables the filter), or it can filter out AWS Key Management Service events by containing "kms.amazonaws.com". By default, ExcludeManagementEventSources is empty, and AWS KMS events are included in events that are logged to your trail.
         */
        excludeManagementEventSources?: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * Specify if you want your event selector to include management events for your trail.
         */
        includeManagementEvents?: pulumi.Input<boolean>;
        /**
         * Specify if you want your trail to log read-only events, write-only events, or all. For example, the EC2 GetConsoleOutput is a read-only API operation and RunInstances is a write-only API operation.
         */
        readWriteType?: pulumi.Input<enums.cloudtrail.TrailEventSelectorReadWriteType>;
    }
    /**
     * A string that contains insight types that are logged on a trail.
     */
    interface TrailInsightSelectorArgs {
        /**
         * The type of insight to log on a trail.
         */
        insightType?: pulumi.Input<string>;
    }
}
export declare namespace cloudwatch {
    /**
     * Dimension is an embedded property of the ``AWS::CloudWatch::Alarm`` type. Dimensions are name/value pairs that can be associated with a CW metric. You can specify a maximum of 10 dimensions for a given metric.
     */
    interface AlarmDimensionArgs {
        /**
         * The name of the dimension, from 1–255 characters in length. This dimension name must have been included when the metric was published.
         */
        name: pulumi.Input<string>;
        /**
         * The value for the dimension, from 1–255 characters in length.
         */
        value: pulumi.Input<string>;
    }
    /**
     * The ``Metric`` property type represents a specific metric. ``Metric`` is a property of the [MetricStat](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-cloudwatch-alarm-metricstat.html) property type.
     */
    interface AlarmMetricArgs {
        /**
         * The metric dimensions that you want to be used for the metric that the alarm will watch.
         */
        dimensions?: pulumi.Input<pulumi.Input<inputs.cloudwatch.AlarmDimensionArgs>[]>;
        /**
         * The name of the metric that you want the alarm to watch. This is a required field.
         */
        metricName?: pulumi.Input<string>;
        /**
         * The namespace of the metric that the alarm will watch.
         */
        namespace?: pulumi.Input<string>;
    }
    /**
     * The ``MetricDataQuery`` property type specifies the metric data to return, and whether this call is just retrieving a batch set of data for one metric, or is performing a math expression on metric data.
     *  Any expression used must return a single time series. For more information, see [Metric Math Syntax and Functions](https://docs.aws.amazon.com/AmazonCloudWatch/latest/monitoring/using-metric-math.html#metric-math-syntax) in the *User Guide*.
     */
    interface AlarmMetricDataQueryArgs {
        /**
         * The ID of the account where the metrics are located, if this is a cross-account alarm.
         */
        accountId?: pulumi.Input<string>;
        /**
         * The math expression to be performed on the returned data, if this object is performing a math expression. This expression can use the ``Id`` of the other metrics to refer to those metrics, and can also use the ``Id`` of other expressions to use the result of those expressions. For more information about metric math expressions, see [Metric Math Syntax and Functions](https://docs.aws.amazon.com/AmazonCloudWatch/latest/monitoring/using-metric-math.html#metric-math-syntax) in the *User Guide*.
         *  Within each MetricDataQuery object, you must specify either ``Expression`` or ``MetricStat`` but not both.
         */
        expression?: pulumi.Input<string>;
        /**
         * A short name used to tie this object to the results in the response. This name must be unique within a single call to ``GetMetricData``. If you are performing math expressions on this set of data, this name represents that data and can serve as a variable in the mathematical expression. The valid characters are letters, numbers, and underscore. The first character must be a lowercase letter.
         */
        id: pulumi.Input<string>;
        /**
         * A human-readable label for this metric or expression. This is especially useful if this is an expression, so that you know what the value represents. If the metric or expression is shown in a CW dashboard widget, the label is shown. If ``Label`` is omitted, CW generates a default.
         */
        label?: pulumi.Input<string>;
        /**
         * The metric to be returned, along with statistics, period, and units. Use this parameter only if this object is retrieving a metric and not performing a math expression on returned data.
         *  Within one MetricDataQuery object, you must specify either ``Expression`` or ``MetricStat`` but not both.
         */
        metricStat?: pulumi.Input<inputs.cloudwatch.AlarmMetricStatArgs>;
        /**
         * The granularity, in seconds, of the returned data points. For metrics with regular resolution, a period can be as short as one minute (60 seconds) and must be a multiple of 60. For high-resolution metrics that are collected at intervals of less than one minute, the period can be 1, 5, 10, 30, 60, or any multiple of 60. High-resolution metrics are those metrics stored by a ``PutMetricData`` operation that includes a ``StorageResolution of 1 second``.
         */
        period?: pulumi.Input<number>;
        /**
         * This option indicates whether to return the timestamps and raw data values of this metric.
         *  When you create an alarm based on a metric math expression, specify ``True`` for this value for only the one math expression that the alarm is based on. You must specify ``False`` for ``ReturnData`` for all the other metrics and expressions used in the alarm.
         *  This field is required.
         */
        returnData?: pulumi.Input<boolean>;
    }
    /**
     * This structure defines the metric to be returned, along with the statistics, period, and units.
     *   ``MetricStat`` is a property of the [MetricDataQuery](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-cloudwatch-alarm-metricdataquery.html) property type.
     */
    interface AlarmMetricStatArgs {
        /**
         * The metric to return, including the metric name, namespace, and dimensions.
         */
        metric: pulumi.Input<inputs.cloudwatch.AlarmMetricArgs>;
        /**
         * The granularity, in seconds, of the returned data points. For metrics with regular resolution, a period can be as short as one minute (60 seconds) and must be a multiple of 60. For high-resolution metrics that are collected at intervals of less than one minute, the period can be 1, 5, 10, 30, 60, or any multiple of 60. High-resolution metrics are those metrics stored by a ``PutMetricData`` call that includes a ``StorageResolution`` of 1 second.
         *  If the ``StartTime`` parameter specifies a time stamp that is greater than 3 hours ago, you must specify the period as follows or no data points in that time range is returned:
         *   +  Start time between 3 hours and 15 days ago - Use a multiple of 60 seconds (1 minute).
         *   +  Start time between 15 and 63 days ago - Use a multiple of 300 seconds (5 minutes).
         *   +  Start time greater than 63 days ago - Use a multiple of 3600 seconds (1 hour).
         */
        period: pulumi.Input<number>;
        /**
         * The statistic to return. It can include any CW statistic or extended statistic. For a list of valid values, see the table in [Statistics](https://docs.aws.amazon.com/AmazonCloudWatch/latest/monitoring/cloudwatch_concepts.html#Statistic) in the *User Guide*.
         */
        stat: pulumi.Input<string>;
        /**
         * The unit to use for the returned data points.
         *  Valid values are: Seconds, Microseconds, Milliseconds, Bytes, Kilobytes, Megabytes, Gigabytes, Terabytes, Bits, Kilobits, Megabits, Gigabits, Terabits, Percent, Count, Bytes/Second, Kilobytes/Second, Megabytes/Second, Gigabytes/Second, Terabytes/Second, Bits/Second, Kilobits/Second, Megabits/Second, Gigabits/Second, Terabits/Second, Count/Second, or None.
         */
        unit?: pulumi.Input<string>;
    }
    /**
     * This structure defines the metrics that will be streamed.
     */
    interface MetricStreamFilterArgs {
        /**
         * Only metrics with MetricNames matching these values will be streamed. Must be set together with Namespace.
         */
        metricNames?: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * Only metrics with Namespace matching this value will be streamed.
         */
        namespace: pulumi.Input<string>;
    }
    /**
     * This structure specifies a list of additional statistics to stream, and the metrics to stream those additional statistics for. All metrics that match the combination of metric name and namespace will be streamed with the extended statistics, no matter their dimensions.
     */
    interface MetricStreamStatisticsConfigurationArgs {
        /**
         * The additional statistics to stream for the metrics listed in IncludeMetrics.
         */
        additionalStatistics: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * An array that defines the metrics that are to have additional statistics streamed.
         */
        includeMetrics: pulumi.Input<pulumi.Input<inputs.cloudwatch.MetricStreamStatisticsMetricArgs>[]>;
    }
    /**
     * A structure that specifies the metric name and namespace for one metric that is going to have additional statistics included in the stream.
     */
    interface MetricStreamStatisticsMetricArgs {
        /**
         * The name of the metric.
         */
        metricName: pulumi.Input<string>;
        /**
         * The namespace of the metric.
         */
        namespace: pulumi.Input<string>;
    }
}
export declare namespace codeartifact {
    interface PackageGroupOriginConfigurationArgs {
        /**
         * The origin configuration that is applied to the package group.
         */
        restrictions: pulumi.Input<inputs.codeartifact.PackageGroupRestrictionsArgs>;
    }
    interface PackageGroupRestrictionTypeArgs {
        repositories?: pulumi.Input<pulumi.Input<string>[]>;
        restrictionMode: pulumi.Input<enums.codeartifact.PackageGroupRestrictionTypeRestrictionMode>;
    }
    interface PackageGroupRestrictionsArgs {
        /**
         * The external upstream restriction determines if new package versions can be ingested or retained from external connections.
         */
        externalUpstream?: pulumi.Input<inputs.codeartifact.PackageGroupRestrictionTypeArgs>;
        /**
         * The internal upstream restriction determines if new package versions can be ingested or retained from upstream repositories.
         */
        internalUpstream?: pulumi.Input<inputs.codeartifact.PackageGroupRestrictionTypeArgs>;
        /**
         * The publish restriction determines if new package versions can be published.
         */
        publish?: pulumi.Input<inputs.codeartifact.PackageGroupRestrictionTypeArgs>;
    }
}
export declare namespace codebuild {
    interface FleetComputeConfigurationArgs {
        /**
         * The amount of disk space of the instance type included in your fleet.
         */
        disk?: pulumi.Input<number>;
        /**
         * The machine type of the instance type included in your fleet.
         */
        machineType?: pulumi.Input<enums.codebuild.FleetComputeConfigurationmachineType>;
        /**
         * The amount of memory of the instance type included in your fleet.
         */
        memory?: pulumi.Input<number>;
        /**
         * The number of vCPUs of the instance type included in your fleet.
         */
        vCpu?: pulumi.Input<number>;
    }
    interface FleetProxyConfigurationArgs {
        /**
         * The default behavior of outgoing traffic.
         */
        defaultBehavior?: pulumi.Input<enums.codebuild.FleetProxyConfigurationDefaultBehavior>;
        /**
         * An array of `FleetProxyRule` objects that represent the specified destination domains or IPs to allow or deny network access control to.
         */
        orderedProxyRules?: pulumi.Input<pulumi.Input<inputs.codebuild.FleetProxyRuleArgs>[]>;
    }
    interface FleetProxyRuleArgs {
        /**
         * The behavior of the proxy rule.
         */
        effect?: pulumi.Input<enums.codebuild.FleetProxyRuleEffect>;
        /**
         * The destination of the proxy rule.
         */
        entities?: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * The type of proxy rule.
         */
        type?: pulumi.Input<enums.codebuild.FleetProxyRuleType>;
    }
    interface FleetScalingConfigurationInputArgs {
        /**
         * The maximum number of instances in the ﬂeet when auto-scaling.
         */
        maxCapacity?: pulumi.Input<number>;
        /**
         * The scaling type for a compute fleet.
         */
        scalingType?: pulumi.Input<enums.codebuild.FleetScalingConfigurationInputScalingType>;
        /**
         * A list of `TargetTrackingScalingConfiguration` objects.
         */
        targetTrackingScalingConfigs?: pulumi.Input<pulumi.Input<inputs.codebuild.FleetTargetTrackingScalingConfigurationArgs>[]>;
    }
    interface FleetTargetTrackingScalingConfigurationArgs {
        /**
         * The metric type to determine auto-scaling.
         */
        metricType?: pulumi.Input<enums.codebuild.FleetTargetTrackingScalingConfigurationMetricType>;
        /**
         * The value of `metricType` when to start scaling.
         */
        targetValue?: pulumi.Input<number>;
    }
    interface FleetVpcConfigArgs {
        /**
         * A list of one or more security groups IDs in your Amazon VPC.
         */
        securityGroupIds?: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * A list of one or more subnet IDs in your Amazon VPC.
         */
        subnets?: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * The ID of the Amazon VPC.
         */
        vpcId?: pulumi.Input<string>;
    }
}
export declare namespace codeconnections {
}
export declare namespace codedeploy {
    interface DeploymentConfigMinimumHealthyHostsArgs {
        /**
         * The minimum healthy instance type:
         *
         * - HOST_COUNT: The minimum number of healthy instance as an absolute value.
         * - FLEET_PERCENT: The minimum number of healthy instance as a percentage of the total number of instance in the deployment.
         *
         * In an example of nine instance, if a HOST_COUNT of six is specified, deploy to up to three instances at a time. The deployment is successful if six or more instances are deployed to successfully. Otherwise, the deployment fails. If a FLEET_PERCENT of 40 is specified, deploy to up to five instance at a time. The deployment is successful if four or more instance are deployed to successfully. Otherwise, the deployment fails.
         *
         * > In a call to `GetDeploymentConfig` , CodeDeployDefault.OneAtATime returns a minimum healthy instance type of MOST_CONCURRENCY and a value of 1. This means a deployment to only one instance at a time. (You cannot set the type to MOST_CONCURRENCY, only to HOST_COUNT or FLEET_PERCENT.) In addition, with CodeDeployDefault.OneAtATime, AWS CodeDeploy attempts to ensure that all instances but one are kept in a healthy state during the deployment. Although this allows one instance at a time to be taken offline for a new deployment, it also means that if the deployment to the last instance fails, the overall deployment is still successful.
         *
         * For more information, see [AWS CodeDeploy Instance Health](https://docs.aws.amazon.com//codedeploy/latest/userguide/instances-health.html) in the *AWS CodeDeploy User Guide* .
         */
        type: pulumi.Input<string>;
        /**
         * The minimum healthy instance value.
         */
        value: pulumi.Input<number>;
    }
    interface DeploymentConfigMinimumHealthyHostsPerZoneArgs {
        /**
         * The `type` associated with the `MinimumHealthyHostsPerZone` option.
         */
        type: pulumi.Input<string>;
        /**
         * The `value` associated with the `MinimumHealthyHostsPerZone` option.
         */
        value: pulumi.Input<number>;
    }
    interface DeploymentConfigTimeBasedCanaryArgs {
        /**
         * The number of minutes between the first and second traffic shifts of a `TimeBasedCanary` deployment.
         */
        canaryInterval: pulumi.Input<number>;
        /**
         * The percentage of traffic to shift in the first increment of a `TimeBasedCanary` deployment.
         */
        canaryPercentage: pulumi.Input<number>;
    }
    interface DeploymentConfigTimeBasedLinearArgs {
        /**
         * The number of minutes between each incremental traffic shift of a `TimeBasedLinear` deployment.
         */
        linearInterval: pulumi.Input<number>;
        /**
         * The percentage of traffic that is shifted at the start of each increment of a `TimeBasedLinear` deployment.
         */
        linearPercentage: pulumi.Input<number>;
    }
    interface DeploymentConfigTrafficRoutingConfigArgs {
        /**
         * A configuration that shifts traffic from one version of a Lambda function or ECS task set to another in two increments. The original and target Lambda function versions or ECS task sets are specified in the deployment's AppSpec file.
         */
        timeBasedCanary?: pulumi.Input<inputs.codedeploy.DeploymentConfigTimeBasedCanaryArgs>;
        /**
         * A configuration that shifts traffic from one version of a Lambda function or Amazon ECS task set to another in equal increments, with an equal number of minutes between each increment. The original and target Lambda function versions or Amazon ECS task sets are specified in the deployment's AppSpec file.
         */
        timeBasedLinear?: pulumi.Input<inputs.codedeploy.DeploymentConfigTimeBasedLinearArgs>;
        /**
         * The type of traffic shifting ( `TimeBasedCanary` or `TimeBasedLinear` ) used by a deployment configuration.
         */
        type: pulumi.Input<string>;
    }
    interface DeploymentConfigZonalConfigArgs {
        /**
         * The period of time, in seconds, that CodeDeploy must wait after completing a deployment to the *first* Availability Zone. CodeDeploy will wait this amount of time before starting a deployment to the second Availability Zone. You might set this option if you want to allow extra bake time for the first Availability Zone. If you don't specify a value for `firstZoneMonitorDurationInSeconds` , then CodeDeploy uses the `monitorDurationInSeconds` value for the first Availability Zone.
         *
         * For more information about the zonal configuration feature, see [zonal configuration](https://docs.aws.amazon.com/codedeploy/latest/userguide/deployment-configurations-create.html#zonal-config) in the *CodeDeploy User Guide* .
         */
        firstZoneMonitorDurationInSeconds?: pulumi.Input<number>;
        /**
         * The number or percentage of instances that must remain available per Availability Zone during a deployment. This option works in conjunction with the `MinimumHealthyHosts` option. For more information, see [About the minimum number of healthy hosts per Availability Zone](https://docs.aws.amazon.com//codedeploy/latest/userguide/instances-health.html#minimum-healthy-hosts-az) in the *CodeDeploy User Guide* .
         *
         * If you don't specify the `minimumHealthyHostsPerZone` option, then CodeDeploy uses a default value of `0` percent.
         *
         * For more information about the zonal configuration feature, see [zonal configuration](https://docs.aws.amazon.com/codedeploy/latest/userguide/deployment-configurations-create.html#zonal-config) in the *CodeDeploy User Guide* .
         */
        minimumHealthyHostsPerZone?: pulumi.Input<inputs.codedeploy.DeploymentConfigMinimumHealthyHostsPerZoneArgs>;
        /**
         * The period of time, in seconds, that CodeDeploy must wait after completing a deployment to an Availability Zone. CodeDeploy will wait this amount of time before starting a deployment to the next Availability Zone. Consider adding a monitor duration to give the deployment some time to prove itself (or 'bake') in one Availability Zone before it is released in the next zone. If you don't specify a `monitorDurationInSeconds` , CodeDeploy starts deploying to the next Availability Zone immediately.
         *
         * For more information about the zonal configuration feature, see [zonal configuration](https://docs.aws.amazon.com/codedeploy/latest/userguide/deployment-configurations-create.html#zonal-config) in the *CodeDeploy User Guide* .
         */
        monitorDurationInSeconds?: pulumi.Input<number>;
    }
}
export declare namespace codeguruprofiler {
    /**
     * The agent permissions attached to this profiling group.
     */
    interface AgentPermissionsPropertiesArgs {
        /**
         * The principals for the agent permissions.
         */
        principals: pulumi.Input<pulumi.Input<string>[]>;
    }
    /**
     * Notification medium for users to get alerted for events that occur in application profile. We support SNS topic as a notification channel.
     */
    interface ProfilingGroupChannelArgs {
        /**
         * The channel ID.
         */
        channelId?: pulumi.Input<string>;
        /**
         * The channel URI.
         */
        channelUri: pulumi.Input<string>;
    }
}
export declare namespace codegurureviewer {
}
export declare namespace codepipeline {
    /**
     * Returns information about the details of an artifact.
     */
    interface CustomActionTypeArtifactDetailsArgs {
        /**
         * The maximum number of artifacts allowed for the action type.
         */
        maximumCount: pulumi.Input<number>;
        /**
         * The minimum number of artifacts allowed for the action type.
         */
        minimumCount: pulumi.Input<number>;
    }
    /**
     * The configuration properties for the custom action.
     */
    interface CustomActionTypeConfigurationPropertiesArgs {
        /**
         * The description of the action configuration property that is displayed to users.
         */
        description?: pulumi.Input<string>;
        /**
         * Whether the configuration property is a key.
         */
        key: pulumi.Input<boolean>;
        /**
         * The name of the action configuration property.
         */
        name: pulumi.Input<string>;
        /**
         * Indicates that the property is used with PollForJobs. When creating a custom action, an action can have up to one queryable property. If it has one, that property must be both required and not secret.If you create a pipeline with a custom action type, and that custom action contains a queryable property, the value for that configuration property is subject to other restrictions. The value must be less than or equal to twenty (20) characters. The value can contain only alphanumeric characters, underscores, and hyphens.
         */
        queryable?: pulumi.Input<boolean>;
        /**
         * Whether the configuration property is a required value.
         */
        required: pulumi.Input<boolean>;
        /**
         * Whether the configuration property is secret. Secrets are hidden from all calls except for GetJobDetails, GetThirdPartyJobDetails, PollForJobs, and PollForThirdPartyJobs.
         */
        secret: pulumi.Input<boolean>;
        /**
         * The type of the configuration property.
         */
        type?: pulumi.Input<string>;
    }
    /**
     * Settings is a property of the AWS::CodePipeline::CustomActionType resource that provides URLs that users can access to view information about the CodePipeline custom action.
     */
    interface CustomActionTypeSettingsArgs {
        /**
         * The URL returned to the AWS CodePipeline console that provides a deep link to the resources of the external system, such as the configuration page for an AWS CodeDeploy deployment group. This link is provided as part of the action display in the pipeline.
         */
        entityUrlTemplate?: pulumi.Input<string>;
        /**
         * The URL returned to the AWS CodePipeline console that contains a link to the top-level landing page for the external system, such as the console page for AWS CodeDeploy. This link is shown on the pipeline view page in the AWS CodePipeline console and provides a link to the execution entity of the external action.
         */
        executionUrlTemplate?: pulumi.Input<string>;
        /**
         * The URL returned to the AWS CodePipeline console that contains a link to the page where customers can update or change the configuration of the external action.
         */
        revisionUrlTemplate?: pulumi.Input<string>;
        /**
         * The URL of a sign-up page where users can sign up for an external service and perform initial configuration of the action provided by that service.
         */
        thirdPartyConfigurationUrl?: pulumi.Input<string>;
    }
    /**
     * Represents information about an action declaration.
     */
    interface PipelineActionDeclarationArgs {
        /**
         * Specifies the action type and the provider of the action.
         */
        actionTypeId: pulumi.Input<inputs.codepipeline.PipelineActionTypeIdArgs>;
        /**
         * The shell commands to run with your compute action in CodePipeline.
         */
        commands?: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * The action's configuration. These are key-value pairs that specify input values for an action.
         */
        configuration?: any;
        /**
         * The name or ID of the artifact consumed by the action, such as a test or build artifact. While the field is not a required parameter, most actions have an action configuration that requires a specified quantity of input artifacts. To refer to the action configuration specification by action provider, see the [Action structure reference](https://docs.aws.amazon.com/codepipeline/latest/userguide/action-reference.html) in the *AWS CodePipeline User Guide* .
         *
         * > For a CodeBuild action with multiple input artifacts, one of your input sources must be designated the PrimarySource. For more information, see the [CodeBuild action reference page](https://docs.aws.amazon.com/codepipeline/latest/userguide/action-reference-CodeBuild.html) in the *AWS CodePipeline User Guide* .
         */
        inputArtifacts?: pulumi.Input<pulumi.Input<inputs.codepipeline.PipelineInputArtifactArgs>[]>;
        /**
         * The action declaration's name.
         */
        name: pulumi.Input<string>;
        /**
         * The variable namespace associated with the action. All variables produced as output by this action fall under this namespace.
         */
        namespace?: pulumi.Input<string>;
        /**
         * The name or ID of the result of the action declaration, such as a test or build artifact. While the field is not a required parameter, most actions have an action configuration that requires a specified quantity of output artifacts. To refer to the action configuration specification by action provider, see the [Action structure reference](https://docs.aws.amazon.com/codepipeline/latest/userguide/action-reference.html) in the *AWS CodePipeline User Guide* .
         */
        outputArtifacts?: pulumi.Input<pulumi.Input<inputs.codepipeline.PipelineOutputArtifactArgs>[]>;
        /**
         * The list of variables that are to be exported from the compute action.
         */
        outputVariables?: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * The action declaration's AWS Region, such as us-east-1.
         */
        region?: pulumi.Input<string>;
        /**
         * The ARN of the IAM service role that performs the declared action. This is assumed through the roleArn for the pipeline.
         */
        roleArn?: pulumi.Input<string>;
        /**
         * The order in which actions are run.
         */
        runOrder?: pulumi.Input<number>;
        /**
         * A timeout duration in minutes that can be applied against the ActionType’s default timeout value specified in Quotas for AWS CodePipeline. This attribute is available only to the manual approval ActionType.
         */
        timeoutInMinutes?: pulumi.Input<number>;
    }
    /**
     * Represents information about an action type.
     */
    interface PipelineActionTypeIdArgs {
        /**
         * A category defines what kind of action can be taken in the stage, and constrains the provider type for the action. Valid categories are limited to one of the values below.
         */
        category: pulumi.Input<enums.codepipeline.PipelineActionTypeIdCategory>;
        /**
         * The creator of the action being called. There are three valid values for the Owner field in the action category section within your pipeline structure: AWS, ThirdParty, and Custom.
         */
        owner: pulumi.Input<string>;
        /**
         * The provider of the service being called by the action. Valid providers are determined by the action category. For example, an action in the Deploy category type might have a provider of CodeDeploy, which would be specified as CodeDeploy.
         */
        provider: pulumi.Input<string>;
        /**
         * A string that describes the action version.
         */
        version: pulumi.Input<string>;
    }
    /**
     * The S3 bucket where artifacts for the pipeline are stored.
     */
    interface PipelineArtifactStoreArgs {
        /**
         * The encryption key used to encrypt the data in the artifact store, such as an AWS Key Management Service ( AWS KMS) key. If this is undefined, the default key for Amazon S3 is used. To see an example artifact store encryption key field, see the example structure here: [AWS::CodePipeline::Pipeline](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-codepipeline-pipeline.html) .
         */
        encryptionKey?: pulumi.Input<inputs.codepipeline.PipelineEncryptionKeyArgs>;
        /**
         * The S3 bucket used for storing the artifacts for a pipeline. You can specify the name of an S3 bucket but not a folder in the bucket. A folder to contain the pipeline artifacts is created for you based on the name of the pipeline. You can use any S3 bucket in the same AWS Region as the pipeline to store your pipeline artifacts.
         */
        location: pulumi.Input<string>;
        /**
         * The type of the artifact store, such as S3.
         */
        type: pulumi.Input<enums.codepipeline.PipelineArtifactStoreType>;
    }
    /**
     * A mapping of artifactStore objects and their corresponding AWS Regions. There must be an artifact store for the pipeline Region and for each cross-region action in the pipeline.
     */
    interface PipelineArtifactStoreMapArgs {
        /**
         * Represents information about the S3 bucket where artifacts are stored for the pipeline.
         *
         * > You must include either `artifactStore` or `artifactStores` in your pipeline, but you cannot use both. If you create a cross-region action in your pipeline, you must use `artifactStores` .
         */
        artifactStore: pulumi.Input<inputs.codepipeline.PipelineArtifactStoreArgs>;
        /**
         * The action declaration's AWS Region, such as us-east-1.
         */
        region: pulumi.Input<string>;
    }
    /**
     * The configuration that specifies the rules to run before stage starts.
     */
    interface PipelineBeforeEntryConditionsArgs {
        /**
         * The conditions that are configured as entry conditions.
         */
        conditions?: pulumi.Input<pulumi.Input<inputs.codepipeline.PipelineConditionArgs>[]>;
    }
    /**
     * Reserved for future use.
     */
    interface PipelineBlockerDeclarationArgs {
        /**
         * Reserved for future use.
         */
        name: pulumi.Input<string>;
        /**
         * Reserved for future use.
         */
        type: pulumi.Input<enums.codepipeline.PipelineBlockerDeclarationType>;
    }
    /**
     * Represents information about condition.
     */
    interface PipelineConditionArgs {
        /**
         * The specified result for when the failure conditions are met, such as rolling back the stage
         */
        result?: pulumi.Input<string>;
        /**
         * The rules that make up the condition.
         */
        rules?: pulumi.Input<pulumi.Input<inputs.codepipeline.PipelineRuleDeclarationArgs>[]>;
    }
    /**
     * Represents information about the key used to encrypt data in the artifact store, such as an AWS Key Management Service (AWS KMS) key
     */
    interface PipelineEncryptionKeyArgs {
        /**
         * The ID used to identify the key. For an AWS KMS key, you can use the key ID, the key ARN, or the alias ARN.
         */
        id: pulumi.Input<string>;
        /**
         * The type of encryption key, such as an AWS KMS key. When creating or updating a pipeline, the value must be set to 'KMS'.
         */
        type: pulumi.Input<string>;
    }
    /**
     * The configuration that specifies the result, such as rollback, to occur upon stage failure
     */
    interface PipelineFailureConditionsArgs {
        /**
         * The conditions that are configured as failure conditions. For more information about conditions, see [Stage conditions](https://docs.aws.amazon.com/codepipeline/latest/userguide/stage-conditions.html) and [How do stage conditions work?](https://docs.aws.amazon.com/codepipeline/latest/userguide/concepts-how-it-works-conditions.html) .
         */
        conditions?: pulumi.Input<pulumi.Input<inputs.codepipeline.PipelineConditionArgs>[]>;
        /**
         * The specified result for when the failure conditions are met, such as rolling back the stage
         */
        result?: pulumi.Input<enums.codepipeline.PipelineFailureConditionsResult>;
        /**
         * The configuration that specifies the retry configuration for a stage
         */
        retryConfiguration?: pulumi.Input<inputs.codepipeline.PipelineFailureConditionsRetryConfigurationPropertiesArgs>;
    }
    /**
     * The configuration that specifies the retry configuration for a stage
     */
    interface PipelineFailureConditionsRetryConfigurationPropertiesArgs {
        /**
         * The specified retry mode type for the given stage. FAILED_ACTIONS will retry only the failed actions. ALL_ACTIONS will retry both failed and successful
         */
        retryMode?: pulumi.Input<enums.codepipeline.PipelineFailureConditionsRetryConfigurationPropertiesRetryMode>;
    }
    /**
     * The Git repository branches specified as filter criteria to start the pipeline.
     */
    interface PipelineGitBranchFilterCriteriaArgs {
        /**
         * The list of patterns of Git branches that, when a commit is pushed, are to be excluded from starting the pipeline.
         */
        excludes?: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * The list of patterns of Git branches that, when a commit is pushed, are to be included as criteria that starts the pipeline.
         */
        includes?: pulumi.Input<pulumi.Input<string>[]>;
    }
    /**
     * A type of trigger configuration for Git-based source actions.
     */
    interface PipelineGitConfigurationArgs {
        /**
         * The field where the repository event that will start the pipeline is specified as pull requests.
         */
        pullRequest?: pulumi.Input<pulumi.Input<inputs.codepipeline.PipelineGitPullRequestFilterArgs>[]>;
        /**
         * The field where the repository event that will start the pipeline, such as pushing Git tags, is specified with details.
         */
        push?: pulumi.Input<pulumi.Input<inputs.codepipeline.PipelineGitPushFilterArgs>[]>;
        /**
         * The name of the pipeline source action where the trigger configuration, such as Git tags, is specified. The trigger configuration will start the pipeline upon the specified change only.
         */
        sourceActionName: pulumi.Input<string>;
    }
    /**
     * The Git repository file paths specified as filter criteria to start the pipeline.
     */
    interface PipelineGitFilePathFilterCriteriaArgs {
        /**
         * The list of patterns of Git repository file paths that, when a commit is pushed, are to be excluded from starting the pipeline.
         */
        excludes?: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * The list of patterns of Git repository file paths that, when a commit is pushed, are to be included as criteria that starts the pipeline.
         */
        includes?: pulumi.Input<pulumi.Input<string>[]>;
    }
    /**
     * The event criteria for the pull request trigger configuration, such as the lists of branches or file paths to include and exclude.
     */
    interface PipelineGitPullRequestFilterArgs {
        /**
         * The field that specifies to filter on branches for the pull request trigger configuration.
         */
        branches?: pulumi.Input<inputs.codepipeline.PipelineGitBranchFilterCriteriaArgs>;
        /**
         * The field that specifies which pull request events to filter on (opened, updated, closed) for the trigger configuration.
         */
        events?: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * The field that specifies to filter on file paths for the pull request trigger configuration.
         */
        filePaths?: pulumi.Input<inputs.codepipeline.PipelineGitFilePathFilterCriteriaArgs>;
    }
    /**
     * The event criteria that specify when a specified repository event will start the pipeline for the specified trigger configuration, such as the lists of Git tags to include and exclude.
     */
    interface PipelineGitPushFilterArgs {
        /**
         * The field that specifies to filter on branches for the push trigger configuration.
         */
        branches?: pulumi.Input<inputs.codepipeline.PipelineGitBranchFilterCriteriaArgs>;
        /**
         * The field that specifies to filter on file paths for the push trigger configuration.
         */
        filePaths?: pulumi.Input<inputs.codepipeline.PipelineGitFilePathFilterCriteriaArgs>;
        /**
         * The field that contains the details for the Git tags trigger configuration.
         */
        tags?: pulumi.Input<inputs.codepipeline.PipelineGitTagFilterCriteriaArgs>;
    }
    /**
     * The Git tags specified as filter criteria for whether a Git tag repository event will start the pipeline.
     */
    interface PipelineGitTagFilterCriteriaArgs {
        /**
         * The list of patterns of Git tags that, when pushed, are to be excluded from starting the pipeline.
         */
        excludes?: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * The list of patterns of Git tags that, when pushed, are to be included as criteria that starts the pipeline.
         */
        includes?: pulumi.Input<pulumi.Input<string>[]>;
    }
    /**
     * Represents information about an artifact to be worked on, such as a test or build artifact.
     */
    interface PipelineInputArtifactArgs {
        /**
         * The name of the artifact to be worked on (for example, "My App").
         */
        name: pulumi.Input<string>;
    }
    /**
     * Represents information about the output of an action.
     */
    interface PipelineOutputArtifactArgs {
        /**
         * The files that you want to associate with the output artifact that will be exported from the compute action.
         */
        files?: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * The name of the output of an artifact, such as "My App".
         */
        name: pulumi.Input<string>;
    }
    /**
     * Represents information about condition.
     */
    interface PipelineRuleDeclarationArgs {
        /**
         * The shell commands to run with your compute action in CodePipeline.
         */
        commands?: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * The rule's configuration. These are key-value pairs that specify input values for a rule.
         */
        configuration?: any;
        /**
         * The input artifacts fields for the rule, such as specifying an input file for the rule.
         */
        inputArtifacts?: pulumi.Input<pulumi.Input<inputs.codepipeline.PipelineInputArtifactArgs>[]>;
        /**
         * The rule declaration's name.
         */
        name?: pulumi.Input<string>;
        /**
         * The rule declaration's AWS Region, such as us-east-1.
         */
        region?: pulumi.Input<string>;
        /**
         * The ARN of the IAM service role that performs the declared rule. This is assumed through the roleArn for the pipeline.
         */
        roleArn?: pulumi.Input<string>;
        /**
         * The ID for the rule type, which is made up of the combined values for category, owner, provider, and version.
         */
        ruleTypeId?: pulumi.Input<inputs.codepipeline.PipelineRuleTypeIdArgs>;
    }
    /**
     * Represents information about a rule type.
     */
    interface PipelineRuleTypeIdArgs {
        /**
         * A category for the provider type for the rule.
         */
        category?: pulumi.Input<string>;
        /**
         * The creator of the rule being called. Only AWS is supported.
         */
        owner?: pulumi.Input<string>;
        /**
         * The provider of the service being called by the rule.
         */
        provider?: pulumi.Input<string>;
        /**
         * A string that describes the rule version.
         */
        version?: pulumi.Input<string>;
    }
    /**
     * Represents information about a stage and its definition.
     */
    interface PipelineStageDeclarationArgs {
        /**
         * The actions included in a stage.
         */
        actions: pulumi.Input<pulumi.Input<inputs.codepipeline.PipelineActionDeclarationArgs>[]>;
        /**
         * The method to use before stage runs.
         */
        beforeEntry?: pulumi.Input<inputs.codepipeline.PipelineBeforeEntryConditionsArgs>;
        /**
         * Reserved for future use.
         */
        blockers?: pulumi.Input<pulumi.Input<inputs.codepipeline.PipelineBlockerDeclarationArgs>[]>;
        /**
         * The name of the stage.
         */
        name: pulumi.Input<string>;
        /**
         * The method to use when a stage has not completed successfully
         */
        onFailure?: pulumi.Input<inputs.codepipeline.PipelineFailureConditionsArgs>;
        /**
         * The method to use when a stage has completed successfully
         */
        onSuccess?: pulumi.Input<inputs.codepipeline.PipelineSuccessConditionsArgs>;
    }
    /**
     * The name of the pipeline in which you want to disable the flow of artifacts from one stage to another.
     */
    interface PipelineStageTransitionArgs {
        /**
         * The reason given to the user that a stage is disabled, such as waiting for manual approval or manual tests. This message is displayed in the pipeline console UI.
         */
        reason: pulumi.Input<string>;
        /**
         * The name of the stage where you want to disable the inbound or outbound transition of artifacts.
         */
        stageName: pulumi.Input<string>;
    }
    /**
     * The configuration that specifies the result, such as rollback, to occur upon stage failure
     */
    interface PipelineSuccessConditionsArgs {
        /**
         * The conditions that are success conditions.
         */
        conditions?: pulumi.Input<pulumi.Input<inputs.codepipeline.PipelineConditionArgs>[]>;
    }
    /**
     * Represents information about the specified trigger configuration, such as the filter criteria and the source stage for the action that contains the trigger.
     */
    interface PipelineTriggerDeclarationArgs {
        /**
         * Provides the filter criteria and the source stage for the repository event that starts the pipeline, such as Git tags.
         */
        gitConfiguration?: pulumi.Input<inputs.codepipeline.PipelineGitConfigurationArgs>;
        /**
         * The source provider for the event, such as connections configured for a repository with Git tags, for the specified trigger configuration.
         */
        providerType: pulumi.Input<enums.codepipeline.PipelineTriggerDeclarationProviderType>;
    }
    /**
     * A variable declared at the pipeline level.
     */
    interface PipelineVariableDeclarationArgs {
        /**
         * The value of a pipeline-level variable.
         */
        defaultValue?: pulumi.Input<string>;
        /**
         * The description of a pipeline-level variable. It's used to add additional context about the variable, and not being used at time when pipeline executes.
         */
        description?: pulumi.Input<string>;
        /**
         * The name of a pipeline-level variable.
         */
        name: pulumi.Input<string>;
    }
}
export declare namespace codestarconnections {
}
export declare namespace codestarnotifications {
    interface NotificationRuleTargetArgs {
        /**
         * The Amazon Resource Name (ARN) of the  topic or  client.
         */
        targetAddress: pulumi.Input<string>;
        /**
         * The target type. Can be an Amazon Simple Notification Service topic or  client.
         *
         * - Amazon Simple Notification Service topics are specified as `SNS` .
         * - clients are specified as `AWSChatbotSlack` .
         * - clients for Microsoft Teams are specified as `AWSChatbotMicrosoftTeams` .
         */
        targetType: pulumi.Input<string>;
    }
}
export declare namespace cognito {
    interface IdentityPoolCognitoIdentityProviderArgs {
        /**
         * The client ID for the Amazon Cognito user pool.
         */
        clientId: pulumi.Input<string>;
        /**
         * The provider name for an Amazon Cognito user pool. For example: `cognito-idp.us-east-2.amazonaws.com/us-east-2_123456789` .
         */
        providerName: pulumi.Input<string>;
        /**
         * TRUE if server-side token validation is enabled for the identity provider’s token.
         *
         * After you set the `ServerSideTokenCheck` to TRUE for an identity pool, that identity pool checks with the integrated user pools to make sure the user has not been globally signed out or deleted before the identity pool provides an OIDC token or AWS credentials for the user.
         *
         * If the user is signed out or deleted, the identity pool returns a 400 Not Authorized error.
         */
        serverSideTokenCheck?: pulumi.Input<boolean>;
    }
    interface IdentityPoolCognitoStreamsArgs {
        /**
         * The Amazon Resource Name (ARN) of the role Amazon Cognito can assume to publish to the stream. This role must grant access to Amazon Cognito (cognito-sync) to invoke `PutRecord` on your Amazon Cognito stream.
         */
        roleArn?: pulumi.Input<string>;
        /**
         * The name of the Amazon Cognito stream to receive updates. This stream must be in the developer's account and in the same Region as the identity pool.
         */
        streamName?: pulumi.Input<string>;
        /**
         * Status of the Amazon Cognito streams. Valid values are: `ENABLED` or `DISABLED` .
         */
        streamingStatus?: pulumi.Input<string>;
    }
    interface IdentityPoolPushSyncArgs {
        /**
         * The ARNs of the Amazon SNS platform applications that could be used by clients.
         */
        applicationArns?: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * An IAM role configured to allow Amazon Cognito to call Amazon SNS on behalf of the developer.
         */
        roleArn?: pulumi.Input<string>;
    }
    interface IdentityPoolRoleAttachmentMappingRuleArgs {
        claim: pulumi.Input<string>;
        matchType: pulumi.Input<string>;
        roleArn: pulumi.Input<string>;
        value: pulumi.Input<string>;
    }
    interface IdentityPoolRoleAttachmentRoleMappingArgs {
        ambiguousRoleResolution?: pulumi.Input<string>;
        identityProvider?: pulumi.Input<string>;
        rulesConfiguration?: pulumi.Input<inputs.cognito.IdentityPoolRoleAttachmentRulesConfigurationTypeArgs>;
        type: pulumi.Input<string>;
    }
    interface IdentityPoolRoleAttachmentRulesConfigurationTypeArgs {
        rules: pulumi.Input<pulumi.Input<inputs.cognito.IdentityPoolRoleAttachmentMappingRuleArgs>[]>;
    }
    interface LogDeliveryConfigurationCloudWatchLogsConfigurationArgs {
        logGroupArn?: pulumi.Input<string>;
    }
    interface LogDeliveryConfigurationFirehoseConfigurationArgs {
        streamArn?: pulumi.Input<string>;
    }
    interface LogDeliveryConfigurationLogConfigurationArgs {
        cloudWatchLogsConfiguration?: pulumi.Input<inputs.cognito.LogDeliveryConfigurationCloudWatchLogsConfigurationArgs>;
        eventSource?: pulumi.Input<string>;
        firehoseConfiguration?: pulumi.Input<inputs.cognito.LogDeliveryConfigurationFirehoseConfigurationArgs>;
        logLevel?: pulumi.Input<string>;
        s3Configuration?: pulumi.Input<inputs.cognito.LogDeliveryConfigurationS3ConfigurationArgs>;
    }
    interface LogDeliveryConfigurationS3ConfigurationArgs {
        bucketArn?: pulumi.Input<string>;
    }
    interface ManagedLoginBrandingAssetTypeArgs {
        bytes?: pulumi.Input<string>;
        category: pulumi.Input<enums.cognito.ManagedLoginBrandingCategoryType>;
        colorMode: pulumi.Input<enums.cognito.ManagedLoginBrandingColorModeType>;
        extension: pulumi.Input<enums.cognito.ManagedLoginBrandingExtensionType>;
        resourceId?: pulumi.Input<string>;
    }
    interface UserPoolAccountRecoverySettingArgs {
        /**
         * The list of options and priorities for user message delivery in forgot-password operations. Sets or displays user pool preferences for email or SMS message priority, whether users should fall back to a second delivery method, and whether passwords should only be reset by administrators.
         */
        recoveryMechanisms?: pulumi.Input<pulumi.Input<inputs.cognito.UserPoolRecoveryOptionArgs>[]>;
    }
    interface UserPoolAddOnsArgs {
        /**
         * Threat protection configuration options for additional authentication types in your user pool, including custom authentication.
         */
        advancedSecurityAdditionalFlows?: pulumi.Input<inputs.cognito.UserPoolAdvancedSecurityAdditionalFlowsArgs>;
        /**
         * The operating mode of threat protection for standard authentication types in your user pool, including username-password and secure remote password (SRP) authentication.
         */
        advancedSecurityMode?: pulumi.Input<string>;
    }
    interface UserPoolAdminCreateUserConfigArgs {
        /**
         * The setting for allowing self-service sign-up. When `true` , only administrators can create new user profiles. When `false` , users can register themselves and create a new user profile with the `SignUp` operation.
         */
        allowAdminCreateUserOnly?: pulumi.Input<boolean>;
        /**
         * The template for the welcome message to new users. This template must include the `{####}` temporary password placeholder if you are creating users with passwords. If your users don't have passwords, you can omit the placeholder.
         *
         * See also [Customizing User Invitation Messages](https://docs.aws.amazon.com/cognito/latest/developerguide/cognito-user-pool-settings-message-customizations.html#cognito-user-pool-settings-user-invitation-message-customization) .
         */
        inviteMessageTemplate?: pulumi.Input<inputs.cognito.UserPoolInviteMessageTemplateArgs>;
        /**
         * This parameter is no longer in use.
         *
         * The password expiration limit in days for administrator-created users. When this time expires, the user can't sign in with their temporary password. To reset the account after that time limit, you must call `AdminCreateUser` again, specifying `RESEND` for the `MessageAction` parameter.
         *
         * The default value for this parameter is 7.
         */
        unusedAccountValidityDays?: pulumi.Input<number>;
    }
    interface UserPoolAdvancedSecurityAdditionalFlowsArgs {
        /**
         * The operating mode of threat protection in custom authentication with [Custom authentication challenge Lambda triggers](https://docs.aws.amazon.com/cognito/latest/developerguide/user-pool-lambda-challenge.html) .
         */
        customAuthMode?: pulumi.Input<string>;
    }
    interface UserPoolClientAnalyticsConfigurationArgs {
        /**
         * The Amazon Resource Name (ARN) of an Amazon Pinpoint project that you want to connect to your user pool app client. Amazon Cognito publishes events to the Amazon Pinpoint project that `ApplicationArn` declares. You can also configure your application to pass an endpoint ID in the `AnalyticsMetadata` parameter of sign-in operations. The endpoint ID is information about the destination for push notifications
         */
        applicationArn?: pulumi.Input<string>;
        /**
         * Your Amazon Pinpoint project ID.
         */
        applicationId?: pulumi.Input<string>;
        /**
         * The [external ID](https://docs.aws.amazon.com/IAM/latest/UserGuide/id_roles_create_for-user_externalid.html) of the role that Amazon Cognito assumes to send analytics data to Amazon Pinpoint.
         */
        externalId?: pulumi.Input<string>;
        /**
         * The ARN of an AWS Identity and Access Management role that has the permissions required for Amazon Cognito to publish events to Amazon Pinpoint analytics.
         */
        roleArn?: pulumi.Input<string>;
        /**
         * If `UserDataShared` is `true` , Amazon Cognito includes user data in the events that it publishes to Amazon Pinpoint analytics.
         */
        userDataShared?: pulumi.Input<boolean>;
    }
    interface UserPoolClientTokenValidityUnitsArgs {
        /**
         * A time unit for the value that you set in the `AccessTokenValidity` parameter. The default `AccessTokenValidity` time unit is `hours` . `AccessTokenValidity` duration can range from five minutes to one day.
         */
        accessToken?: pulumi.Input<string>;
        /**
         * A time unit for the value that you set in the `IdTokenValidity` parameter. The default `IdTokenValidity` time unit is `hours` . `IdTokenValidity` duration can range from five minutes to one day.
         */
        idToken?: pulumi.Input<string>;
        /**
         * A time unit for the value that you set in the `RefreshTokenValidity` parameter. The default `RefreshTokenValidity` time unit is `days` . `RefreshTokenValidity` duration can range from 60 minutes to 10 years.
         */
        refreshToken?: pulumi.Input<string>;
    }
    interface UserPoolCustomEmailSenderArgs {
        /**
         * The Amazon Resource Name (ARN) of the function that you want to assign to your Lambda trigger.
         */
        lambdaArn?: pulumi.Input<string>;
        /**
         * The user pool trigger version of the request that Amazon Cognito sends to your Lambda function. Higher-numbered versions add fields that support new features.
         *
         * You must use a `LambdaVersion` of `V1_0` with a custom sender function.
         */
        lambdaVersion?: pulumi.Input<string>;
    }
    interface UserPoolCustomSmsSenderArgs {
        /**
         * The Amazon Resource Name (ARN) of the function that you want to assign to your Lambda trigger.
         */
        lambdaArn?: pulumi.Input<string>;
        /**
         * The user pool trigger version of the request that Amazon Cognito sends to your Lambda function. Higher-numbered versions add fields that support new features.
         *
         * You must use a `LambdaVersion` of `V1_0` with a custom sender function.
         */
        lambdaVersion?: pulumi.Input<string>;
    }
    interface UserPoolDeviceConfigurationArgs {
        /**
         * When true, a remembered device can sign in with device authentication instead of SMS and time-based one-time password (TOTP) factors for multi-factor authentication (MFA).
         *
         * > Whether or not `ChallengeRequiredOnNewDevice` is true, users who sign in with devices that have not been confirmed or remembered must still provide a second factor in a user pool that requires MFA.
         */
        challengeRequiredOnNewDevice?: pulumi.Input<boolean>;
        /**
         * When true, Amazon Cognito doesn't automatically remember a user's device when your app sends a `ConfirmDevice` API request. In your app, create a prompt for your user to choose whether they want to remember their device. Return the user's choice in an `UpdateDeviceStatus` API request.
         *
         * When `DeviceOnlyRememberedOnUserPrompt` is `false` , Amazon Cognito immediately remembers devices that you register in a `ConfirmDevice` API request.
         */
        deviceOnlyRememberedOnUserPrompt?: pulumi.Input<boolean>;
    }
    interface UserPoolDomainCustomDomainConfigTypeArgs {
        /**
         * The Amazon Resource Name (ARN) of an AWS Certificate Manager SSL certificate. You use this certificate for the subdomain of your custom domain.
         */
        certificateArn?: pulumi.Input<string>;
    }
    interface UserPoolEmailConfigurationArgs {
        /**
         * The set of configuration rules that can be applied to emails sent using Amazon Simple Email Service. A configuration set is applied to an email by including a reference to the configuration set in the headers of the email. Once applied, all of the rules in that configuration set are applied to the email. Configuration sets can be used to apply the following types of rules to emails:
         *
         * - **Event publishing** - Amazon Simple Email Service can track the number of send, delivery, open, click, bounce, and complaint events for each email sent. Use event publishing to send information about these events to other AWS services such as and Amazon CloudWatch
         * - **IP pool management** - When leasing dedicated IP addresses with Amazon Simple Email Service, you can create groups of IP addresses, called dedicated IP pools. You can then associate the dedicated IP pools with configuration sets.
         */
        configurationSet?: pulumi.Input<string>;
        /**
         * Specifies whether Amazon Cognito uses its built-in functionality to send your users email messages, or uses your Amazon Simple Email Service email configuration. Specify one of the following values:
         *
         * - **COGNITO_DEFAULT** - When Amazon Cognito emails your users, it uses its built-in email functionality. When you use the default option, Amazon Cognito allows only a limited number of emails each day for your user pool. For typical production environments, the default email limit is less than the required delivery volume. To achieve a higher delivery volume, specify DEVELOPER to use your Amazon SES email configuration.
         *
         * To look up the email delivery limit for the default option, see [Limits](https://docs.aws.amazon.com/cognito/latest/developerguide/limits.html) in the *Amazon Cognito Developer Guide* .
         *
         * The default FROM address is `no-reply@verificationemail.com` . To customize the FROM address, provide the Amazon Resource Name (ARN) of an Amazon SES verified email address for the `SourceArn` parameter.
         * - **DEVELOPER** - When Amazon Cognito emails your users, it uses your Amazon SES configuration. Amazon Cognito calls Amazon SES on your behalf to send email from your verified email address. When you use this option, the email delivery limits are the same limits that apply to your Amazon SES verified email address in your AWS account .
         *
         * If you use this option, provide the ARN of an Amazon SES verified email address for the `SourceArn` parameter.
         *
         * Before Amazon Cognito can email your users, it requires additional permissions to call Amazon SES on your behalf. When you update your user pool with this option, Amazon Cognito creates a *service-linked role* , which is a type of role in your AWS account . This role contains the permissions that allow you to access Amazon SES and send email messages from your email address. For more information about the service-linked role that Amazon Cognito creates, see [Using Service-Linked Roles for Amazon Cognito](https://docs.aws.amazon.com/cognito/latest/developerguide/using-service-linked-roles.html) in the *Amazon Cognito Developer Guide* .
         */
        emailSendingAccount?: pulumi.Input<string>;
        /**
         * Either the sender’s email address or the sender’s name with their email address. For example, `testuser@example.com` or `Test User <testuser@example.com>` . This address appears before the body of the email.
         */
        from?: pulumi.Input<string>;
        /**
         * The destination to which the receiver of the email should reply.
         */
        replyToEmailAddress?: pulumi.Input<string>;
        /**
         * The ARN of a verified email address or an address from a verified domain in Amazon SES. You can set a `SourceArn` email from a verified domain only with an API request. You can set a verified email address, but not an address in a verified domain, in the Amazon Cognito console. Amazon Cognito uses the email address that you provide in one of the following ways, depending on the value that you specify for the `EmailSendingAccount` parameter:
         *
         * - If you specify `COGNITO_DEFAULT` , Amazon Cognito uses this address as the custom FROM address when it emails your users using its built-in email account.
         * - If you specify `DEVELOPER` , Amazon Cognito emails your users with this address by calling Amazon SES on your behalf.
         *
         * The Region value of the `SourceArn` parameter must indicate a supported AWS Region of your user pool. Typically, the Region in the `SourceArn` and the user pool Region are the same. For more information, see [Amazon SES email configuration regions](https://docs.aws.amazon.com/cognito/latest/developerguide/user-pool-email.html#user-pool-email-developer-region-mapping) in the [Amazon Cognito Developer Guide](https://docs.aws.amazon.com/cognito/latest/developerguide/cognito-user-identity-pools.html) .
         */
        sourceArn?: pulumi.Input<string>;
    }
    interface UserPoolInviteMessageTemplateArgs {
        /**
         * The message template for email messages. EmailMessage is allowed only if [EmailSendingAccount](https://docs.aws.amazon.com/cognito-user-identity-pools/latest/APIReference/API_EmailConfigurationType.html#CognitoUserPools-Type-EmailConfigurationType-EmailSendingAccount) is DEVELOPER.
         */
        emailMessage?: pulumi.Input<string>;
        /**
         * The subject line for email messages. EmailSubject is allowed only if [EmailSendingAccount](https://docs.aws.amazon.com/cognito-user-identity-pools/latest/APIReference/API_EmailConfigurationType.html#CognitoUserPools-Type-EmailConfigurationType-EmailSendingAccount) is DEVELOPER.
         */
        emailSubject?: pulumi.Input<string>;
        /**
         * The message template for SMS messages.
         */
        smsMessage?: pulumi.Input<string>;
    }
    interface UserPoolLambdaConfigArgs {
        /**
         * The configuration of a create auth challenge Lambda trigger, one of three triggers in the sequence of the [custom authentication challenge triggers](https://docs.aws.amazon.com/cognito/latest/developerguide/user-pool-lambda-challenge.html) .
         */
        createAuthChallenge?: pulumi.Input<string>;
        /**
         * The configuration of a custom email sender Lambda trigger. This trigger routes all email notifications from a user pool to a Lambda function that delivers the message using custom logic.
         */
        customEmailSender?: pulumi.Input<inputs.cognito.UserPoolCustomEmailSenderArgs>;
        /**
         * A custom message Lambda trigger. This trigger is an opportunity to customize all SMS and email messages from your user pool. When a custom message trigger is active, your user pool routes all messages to a Lambda function that returns a runtime-customized message subject and body for your user pool to deliver to a user.
         */
        customMessage?: pulumi.Input<string>;
        /**
         * The configuration of a custom SMS sender Lambda trigger. This trigger routes all SMS notifications from a user pool to a Lambda function that delivers the message using custom logic.
         */
        customSmsSender?: pulumi.Input<inputs.cognito.UserPoolCustomSmsSenderArgs>;
        /**
         * The configuration of a define auth challenge Lambda trigger, one of three triggers in the sequence of the [custom authentication challenge triggers](https://docs.aws.amazon.com/cognito/latest/developerguide/user-pool-lambda-challenge.html) .
         */
        defineAuthChallenge?: pulumi.Input<string>;
        /**
         * The ARN of an [KMS key](https://docs.aws.amazon.com//kms/latest/developerguide/concepts.html#master_keys) . Amazon Cognito uses the key to encrypt codes and temporary passwords sent to custom sender Lambda triggers.
         */
        kmsKeyId?: pulumi.Input<string>;
        /**
         * The configuration of a [post authentication Lambda trigger](https://docs.aws.amazon.com/cognito/latest/developerguide/user-pool-lambda-post-authentication.html) in a user pool. This trigger can take custom actions after a user signs in.
         */
        postAuthentication?: pulumi.Input<string>;
        /**
         * The configuration of a [post confirmation Lambda trigger](https://docs.aws.amazon.com/cognito/latest/developerguide/user-pool-lambda-post-confirmation.html) in a user pool. This trigger can take custom actions after a user confirms their user account and their email address or phone number.
         */
        postConfirmation?: pulumi.Input<string>;
        /**
         * The configuration of a [pre authentication trigger](https://docs.aws.amazon.com/cognito/latest/developerguide/user-pool-lambda-pre-authentication.html) in a user pool. This trigger can evaluate and modify user sign-in events.
         */
        preAuthentication?: pulumi.Input<string>;
        /**
         * The configuration of a [pre sign-up Lambda trigger](https://docs.aws.amazon.com/cognito/latest/developerguide/user-pool-lambda-pre-sign-up.html) in a user pool. This trigger evaluates new users and can bypass confirmation, [link a federated user profile](https://docs.aws.amazon.com/cognito/latest/developerguide/cognito-user-pools-identity-federation-consolidate-users.html) , or block sign-up requests.
         */
        preSignUp?: pulumi.Input<string>;
        /**
         * The legacy configuration of a [pre token generation Lambda trigger](https://docs.aws.amazon.com/cognito/latest/developerguide/user-pool-lambda-pre-token-generation.html) in a user pool.
         *
         * Set this parameter for legacy purposes. If you also set an ARN in `PreTokenGenerationConfig` , its value must be identical to `PreTokenGeneration` . For new instances of pre token generation triggers, set the `LambdaArn` of `PreTokenGenerationConfig` .
         */
        preTokenGeneration?: pulumi.Input<string>;
        /**
         * The detailed configuration of a [pre token generation Lambda trigger](https://docs.aws.amazon.com/cognito/latest/developerguide/user-pool-lambda-pre-token-generation.html) in a user pool. If you also set an ARN in `PreTokenGeneration` , its value must be identical to `PreTokenGenerationConfig` .
         */
        preTokenGenerationConfig?: pulumi.Input<inputs.cognito.UserPoolPreTokenGenerationConfigArgs>;
        /**
         * The configuration of a [migrate user Lambda trigger](https://docs.aws.amazon.com/cognito/latest/developerguide/user-pool-lambda-migrate-user.html) in a user pool. This trigger can create user profiles when users sign in or attempt to reset their password with credentials that don't exist yet.
         */
        userMigration?: pulumi.Input<string>;
        /**
         * The configuration of a verify auth challenge Lambda trigger, one of three triggers in the sequence of the [custom authentication challenge triggers](https://docs.aws.amazon.com/cognito/latest/developerguide/user-pool-lambda-challenge.html) .
         */
        verifyAuthChallengeResponse?: pulumi.Input<string>;
    }
    interface UserPoolNumberAttributeConstraintsArgs {
        /**
         * The maximum length of a number attribute value. Must be a number less than or equal to `2^1023` , represented as a string with a length of 131072 characters or fewer.
         */
        maxValue?: pulumi.Input<string>;
        /**
         * The minimum value of an attribute that is of the number data type.
         */
        minValue?: pulumi.Input<string>;
    }
    interface UserPoolPasswordPolicyArgs {
        /**
         * The minimum length of the password in the policy that you have set. This value can't be less than 6.
         */
        minimumLength?: pulumi.Input<number>;
        /**
         * The number of previous passwords that you want Amazon Cognito to restrict each user from reusing. Users can't set a password that matches any of `n` previous passwords, where `n` is the value of `PasswordHistorySize` .
         */
        passwordHistorySize?: pulumi.Input<number>;
        /**
         * The requirement in a password policy that users must include at least one lowercase letter in their password.
         */
        requireLowercase?: pulumi.Input<boolean>;
        /**
         * The requirement in a password policy that users must include at least one number in their password.
         */
        requireNumbers?: pulumi.Input<boolean>;
        /**
         * The requirement in a password policy that users must include at least one symbol in their password.
         */
        requireSymbols?: pulumi.Input<boolean>;
        /**
         * The requirement in a password policy that users must include at least one uppercase letter in their password.
         */
        requireUppercase?: pulumi.Input<boolean>;
        /**
         * The number of days a temporary password is valid in the password policy. If the user doesn't sign in during this time, an administrator must reset their password. Defaults to `7` . If you submit a value of `0` , Amazon Cognito treats it as a null value and sets `TemporaryPasswordValidityDays` to its default value.
         *
         * > When you set `TemporaryPasswordValidityDays` for a user pool, you can no longer set a value for the legacy `UnusedAccountValidityDays` parameter in that user pool.
         */
        temporaryPasswordValidityDays?: pulumi.Input<number>;
    }
    interface UserPoolPoliciesArgs {
        /**
         * The password policy settings for a user pool, including complexity, history, and length requirements.
         */
        passwordPolicy?: pulumi.Input<inputs.cognito.UserPoolPasswordPolicyArgs>;
        /**
         * The policy for allowed types of authentication in a user pool. To activate this setting, your user pool must be in the [Essentials tier](https://docs.aws.amazon.com/cognito/latest/developerguide/feature-plans-features-essentials.html) or higher.
         */
        signInPolicy?: pulumi.Input<inputs.cognito.UserPoolSignInPolicyArgs>;
    }
    interface UserPoolPreTokenGenerationConfigArgs {
        /**
         * The Amazon Resource Name (ARN) of the function that you want to assign to your Lambda trigger.
         *
         * This parameter and the `PreTokenGeneration` property of `LambdaConfig` have the same value. For new instances of pre token generation triggers, set `LambdaArn` .
         */
        lambdaArn?: pulumi.Input<string>;
        /**
         * The user pool trigger version of the request that Amazon Cognito sends to your Lambda function. Higher-numbered versions add fields that support new features.
         */
        lambdaVersion?: pulumi.Input<string>;
    }
    interface UserPoolRecoveryOptionArgs {
        /**
         * The recovery method that this object sets a recovery option for.
         */
        name?: pulumi.Input<string>;
        /**
         * Your priority preference for using the specified attribute in account recovery. The highest priority is `1` .
         */
        priority?: pulumi.Input<number>;
    }
    interface UserPoolResourceServerResourceServerScopeTypeArgs {
        /**
         * A friendly description of a custom scope.
         */
        scopeDescription: pulumi.Input<string>;
        /**
         * The name of the scope. Amazon Cognito renders custom scopes in the format `resourceServerIdentifier/ScopeName` . For example, if this parameter is `exampleScope` in the resource server with the identifier `exampleResourceServer` , you request and receive the scope `exampleResourceServer/exampleScope` .
         */
        scopeName: pulumi.Input<string>;
    }
    interface UserPoolRiskConfigurationAttachmentAccountTakeoverActionTypeArgs {
        /**
         * The action to take for the attempted account takeover action for the associated risk level. Valid values are as follows:
         *
         * - `BLOCK` : Block the request.
         * - `MFA_IF_CONFIGURED` : Present an MFA challenge if possible. MFA is possible if the user pool has active MFA methods that the user can set up. For example, if the user pool only supports SMS message MFA but the user doesn't have a phone number attribute, MFA setup isn't possible. If MFA setup isn't possible, allow the request.
         * - `MFA_REQUIRED` : Present an MFA challenge if possible. Block the request if a user hasn't set up MFA. To sign in with required MFA, users must have an email address or phone number attribute, or a registered TOTP factor.
         * - `NO_ACTION` : Take no action. Permit sign-in.
         */
        eventAction: pulumi.Input<string>;
        /**
         * Determines whether Amazon Cognito sends a user a notification message when your user pools assesses a user's session at the associated risk level.
         */
        notify: pulumi.Input<boolean>;
    }
    interface UserPoolRiskConfigurationAttachmentAccountTakeoverActionsTypeArgs {
        /**
         * The action that you assign to a high-risk assessment by threat protection.
         */
        highAction?: pulumi.Input<inputs.cognito.UserPoolRiskConfigurationAttachmentAccountTakeoverActionTypeArgs>;
        /**
         * The action that you assign to a low-risk assessment by threat protection.
         */
        lowAction?: pulumi.Input<inputs.cognito.UserPoolRiskConfigurationAttachmentAccountTakeoverActionTypeArgs>;
        /**
         * The action that you assign to a medium-risk assessment by threat protection.
         */
        mediumAction?: pulumi.Input<inputs.cognito.UserPoolRiskConfigurationAttachmentAccountTakeoverActionTypeArgs>;
    }
    interface UserPoolRiskConfigurationAttachmentAccountTakeoverRiskConfigurationTypeArgs {
        /**
         * A list of account-takeover actions for each level of risk that Amazon Cognito might assess with threat protection.
         */
        actions: pulumi.Input<inputs.cognito.UserPoolRiskConfigurationAttachmentAccountTakeoverActionsTypeArgs>;
        /**
         * The settings for composing and sending an email message when threat protection assesses a risk level with adaptive authentication. When you choose to notify users in `AccountTakeoverRiskConfiguration` , Amazon Cognito sends an email message using the method and template that you set with this data type.
         */
        notifyConfiguration?: pulumi.Input<inputs.cognito.UserPoolRiskConfigurationAttachmentNotifyConfigurationTypeArgs>;
    }
    interface UserPoolRiskConfigurationAttachmentCompromisedCredentialsActionsTypeArgs {
        /**
         * The action that Amazon Cognito takes when it detects compromised credentials.
         */
        eventAction: pulumi.Input<string>;
    }
    interface UserPoolRiskConfigurationAttachmentCompromisedCredentialsRiskConfigurationTypeArgs {
        /**
         * Settings for the actions that you want your user pool to take when Amazon Cognito detects compromised credentials.
         */
        actions: pulumi.Input<inputs.cognito.UserPoolRiskConfigurationAttachmentCompromisedCredentialsActionsTypeArgs>;
        /**
         * Settings for the sign-in activity where you want to configure compromised-credentials actions. Defaults to all events.
         */
        eventFilter?: pulumi.Input<pulumi.Input<string>[]>;
    }
    interface UserPoolRiskConfigurationAttachmentNotifyConfigurationTypeArgs {
        /**
         * The template for the email message that your user pool sends when a detected risk event is blocked.
         */
        blockEmail?: pulumi.Input<inputs.cognito.UserPoolRiskConfigurationAttachmentNotifyEmailTypeArgs>;
        /**
         * The email address that sends the email message. The address must be either individually verified with Amazon Simple Email Service, or from a domain that has been verified with Amazon SES.
         */
        from?: pulumi.Input<string>;
        /**
         * The template for the email message that your user pool sends when MFA is challenged in response to a detected risk.
         */
        mfaEmail?: pulumi.Input<inputs.cognito.UserPoolRiskConfigurationAttachmentNotifyEmailTypeArgs>;
        /**
         * The template for the email message that your user pool sends when no action is taken in response to a detected risk.
         */
        noActionEmail?: pulumi.Input<inputs.cognito.UserPoolRiskConfigurationAttachmentNotifyEmailTypeArgs>;
        /**
         * The reply-to email address of an email template.
         */
        replyTo?: pulumi.Input<string>;
        /**
         * The Amazon Resource Name (ARN) of the identity that is associated with the sending authorization policy. This identity permits Amazon Cognito to send for the email address specified in the `From` parameter.
         */
        sourceArn: pulumi.Input<string>;
    }
    interface UserPoolRiskConfigurationAttachmentNotifyEmailTypeArgs {
        /**
         * The body of an email notification formatted in HTML. Choose an `HtmlBody` or a `TextBody` to send an HTML-formatted or plaintext message, respectively.
         */
        htmlBody?: pulumi.Input<string>;
        /**
         * The subject of the threat protection email notification.
         */
        subject: pulumi.Input<string>;
        /**
         * The body of an email notification formatted in plaintext. Choose an `HtmlBody` or a `TextBody` to send an HTML-formatted or plaintext message, respectively.
         */
        textBody?: pulumi.Input<string>;
    }
    interface UserPoolRiskConfigurationAttachmentRiskExceptionConfigurationTypeArgs {
        /**
         * An always-block IP address list. Overrides the risk decision and always blocks authentication requests. This parameter is displayed and set in CIDR notation.
         */
        blockedIpRangeList?: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * An always-allow IP address list. Risk detection isn't performed on the IP addresses in this range list. This parameter is displayed and set in CIDR notation.
         */
        skippedIpRangeList?: pulumi.Input<pulumi.Input<string>[]>;
    }
    interface UserPoolSchemaAttributeArgs {
        /**
         * The data format of the values for your attribute. When you choose an `AttributeDataType` , Amazon Cognito validates the input against the data type. A custom attribute value in your user's ID token is always a string, for example `"custom:isMember" : "true"` or `"custom:YearsAsMember" : "12"` .
         */
        attributeDataType?: pulumi.Input<string>;
        /**
         * > You should use [WriteAttributes](https://docs.aws.amazon.com/cognito-user-identity-pools/latest/APIReference/API_UserPoolClientType.html#CognitoUserPools-Type-UserPoolClientType-WriteAttributes) in the user pool client to control how attributes can be mutated for new use cases instead of using `DeveloperOnlyAttribute` .
         *
         * Specifies whether the attribute type is developer only. This attribute can only be modified by an administrator. Users won't be able to modify this attribute using their access token. For example, `DeveloperOnlyAttribute` can be modified using AdminUpdateUserAttributes but can't be updated using UpdateUserAttributes.
         */
        developerOnlyAttribute?: pulumi.Input<boolean>;
        /**
         * Specifies whether the value of the attribute can be changed.
         *
         * Any user pool attribute whose value you map from an IdP attribute must be mutable, with a parameter value of `true` . Amazon Cognito updates mapped attributes when users sign in to your application through an IdP. If an attribute is immutable, Amazon Cognito throws an error when it attempts to update the attribute. For more information, see [Specifying Identity Provider Attribute Mappings for Your User Pool](https://docs.aws.amazon.com/cognito/latest/developerguide/cognito-user-pools-specifying-attribute-mapping.html) .
         */
        mutable?: pulumi.Input<boolean>;
        /**
         * The name of your user pool attribute. When you create or update a user pool, adding a schema attribute creates a custom or developer-only attribute. When you add an attribute with a `Name` value of `MyAttribute` , Amazon Cognito creates the custom attribute `custom:MyAttribute` . When `DeveloperOnlyAttribute` is `true` , Amazon Cognito creates your attribute as `dev:MyAttribute` . In an operation that describes a user pool, Amazon Cognito returns this value as `value` for standard attributes, `custom:value` for custom attributes, and `dev:value` for developer-only attributes..
         */
        name?: pulumi.Input<string>;
        /**
         * Specifies the constraints for an attribute of the number type.
         */
        numberAttributeConstraints?: pulumi.Input<inputs.cognito.UserPoolNumberAttributeConstraintsArgs>;
        /**
         * Specifies whether a user pool attribute is required. If the attribute is required and the user doesn't provide a value, registration or sign-in will fail.
         */
        required?: pulumi.Input<boolean>;
        /**
         * Specifies the constraints for an attribute of the string type.
         */
        stringAttributeConstraints?: pulumi.Input<inputs.cognito.UserPoolStringAttributeConstraintsArgs>;
    }
    interface UserPoolSignInPolicyArgs {
        /**
         * The sign-in methods that a user pool supports as the first factor. You can permit users to start authentication with a standard username and password, or with other one-time password and hardware factors.
         *
         * Supports values of `EMAIL_OTP` , `SMS_OTP` , `WEB_AUTHN` and `PASSWORD` ,
         */
        allowedFirstAuthFactors?: pulumi.Input<pulumi.Input<string>[]>;
    }
    interface UserPoolSmsConfigurationArgs {
        /**
         * The external ID provides additional security for your IAM role. You can use an `ExternalId` with the IAM role that you use with Amazon SNS to send SMS messages for your user pool. If you provide an `ExternalId` , your Amazon Cognito user pool includes it in the request to assume your IAM role. You can configure the role trust policy to require that Amazon Cognito, and any principal, provide the `ExternalID` . If you use the Amazon Cognito Management Console to create a role for SMS multi-factor authentication (MFA), Amazon Cognito creates a role with the required permissions and a trust policy that demonstrates use of the `ExternalId` .
         *
         * For more information about the `ExternalId` of a role, see [How to use an external ID when granting access to your AWS resources to a third party](https://docs.aws.amazon.com/IAM/latest/UserGuide/id_roles_create_for-user_externalid.html) .
         */
        externalId?: pulumi.Input<string>;
        /**
         * The Amazon Resource Name (ARN) of the Amazon SNS caller. This is the ARN of the IAM role in your AWS account that Amazon Cognito will use to send SMS messages. SMS messages are subject to a [spending limit](https://docs.aws.amazon.com/cognito/latest/developerguide/user-pool-settings-email-phone-verification.html) .
         */
        snsCallerArn?: pulumi.Input<string>;
        /**
         * The AWS Region to use with Amazon SNS integration. You can choose the same Region as your user pool, or a supported *Legacy Amazon SNS alternate Region* .
         *
         * Amazon Cognito resources in the Asia Pacific (Seoul) AWS Region must use your Amazon SNS configuration in the Asia Pacific (Tokyo) Region. For more information, see [SMS message settings for Amazon Cognito user pools](https://docs.aws.amazon.com/cognito/latest/developerguide/user-pool-sms-settings.html) .
         */
        snsRegion?: pulumi.Input<string>;
    }
    interface UserPoolStringAttributeConstraintsArgs {
        /**
         * The maximum length of a string attribute value. Must be a number less than or equal to `2^1023` , represented as a string with a length of 131072 characters or fewer.
         */
        maxLength?: pulumi.Input<string>;
        /**
         * The minimum length of a string attribute value.
         */
        minLength?: pulumi.Input<string>;
    }
    interface UserPoolUserAttributeTypeArgs {
        /**
         * The name of the attribute.
         */
        name?: pulumi.Input<string>;
        /**
         * The value of the attribute.
         */
        value?: pulumi.Input<string>;
    }
    interface UserPoolUserAttributeUpdateSettingsArgs {
        /**
         * Requires that your user verifies their email address, phone number, or both before Amazon Cognito updates the value of that attribute. When you update a user attribute that has this option activated, Amazon Cognito sends a verification message to the new phone number or email address. Amazon Cognito doesn’t change the value of the attribute until your user responds to the verification message and confirms the new value.
         *
         * When `AttributesRequireVerificationBeforeUpdate` is false, your user pool doesn't require that your users verify attribute changes before Amazon Cognito updates them. In a user pool where `AttributesRequireVerificationBeforeUpdate` is false, API operations that change attribute values can immediately update a user’s `email` or `phone_number` attribute.
         */
        attributesRequireVerificationBeforeUpdate: pulumi.Input<pulumi.Input<string>[]>;
    }
    interface UserPoolUsernameConfigurationArgs {
        /**
         * Specifies whether user name case sensitivity will be applied for all users in the user pool through Amazon Cognito APIs. For most use cases, set case sensitivity to `False` (case insensitive) as a best practice. When usernames and email addresses are case insensitive, users can sign in as the same user when they enter a different capitalization of their user name.
         *
         * Valid values include:
         *
         * - **true** - Enables case sensitivity for all username input. When this option is set to `true` , users must sign in using the exact capitalization of their given username, such as "UserName". This is the default value.
         * - **false** - Enables case insensitivity for all username input. For example, when this option is set to `false` , users can sign in using `username` , `USERNAME` , or `UserName` . This option also enables both `preferred_username` and `email` alias to be case insensitive, in addition to the `username` attribute.
         */
        caseSensitive?: pulumi.Input<boolean>;
    }
    interface UserPoolVerificationMessageTemplateArgs {
        /**
         * The configuration of verification emails to contain a clickable link or a verification code.
         *
         * For link, your template body must contain link text in the format `{##Click here##}` . "Click here" in the example is a customizable string. For code, your template body must contain a code placeholder in the format `{####}` .
         */
        defaultEmailOption?: pulumi.Input<string>;
        /**
         * The template for email messages that Amazon Cognito sends to your users. You can set an `EmailMessage` template only if the value of [EmailSendingAccount](https://docs.aws.amazon.com/cognito-user-identity-pools/latest/APIReference/API_EmailConfigurationType.html#CognitoUserPools-Type-EmailConfigurationType-EmailSendingAccount) is `DEVELOPER` . When your [EmailSendingAccount](https://docs.aws.amazon.com/cognito-user-identity-pools/latest/APIReference/API_EmailConfigurationType.html#CognitoUserPools-Type-EmailConfigurationType-EmailSendingAccount) is `DEVELOPER` , your user pool sends email messages with your own Amazon SES configuration.
         */
        emailMessage?: pulumi.Input<string>;
        /**
         * The email message template for sending a confirmation link to the user. You can set an `EmailMessageByLink` template only if the value of [EmailSendingAccount](https://docs.aws.amazon.com/cognito-user-identity-pools/latest/APIReference/API_EmailConfigurationType.html#CognitoUserPools-Type-EmailConfigurationType-EmailSendingAccount) is `DEVELOPER` . When your [EmailSendingAccount](https://docs.aws.amazon.com/cognito-user-identity-pools/latest/APIReference/API_EmailConfigurationType.html#CognitoUserPools-Type-EmailConfigurationType-EmailSendingAccount) is `DEVELOPER` , your user pool sends email messages with your own Amazon SES configuration.
         */
        emailMessageByLink?: pulumi.Input<string>;
        /**
         * The subject line for the email message template. You can set an `EmailSubject` template only if the value of [EmailSendingAccount](https://docs.aws.amazon.com/cognito-user-identity-pools/latest/APIReference/API_EmailConfigurationType.html#CognitoUserPools-Type-EmailConfigurationType-EmailSendingAccount) is `DEVELOPER` . When your [EmailSendingAccount](https://docs.aws.amazon.com/cognito-user-identity-pools/latest/APIReference/API_EmailConfigurationType.html#CognitoUserPools-Type-EmailConfigurationType-EmailSendingAccount) is `DEVELOPER` , your user pool sends email messages with your own Amazon SES configuration.
         */
        emailSubject?: pulumi.Input<string>;
        /**
         * The subject line for the email message template for sending a confirmation link to the user. You can set an `EmailSubjectByLink` template only if the value of [EmailSendingAccount](https://docs.aws.amazon.com/cognito-user-identity-pools/latest/APIReference/API_EmailConfigurationType.html#CognitoUserPools-Type-EmailConfigurationType-EmailSendingAccount) is `DEVELOPER` . When your [EmailSendingAccount](https://docs.aws.amazon.com/cognito-user-identity-pools/latest/APIReference/API_EmailConfigurationType.html#CognitoUserPools-Type-EmailConfigurationType-EmailSendingAccount) is `DEVELOPER` , your user pool sends email messages with your own Amazon SES configuration.
         */
        emailSubjectByLink?: pulumi.Input<string>;
        /**
         * The template for SMS messages that Amazon Cognito sends to your users.
         */
        smsMessage?: pulumi.Input<string>;
    }
}
export declare namespace comprehend {
    interface DocumentClassifierAugmentedManifestsListItemArgs {
        /**
         * The JSON attribute that contains the annotations for your training documents. The number of attribute names that you specify depends on whether your augmented manifest file is the output of a single labeling job or a chained labeling job.
         *
         * If your file is the output of a single labeling job, specify the LabelAttributeName key that was used when the job was created in Ground Truth.
         *
         * If your file is the output of a chained labeling job, specify the LabelAttributeName key for one or more jobs in the chain. Each LabelAttributeName key provides the annotations from an individual job.
         */
        attributeNames: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * The Amazon S3 location of the augmented manifest file.
         */
        s3Uri: pulumi.Input<string>;
        /**
         * The purpose of the data you've provided in the augmented manifest. You can either train or test this data. If you don't specify, the default is train.
         *
         * TRAIN - all of the documents in the manifest will be used for training. If no test documents are provided, Amazon Comprehend will automatically reserve a portion of the training documents for testing.
         *
         * TEST - all of the documents in the manifest will be used for testing.
         */
        split?: pulumi.Input<enums.comprehend.DocumentClassifierAugmentedManifestsListItemSplit>;
    }
    interface DocumentClassifierDocumentReaderConfigArgs {
        /**
         * This field defines the Amazon Textract API operation that Amazon Comprehend uses to extract text from PDF files and image files. Enter one of the following values:
         *
         * - `TEXTRACT_DETECT_DOCUMENT_TEXT` - The Amazon Comprehend service uses the `DetectDocumentText` API operation.
         * - `TEXTRACT_ANALYZE_DOCUMENT` - The Amazon Comprehend service uses the `AnalyzeDocument` API operation.
         */
        documentReadAction: pulumi.Input<enums.comprehend.DocumentClassifierDocumentReaderConfigDocumentReadAction>;
        /**
         * Determines the text extraction actions for PDF files. Enter one of the following values:
         *
         * - `SERVICE_DEFAULT` - use the Amazon Comprehend service defaults for PDF files.
         * - `FORCE_DOCUMENT_READ_ACTION` - Amazon Comprehend uses the Textract API specified by DocumentReadAction for all PDF files, including digital PDF files.
         */
        documentReadMode?: pulumi.Input<enums.comprehend.DocumentClassifierDocumentReaderConfigDocumentReadMode>;
        /**
         * Specifies the type of Amazon Textract features to apply. If you chose `TEXTRACT_ANALYZE_DOCUMENT` as the read action, you must specify one or both of the following values:
         *
         * - `TABLES` - Returns additional information about any tables that are detected in the input document.
         * - `FORMS` - Returns additional information about any forms that are detected in the input document.
         */
        featureTypes?: pulumi.Input<pulumi.Input<enums.comprehend.DocumentClassifierDocumentReaderConfigFeatureTypesItem>[]>;
    }
    interface DocumentClassifierDocumentsArgs {
        /**
         * The S3 URI location of the training documents specified in the S3Uri CSV file.
         */
        s3Uri: pulumi.Input<string>;
        /**
         * The S3 URI location of the test documents included in the TestS3Uri CSV file. This field is not required if you do not specify a test CSV file.
         */
        testS3Uri?: pulumi.Input<string>;
    }
    interface DocumentClassifierInputDataConfigArgs {
        /**
         * A list of augmented manifest files that provide training data for your custom model. An augmented manifest file is a labeled dataset that is produced by Amazon SageMaker Ground Truth.
         *
         * This parameter is required if you set `DataFormat` to `AUGMENTED_MANIFEST` .
         */
        augmentedManifests?: pulumi.Input<pulumi.Input<inputs.comprehend.DocumentClassifierAugmentedManifestsListItemArgs>[]>;
        /**
         * The format of your training data:
         *
         * - `COMPREHEND_CSV` : A two-column CSV file, where labels are provided in the first column, and documents are provided in the second. If you use this value, you must provide the `S3Uri` parameter in your request.
         * - `AUGMENTED_MANIFEST` : A labeled dataset that is produced by Amazon SageMaker Ground Truth. This file is in JSON lines format. Each line is a complete JSON object that contains a training document and its associated labels.
         *
         * If you use this value, you must provide the `AugmentedManifests` parameter in your request.
         *
         * If you don't specify a value, Amazon Comprehend uses `COMPREHEND_CSV` as the default.
         */
        dataFormat?: pulumi.Input<enums.comprehend.DocumentClassifierInputDataConfigDataFormat>;
        documentReaderConfig?: pulumi.Input<inputs.comprehend.DocumentClassifierDocumentReaderConfigArgs>;
        /**
         * The type of input documents for training the model. Provide plain-text documents to create a plain-text model, and provide semi-structured documents to create a native document model.
         */
        documentType?: pulumi.Input<enums.comprehend.DocumentClassifierInputDataConfigDocumentType>;
        /**
         * The S3 location of the training documents. This parameter is required in a request to create a native document model.
         */
        documents?: pulumi.Input<inputs.comprehend.DocumentClassifierDocumentsArgs>;
        /**
         * Indicates the delimiter used to separate each label for training a multi-label classifier. The default delimiter between labels is a pipe (|). You can use a different character as a delimiter (if it's an allowed character) by specifying it under Delimiter for labels. If the training documents use a delimiter other than the default or the delimiter you specify, the labels on that line will be combined to make a single unique label, such as LABELLABELLABEL.
         */
        labelDelimiter?: pulumi.Input<string>;
        /**
         * The Amazon S3 URI for the input data. The S3 bucket must be in the same Region as the API endpoint that you are calling. The URI can point to a single input file or it can provide the prefix for a collection of input files.
         *
         * For example, if you use the URI `S3://bucketName/prefix` , if the prefix is a single file, Amazon Comprehend uses that file as input. If more than one file begins with the prefix, Amazon Comprehend uses all of them as input.
         *
         * This parameter is required if you set `DataFormat` to `COMPREHEND_CSV` .
         */
        s3Uri?: pulumi.Input<string>;
        /**
         * This specifies the Amazon S3 location that contains the test annotations for the document classifier. The URI must be in the same AWS Region as the API endpoint that you are calling.
         */
        testS3Uri?: pulumi.Input<string>;
    }
    interface DocumentClassifierOutputDataConfigArgs {
        /**
         * ID for the AWS Key Management Service (KMS) key that Amazon Comprehend uses to encrypt the output results from an analysis job. The KmsKeyId can be one of the following formats:
         *
         * - KMS Key ID: `"1234abcd-12ab-34cd-56ef-1234567890ab"`
         * - Amazon Resource Name (ARN) of a KMS Key: `"arn:aws:kms:us-west-2:111122223333:key/1234abcd-12ab-34cd-56ef-1234567890ab"`
         * - KMS Key Alias: `"alias/ExampleAlias"`
         * - ARN of a KMS Key Alias: `"arn:aws:kms:us-west-2:111122223333:alias/ExampleAlias"`
         */
        kmsKeyId?: pulumi.Input<string>;
        /**
         * When you use the `OutputDataConfig` object while creating a custom classifier, you specify the Amazon S3 location where you want to write the confusion matrix and other output files. The URI must be in the same Region as the API endpoint that you are calling. The location is used as the prefix for the actual location of this output file.
         *
         * When the custom classifier job is finished, the service creates the output file in a directory specific to the job. The `S3Uri` field contains the location of the output file, called `output.tar.gz` . It is a compressed archive that contains the confusion matrix.
         */
        s3Uri?: pulumi.Input<string>;
    }
    interface DocumentClassifierVpcConfigArgs {
        /**
         * The ID number for a security group on an instance of your private VPC. Security groups on your VPC function serve as a virtual firewall to control inbound and outbound traffic and provides security for the resources that you’ll be accessing on the VPC. This ID number is preceded by "sg-", for instance: "sg-03b388029b0a285ea". For more information, see [Security Groups for your VPC](https://docs.aws.amazon.com/vpc/latest/userguide/VPC_SecurityGroups.html) .
         */
        securityGroupIds: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * The ID for each subnet being used in your private VPC. This subnet is a subset of the a range of IPv4 addresses used by the VPC and is specific to a given availability zone in the VPC’s Region. This ID number is preceded by "subnet-", for instance: "subnet-04ccf456919e69055". For more information, see [VPCs and Subnets](https://docs.aws.amazon.com/vpc/latest/userguide/VPC_Subnets.html) .
         */
        subnets: pulumi.Input<pulumi.Input<string>[]>;
    }
    interface FlywheelDataSecurityConfigArgs {
        /**
         * ID for the AWS KMS key that Amazon Comprehend uses to encrypt the data in the data lake.
         */
        dataLakeKmsKeyId?: pulumi.Input<string>;
        /**
         * ID for the AWS KMS key that Amazon Comprehend uses to encrypt trained custom models. The ModelKmsKeyId can be either of the following formats:
         *
         * - KMS Key ID: `"1234abcd-12ab-34cd-56ef-1234567890ab"`
         * - Amazon Resource Name (ARN) of a KMS Key: `"arn:aws:kms:us-west-2:111122223333:key/1234abcd-12ab-34cd-56ef-1234567890ab"`
         */
        modelKmsKeyId?: pulumi.Input<string>;
        /**
         * ID for the AWS KMS key that Amazon Comprehend uses to encrypt the volume.
         */
        volumeKmsKeyId?: pulumi.Input<string>;
        /**
         * Configuration parameters for an optional private Virtual Private Cloud (VPC) containing the resources you are using for the job. For more information, see [Amazon VPC](https://docs.aws.amazon.com/vpc/latest/userguide/what-is-amazon-vpc.html) .
         */
        vpcConfig?: pulumi.Input<inputs.comprehend.FlywheelVpcConfigArgs>;
    }
    interface FlywheelDocumentClassificationConfigArgs {
        /**
         * One or more labels to associate with the custom classifier.
         */
        labels?: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * Classification mode indicates whether the documents are `MULTI_CLASS` or `MULTI_LABEL` .
         */
        mode: pulumi.Input<enums.comprehend.FlywheelDocumentClassificationConfigMode>;
    }
    interface FlywheelEntityRecognitionConfigArgs {
        /**
         * Up to 25 entity types that the model is trained to recognize.
         */
        entityTypes?: pulumi.Input<pulumi.Input<inputs.comprehend.FlywheelEntityTypesListItemArgs>[]>;
    }
    interface FlywheelEntityTypesListItemArgs {
        /**
         * An entity type within a labeled training dataset that Amazon Comprehend uses to train a custom entity recognizer.
         *
         * Entity types must not contain the following invalid characters: \n (line break), \\n (escaped line break, \r (carriage return), \\r (escaped carriage return), \t (tab), \\t (escaped tab), and , (comma).
         */
        type: pulumi.Input<string>;
    }
    interface FlywheelTaskConfigArgs {
        /**
         * Configuration required for a document classification model.
         */
        documentClassificationConfig?: pulumi.Input<inputs.comprehend.FlywheelDocumentClassificationConfigArgs>;
        /**
         * Configuration required for an entity recognition model.
         */
        entityRecognitionConfig?: pulumi.Input<inputs.comprehend.FlywheelEntityRecognitionConfigArgs>;
        /**
         * Language code for the language that the model supports.
         */
        languageCode: pulumi.Input<enums.comprehend.FlywheelTaskConfigLanguageCode>;
    }
    interface FlywheelVpcConfigArgs {
        /**
         * The ID number for a security group on an instance of your private VPC. Security groups on your VPC function serve as a virtual firewall to control inbound and outbound traffic and provides security for the resources that you’ll be accessing on the VPC. This ID number is preceded by "sg-", for instance: "sg-03b388029b0a285ea". For more information, see [Security Groups for your VPC](https://docs.aws.amazon.com/vpc/latest/userguide/VPC_SecurityGroups.html) .
         */
        securityGroupIds: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * The ID for each subnet being used in your private VPC. This subnet is a subset of the a range of IPv4 addresses used by the VPC and is specific to a given availability zone in the VPC’s Region. This ID number is preceded by "subnet-", for instance: "subnet-04ccf456919e69055". For more information, see [VPCs and Subnets](https://docs.aws.amazon.com/vpc/latest/userguide/VPC_Subnets.html) .
         */
        subnets: pulumi.Input<pulumi.Input<string>[]>;
    }
}
export declare namespace config {
}
export declare namespace configuration {
    /**
     * Indicates whether an AWS resource or CC rule is compliant and provides the number of contributors that affect the compliance.
     */
    interface CompliancePropertiesArgs {
        /**
         * Compliance type determined by the Config rule
         */
        type?: pulumi.Input<string>;
    }
    /**
     * Provides the CustomPolicyDetails, the rule owner (```` for managed rules, ``CUSTOM_POLICY`` for Custom Policy rules, and ``CUSTOM_LAMBDA`` for Custom Lambda rules), the rule identifier, and the events that cause the evaluation of your AWS resources.
     */
    interface ConfigRuleCustomPolicyDetailsArgs {
        /**
         * The boolean expression for enabling debug logging for your CC Custom Policy rule. The default value is ``false``.
         */
        enableDebugLogDelivery?: pulumi.Input<boolean>;
        /**
         * The runtime system for your CC Custom Policy rule. Guard is a policy-as-code language that allows you to write policies that are enforced by CC Custom Policy rules. For more information about Guard, see the [Guard GitHub Repository](https://docs.aws.amazon.com/https://github.com/aws-cloudformation/cloudformation-guard).
         */
        policyRuntime?: pulumi.Input<string>;
        /**
         * The policy definition containing the logic for your CC Custom Policy rule.
         */
        policyText?: pulumi.Input<string>;
    }
    /**
     * The configuration object for CC rule evaluation mode. The supported valid values are Detective or Proactive.
     */
    interface ConfigRuleEvaluationModeConfigurationArgs {
        /**
         * The mode of an evaluation. The valid values are Detective or Proactive.
         */
        mode?: pulumi.Input<string>;
    }
    /**
     * Defines which resources trigger an evaluation for an CC rule. The scope can include one or more resource types, a combination of a tag key and value, or a combination of one resource type and one resource ID. Specify a scope to constrain which resources trigger an evaluation for a rule. Otherwise, evaluations for the rule are triggered when any resource in your recording group changes in configuration.
     */
    interface ConfigRuleScopeArgs {
        /**
         * The ID of the only AWS resource that you want to trigger an evaluation for the rule. If you specify a resource ID, you must specify one resource type for ``ComplianceResourceTypes``.
         */
        complianceResourceId?: pulumi.Input<string>;
        /**
         * The resource types of only those AWS resources that you want to trigger an evaluation for the rule. You can only specify one type if you also specify a resource ID for ``ComplianceResourceId``.
         */
        complianceResourceTypes?: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * The tag key that is applied to only those AWS resources that you want to trigger an evaluation for the rule.
         */
        tagKey?: pulumi.Input<string>;
        /**
         * The tag value applied to only those AWS resources that you want to trigger an evaluation for the rule. If you specify a value for ``TagValue``, you must also specify a value for ``TagKey``.
         */
        tagValue?: pulumi.Input<string>;
    }
    /**
     * Provides the CustomPolicyDetails, the rule owner (```` for managed rules, ``CUSTOM_POLICY`` for Custom Policy rules, and ``CUSTOM_LAMBDA`` for Custom Lambda rules), the rule identifier, and the events that cause the evaluation of your AWS resources.
     */
    interface ConfigRuleSourceArgs {
        /**
         * Provides the runtime system, policy definition, and whether debug logging is enabled. Required when owner is set to ``CUSTOM_POLICY``.
         */
        customPolicyDetails?: pulumi.Input<inputs.configuration.ConfigRuleCustomPolicyDetailsArgs>;
        /**
         * Indicates whether AWS or the customer owns and manages the CC rule.
         *   CC Managed Rules are predefined rules owned by AWS. For more information, see [Managed Rules](https://docs.aws.amazon.com/config/latest/developerguide/evaluate-config_use-managed-rules.html) in the *developer guide*.
         *   CC Custom Rules are rules that you can develop either with Guard (``CUSTOM_POLICY``) or LAMlong (``CUSTOM_LAMBDA``). For more information, see [Custom Rules](https://docs.aws.amazon.com/config/latest/developerguide/evaluate-config_develop-rules.html) in the *developer guide*.
         */
        owner: pulumi.Input<string>;
        /**
         * Provides the source and the message types that cause CC to evaluate your AWS resources against a rule. It also provides the frequency with which you want CC to run evaluations for the rule if the trigger type is periodic.
         *  If the owner is set to ``CUSTOM_POLICY``, the only acceptable values for the CC rule trigger message type are ``ConfigurationItemChangeNotification`` and ``OversizedConfigurationItemChangeNotification``.
         */
        sourceDetails?: pulumi.Input<pulumi.Input<inputs.configuration.ConfigRuleSourceDetailArgs>[]>;
        /**
         * For CC Managed rules, a predefined identifier from a list. For example, ``IAM_PASSWORD_POLICY`` is a managed rule. To reference a managed rule, see [List of Managed Rules](https://docs.aws.amazon.com/config/latest/developerguide/managed-rules-by-aws-config.html).
         *  For CC Custom Lambda rules, the identifier is the Amazon Resource Name (ARN) of the rule's LAMlong function, such as ``arn:aws:lambda:us-east-2:123456789012:function:custom_rule_name``.
         *  For CC Custom Policy rules, this field will be ignored.
         */
        sourceIdentifier?: pulumi.Input<string>;
    }
    /**
     * Provides the source and the message types that trigger CC to evaluate your AWS resources against a rule. It also provides the frequency with which you want CC to run evaluations for the rule if the trigger type is periodic. You can specify the parameter values for ``SourceDetail`` only for custom rules.
     */
    interface ConfigRuleSourceDetailArgs {
        /**
         * The source of the event, such as an AWS service, that triggers CC to evaluate your AWS resources.
         */
        eventSource: pulumi.Input<string>;
        /**
         * The frequency at which you want CC to run evaluations for a custom rule with a periodic trigger. If you specify a value for ``MaximumExecutionFrequency``, then ``MessageType`` must use the ``ScheduledNotification`` value.
         *   By default, rules with a periodic trigger are evaluated every 24 hours. To change the frequency, specify a valid value for the ``MaximumExecutionFrequency`` parameter.
         *  Based on the valid value you choose, CC runs evaluations once for each valid value. For example, if you choose ``Three_Hours``, CC runs evaluations once every three hours. In this case, ``Three_Hours`` is the frequency of this rule.
         */
        maximumExecutionFrequency?: pulumi.Input<string>;
        /**
         * The type of notification that triggers CC to run an evaluation for a rule. You can specify the following notification types:
         *   +   ``ConfigurationItemChangeNotification`` - Triggers an evaluation when CC delivers a configuration item as a result of a resource change.
         *   +   ``OversizedConfigurationItemChangeNotification`` - Triggers an evaluation when CC delivers an oversized configuration item. CC may generate this notification type when a resource changes and the notification exceeds the maximum size allowed by Amazon SNS.
         *   +   ``ScheduledNotification`` - Triggers a periodic evaluation at the frequency specified for ``MaximumExecutionFrequency``.
         *   +   ``ConfigurationSnapshotDeliveryCompleted`` - Triggers a periodic evaluation when CC delivers a configuration snapshot.
         *
         *  If you want your custom rule to be triggered by configuration changes, specify two SourceDetail objects, one for ``ConfigurationItemChangeNotification`` and one for ``OversizedConfigurationItemChangeNotification``.
         */
        messageType: pulumi.Input<string>;
    }
    interface ConfigurationAggregatorAccountAggregationSourceArgs {
        /**
         * The 12-digit account ID of the account being aggregated.
         */
        accountIds: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * If true, aggregate existing AWS Config regions and future regions.
         */
        allAwsRegions?: pulumi.Input<boolean>;
        /**
         * The source regions being aggregated.
         */
        awsRegions?: pulumi.Input<pulumi.Input<string>[]>;
    }
    interface ConfigurationAggregatorOrganizationAggregationSourceArgs {
        /**
         * If true, aggregate existing AWS Config regions and future regions.
         */
        allAwsRegions?: pulumi.Input<boolean>;
        /**
         * The source regions being aggregated.
         */
        awsRegions?: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * ARN of the IAM role used to retrieve AWS Organizations details associated with the aggregator account.
         */
        roleArn: pulumi.Input<string>;
    }
    /**
     * Input parameters in the form of key-value pairs for the conformance pack.
     */
    interface ConformancePackInputParameterArgs {
        /**
         * One part of a key-value pair.
         */
        parameterName: pulumi.Input<string>;
        /**
         * Another part of the key-value pair.
         */
        parameterValue: pulumi.Input<string>;
    }
    /**
     * Input parameters in the form of key-value pairs for the conformance pack.
     */
    interface OrganizationConformancePackConformancePackInputParameterArgs {
        /**
         * One part of a key-value pair.
         */
        parameterName: pulumi.Input<string>;
        /**
         * One part of a key-value pair.
         */
        parameterValue: pulumi.Input<string>;
    }
    /**
     * The TemplateSSMDocumentDetails object contains the name of the SSM document and the version of the SSM document.
     */
    interface TemplateSsmDocumentDetailsPropertiesArgs {
        /**
         * The name or Amazon Resource Name (ARN) of the SSM document to use to create a conformance pack. If you use the document name, AWS Config checks only your account and AWS Region for the SSM document.
         */
        documentName?: pulumi.Input<string>;
        /**
         * The version of the SSM document to use to create a conformance pack. By default, AWS Config uses the latest version.
         *
         * > This field is optional.
         */
        documentVersion?: pulumi.Input<string>;
    }
}
export declare namespace connect {
    /**
     * The constraints for the task template
     */
    interface ConstraintsPropertiesArgs {
        /**
         * Lists the fields that are invisible to agents.
         */
        invisibleFields?: pulumi.Input<pulumi.Input<inputs.connect.TaskTemplateInvisibleFieldInfoArgs>[]>;
        /**
         * Lists the fields that are read-only to agents, and cannot be edited.
         */
        readOnlyFields?: pulumi.Input<pulumi.Input<inputs.connect.TaskTemplateReadOnlyFieldInfoArgs>[]>;
        /**
         * Lists the fields that are required to be filled by agents.
         */
        requiredFields?: pulumi.Input<pulumi.Input<inputs.connect.TaskTemplateRequiredFieldInfoArgs>[]>;
    }
    /**
     * An item at the root level. All items must be sections.
     */
    interface EvaluationFormBaseItemArgs {
        /**
         * A subsection or inner section of an item.
         */
        section: pulumi.Input<inputs.connect.EvaluationFormSectionArgs>;
    }
    /**
     * Items that are part of the evaluation form. The total number of sections and questions must not exceed 100 each. Questions must be contained in a section.
     */
    interface EvaluationFormItemArgs {
        /**
         * The information of the question.
         */
        question?: pulumi.Input<inputs.connect.EvaluationFormQuestionArgs>;
        /**
         * The information of the section.
         */
        section?: pulumi.Input<inputs.connect.EvaluationFormSectionArgs>;
    }
    /**
     * Information about the automation configuration in numeric questions.
     */
    interface EvaluationFormNumericQuestionAutomationArgs {
        /**
         * The property value of the automation.
         */
        propertyValue: pulumi.Input<inputs.connect.EvaluationFormNumericQuestionPropertyValueAutomationArgs>;
    }
    /**
     * Information about the option range used for scoring in numeric questions.
     */
    interface EvaluationFormNumericQuestionOptionArgs {
        /**
         * The flag to mark the option as automatic fail. If an automatic fail answer is provided, the overall evaluation gets a score of 0.
         */
        automaticFail?: pulumi.Input<boolean>;
        /**
         * The maximum answer value of the range option.
         */
        maxValue: pulumi.Input<number>;
        /**
         * The minimum answer value of the range option.
         */
        minValue: pulumi.Input<number>;
        /**
         * The score assigned to answer values within the range option.
         *   *Minimum*: 0
         *   *Maximum*: 10
         */
        score?: pulumi.Input<number>;
    }
    /**
     * Information about properties for a numeric question in an evaluation form.
     */
    interface EvaluationFormNumericQuestionPropertiesArgs {
        /**
         * The automation properties of the numeric question.
         */
        automation?: pulumi.Input<inputs.connect.EvaluationFormNumericQuestionAutomationArgs>;
        /**
         * The maximum answer value.
         */
        maxValue: pulumi.Input<number>;
        /**
         * The minimum answer value.
         */
        minValue: pulumi.Input<number>;
        /**
         * The scoring options of the numeric question.
         */
        options?: pulumi.Input<pulumi.Input<inputs.connect.EvaluationFormNumericQuestionOptionArgs>[]>;
    }
    /**
     * Information about the property value used in automation of a numeric questions.
     */
    interface EvaluationFormNumericQuestionPropertyValueAutomationArgs {
        /**
         * The property label of the automation.
         */
        label: pulumi.Input<enums.connect.EvaluationFormNumericQuestionPropertyValueAutomationLabel>;
    }
    /**
     * Information about a question from an evaluation form.
     */
    interface EvaluationFormQuestionArgs {
        /**
         * The instructions of the section.
         *   *Length Constraints*: Minimum length of 0. Maximum length of 1024.
         */
        instructions?: pulumi.Input<string>;
        /**
         * The flag to enable not applicable answers to the question.
         */
        notApplicableEnabled?: pulumi.Input<boolean>;
        /**
         * The type of the question.
         *   *Allowed values*: ``NUMERIC`` | ``SINGLESELECT`` | ``TEXT``
         */
        questionType: pulumi.Input<enums.connect.EvaluationFormQuestionQuestionType>;
        /**
         * The properties of the type of question. Text questions do not have to define question type properties.
         */
        questionTypeProperties?: pulumi.Input<inputs.connect.EvaluationFormQuestionTypePropertiesArgs>;
        /**
         * The identifier of the question. An identifier must be unique within the evaluation form.
         *   *Length Constraints*: Minimum length of 1. Maximum length of 40.
         */
        refId: pulumi.Input<string>;
        /**
         * The title of the question.
         *   *Length Constraints*: Minimum length of 1. Maximum length of 350.
         */
        title: pulumi.Input<string>;
        /**
         * The scoring weight of the section.
         *   *Minimum*: 0
         *   *Maximum*: 100
         */
        weight?: pulumi.Input<number>;
    }
    /**
     * Information about properties for a question in an evaluation form. The question type properties must be either for a numeric question or a single select question.
     */
    interface EvaluationFormQuestionTypePropertiesArgs {
        /**
         * The properties of the numeric question.
         */
        numeric?: pulumi.Input<inputs.connect.EvaluationFormNumericQuestionPropertiesArgs>;
        /**
         * The properties of the numeric question.
         */
        singleSelect?: pulumi.Input<inputs.connect.EvaluationFormSingleSelectQuestionPropertiesArgs>;
    }
    /**
     * A scoring strategy of the evaluation form.
     */
    interface EvaluationFormScoringStrategyArgs {
        /**
         * The scoring mode of the evaluation form.
         *   *Allowed values*: ``QUESTION_ONLY`` | ``SECTION_ONLY``
         */
        mode: pulumi.Input<enums.connect.EvaluationFormScoringStrategyMode>;
        /**
         * The scoring status of the evaluation form.
         *   *Allowed values*: ``ENABLED`` | ``DISABLED``
         */
        status: pulumi.Input<enums.connect.EvaluationFormScoringStrategyStatus>;
    }
    /**
     * Information about a section from an evaluation form. A section can contain sections and/or questions. Evaluation forms can only contain sections and subsections (two level nesting).
     */
    interface EvaluationFormSectionArgs {
        /**
         * The instructions of the section.
         */
        instructions?: pulumi.Input<string>;
        /**
         * The items of the section.
         *   *Minimum*: 1
         */
        items?: pulumi.Input<pulumi.Input<inputs.connect.EvaluationFormItemArgs>[]>;
        /**
         * The identifier of the section. An identifier must be unique within the evaluation form.
         *   *Length Constraints*: Minimum length of 1. Maximum length of 40.
         */
        refId: pulumi.Input<string>;
        /**
         * The title of the section.
         *   *Length Constraints*: Minimum length of 1. Maximum length of 128.
         */
        title: pulumi.Input<string>;
        /**
         * The scoring weight of the section.
         *   *Minimum*: 0
         *   *Maximum*: 100
         */
        weight?: pulumi.Input<number>;
    }
    /**
     * Information about the automation configuration in single select questions. Automation options are evaluated in order, and the first matched option is applied. If no automation option matches, and there is a default option, then the default option is applied.
     */
    interface EvaluationFormSingleSelectQuestionAutomationArgs {
        /**
         * The identifier of the default answer option, when none of the automation options match the criteria.
         *   *Length Constraints*: Minimum length of 1. Maximum length of 40.
         */
        defaultOptionRefId?: pulumi.Input<string>;
        /**
         * The automation options of the single select question.
         *   *Minimum*: 1
         *   *Maximum*: 20
         */
        options: pulumi.Input<pulumi.Input<inputs.connect.EvaluationFormSingleSelectQuestionAutomationOptionArgs>[]>;
    }
    /**
     * The automation options of the single select question.
     */
    interface EvaluationFormSingleSelectQuestionAutomationOptionArgs {
        /**
         * The automation option based on a rule category for the single select question.
         */
        ruleCategory: pulumi.Input<inputs.connect.EvaluationFormSingleSelectQuestionRuleCategoryAutomationArgs>;
    }
    /**
     * Information about the automation configuration in single select questions.
     */
    interface EvaluationFormSingleSelectQuestionOptionArgs {
        /**
         * The flag to mark the option as automatic fail. If an automatic fail answer is provided, the overall evaluation gets a score of 0.
         */
        automaticFail?: pulumi.Input<boolean>;
        /**
         * The identifier of the answer option. An identifier must be unique within the question.
         *   *Length Constraints*: Minimum length of 1. Maximum length of 40.
         */
        refId: pulumi.Input<string>;
        /**
         * The score assigned to the answer option.
         *   *Minimum*: 0
         *   *Maximum*: 10
         */
        score?: pulumi.Input<number>;
        /**
         * The title of the answer option.
         *   *Length Constraints*: Minimum length of 1. Maximum length of 128.
         */
        text: pulumi.Input<string>;
    }
    /**
     * Information about the options in single select questions.
     */
    interface EvaluationFormSingleSelectQuestionPropertiesArgs {
        /**
         * The display mode of the single select question.
         */
        automation?: pulumi.Input<inputs.connect.EvaluationFormSingleSelectQuestionAutomationArgs>;
        /**
         * The display mode of the single select question.
         *   *Allowed values*: ``DROPDOWN`` | ``RADIO``
         */
        displayAs?: pulumi.Input<enums.connect.EvaluationFormSingleSelectQuestionPropertiesDisplayAs>;
        /**
         * The answer options of the single select question.
         *   *Minimum*: 2
         *   *Maximum*: 256
         */
        options: pulumi.Input<pulumi.Input<inputs.connect.EvaluationFormSingleSelectQuestionOptionArgs>[]>;
    }
    /**
     * Information about the automation option based on a rule category for a single select question.
     *   *Length Constraints*: Minimum length of 1. Maximum length of 50.
     */
    interface EvaluationFormSingleSelectQuestionRuleCategoryAutomationArgs {
        /**
         * The category name, as defined in Rules.
         *   *Minimum*: 1
         *   *Maximum*: 50
         */
        category: pulumi.Input<string>;
        /**
         * The condition to apply for the automation option. If the condition is PRESENT, then the option is applied when the contact data includes the category. Similarly, if the condition is NOT_PRESENT, then the option is applied when the contact data does not include the category.
         *   *Allowed values*: ``PRESENT`` | ``NOT_PRESENT``
         *   *Maximum*: 50
         */
        condition: pulumi.Input<enums.connect.EvaluationFormSingleSelectQuestionRuleCategoryAutomationCondition>;
        /**
         * The identifier of the answer option. An identifier must be unique within the question.
         *   *Length Constraints*: Minimum length of 1. Maximum length of 40.
         */
        optionRefId: pulumi.Input<string>;
    }
    /**
     * Contains information about the hours of operation.
     */
    interface HoursOfOperationConfigArgs {
        /**
         * The day that the hours of operation applies to.
         */
        day: pulumi.Input<enums.connect.HoursOfOperationConfigDay>;
        /**
         * The end time that your contact center closes.
         */
        endTime: pulumi.Input<inputs.connect.HoursOfOperationTimeSliceArgs>;
        /**
         * The start time that your contact center opens.
         */
        startTime: pulumi.Input<inputs.connect.HoursOfOperationTimeSliceArgs>;
    }
    /**
     * Overrides attached to the hours of operation.
     */
    interface HoursOfOperationOverrideArgs {
        /**
         * The date from which the hours of operation override would be effective.
         */
        effectiveFrom: pulumi.Input<string>;
        /**
         * The date till which the hours of operation override would be effective.
         */
        effectiveTill: pulumi.Input<string>;
        /**
         * The identifier for the hours of operation override.
         */
        hoursOfOperationOverrideId?: pulumi.Input<string>;
        overrideConfig: pulumi.Input<pulumi.Input<inputs.connect.HoursOfOperationOverrideConfigArgs>[]>;
        overrideDescription?: pulumi.Input<string>;
        overrideName: pulumi.Input<string>;
    }
    /**
     * Contains information about the hours of operation override.
     */
    interface HoursOfOperationOverrideConfigArgs {
        /**
         * The day that the hours of operation override applies to.
         */
        day: pulumi.Input<enums.connect.HoursOfOperationOverrideConfigDay>;
        /**
         * The new end time that your contact center closes for the overriden days.
         */
        endTime: pulumi.Input<inputs.connect.HoursOfOperationOverrideTimeSliceArgs>;
        /**
         * The new start time that your contact center opens for the overriden days.
         */
        startTime: pulumi.Input<inputs.connect.HoursOfOperationOverrideTimeSliceArgs>;
    }
    /**
     * The start time or end time for an an hours of operation override.
     */
    interface HoursOfOperationOverrideTimeSliceArgs {
        /**
         * The hours.
         */
        hours: pulumi.Input<number>;
        /**
         * The minutes.
         */
        minutes: pulumi.Input<number>;
    }
    /**
     * The start time or end time for an hours of operation.
     */
    interface HoursOfOperationTimeSliceArgs {
        /**
         * The hours.
         */
        hours: pulumi.Input<number>;
        /**
         * The minutes.
         */
        minutes: pulumi.Input<number>;
    }
    interface InstanceAttributesArgs {
        autoResolveBestVoices?: pulumi.Input<boolean>;
        contactLens?: pulumi.Input<boolean>;
        contactflowLogs?: pulumi.Input<boolean>;
        earlyMedia?: pulumi.Input<boolean>;
        inboundCalls: pulumi.Input<boolean>;
        outboundCalls: pulumi.Input<boolean>;
        useCustomTtsVoices?: pulumi.Input<boolean>;
    }
    interface InstanceStorageConfigEncryptionConfigArgs {
        /**
         * The type of encryption.
         */
        encryptionType: pulumi.Input<enums.connect.InstanceStorageConfigEncryptionType>;
        /**
         * The full ARN of the encryption key.
         *
         * > Be sure to provide the full ARN of the encryption key, not just the ID.
         * >
         * > Amazon Connect supports only KMS keys with the default key spec of [`SYMMETRIC_DEFAULT`](https://docs.aws.amazon.com/kms/latest/developerguide/asymmetric-key-specs.html#key-spec-symmetric-default) .
         */
        keyId: pulumi.Input<string>;
    }
    interface InstanceStorageConfigKinesisFirehoseConfigArgs {
        /**
         * The Amazon Resource Name (ARN) of the delivery stream.
         */
        firehoseArn: pulumi.Input<string>;
    }
    interface InstanceStorageConfigKinesisStreamConfigArgs {
        /**
         * The Amazon Resource Name (ARN) of the data stream.
         */
        streamArn: pulumi.Input<string>;
    }
    interface InstanceStorageConfigKinesisVideoStreamConfigArgs {
        /**
         * The encryption configuration.
         */
        encryptionConfig: pulumi.Input<inputs.connect.InstanceStorageConfigEncryptionConfigArgs>;
        /**
         * The prefix of the video stream.
         */
        prefix: pulumi.Input<string>;
        /**
         * The number of hours data is retained in the stream. Kinesis Video Streams retains the data in a data store that is associated with the stream.
         *
         * The default value is 0, indicating that the stream does not persist data.
         */
        retentionPeriodHours: pulumi.Input<number>;
    }
    interface InstanceStorageConfigS3ConfigArgs {
        /**
         * The S3 bucket name.
         */
        bucketName: pulumi.Input<string>;
        /**
         * The S3 bucket prefix.
         */
        bucketPrefix: pulumi.Input<string>;
        /**
         * The Amazon S3 encryption configuration.
         */
        encryptionConfig?: pulumi.Input<inputs.connect.InstanceStorageConfigEncryptionConfigArgs>;
    }
    /**
     * The outbound caller ID name, number, and outbound whisper flow.
     */
    interface QueueOutboundCallerConfigArgs {
        /**
         * The caller ID name.
         */
        outboundCallerIdName?: pulumi.Input<string>;
        /**
         * The Amazon Resource Name (ARN) of the outbound caller ID number.
         *
         * > Only use the phone number ARN format that doesn't contain `instance` in the path, for example, `arn:aws:connect:us-east-1:1234567890:phone-number/uuid` . This is the same ARN format that is returned when you create a phone number using CloudFormation , or when you call the [ListPhoneNumbersV2](https://docs.aws.amazon.com/connect/latest/APIReference/API_ListPhoneNumbersV2.html) API.
         */
        outboundCallerIdNumberArn?: pulumi.Input<string>;
        /**
         * The Amazon Resource Name (ARN) of the outbound flow.
         */
        outboundFlowArn?: pulumi.Input<string>;
    }
    /**
     * The outbound email address ID.
     */
    interface QueueOutboundEmailConfigArgs {
        /**
         * The identifier of the email address.
         */
        outboundEmailAddressId?: pulumi.Input<string>;
    }
    /**
     * Configuration settings for the quick connect.
     */
    interface QuickConnectConfigArgs {
        /**
         * The phone configuration. This is required only if QuickConnectType is PHONE_NUMBER.
         */
        phoneConfig?: pulumi.Input<inputs.connect.QuickConnectPhoneNumberQuickConnectConfigArgs>;
        /**
         * The queue configuration. This is required only if QuickConnectType is QUEUE.
         */
        queueConfig?: pulumi.Input<inputs.connect.QuickConnectQueueQuickConnectConfigArgs>;
        /**
         * The type of quick connect. In the Amazon Connect console, when you create a quick connect, you are prompted to assign one of the following types: Agent (USER), External (PHONE_NUMBER), or Queue (QUEUE).
         */
        quickConnectType: pulumi.Input<enums.connect.QuickConnectType>;
        /**
         * The user configuration. This is required only if QuickConnectType is USER.
         */
        userConfig?: pulumi.Input<inputs.connect.QuickConnectUserQuickConnectConfigArgs>;
    }
    /**
     * The phone configuration. This is required only if QuickConnectType is PHONE_NUMBER.
     */
    interface QuickConnectPhoneNumberQuickConnectConfigArgs {
        /**
         * The phone number in E.164 format.
         */
        phoneNumber: pulumi.Input<string>;
    }
    /**
     * The queue configuration. This is required only if QuickConnectType is QUEUE.
     */
    interface QuickConnectQueueQuickConnectConfigArgs {
        /**
         * The Amazon Resource Name (ARN) of the flow.
         */
        contactFlowArn: pulumi.Input<string>;
        /**
         * The Amazon Resource Name (ARN) of the queue.
         */
        queueArn: pulumi.Input<string>;
    }
    /**
     * The user configuration. This is required only if QuickConnectType is USER.
     */
    interface QuickConnectUserQuickConnectConfigArgs {
        /**
         * The Amazon Resource Name (ARN) of the flow.
         */
        contactFlowArn: pulumi.Input<string>;
        /**
         * The Amazon Resource Name (ARN) of the user.
         */
        userArn: pulumi.Input<string>;
    }
    /**
     * Defines the cross-channel routing behavior that allows an agent working on a contact in one channel to be offered a contact from a different channel.
     */
    interface RoutingProfileCrossChannelBehaviorArgs {
        /**
         * Specifies the other channels that can be routed to an agent handling their current channel.
         */
        behaviorType: pulumi.Input<enums.connect.RoutingProfileBehaviorType>;
    }
    /**
     * Contains information about which channels are supported, and how many contacts an agent can have on a channel simultaneously.
     */
    interface RoutingProfileMediaConcurrencyArgs {
        /**
         * The channels that agents can handle in the Contact Control Panel (CCP).
         */
        channel: pulumi.Input<enums.connect.RoutingProfileChannel>;
        /**
         * The number of contacts an agent can have on a channel simultaneously.
         *
         * Valid Range for `VOICE` : Minimum value of 1. Maximum value of 1.
         *
         * Valid Range for `CHAT` : Minimum value of 1. Maximum value of 10.
         *
         * Valid Range for `TASK` : Minimum value of 1. Maximum value of 10.
         */
        concurrency: pulumi.Input<number>;
        /**
         * Defines the cross-channel routing behavior for each channel that is enabled for this Routing Profile. For example, this allows you to offer an agent a different contact from another channel when they are currently working with a contact from a Voice channel.
         */
        crossChannelBehavior?: pulumi.Input<inputs.connect.RoutingProfileCrossChannelBehaviorArgs>;
    }
    /**
     * Contains information about the queue and channel for which priority and delay can be set.
     */
    interface RoutingProfileQueueConfigArgs {
        /**
         * The delay, in seconds, a contact should be in the queue before they are routed to an available agent. For more information, see [Queues: priority and delay](https://docs.aws.amazon.com/connect/latest/adminguide/concepts-routing-profiles-priority.html) in the *Amazon Connect Administrator Guide* .
         */
        delay: pulumi.Input<number>;
        /**
         * The order in which contacts are to be handled for the queue. For more information, see [Queues: priority and delay](https://docs.aws.amazon.com/connect/latest/adminguide/concepts-routing-profiles-priority.html) .
         */
        priority: pulumi.Input<number>;
        /**
         * Contains information about a queue resource.
         */
        queueReference: pulumi.Input<inputs.connect.RoutingProfileQueueReferenceArgs>;
    }
    /**
     * Contains the channel and queue identifier for a routing profile.
     */
    interface RoutingProfileQueueReferenceArgs {
        /**
         * The channels agents can handle in the Contact Control Panel (CCP) for this routing profile.
         */
        channel: pulumi.Input<enums.connect.RoutingProfileChannel>;
        /**
         * The Amazon Resource Name (ARN) of the queue.
         */
        queueArn: pulumi.Input<string>;
    }
    /**
     * A list of actions to be run when the rule is triggered.
     */
    interface RuleActionsArgs {
        /**
         * Information about the contact category action. The syntax can be empty, for example, ``{}``.
         */
        assignContactCategoryActions?: pulumi.Input<pulumi.Input<inputs.connect.RuleAssignContactCategoryActionArgs>[]>;
        createCaseActions?: pulumi.Input<pulumi.Input<inputs.connect.RuleCreateCaseActionArgs>[]>;
        endAssociatedTasksActions?: pulumi.Input<pulumi.Input<inputs.connect.RuleEndAssociatedTasksActionArgs>[]>;
        /**
         * Information about the EV action.
         */
        eventBridgeActions?: pulumi.Input<pulumi.Input<inputs.connect.RuleEventBridgeActionArgs>[]>;
        /**
         * Information about the send notification action.
         */
        sendNotificationActions?: pulumi.Input<pulumi.Input<inputs.connect.RuleSendNotificationActionArgs>[]>;
        submitAutoEvaluationActions?: pulumi.Input<pulumi.Input<inputs.connect.RuleSubmitAutoEvaluationActionArgs>[]>;
        /**
         * Information about the task action. This field is required if ``TriggerEventSource`` is one of the following values: ``OnZendeskTicketCreate`` | ``OnZendeskTicketStatusUpdate`` | ``OnSalesforceCaseCreate``
         */
        taskActions?: pulumi.Input<pulumi.Input<inputs.connect.RuleTaskActionArgs>[]>;
        updateCaseActions?: pulumi.Input<pulumi.Input<inputs.connect.RuleUpdateCaseActionArgs>[]>;
    }
    /**
     * The definition for assigning contact category action.
     */
    interface RuleAssignContactCategoryActionArgs {
    }
    interface RuleCreateCaseActionArgs {
        fields: pulumi.Input<pulumi.Input<inputs.connect.RuleFieldArgs>[]>;
        templateId: pulumi.Input<string>;
    }
    /**
     * The definition for ending associated task action.
     */
    interface RuleEndAssociatedTasksActionArgs {
    }
    /**
     * The EV action definition.
     */
    interface RuleEventBridgeActionArgs {
        /**
         * The name.
         */
        name: pulumi.Input<string>;
    }
    interface RuleFieldArgs {
        id: pulumi.Input<string>;
        value: pulumi.Input<inputs.connect.RuleFieldValueArgs>;
    }
    /**
     * Object for case field values.
     */
    interface RuleFieldValueArgs {
        booleanValue?: pulumi.Input<boolean>;
        doubleValue?: pulumi.Input<number>;
        emptyValue?: any;
        stringValue?: pulumi.Input<string>;
    }
    /**
     * The type of notification recipient.
     */
    interface RuleNotificationRecipientTypeArgs {
        /**
         * The Amazon Resource Name (ARN) of the user account.
         */
        userArns?: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * The tags used to organize, track, or control access for this resource. For example, { "tags": {"key1":"value1", "key2":"value2"} }. CON users with the specified tags will be notified.
         */
        userTags?: pulumi.Input<{
            [key: string]: pulumi.Input<string>;
        }>;
    }
    /**
     * Information about the reference when the ``referenceType`` is ``URL``. Otherwise, null. (Supports variable injection in the ``Value`` field.)
     */
    interface RuleReferenceArgs {
        /**
         * The type of the reference. ``DATE`` must be of type Epoch timestamp.
         *   *Allowed values*: ``URL`` | ``ATTACHMENT`` | ``NUMBER`` | ``STRING`` | ``DATE`` | ``EMAIL``
         */
        type: pulumi.Input<enums.connect.RuleReferenceType>;
        /**
         * A valid value for the reference. For example, for a URL reference, a formatted URL that is displayed to an agent in the Contact Control Panel (CCP).
         */
        value: pulumi.Input<string>;
    }
    /**
     * Information about the send notification action.
     */
    interface RuleSendNotificationActionArgs {
        /**
         * Notification content. Supports variable injection. For more information, see [JSONPath reference](https://docs.aws.amazon.com/connect/latest/adminguide/contact-lens-variable-injection.html) in the *Administrators Guide*.
         */
        content: pulumi.Input<string>;
        /**
         * Content type format.
         *   *Allowed value*: ``PLAIN_TEXT``
         */
        contentType: pulumi.Input<enums.connect.RuleSendNotificationActionContentType>;
        /**
         * Notification delivery method.
         *   *Allowed value*: ``EMAIL``
         */
        deliveryMethod: pulumi.Input<enums.connect.RuleSendNotificationActionDeliveryMethod>;
        /**
         * Notification recipient.
         */
        recipient: pulumi.Input<inputs.connect.RuleNotificationRecipientTypeArgs>;
        /**
         * The subject of the email if the delivery method is ``EMAIL``. Supports variable injection. For more information, see [JSONPath reference](https://docs.aws.amazon.com/connect/latest/adminguide/contact-lens-variable-injection.html) in the *Administrators Guide*.
         */
        subject?: pulumi.Input<string>;
    }
    interface RuleSubmitAutoEvaluationActionArgs {
        evaluationFormArn: pulumi.Input<string>;
    }
    /**
     * Information about the task action. This field is required if ``TriggerEventSource`` is one of the following values: ``OnZendeskTicketCreate`` | ``OnZendeskTicketStatusUpdate`` | ``OnSalesforceCaseCreate``
     */
    interface RuleTaskActionArgs {
        /**
         * The Amazon Resource Name (ARN) of the flow.
         */
        contactFlowArn: pulumi.Input<string>;
        /**
         * The description. Supports variable injection. For more information, see [JSONPath reference](https://docs.aws.amazon.com/connect/latest/adminguide/contact-lens-variable-injection.html) in the *Administrators Guide*.
         */
        description?: pulumi.Input<string>;
        /**
         * The name. Supports variable injection. For more information, see [JSONPath reference](https://docs.aws.amazon.com/connect/latest/adminguide/contact-lens-variable-injection.html) in the *Administrators Guide*.
         */
        name: pulumi.Input<string>;
        /**
         * Information about the reference when the ``referenceType`` is ``URL``. Otherwise, null. ``URL`` is the only accepted type. (Supports variable injection in the ``Value`` field.)
         */
        references?: pulumi.Input<{
            [key: string]: pulumi.Input<inputs.connect.RuleReferenceArgs>;
        }>;
    }
    /**
     * The name of the event source.
     */
    interface RuleTriggerEventSourceArgs {
        /**
         * The name of the event source.
         */
        eventSourceName: pulumi.Input<enums.connect.RuleTriggerEventSourceEventSourceName>;
        /**
         * The Amazon Resource Name (ARN) of the integration association. ``IntegrationAssociationArn`` is required if ``TriggerEventSource`` is one of the following values: ``OnZendeskTicketCreate`` | ``OnZendeskTicketStatusUpdate`` | ``OnSalesforceCaseCreate``
         */
        integrationAssociationArn?: pulumi.Input<string>;
    }
    interface RuleUpdateCaseActionArgs {
        fields: pulumi.Input<pulumi.Input<inputs.connect.RuleFieldArgs>[]>;
    }
    /**
     * A third-party application's metadata.
     */
    interface SecurityProfileApplicationArgs {
        /**
         * The permissions that the agent is granted on the application
         */
        applicationPermissions: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * Namespace of the application that you want to give access to.
         */
        namespace: pulumi.Input<string>;
    }
    /**
     * A key-value pair to associate with a resource.
     */
    interface SecurityProfileTagArgs {
        /**
         * The key name of the tag. You can specify a value that is 1 to 128 Unicode characters in length and cannot be prefixed with aws:. You can use any of the following characters: the set of Unicode letters, digits, whitespace, _, ., /, =, +, and -.
         */
        key: pulumi.Input<string>;
        /**
         * The value for the tag. You can specify a value that is 0 to 256 Unicode characters in length and cannot be prefixed with aws:. You can use any of the following characters: the set of Unicode letters, digits, whitespace, _, ., /, =, +, and -.
         */
        value: pulumi.Input<string>;
    }
    /**
     * the default value for the task template's field
     */
    interface TaskTemplateDefaultFieldValueArgs {
        /**
         * Default value for the field.
         */
        defaultValue: pulumi.Input<string>;
        /**
         * Identifier of a field.
         */
        id: pulumi.Input<inputs.connect.TaskTemplateFieldIdentifierArgs>;
    }
    /**
     * A task template field object.
     */
    interface TaskTemplateFieldArgs {
        /**
         * The description of the task template's field
         */
        description?: pulumi.Input<string>;
        /**
         * The unique identifier for the field.
         */
        id: pulumi.Input<inputs.connect.TaskTemplateFieldIdentifierArgs>;
        /**
         * list of field options to be used with single select
         */
        singleSelectOptions?: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * Indicates the type of field. Following are the valid field types: `NAME` `DESCRIPTION` | `SCHEDULED_TIME` | `QUICK_CONNECT` | `URL` | `NUMBER` | `TEXT` | `TEXT_AREA` | `DATE_TIME` | `BOOLEAN` | `SINGLE_SELECT` | `EMAIL`
         */
        type: pulumi.Input<enums.connect.TaskTemplateFieldType>;
    }
    /**
     * the identifier (name) for the task template field
     */
    interface TaskTemplateFieldIdentifierArgs {
        /**
         * The name of the task template field
         */
        name: pulumi.Input<string>;
    }
    /**
     * Invisible field info
     */
    interface TaskTemplateInvisibleFieldInfoArgs {
        id: pulumi.Input<inputs.connect.TaskTemplateFieldIdentifierArgs>;
    }
    /**
     * ReadOnly field info
     */
    interface TaskTemplateReadOnlyFieldInfoArgs {
        id: pulumi.Input<inputs.connect.TaskTemplateFieldIdentifierArgs>;
    }
    /**
     * Required field info
     */
    interface TaskTemplateRequiredFieldInfoArgs {
        id: pulumi.Input<inputs.connect.TaskTemplateFieldIdentifierArgs>;
    }
    /**
     * Information about level five.
     */
    interface UserHierarchyStructureLevelFiveArgs {
        /**
         * The Amazon Resource Name (ARN) of the hierarchy level.
         */
        hierarchyLevelArn?: pulumi.Input<string>;
        /**
         * The identifier of the hierarchy level.
         */
        hierarchyLevelId?: pulumi.Input<string>;
        /**
         * The name of the hierarchy level.
         */
        name: pulumi.Input<string>;
    }
    /**
     * Information about level four.
     */
    interface UserHierarchyStructureLevelFourArgs {
        /**
         * The Amazon Resource Name (ARN) of the hierarchy level.
         */
        hierarchyLevelArn?: pulumi.Input<string>;
        /**
         * The identifier of the hierarchy level.
         */
        hierarchyLevelId?: pulumi.Input<string>;
        /**
         * The name of the hierarchy level.
         */
        name: pulumi.Input<string>;
    }
    /**
     * Information about level one.
     */
    interface UserHierarchyStructureLevelOneArgs {
        /**
         * The Amazon Resource Name (ARN) of the hierarchy level.
         */
        hierarchyLevelArn?: pulumi.Input<string>;
        /**
         * The identifier of the hierarchy level.
         */
        hierarchyLevelId?: pulumi.Input<string>;
        /**
         * The name of the hierarchy level.
         */
        name: pulumi.Input<string>;
    }
    /**
     * Information about level three.
     */
    interface UserHierarchyStructureLevelThreeArgs {
        /**
         * The Amazon Resource Name (ARN) of the hierarchy level.
         */
        hierarchyLevelArn?: pulumi.Input<string>;
        hierarchyLevelId?: pulumi.Input<string>;
        /**
         * The name of the hierarchy level.
         */
        name: pulumi.Input<string>;
    }
    /**
     * Information about level two.
     */
    interface UserHierarchyStructureLevelTwoArgs {
        /**
         * The Amazon Resource Name (ARN) of the hierarchy level.
         */
        hierarchyLevelArn?: pulumi.Input<string>;
        /**
         * The identifier of the hierarchy level.
         */
        hierarchyLevelId?: pulumi.Input<string>;
        /**
         * The name of the hierarchy level.
         */
        name: pulumi.Input<string>;
    }
    /**
     * Information about the hierarchy structure.
     */
    interface UserHierarchyStructurePropertiesArgs {
        levelFive?: pulumi.Input<inputs.connect.UserHierarchyStructureLevelFiveArgs>;
        /**
         * The update for level four.
         */
        levelFour?: pulumi.Input<inputs.connect.UserHierarchyStructureLevelFourArgs>;
        /**
         * The update for level one.
         */
        levelOne?: pulumi.Input<inputs.connect.UserHierarchyStructureLevelOneArgs>;
        /**
         * The update for level three.
         */
        levelThree?: pulumi.Input<inputs.connect.UserHierarchyStructureLevelThreeArgs>;
        /**
         * The update for level two.
         */
        levelTwo?: pulumi.Input<inputs.connect.UserHierarchyStructureLevelTwoArgs>;
    }
    /**
     * Contains information about the identity of a user.
     */
    interface UserIdentityInfoArgs {
        /**
         * The email address. If you are using SAML for identity management and include this parameter, an error is returned.
         */
        email?: pulumi.Input<string>;
        /**
         * The first name. This is required if you are using Amazon Connect or SAML for identity management. Inputs must be in Unicode Normalization Form C (NFC). Text containing characters in a non-NFC form (for example, decomposed characters or combining marks) are not accepted.
         */
        firstName?: pulumi.Input<string>;
        /**
         * The last name. This is required if you are using Amazon Connect or SAML for identity management. Inputs must be in Unicode Normalization Form C (NFC). Text containing characters in a non-NFC form (for example, decomposed characters or combining marks) are not accepted.
         */
        lastName?: pulumi.Input<string>;
        /**
         * The user's mobile number.
         */
        mobile?: pulumi.Input<string>;
        /**
         * The user's secondary email address. If you provide a secondary email, the user receives email notifications -- other than password reset notifications -- to this email address instead of to their primary email address.
         *
         * *Pattern* : `(?=^.{0,265}$)[a-zA-Z0-9._%+-]+@[a-zA-Z0-9.-]+\.[a-zA-Z]{2,63}`
         */
        secondaryEmail?: pulumi.Input<string>;
    }
    /**
     * Contains information about the phone configuration settings for a user.
     */
    interface UserPhoneConfigArgs {
        /**
         * The After Call Work (ACW) timeout setting, in seconds. This parameter has a minimum value of 0 and a maximum value of 2,000,000 seconds (24 days). Enter 0 if you don't want to allocate a specific amount of ACW time. It essentially means an indefinite amount of time. When the conversation ends, ACW starts; the agent must choose Close contact to end ACW.
         *
         * > When returned by a `SearchUsers` call, `AfterContactWorkTimeLimit` is returned in milliseconds.
         */
        afterContactWorkTimeLimit?: pulumi.Input<number>;
        /**
         * The Auto accept setting.
         */
        autoAccept?: pulumi.Input<boolean>;
        /**
         * The phone number for the user's desk phone.
         */
        deskPhoneNumber?: pulumi.Input<string>;
        /**
         * The phone type.
         */
        phoneType: pulumi.Input<enums.connect.UserPhoneType>;
    }
    /**
     * Proficiency of a user.
     */
    interface UserProficiencyArgs {
        /**
         * The name of user’s proficiency. You must use a predefined attribute name that is present in the Amazon Connect instance.
         */
        attributeName: pulumi.Input<string>;
        /**
         * The value of user’s proficiency. You must use a predefined attribute value that is present in the Amazon Connect instance.
         */
        attributeValue: pulumi.Input<string>;
        /**
         * The level of the proficiency. The valid values are 1, 2, 3, 4 and 5.
         */
        level: pulumi.Input<number>;
    }
    /**
     * The values of a predefined attribute.
     */
    interface ValuesPropertiesArgs {
        /**
         * Predefined attribute values of type string list.
         */
        stringList?: pulumi.Input<pulumi.Input<string>[]>;
    }
}
export declare namespace connectcampaigns {
    /**
     * Agentless Dialer config
     */
    interface CampaignAgentlessDialerConfigArgs {
        /**
         * Allocates dialing capacity for this campaign between multiple active campaigns.
         */
        dialingCapacity?: pulumi.Input<number>;
    }
    /**
     * The configuration used for answering machine detection during outbound calls
     */
    interface CampaignAnswerMachineDetectionConfigArgs {
        /**
         * Enables detection of prompts (e.g., beep after after a voicemail greeting)
         */
        awaitAnswerMachinePrompt?: pulumi.Input<boolean>;
        /**
         * Flag to decided whether outbound calls should have answering machine detection enabled or not
         */
        enableAnswerMachineDetection: pulumi.Input<boolean>;
    }
    /**
     * The possible types of dialer config parameters
     */
    interface CampaignDialerConfigArgs {
        /**
         * The configuration of the agentless dialer.
         */
        agentlessDialerConfig?: pulumi.Input<inputs.connectcampaigns.CampaignAgentlessDialerConfigArgs>;
        /**
         * The configuration of the predictive dialer.
         */
        predictiveDialerConfig?: pulumi.Input<inputs.connectcampaigns.CampaignPredictiveDialerConfigArgs>;
        /**
         * The configuration of the progressive dialer.
         */
        progressiveDialerConfig?: pulumi.Input<inputs.connectcampaigns.CampaignProgressiveDialerConfigArgs>;
    }
    /**
     * The configuration used for outbound calls.
     */
    interface CampaignOutboundCallConfigArgs {
        /**
         * Whether answering machine detection has been enabled.
         */
        answerMachineDetectionConfig?: pulumi.Input<inputs.connectcampaigns.CampaignAnswerMachineDetectionConfigArgs>;
        /**
         * The identifier of the contact flow for the outbound call.
         */
        connectContactFlowArn: pulumi.Input<string>;
        /**
         * The queue for the call. If you specify a queue, the phone displayed for caller ID is the phone number specified in the queue. If you do not specify a queue, the queue defined in the contact flow is used. If you do not specify a queue, you must specify a source phone number.
         */
        connectQueueArn?: pulumi.Input<string>;
        /**
         * The phone number associated with the Amazon Connect instance, in E.164 format. If you do not specify a source phone number, you must specify a queue.
         */
        connectSourcePhoneNumber?: pulumi.Input<string>;
    }
    /**
     * Predictive Dialer config
     */
    interface CampaignPredictiveDialerConfigArgs {
        /**
         * The bandwidth allocation of a queue resource.
         */
        bandwidthAllocation: pulumi.Input<number>;
        /**
         * Allocates dialing capacity for this campaign between multiple active campaigns.
         */
        dialingCapacity?: pulumi.Input<number>;
    }
    /**
     * Progressive Dialer config
     */
    interface CampaignProgressiveDialerConfigArgs {
        /**
         * The bandwidth allocation of a queue resource.
         */
        bandwidthAllocation: pulumi.Input<number>;
        /**
         * Allocates dialing capacity for this campaign between multiple active campaigns.
         */
        dialingCapacity?: pulumi.Input<number>;
    }
}
export declare namespace connectcampaignsv2 {
    /**
     * Agentless config
     */
    interface CampaignAgentlessConfigArgs {
    }
    /**
     * The configuration used for answering machine detection during outbound calls
     */
    interface CampaignAnswerMachineDetectionConfigArgs {
        /**
         * Enables detection of prompts (e.g., beep after after a voicemail greeting)
         */
        awaitAnswerMachinePrompt?: pulumi.Input<boolean>;
        /**
         * Flag to decided whether outbound calls should have answering machine detection enabled or not
         */
        enableAnswerMachineDetection: pulumi.Input<boolean>;
    }
    /**
     * The possible types of channel subtype config parameters
     */
    interface CampaignChannelSubtypeConfigArgs {
        /**
         * The configuration of the email channel subtype.
         */
        email?: pulumi.Input<inputs.connectcampaignsv2.CampaignEmailChannelSubtypeConfigArgs>;
        /**
         * The configuration of the SMS channel subtype.
         */
        sms?: pulumi.Input<inputs.connectcampaignsv2.CampaignSmsChannelSubtypeConfigArgs>;
        /**
         * The configuration of the telephony channel subtype.
         */
        telephony?: pulumi.Input<inputs.connectcampaignsv2.CampaignTelephonyChannelSubtypeConfigArgs>;
    }
    /**
     * Communication Limit
     */
    interface CampaignCommunicationLimitArgs {
        frequency: pulumi.Input<number>;
        maxCountPerRecipient: pulumi.Input<number>;
        unit: pulumi.Input<enums.connectcampaignsv2.CampaignCommunicationLimitTimeUnit>;
    }
    /**
     * Communication limits
     */
    interface CampaignCommunicationLimitsArgs {
        /**
         * The list of CommunicationLimits.
         */
        communicationLimitList?: pulumi.Input<pulumi.Input<inputs.connectcampaignsv2.CampaignCommunicationLimitArgs>[]>;
    }
    /**
     * Communication limits config
     */
    interface CampaignCommunicationLimitsConfigArgs {
        /**
         * The CommunicationLimits that apply to all channel subtypes defined in an outbound campaign.
         */
        allChannelsSubtypes?: pulumi.Input<inputs.connectcampaignsv2.CampaignCommunicationLimitsArgs>;
    }
    /**
     * Campaign communication time config
     */
    interface CampaignCommunicationTimeConfigArgs {
        /**
         * The communication time configuration for the email channel subtype.
         */
        email?: pulumi.Input<inputs.connectcampaignsv2.CampaignTimeWindowArgs>;
        /**
         * The local timezone configuration.
         */
        localTimeZoneConfig: pulumi.Input<inputs.connectcampaignsv2.CampaignLocalTimeZoneConfigArgs>;
        /**
         * The communication time configuration for the SMS channel subtype.
         */
        sms?: pulumi.Input<inputs.connectcampaignsv2.CampaignTimeWindowArgs>;
        /**
         * The communication time configuration for the telephony channel subtype.
         */
        telephony?: pulumi.Input<inputs.connectcampaignsv2.CampaignTimeWindowArgs>;
    }
    /**
     * Daily Hour
     */
    interface CampaignDailyHourArgs {
        key?: pulumi.Input<enums.connectcampaignsv2.CampaignDayOfWeek>;
        value?: pulumi.Input<pulumi.Input<inputs.connectcampaignsv2.CampaignTimeRangeArgs>[]>;
    }
    /**
     * Email Channel Subtype config
     */
    interface CampaignEmailChannelSubtypeConfigArgs {
        /**
         * The allocation of email capacity between multiple running outbound campaigns.
         */
        capacity?: pulumi.Input<number>;
        /**
         * The default email outbound configuration of an outbound campaign.
         */
        defaultOutboundConfig: pulumi.Input<inputs.connectcampaignsv2.CampaignEmailOutboundConfigArgs>;
        /**
         * The outbound mode for email of an outbound campaign.
         */
        outboundMode: pulumi.Input<inputs.connectcampaignsv2.CampaignEmailOutboundModeArgs>;
    }
    /**
     * Default SMS outbound config
     */
    interface CampaignEmailOutboundConfigArgs {
        /**
         * The Amazon Connect source email address.
         */
        connectSourceEmailAddress: pulumi.Input<string>;
        /**
         * The display name for the Amazon Connect source email address.
         */
        sourceEmailAddressDisplayName?: pulumi.Input<string>;
        /**
         * The Amazon Resource Name (ARN) of the Amazon Q in Connect template.
         */
        wisdomTemplateArn: pulumi.Input<string>;
    }
    /**
     * Email Outbound Mode
     */
    interface CampaignEmailOutboundModeArgs {
        /**
         * The agentless outbound mode configuration for email.
         */
        agentlessConfig?: pulumi.Input<inputs.connectcampaignsv2.CampaignAgentlessConfigArgs>;
    }
    /**
     * The event trigger of the campaign
     */
    interface CampaignEventTriggerArgs {
        /**
         * The Amazon Resource Name (ARN) of the Customer Profiles domain.
         */
        customerProfilesDomainArn?: pulumi.Input<string>;
    }
    /**
     * Local time zone config
     */
    interface CampaignLocalTimeZoneConfigArgs {
        /**
         * The timezone to use for all recipients.
         */
        defaultTimeZone?: pulumi.Input<string>;
        /**
         * Detects methods for the recipient's timezone.
         */
        localTimeZoneDetection?: pulumi.Input<pulumi.Input<enums.connectcampaignsv2.CampaignLocalTimeZoneDetectionType>[]>;
    }
    /**
     * Open Hours config
     */
    interface CampaignOpenHoursArgs {
        /**
         * The daily hours configuration.
         */
        dailyHours: pulumi.Input<pulumi.Input<inputs.connectcampaignsv2.CampaignDailyHourArgs>[]>;
    }
    /**
     * Predictive config
     */
    interface CampaignPredictiveConfigArgs {
        /**
         * Bandwidth allocation for the predictive outbound mode.
         */
        bandwidthAllocation: pulumi.Input<number>;
    }
    /**
     * Progressive config
     */
    interface CampaignProgressiveConfigArgs {
        /**
         * Bandwidth allocation for the progressive outbound mode.
         */
        bandwidthAllocation: pulumi.Input<number>;
    }
    /**
     * Restricted period
     */
    interface CampaignRestrictedPeriodArgs {
        endDate: pulumi.Input<string>;
        /**
         * The name of a restricted period
         */
        name?: pulumi.Input<string>;
        startDate: pulumi.Input<string>;
    }
    /**
     * Restricted period config
     */
    interface CampaignRestrictedPeriodsArgs {
        /**
         * The restricted period list.
         */
        restrictedPeriodList?: pulumi.Input<pulumi.Input<inputs.connectcampaignsv2.CampaignRestrictedPeriodArgs>[]>;
    }
    /**
     * Campaign schedule
     */
    interface CampaignScheduleArgs {
        /**
         * The end time of the schedule in UTC.
         */
        endTime: pulumi.Input<string>;
        /**
         * The refresh frequency of the campaign.
         */
        refreshFrequency?: pulumi.Input<string>;
        /**
         * The start time of the schedule in UTC.
         */
        startTime: pulumi.Input<string>;
    }
    /**
     * SMS Channel Subtype config
     */
    interface CampaignSmsChannelSubtypeConfigArgs {
        /**
         * The allocation of SMS capacity between multiple running outbound campaigns.
         */
        capacity?: pulumi.Input<number>;
        /**
         * The default SMS outbound configuration of an outbound campaign.
         */
        defaultOutboundConfig: pulumi.Input<inputs.connectcampaignsv2.CampaignSmsOutboundConfigArgs>;
        /**
         * The outbound mode of SMS for an outbound campaign.
         */
        outboundMode: pulumi.Input<inputs.connectcampaignsv2.CampaignSmsOutboundModeArgs>;
    }
    /**
     * Default SMS outbound config
     */
    interface CampaignSmsOutboundConfigArgs {
        /**
         * The Amazon Resource Name (ARN) of the Amazon Connect source SMS phone number.
         */
        connectSourcePhoneNumberArn: pulumi.Input<string>;
        /**
         * The Amazon Resource Name (ARN) of the Amazon Q in Connect template.
         */
        wisdomTemplateArn: pulumi.Input<string>;
    }
    /**
     * SMS Outbound Mode
     */
    interface CampaignSmsOutboundModeArgs {
        /**
         * Contains agentless outbound mode configuration.
         */
        agentlessConfig?: pulumi.Input<inputs.connectcampaignsv2.CampaignAgentlessConfigArgs>;
    }
    /**
     * The possible source of the campaign
     */
    interface CampaignSourceArgs {
        /**
         * The Amazon Resource Name (ARN) of the Customer Profiles segment.
         */
        customerProfilesSegmentArn?: pulumi.Input<string>;
        /**
         * The event trigger of the campaign.
         */
        eventTrigger?: pulumi.Input<inputs.connectcampaignsv2.CampaignEventTriggerArgs>;
    }
    /**
     * Telephony Channel Subtype config
     */
    interface CampaignTelephonyChannelSubtypeConfigArgs {
        /**
         * The allocation of telephony capacity between multiple running outbound campaigns.
         */
        capacity?: pulumi.Input<number>;
        /**
         * The identifier of the Amazon Connect queue associated with telephony outbound requests of an outbound campaign.
         */
        connectQueueId?: pulumi.Input<string>;
        /**
         * The default telephony outbound configuration of an outbound campaign.
         */
        defaultOutboundConfig: pulumi.Input<inputs.connectcampaignsv2.CampaignTelephonyOutboundConfigArgs>;
        /**
         * The outbound mode of telephony for an outbound campaign.
         */
        outboundMode: pulumi.Input<inputs.connectcampaignsv2.CampaignTelephonyOutboundModeArgs>;
    }
    /**
     * Default Telephone Outbound config
     */
    interface CampaignTelephonyOutboundConfigArgs {
        /**
         * The answering machine detection configuration.
         */
        answerMachineDetectionConfig?: pulumi.Input<inputs.connectcampaignsv2.CampaignAnswerMachineDetectionConfigArgs>;
        /**
         * The identifier of the published Amazon Connect contact flow.
         */
        connectContactFlowId: pulumi.Input<string>;
        /**
         * The Amazon Connect source phone number.
         */
        connectSourcePhoneNumber?: pulumi.Input<string>;
    }
    /**
     * Telephony Outbound Mode
     */
    interface CampaignTelephonyOutboundModeArgs {
        /**
         * The agentless outbound mode configuration for telephony.
         */
        agentlessConfig?: pulumi.Input<inputs.connectcampaignsv2.CampaignAgentlessConfigArgs>;
        /**
         * Contains predictive outbound mode configuration.
         */
        predictiveConfig?: pulumi.Input<inputs.connectcampaignsv2.CampaignPredictiveConfigArgs>;
        /**
         * Contains progressive telephony outbound mode configuration.
         */
        progressiveConfig?: pulumi.Input<inputs.connectcampaignsv2.CampaignProgressiveConfigArgs>;
    }
    /**
     * Time range in 24 hour format
     */
    interface CampaignTimeRangeArgs {
        endTime: pulumi.Input<string>;
        startTime: pulumi.Input<string>;
    }
    /**
     * Time window config
     */
    interface CampaignTimeWindowArgs {
        /**
         * The open hours configuration.
         */
        openHours: pulumi.Input<inputs.connectcampaignsv2.CampaignOpenHoursArgs>;
        /**
         * The restricted periods configuration.
         */
        restrictedPeriods?: pulumi.Input<inputs.connectcampaignsv2.CampaignRestrictedPeriodsArgs>;
    }
}
export declare namespace controltower {
    interface EnabledBaselineParameterArgs {
        key?: pulumi.Input<string>;
        value?: pulumi.Input<string | any | number | pulumi.Input<boolean | number | any | string>[] | boolean>;
    }
    interface EnabledControlParameterArgs {
        /**
         * The key of a key/value pair. It is of type `string` .
         */
        key: pulumi.Input<string>;
        /**
         * The value of a key/value pair. It can be of type `array` , `string` , `number` , `object` , or `boolean` . [Note: The *Type* field that follows may show a single type such as Number, which is only one possible type.]
         */
        value: pulumi.Input<pulumi.Input<string | number | any | boolean>[] | string | number | any | boolean>;
    }
}
export declare namespace customerprofiles {
    /**
     * Mathematical expression and a list of attribute items specified in that expression.
     */
    interface CalculatedAttributeDefinitionAttributeDetailsArgs {
        /**
         * Mathematical expression and a list of attribute items specified in that expression.
         */
        attributes: pulumi.Input<pulumi.Input<inputs.customerprofiles.CalculatedAttributeDefinitionAttributeItemArgs>[]>;
        /**
         * Mathematical expression that is performed on attribute items provided in the attribute list. Each element in the expression should follow the structure of \"{ObjectTypeName.AttributeName}\".
         */
        expression: pulumi.Input<string>;
    }
    /**
     * The details of a single attribute item specified in the mathematical expression.
     */
    interface CalculatedAttributeDefinitionAttributeItemArgs {
        name: pulumi.Input<string>;
    }
    /**
     * The conditions including range, object count, and threshold for the calculated attribute.
     */
    interface CalculatedAttributeDefinitionConditionsArgs {
        /**
         * The number of profile objects used for the calculated attribute.
         */
        objectCount?: pulumi.Input<number>;
        /**
         * The relative time period over which data is included in the aggregation.
         */
        range?: pulumi.Input<inputs.customerprofiles.CalculatedAttributeDefinitionRangeArgs>;
        /**
         * The threshold for the calculated attribute.
         */
        threshold?: pulumi.Input<inputs.customerprofiles.CalculatedAttributeDefinitionThresholdArgs>;
    }
    /**
     * The relative time period over which data is included in the aggregation.
     */
    interface CalculatedAttributeDefinitionRangeArgs {
        /**
         * The unit of time.
         */
        unit: pulumi.Input<enums.customerprofiles.CalculatedAttributeDefinitionRangeUnit>;
        /**
         * The amount of time of the specified unit.
         */
        value: pulumi.Input<number>;
    }
    /**
     * The threshold for the calculated attribute.
     */
    interface CalculatedAttributeDefinitionThresholdArgs {
        /**
         * The operator of the threshold.
         */
        operator: pulumi.Input<enums.customerprofiles.CalculatedAttributeDefinitionThresholdOperator>;
        /**
         * The value of the threshold.
         */
        value: pulumi.Input<string>;
    }
    /**
     * Configures information about the AttributeTypesSelector where the rule-based identity resolution uses to match profiles.
     */
    interface DomainAttributeTypesSelectorArgs {
        /**
         * The Address type. You can choose from Address, BusinessAddress, MaillingAddress, and ShippingAddress. You only can use the Address type in the MatchingRule. For example, if you want to match profile based on BusinessAddress.City or MaillingAddress.City, you need to choose the BusinessAddress and the MaillingAddress to represent the Address type and specify the Address.City on the matching rule.
         */
        address?: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * Configures the AttributeMatchingModel, you can either choose ONE_TO_ONE or MANY_TO_MANY.
         */
        attributeMatchingModel: pulumi.Input<enums.customerprofiles.DomainAttributeTypesSelectorAttributeMatchingModel>;
        /**
         * The Email type. You can choose from EmailAddress, BusinessEmailAddress and PersonalEmailAddress. You only can use the EmailAddress type in the MatchingRule. For example, if you want to match profile based on PersonalEmailAddress or BusinessEmailAddress, you need to choose the PersonalEmailAddress and the BusinessEmailAddress to represent the EmailAddress type and only specify the EmailAddress on the matching rule.
         */
        emailAddress?: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * The PhoneNumber type. You can choose from PhoneNumber, HomePhoneNumber, and MobilePhoneNumber. You only can use the PhoneNumber type in the MatchingRule. For example, if you want to match a profile based on Phone or HomePhone, you need to choose the Phone and the HomePhone to represent the PhoneNumber type and only specify the PhoneNumber on the matching rule.
         */
        phoneNumber?: pulumi.Input<pulumi.Input<string>[]>;
    }
    /**
     * Configuration information about the auto-merging process.
     */
    interface DomainAutoMergingArgs {
        /**
         * Determines how the auto-merging process should resolve conflicts between different profiles. For example, if Profile A and Profile B have the same `FirstName` and `LastName` , `ConflictResolution` specifies which `EmailAddress` should be used.
         */
        conflictResolution?: pulumi.Input<inputs.customerprofiles.DomainConflictResolutionArgs>;
        /**
         * A list of matching attributes that represent matching criteria. If two profiles meet at least one of the requirements in the matching attributes list, they will be merged.
         */
        consolidation?: pulumi.Input<inputs.customerprofiles.DomainConsolidationArgs>;
        /**
         * The flag that enables the auto-merging of duplicate profiles.
         */
        enabled: pulumi.Input<boolean>;
        /**
         * A number between 0 and 1 that represents the minimum confidence score required for profiles within a matching group to be merged during the auto-merge process. A higher score means higher similarity required to merge profiles.
         */
        minAllowedConfidenceScoreForMerging?: pulumi.Input<number>;
    }
    /**
     * How the auto-merging process should resolve conflicts between different profiles. For example, if Profile A and Profile B have the same FirstName and LastName (and that is the matching criteria), which EmailAddress should be used?
     */
    interface DomainConflictResolutionArgs {
        /**
         * How the auto-merging process should resolve conflicts between different profiles.
         */
        conflictResolvingModel: pulumi.Input<enums.customerprofiles.DomainConflictResolutionConflictResolvingModel>;
        /**
         * The ObjectType name that is used to resolve profile merging conflicts when choosing SOURCE as the ConflictResolvingModel.
         */
        sourceName?: pulumi.Input<string>;
    }
    /**
     * A list of matching attributes that represent matching criteria. If two profiles meet at least one of the requirements in the matching attributes list, they will be merged.
     */
    interface DomainConsolidationArgs {
        /**
         * A list of matching criteria.
         */
        matchingAttributesList: pulumi.Input<pulumi.Input<pulumi.Input<string>[]>[]>;
    }
    /**
     * Configuration information for exporting Identity Resolution results, for example, to an S3 bucket.
     */
    interface DomainExportingConfigArgs {
        s3Exporting?: pulumi.Input<inputs.customerprofiles.DomainS3ExportingConfigArgs>;
    }
    /**
     * The day and time when do you want to start the Identity Resolution Job every week.
     */
    interface DomainJobScheduleArgs {
        /**
         * The day when the Identity Resolution Job should run every week.
         */
        dayOfTheWeek: pulumi.Input<enums.customerprofiles.DomainJobScheduleDayOfTheWeek>;
        /**
         * The time when the Identity Resolution Job should run every week.
         */
        time: pulumi.Input<string>;
    }
    /**
     * The process of matching duplicate profiles. If Matching = true, Amazon Connect Customer Profiles starts a weekly batch process called Identity Resolution Job. If you do not specify a date and time for Identity Resolution Job to run, by default it runs every Saturday at 12AM UTC to detect duplicate profiles in your domains. After the Identity Resolution Job completes, use the GetMatches API to return and review the results. Or, if you have configured ExportingConfig in the MatchingRequest, you can download the results from S3.
     */
    interface DomainMatchingArgs {
        /**
         * Configuration information about the auto-merging process.
         */
        autoMerging?: pulumi.Input<inputs.customerprofiles.DomainAutoMergingArgs>;
        /**
         * The flag that enables the matching process of duplicate profiles.
         */
        enabled: pulumi.Input<boolean>;
        /**
         * The S3 location where Identity Resolution Jobs write result files.
         */
        exportingConfig?: pulumi.Input<inputs.customerprofiles.DomainExportingConfigArgs>;
        /**
         * The day and time when do you want to start the Identity Resolution Job every week.
         */
        jobSchedule?: pulumi.Input<inputs.customerprofiles.DomainJobScheduleArgs>;
    }
    /**
     * Specifies how does the rule-based matching process should match profiles.
     */
    interface DomainMatchingRuleArgs {
        /**
         * A single rule level of the `MatchRules` . Configures how the rule-based matching process should match profiles.
         */
        rule: pulumi.Input<pulumi.Input<string>[]>;
    }
    /**
     * The process of matching duplicate profiles using the Rule-Based matching. If RuleBasedMatching = true, Amazon Connect Customer Profiles will start to match and merge your profiles according to your configuration in the RuleBasedMatchingRequest. You can use the ListRuleBasedMatches and GetSimilarProfiles API to return and review the results. Also, if you have configured ExportingConfig in the RuleBasedMatchingRequest, you can download the results from S3.
     */
    interface DomainRuleBasedMatchingArgs {
        /**
         * Configures information about the `AttributeTypesSelector` where the rule-based identity resolution uses to match profiles.
         */
        attributeTypesSelector?: pulumi.Input<inputs.customerprofiles.DomainAttributeTypesSelectorArgs>;
        /**
         * Determines how the auto-merging process should resolve conflicts between different profiles. For example, if Profile A and Profile B have the same `FirstName` and `LastName` , `ConflictResolution` specifies which `EmailAddress` should be used.
         */
        conflictResolution?: pulumi.Input<inputs.customerprofiles.DomainConflictResolutionArgs>;
        /**
         * The flag that enables the rule-based matching process of duplicate profiles.
         */
        enabled: pulumi.Input<boolean>;
        /**
         * The S3 location where Identity Resolution Jobs write result files.
         */
        exportingConfig?: pulumi.Input<inputs.customerprofiles.DomainExportingConfigArgs>;
        /**
         * Configures how the rule-based matching process should match profiles. You can have up to 15 MatchingRule in the MatchingRules.
         */
        matchingRules?: pulumi.Input<pulumi.Input<inputs.customerprofiles.DomainMatchingRuleArgs>[]>;
        /**
         * Indicates the maximum allowed rule level for matching.
         */
        maxAllowedRuleLevelForMatching?: pulumi.Input<number>;
        /**
         * Indicates the maximum allowed rule level for merging.
         */
        maxAllowedRuleLevelForMerging?: pulumi.Input<number>;
        /**
         * The status of rule-based matching rule.
         */
        status?: pulumi.Input<enums.customerprofiles.DomainRuleBasedMatchingStatus>;
    }
    /**
     * The S3 location where Identity Resolution Jobs write result files.
     */
    interface DomainS3ExportingConfigArgs {
        /**
         * The name of the S3 bucket where Identity Resolution Jobs write result files.
         */
        s3BucketName: pulumi.Input<string>;
        /**
         * The S3 key name of the location where Identity Resolution Jobs write result files.
         */
        s3KeyName?: pulumi.Input<string>;
    }
    /**
     * Specifies the circumstances under which the event should trigger the destination.
     */
    interface EventTriggerConditionArgs {
        eventTriggerDimensions: pulumi.Input<pulumi.Input<inputs.customerprofiles.EventTriggerDimensionArgs>[]>;
        logicalOperator: pulumi.Input<enums.customerprofiles.EventTriggerLogicalOperator>;
    }
    /**
     * A specific event dimension to be assessed.
     */
    interface EventTriggerDimensionArgs {
        objectAttributes: pulumi.Input<pulumi.Input<inputs.customerprofiles.EventTriggerObjectAttributeArgs>[]>;
    }
    /**
     * Defines limits controlling whether an event triggers the destination, based on ingestion latency and the number of invocations per profile over specific time periods.
     */
    interface EventTriggerLimitsArgs {
        /**
         * Specifies that an event will only trigger the destination if it is processed within a certain latency period.
         */
        eventExpiration?: pulumi.Input<number>;
        /**
         * A list of time periods during which the limits apply.
         */
        periods?: pulumi.Input<pulumi.Input<inputs.customerprofiles.EventTriggerPeriodArgs>[]>;
    }
    /**
     * The criteria that a specific object attribute must meet to trigger the destination.
     */
    interface EventTriggerObjectAttributeArgs {
        /**
         * The operator used to compare an attribute against a list of values.
         */
        comparisonOperator: pulumi.Input<enums.customerprofiles.EventTriggerObjectAttributeComparisonOperator>;
        /**
         * A field defined within an object type.
         */
        fieldName?: pulumi.Input<string>;
        /**
         * An attribute contained within a source object.
         */
        source?: pulumi.Input<string>;
        /**
         * A list of attribute values used for comparison.
         */
        values: pulumi.Input<pulumi.Input<string>[]>;
    }
    /**
     * Defines a limit and the time period during which it is enforced.
     */
    interface EventTriggerPeriodArgs {
        /**
         * The maximum allowed number of destination invocations per profile.
         */
        maxInvocationsPerProfile?: pulumi.Input<number>;
        /**
         * The unit of time.
         */
        unit: pulumi.Input<enums.customerprofiles.EventTriggerPeriodUnit>;
        /**
         * If set to true, there is no limit on the number of destination invocations per profile. The default is false.
         */
        unlimited?: pulumi.Input<boolean>;
        /**
         * The amount of time of the specified unit.
         */
        value: pulumi.Input<number>;
    }
    interface IntegrationConnectorOperatorArgs {
        /**
         * The operation to be performed on the provided Marketo source fields.
         */
        marketo?: pulumi.Input<enums.customerprofiles.IntegrationMarketoConnectorOperator>;
        /**
         * The operation to be performed on the provided Amazon S3 source fields.
         */
        s3?: pulumi.Input<enums.customerprofiles.IntegrationS3ConnectorOperator>;
        /**
         * The operation to be performed on the provided Salesforce source fields.
         */
        salesforce?: pulumi.Input<enums.customerprofiles.IntegrationSalesforceConnectorOperator>;
        /**
         * The operation to be performed on the provided ServiceNow source fields.
         */
        serviceNow?: pulumi.Input<enums.customerprofiles.IntegrationServiceNowConnectorOperator>;
        /**
         * The operation to be performed on the provided Zendesk source fields.
         */
        zendesk?: pulumi.Input<enums.customerprofiles.IntegrationZendeskConnectorOperator>;
    }
    interface IntegrationFlowDefinitionArgs {
        /**
         * A description of the flow you want to create.
         */
        description?: pulumi.Input<string>;
        /**
         * The specified name of the flow. Use underscores (_) or hyphens (-) only. Spaces are not allowed.
         */
        flowName: pulumi.Input<string>;
        /**
         * The Amazon Resource Name (ARN) of the AWS Key Management Service (KMS) key you provide for encryption.
         */
        kmsArn: pulumi.Input<string>;
        /**
         * The configuration that controls how Customer Profiles retrieves data from the source.
         */
        sourceFlowConfig: pulumi.Input<inputs.customerprofiles.IntegrationSourceFlowConfigArgs>;
        /**
         * A list of tasks that Customer Profiles performs while transferring the data in the flow run.
         */
        tasks: pulumi.Input<pulumi.Input<inputs.customerprofiles.IntegrationTaskArgs>[]>;
        /**
         * The trigger settings that determine how and when the flow runs.
         */
        triggerConfig: pulumi.Input<inputs.customerprofiles.IntegrationTriggerConfigArgs>;
    }
    interface IntegrationIncrementalPullConfigArgs {
        /**
         * A field that specifies the date time or timestamp field as the criteria to use when importing incremental records from the source.
         */
        datetimeTypeFieldName?: pulumi.Input<string>;
    }
    interface IntegrationMarketoSourcePropertiesArgs {
        /**
         * The object specified in the Marketo flow source.
         */
        object: pulumi.Input<string>;
    }
    interface IntegrationObjectTypeMappingArgs {
        /**
         * The key.
         */
        key: pulumi.Input<string>;
        /**
         * The value.
         */
        value: pulumi.Input<string>;
    }
    interface IntegrationS3SourcePropertiesArgs {
        /**
         * The Amazon S3 bucket name where the source files are stored.
         */
        bucketName: pulumi.Input<string>;
        /**
         * The object key for the Amazon S3 bucket in which the source files are stored.
         */
        bucketPrefix?: pulumi.Input<string>;
    }
    interface IntegrationSalesforceSourcePropertiesArgs {
        /**
         * The flag that enables dynamic fetching of new (recently added) fields in the Salesforce objects while running a flow.
         */
        enableDynamicFieldUpdate?: pulumi.Input<boolean>;
        /**
         * Indicates whether Amazon AppFlow includes deleted files in the flow run.
         */
        includeDeletedRecords?: pulumi.Input<boolean>;
        /**
         * The object specified in the Salesforce flow source.
         */
        object: pulumi.Input<string>;
    }
    interface IntegrationScheduledTriggerPropertiesArgs {
        /**
         * Specifies whether a scheduled flow has an incremental data transfer or a complete data transfer for each flow run.
         */
        dataPullMode?: pulumi.Input<enums.customerprofiles.IntegrationScheduledTriggerPropertiesDataPullMode>;
        /**
         * Specifies the date range for the records to import from the connector in the first flow run.
         */
        firstExecutionFrom?: pulumi.Input<number>;
        /**
         * Specifies the scheduled end time for a scheduled-trigger flow.
         */
        scheduleEndTime?: pulumi.Input<number>;
        /**
         * The scheduling expression that determines the rate at which the schedule will run, for example rate (5 minutes).
         */
        scheduleExpression: pulumi.Input<string>;
        /**
         * Specifies the optional offset that is added to the time interval for a schedule-triggered flow.
         */
        scheduleOffset?: pulumi.Input<number>;
        /**
         * Specifies the scheduled start time for a scheduled-trigger flow. The value must be a date/time value in EPOCH format.
         */
        scheduleStartTime?: pulumi.Input<number>;
        /**
         * Specifies the time zone used when referring to the date and time of a scheduled-triggered flow, such as America/New_York.
         */
        timezone?: pulumi.Input<string>;
    }
    interface IntegrationServiceNowSourcePropertiesArgs {
        /**
         * The object specified in the ServiceNow flow source.
         */
        object: pulumi.Input<string>;
    }
    interface IntegrationSourceConnectorPropertiesArgs {
        /**
         * The properties that are applied when Marketo is being used as a source.
         */
        marketo?: pulumi.Input<inputs.customerprofiles.IntegrationMarketoSourcePropertiesArgs>;
        /**
         * The properties that are applied when Amazon S3 is being used as the flow source.
         */
        s3?: pulumi.Input<inputs.customerprofiles.IntegrationS3SourcePropertiesArgs>;
        /**
         * The properties that are applied when Salesforce is being used as a source.
         */
        salesforce?: pulumi.Input<inputs.customerprofiles.IntegrationSalesforceSourcePropertiesArgs>;
        /**
         * The properties that are applied when ServiceNow is being used as a source.
         */
        serviceNow?: pulumi.Input<inputs.customerprofiles.IntegrationServiceNowSourcePropertiesArgs>;
        /**
         * The properties that are applied when using Zendesk as a flow source.
         */
        zendesk?: pulumi.Input<inputs.customerprofiles.IntegrationZendeskSourcePropertiesArgs>;
    }
    interface IntegrationSourceFlowConfigArgs {
        /**
         * The name of the Amazon AppFlow connector profile. This name must be unique for each connector profile in the AWS account .
         */
        connectorProfileName?: pulumi.Input<string>;
        /**
         * The type of connector, such as Salesforce, Marketo, and so on.
         */
        connectorType: pulumi.Input<enums.customerprofiles.IntegrationConnectorType>;
        /**
         * Defines the configuration for a scheduled incremental data pull. If a valid configuration is provided, the fields specified in the configuration are used when querying for the incremental data pull.
         */
        incrementalPullConfig?: pulumi.Input<inputs.customerprofiles.IntegrationIncrementalPullConfigArgs>;
        /**
         * Specifies the information that is required to query a particular source connector.
         */
        sourceConnectorProperties: pulumi.Input<inputs.customerprofiles.IntegrationSourceConnectorPropertiesArgs>;
    }
    interface IntegrationTaskArgs {
        /**
         * The operation to be performed on the provided source fields.
         */
        connectorOperator?: pulumi.Input<inputs.customerprofiles.IntegrationConnectorOperatorArgs>;
        /**
         * A field in a destination connector, or a field value against which Amazon AppFlow validates a source field.
         */
        destinationField?: pulumi.Input<string>;
        /**
         * The source fields to which a particular task is applied.
         */
        sourceFields: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * A map used to store task-related information. The service looks for particular information based on the TaskType.
         */
        taskProperties?: pulumi.Input<pulumi.Input<inputs.customerprofiles.IntegrationTaskPropertiesMapArgs>[]>;
        /**
         * Specifies the particular task implementation that Amazon AppFlow performs.
         */
        taskType: pulumi.Input<enums.customerprofiles.IntegrationTaskType>;
    }
    interface IntegrationTaskPropertiesMapArgs {
        /**
         * The task property key.
         */
        operatorPropertyKey: pulumi.Input<enums.customerprofiles.IntegrationOperatorPropertiesKeys>;
        /**
         * The task property value.
         */
        property: pulumi.Input<string>;
    }
    interface IntegrationTriggerConfigArgs {
        /**
         * Specifies the configuration details of a schedule-triggered flow that you define. Currently, these settings only apply to the Scheduled trigger type.
         */
        triggerProperties?: pulumi.Input<inputs.customerprofiles.IntegrationTriggerPropertiesArgs>;
        /**
         * Specifies the type of flow trigger. It can be OnDemand, Scheduled, or Event.
         */
        triggerType: pulumi.Input<enums.customerprofiles.IntegrationTriggerType>;
    }
    interface IntegrationTriggerPropertiesArgs {
        /**
         * Specifies the configuration details of a schedule-triggered flow that you define.
         */
        scheduled?: pulumi.Input<inputs.customerprofiles.IntegrationScheduledTriggerPropertiesArgs>;
    }
    interface IntegrationZendeskSourcePropertiesArgs {
        /**
         * The object specified in the Zendesk flow source.
         */
        object: pulumi.Input<string>;
    }
    /**
     * Represents a field in a ProfileObjectType.
     */
    interface ObjectTypeFieldArgs {
        /**
         * The content type of the field. Used for determining equality when searching.
         */
        contentType?: pulumi.Input<enums.customerprofiles.ObjectTypeFieldContentType>;
        /**
         * A field of a ProfileObject. For example: _source.FirstName, where "_source" is a ProfileObjectType of a Zendesk user and "FirstName" is a field in that ObjectType.
         */
        source?: pulumi.Input<string>;
        /**
         * The location of the data in the standard ProfileObject model. For example: _profile.Address.PostalCode.
         */
        target?: pulumi.Input<string>;
    }
    interface ObjectTypeFieldMapArgs {
        /**
         * Name of the field.
         */
        name?: pulumi.Input<string>;
        /**
         * Represents a field in a ProfileObjectType.
         */
        objectTypeField?: pulumi.Input<inputs.customerprofiles.ObjectTypeFieldArgs>;
    }
    /**
     * An object that defines the Key element of a ProfileObject. A Key is a special element that can be used to search for a customer profile.
     */
    interface ObjectTypeKeyArgs {
        /**
         * The reference for the key name of the fields map.
         */
        fieldNames?: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * The types of keys that a ProfileObject can have. Each ProfileObject can have only 1 UNIQUE key but multiple PROFILE keys. PROFILE means that this key can be used to tie an object to a PROFILE. UNIQUE means that it can be used to uniquely identify an object. If a key a is marked as SECONDARY, it will be used to search for profiles after all other PROFILE keys have been searched. A LOOKUP_ONLY key is only used to match a profile but is not persisted to be used for searching of the profile. A NEW_ONLY key is only used if the profile does not already exist before the object is ingested, otherwise it is only used for matching objects to profiles.
         */
        standardIdentifiers?: pulumi.Input<pulumi.Input<enums.customerprofiles.ObjectTypeKeyStandardIdentifiersItem>[]>;
    }
    interface ObjectTypeKeyMapArgs {
        /**
         * Name of the key.
         */
        name?: pulumi.Input<string>;
        /**
         * A list of ObjectTypeKey.
         */
        objectTypeKeyList?: pulumi.Input<pulumi.Input<inputs.customerprofiles.ObjectTypeKeyArgs>[]>;
    }
    /**
     * The address based criteria for the segment.
     */
    interface SegmentDefinitionAddressDimensionArgs {
        city?: pulumi.Input<inputs.customerprofiles.SegmentDefinitionProfileDimensionArgs>;
        country?: pulumi.Input<inputs.customerprofiles.SegmentDefinitionProfileDimensionArgs>;
        county?: pulumi.Input<inputs.customerprofiles.SegmentDefinitionProfileDimensionArgs>;
        postalCode?: pulumi.Input<inputs.customerprofiles.SegmentDefinitionProfileDimensionArgs>;
        province?: pulumi.Input<inputs.customerprofiles.SegmentDefinitionProfileDimensionArgs>;
        state?: pulumi.Input<inputs.customerprofiles.SegmentDefinitionProfileDimensionArgs>;
    }
    /**
     * Specifies attribute based criteria for a segment.
     */
    interface SegmentDefinitionAttributeDimensionArgs {
        dimensionType: pulumi.Input<enums.customerprofiles.SegmentDefinitionAttributeDimensionType>;
        values: pulumi.Input<pulumi.Input<string>[]>;
    }
    /**
     * Specifies calculated attribute based criteria for a segment.
     */
    interface SegmentDefinitionCalculatedAttributeDimensionArgs {
        conditionOverrides?: pulumi.Input<inputs.customerprofiles.SegmentDefinitionConditionOverridesArgs>;
        dimensionType: pulumi.Input<enums.customerprofiles.SegmentDefinitionAttributeDimensionType>;
        values: pulumi.Input<pulumi.Input<string>[]>;
    }
    /**
     * Overrides the condition block within the original calculated attribute definition.
     */
    interface SegmentDefinitionConditionOverridesArgs {
        range?: pulumi.Input<inputs.customerprofiles.SegmentDefinitionRangeOverrideArgs>;
    }
    /**
     * Specifies date based criteria for a segment.
     */
    interface SegmentDefinitionDateDimensionArgs {
        dimensionType: pulumi.Input<enums.customerprofiles.SegmentDefinitionDateDimensionType>;
        values: pulumi.Input<pulumi.Input<string>[]>;
    }
    /**
     * The criteria that define the dimensions for the segment.
     */
    interface SegmentDefinitionDimension0PropertiesArgs {
        profileAttributes: pulumi.Input<inputs.customerprofiles.SegmentDefinitionProfileAttributesArgs>;
    }
    /**
     * The criteria that define the dimensions for the segment.
     */
    interface SegmentDefinitionDimension1PropertiesArgs {
        calculatedAttributes?: pulumi.Input<{
            [key: string]: pulumi.Input<inputs.customerprofiles.SegmentDefinitionCalculatedAttributeDimensionArgs>;
        }>;
    }
    /**
     * Specifies criteria for a segment using extended-length string values.
     */
    interface SegmentDefinitionExtraLengthValueProfileDimensionArgs {
        dimensionType: pulumi.Input<enums.customerprofiles.SegmentDefinitionStringDimensionType>;
        values: pulumi.Input<pulumi.Input<string>[]>;
    }
    /**
     * An array that defines the set of segment criteria to evaluate when handling segment groups for the segment.
     */
    interface SegmentDefinitionGroupArgs {
        /**
         * Defines the attributes to segment on.
         */
        dimensions?: pulumi.Input<pulumi.Input<inputs.customerprofiles.SegmentDefinitionDimension0PropertiesArgs | inputs.customerprofiles.SegmentDefinitionDimension1PropertiesArgs>[]>;
        /**
         * Defines the starting source of data.
         */
        sourceSegments?: pulumi.Input<pulumi.Input<inputs.customerprofiles.SegmentDefinitionSourceSegmentArgs>[]>;
        /**
         * Defines how to interact with the source data.
         */
        sourceType?: pulumi.Input<enums.customerprofiles.SegmentDefinitionIncludeOptions>;
        /**
         * Defines how to interact with the profiles found in the current filtering.
         */
        type?: pulumi.Input<enums.customerprofiles.SegmentDefinitionIncludeOptions>;
    }
    /**
     * Specifies the dimension settings within profile attributes for a segment.
     */
    interface SegmentDefinitionProfileAttributesArgs {
        accountNumber?: pulumi.Input<inputs.customerprofiles.SegmentDefinitionProfileDimensionArgs>;
        additionalInformation?: pulumi.Input<inputs.customerprofiles.SegmentDefinitionExtraLengthValueProfileDimensionArgs>;
        address?: pulumi.Input<inputs.customerprofiles.SegmentDefinitionAddressDimensionArgs>;
        attributes?: pulumi.Input<{
            [key: string]: pulumi.Input<inputs.customerprofiles.SegmentDefinitionAttributeDimensionArgs>;
        }>;
        billingAddress?: pulumi.Input<inputs.customerprofiles.SegmentDefinitionAddressDimensionArgs>;
        birthDate?: pulumi.Input<inputs.customerprofiles.SegmentDefinitionDateDimensionArgs>;
        businessEmailAddress?: pulumi.Input<inputs.customerprofiles.SegmentDefinitionProfileDimensionArgs>;
        businessName?: pulumi.Input<inputs.customerprofiles.SegmentDefinitionProfileDimensionArgs>;
        businessPhoneNumber?: pulumi.Input<inputs.customerprofiles.SegmentDefinitionProfileDimensionArgs>;
        emailAddress?: pulumi.Input<inputs.customerprofiles.SegmentDefinitionProfileDimensionArgs>;
        firstName?: pulumi.Input<inputs.customerprofiles.SegmentDefinitionProfileDimensionArgs>;
        genderString?: pulumi.Input<inputs.customerprofiles.SegmentDefinitionProfileDimensionArgs>;
        homePhoneNumber?: pulumi.Input<inputs.customerprofiles.SegmentDefinitionProfileDimensionArgs>;
        lastName?: pulumi.Input<inputs.customerprofiles.SegmentDefinitionProfileDimensionArgs>;
        mailingAddress?: pulumi.Input<inputs.customerprofiles.SegmentDefinitionAddressDimensionArgs>;
        middleName?: pulumi.Input<inputs.customerprofiles.SegmentDefinitionProfileDimensionArgs>;
        mobilePhoneNumber?: pulumi.Input<inputs.customerprofiles.SegmentDefinitionProfileDimensionArgs>;
        partyTypeString?: pulumi.Input<inputs.customerprofiles.SegmentDefinitionProfileDimensionArgs>;
        personalEmailAddress?: pulumi.Input<inputs.customerprofiles.SegmentDefinitionProfileDimensionArgs>;
        phoneNumber?: pulumi.Input<inputs.customerprofiles.SegmentDefinitionProfileDimensionArgs>;
        shippingAddress?: pulumi.Input<inputs.customerprofiles.SegmentDefinitionAddressDimensionArgs>;
    }
    /**
     * Specifies profile based criteria for a segment.
     */
    interface SegmentDefinitionProfileDimensionArgs {
        dimensionType: pulumi.Input<enums.customerprofiles.SegmentDefinitionStringDimensionType>;
        values: pulumi.Input<pulumi.Input<string>[]>;
    }
    /**
     * Defines the range to be applied to the calculated attribute definition.
     */
    interface SegmentDefinitionRangeOverrideArgs {
        /**
         * The ending point for this overridden range.
         */
        end?: pulumi.Input<number>;
        /**
         * The starting point for this overridden range.
         */
        start: pulumi.Input<number>;
        /**
         * The unit to be applied to the range.
         */
        unit: pulumi.Input<enums.customerprofiles.SegmentDefinitionRangeOverrideUnit>;
    }
    interface SegmentDefinitionSegmentGroupArgs {
        /**
         * Holds the list of groups within the segment definition.
         */
        groups?: pulumi.Input<pulumi.Input<inputs.customerprofiles.SegmentDefinitionGroupArgs>[]>;
        /**
         * Defines whether to include or exclude the profiles that fit the segment criteria.
         */
        include?: pulumi.Input<enums.customerprofiles.SegmentDefinitionIncludeOptions>;
    }
    /**
     * The base segment to build the segment on.
     */
    interface SegmentDefinitionSourceSegmentArgs {
        /**
         * The name of the source segment.
         */
        segmentDefinitionName?: pulumi.Input<string>;
    }
}
export declare namespace databrew {
    /**
     * Csv options
     */
    interface DatasetCsvOptionsArgs {
        /**
         * A single character that specifies the delimiter being used in the CSV file.
         */
        delimiter?: pulumi.Input<string>;
        /**
         * A variable that specifies whether the first row in the file is parsed as the header. If this value is false, column names are auto-generated.
         */
        headerRow?: pulumi.Input<boolean>;
    }
    interface DatasetDataCatalogInputDefinitionArgs {
        /**
         * Catalog id
         */
        catalogId?: pulumi.Input<string>;
        /**
         * Database name
         */
        databaseName?: pulumi.Input<string>;
        /**
         * Table name
         */
        tableName?: pulumi.Input<string>;
        /**
         * An Amazon location that AWS Glue Data Catalog can use as a temporary directory.
         */
        tempDirectory?: pulumi.Input<inputs.databrew.DatasetS3LocationArgs>;
    }
    interface DatasetDatabaseInputDefinitionArgs {
        /**
         * Database table name
         */
        databaseTableName?: pulumi.Input<string>;
        /**
         * Glue connection name
         */
        glueConnectionName: pulumi.Input<string>;
        /**
         * Custom SQL to run against the provided AWS Glue connection. This SQL will be used as the input for DataBrew projects and jobs.
         */
        queryString?: pulumi.Input<string>;
        /**
         * An Amazon location that AWS Glue Data Catalog can use as a temporary directory.
         */
        tempDirectory?: pulumi.Input<inputs.databrew.DatasetS3LocationArgs>;
    }
    interface DatasetDatetimeOptionsArgs {
        /**
         * Date/time format of a date parameter
         */
        format: pulumi.Input<string>;
        /**
         * Locale code for a date parameter
         */
        localeCode?: pulumi.Input<string>;
        /**
         * Timezone offset
         */
        timezoneOffset?: pulumi.Input<string>;
    }
    interface DatasetExcelOptionsArgs {
        /**
         * A variable that specifies whether the first row in the file is parsed as the header. If this value is false, column names are auto-generated.
         */
        headerRow?: pulumi.Input<boolean>;
        /**
         * One or more sheet numbers in the Excel file that will be included in the dataset.
         */
        sheetIndexes?: pulumi.Input<pulumi.Input<number>[]>;
        /**
         * One or more named sheets in the Excel file that will be included in the dataset.
         */
        sheetNames?: pulumi.Input<pulumi.Input<string>[]>;
    }
    interface DatasetFilesLimitArgs {
        /**
         * Maximum number of files
         */
        maxFiles: pulumi.Input<number>;
        /**
         * Order
         */
        order?: pulumi.Input<enums.databrew.DatasetFilesLimitOrder>;
        /**
         * Ordered by
         */
        orderedBy?: pulumi.Input<enums.databrew.DatasetFilesLimitOrderedBy>;
    }
    interface DatasetFilterExpressionArgs {
        /**
         * Filtering expression for a parameter
         */
        expression: pulumi.Input<string>;
        /**
         * The map of substitution variable names to their values used in this filter expression.
         */
        valuesMap: pulumi.Input<pulumi.Input<inputs.databrew.DatasetFilterValueArgs>[]>;
    }
    /**
     * A key-value pair to associate expression variable names with their values
     */
    interface DatasetFilterValueArgs {
        /**
         * The value to be associated with the substitution variable.
         */
        value: pulumi.Input<string>;
        /**
         * Variable name
         */
        valueReference: pulumi.Input<string>;
    }
    /**
     * Format options for dataset
     */
    interface DatasetFormatOptionsArgs {
        /**
         * Options that define how CSV input is to be interpreted by DataBrew.
         */
        csv?: pulumi.Input<inputs.databrew.DatasetCsvOptionsArgs>;
        /**
         * Options that define how Excel input is to be interpreted by DataBrew.
         */
        excel?: pulumi.Input<inputs.databrew.DatasetExcelOptionsArgs>;
        /**
         * Options that define how JSON input is to be interpreted by DataBrew.
         */
        json?: pulumi.Input<inputs.databrew.DatasetJsonOptionsArgs>;
    }
    /**
     * Input
     */
    interface DatasetInputArgs {
        /**
         * The AWS Glue Data Catalog parameters for the data.
         */
        dataCatalogInputDefinition?: pulumi.Input<inputs.databrew.DatasetDataCatalogInputDefinitionArgs>;
        /**
         * Connection information for dataset input files stored in a database.
         */
        databaseInputDefinition?: pulumi.Input<inputs.databrew.DatasetDatabaseInputDefinitionArgs>;
        /**
         * Contains additional resource information needed for specific datasets.
         */
        metadata?: pulumi.Input<inputs.databrew.DatasetMetadataArgs>;
        /**
         * The Amazon S3 location where the data is stored.
         */
        s3InputDefinition?: pulumi.Input<inputs.databrew.DatasetS3LocationArgs>;
    }
    /**
     * Json options
     */
    interface DatasetJsonOptionsArgs {
        /**
         * A value that specifies whether JSON input contains embedded new line characters.
         */
        multiLine?: pulumi.Input<boolean>;
    }
    interface DatasetMetadataArgs {
        /**
         * Arn of the source of the dataset. For e.g.: AppFlow Flow ARN.
         */
        sourceArn?: pulumi.Input<string>;
    }
    interface DatasetParameterArgs {
        /**
         * Add the value of this parameter as a column in a dataset.
         */
        createColumn?: pulumi.Input<boolean>;
        /**
         * Additional parameter options such as a format and a timezone. Required for datetime parameters.
         */
        datetimeOptions?: pulumi.Input<inputs.databrew.DatasetDatetimeOptionsArgs>;
        /**
         * The optional filter expression structure to apply additional matching criteria to the parameter.
         */
        filter?: pulumi.Input<inputs.databrew.DatasetFilterExpressionArgs>;
        /**
         * The name of the parameter that is used in the dataset's Amazon S3 path.
         */
        name: pulumi.Input<string>;
        /**
         * Parameter type
         */
        type: pulumi.Input<enums.databrew.DatasetParameterType>;
    }
    /**
     * Path options for dataset
     */
    interface DatasetPathOptionsArgs {
        /**
         * If provided, this structure imposes a limit on a number of files that should be selected.
         */
        filesLimit?: pulumi.Input<inputs.databrew.DatasetFilesLimitArgs>;
        /**
         * If provided, this structure defines a date range for matching Amazon S3 objects based on their LastModifiedDate attribute in Amazon S3 .
         */
        lastModifiedDateCondition?: pulumi.Input<inputs.databrew.DatasetFilterExpressionArgs>;
        /**
         * A structure that maps names of parameters used in the Amazon S3 path of a dataset to their definitions.
         */
        parameters?: pulumi.Input<pulumi.Input<inputs.databrew.DatasetPathParameterArgs>[]>;
    }
    /**
     * A key-value pair to associate dataset parameter name with its definition.
     */
    interface DatasetPathParameterArgs {
        /**
         * The path parameter definition.
         */
        datasetParameter: pulumi.Input<inputs.databrew.DatasetParameterArgs>;
        /**
         * The name of the path parameter.
         */
        pathParameterName: pulumi.Input<string>;
    }
    /**
     * Input location
     */
    interface DatasetS3LocationArgs {
        /**
         * The Amazon S3 bucket name.
         */
        bucket: pulumi.Input<string>;
        /**
         * The AWS account ID of the bucket owner.
         */
        bucketOwner?: pulumi.Input<string>;
        /**
         * The unique name of the object in the bucket.
         */
        key?: pulumi.Input<string>;
    }
    interface JobAllowedStatisticsArgs {
        /**
         * One or more column statistics to allow for columns that contain detected entities.
         */
        statistics: pulumi.Input<pulumi.Input<string>[]>;
    }
    interface JobColumnSelectorArgs {
        /**
         * The name of a column from a dataset.
         */
        name?: pulumi.Input<string>;
        /**
         * A regular expression for selecting a column from a dataset.
         */
        regex?: pulumi.Input<string>;
    }
    interface JobColumnStatisticsConfigurationArgs {
        /**
         * List of column selectors. Selectors can be used to select columns from the dataset. When selectors are undefined, configuration will be applied to all supported columns.
         */
        selectors?: pulumi.Input<pulumi.Input<inputs.databrew.JobColumnSelectorArgs>[]>;
        /**
         * Configuration for evaluations. Statistics can be used to select evaluations and override parameters of evaluations.
         */
        statistics: pulumi.Input<inputs.databrew.JobStatisticsConfigurationArgs>;
    }
    /**
     * Output Csv options
     */
    interface JobCsvOutputOptionsArgs {
        /**
         * A single character that specifies the delimiter used to create CSV job output.
         */
        delimiter?: pulumi.Input<string>;
    }
    interface JobDataCatalogOutputArgs {
        /**
         * The unique identifier of the AWS account that holds the Data Catalog that stores the data.
         */
        catalogId?: pulumi.Input<string>;
        /**
         * The name of a database in the Data Catalog.
         */
        databaseName: pulumi.Input<string>;
        /**
         * Represents options that specify how and where DataBrew writes the database output generated by recipe jobs.
         */
        databaseOptions?: pulumi.Input<inputs.databrew.JobDatabaseTableOutputOptionsArgs>;
        /**
         * A value that, if true, means that any data in the location specified for output is overwritten with new output. Not supported with DatabaseOptions.
         */
        overwrite?: pulumi.Input<boolean>;
        /**
         * Represents options that specify how and where DataBrew writes the Amazon S3 output generated by recipe jobs.
         */
        s3Options?: pulumi.Input<inputs.databrew.JobS3TableOutputOptionsArgs>;
        /**
         * The name of a table in the Data Catalog.
         */
        tableName: pulumi.Input<string>;
    }
    interface JobDatabaseOutputArgs {
        /**
         * Represents options that specify how and where DataBrew writes the database output generated by recipe jobs.
         */
        databaseOptions: pulumi.Input<inputs.databrew.JobDatabaseTableOutputOptionsArgs>;
        /**
         * Database table name
         */
        databaseOutputMode?: pulumi.Input<enums.databrew.JobDatabaseOutputDatabaseOutputMode>;
        /**
         * Glue connection name
         */
        glueConnectionName: pulumi.Input<string>;
    }
    interface JobDatabaseTableOutputOptionsArgs {
        /**
         * A prefix for the name of a table DataBrew will create in the database.
         */
        tableName: pulumi.Input<string>;
        /**
         * Represents an Amazon S3 location (bucket name and object key) where DataBrew can store intermediate results.
         */
        tempDirectory?: pulumi.Input<inputs.databrew.JobS3LocationArgs>;
    }
    interface JobEntityDetectorConfigurationArgs {
        /**
         * Configuration of statistics that are allowed to be run on columns that contain detected entities. When undefined, no statistics will be computed on columns that contain detected entities.
         */
        allowedStatistics?: pulumi.Input<inputs.databrew.JobAllowedStatisticsArgs>;
        /**
         * Entity types to detect. Can be any of the following:
         *
         * - USA_SSN
         * - EMAIL
         * - USA_ITIN
         * - USA_PASSPORT_NUMBER
         * - PHONE_NUMBER
         * - USA_DRIVING_LICENSE
         * - BANK_ACCOUNT
         * - CREDIT_CARD
         * - IP_ADDRESS
         * - MAC_ADDRESS
         * - USA_DEA_NUMBER
         * - USA_HCPCS_CODE
         * - USA_NATIONAL_PROVIDER_IDENTIFIER
         * - USA_NATIONAL_DRUG_CODE
         * - USA_HEALTH_INSURANCE_CLAIM_NUMBER
         * - USA_MEDICARE_BENEFICIARY_IDENTIFIER
         * - USA_CPT_CODE
         * - PERSON_NAME
         * - DATE
         *
         * The Entity type group USA_ALL is also supported, and includes all of the above entity types except PERSON_NAME and DATE.
         */
        entityTypes: pulumi.Input<pulumi.Input<string>[]>;
    }
    interface JobOutputArgs {
        /**
         * The compression algorithm used to compress the output text of the job.
         */
        compressionFormat?: pulumi.Input<enums.databrew.JobOutputCompressionFormat>;
        /**
         * The data format of the output of the job.
         */
        format?: pulumi.Input<enums.databrew.JobOutputFormat>;
        /**
         * Represents options that define how DataBrew formats job output files.
         */
        formatOptions?: pulumi.Input<inputs.databrew.JobOutputFormatOptionsArgs>;
        /**
         * The location in Amazon S3 where the job writes its output.
         */
        location: pulumi.Input<inputs.databrew.JobS3LocationArgs>;
        /**
         * The maximum number of files to be generated by the job and written to the output folder.
         */
        maxOutputFiles?: pulumi.Input<number>;
        /**
         * A value that, if true, means that any data in the location specified for output is overwritten with new output.
         */
        overwrite?: pulumi.Input<boolean>;
        /**
         * The names of one or more partition columns for the output of the job.
         */
        partitionColumns?: pulumi.Input<pulumi.Input<string>[]>;
    }
    /**
     * Format options for job Output
     */
    interface JobOutputFormatOptionsArgs {
        /**
         * Represents a set of options that define the structure of comma-separated value (CSV) job output.
         */
        csv?: pulumi.Input<inputs.databrew.JobCsvOutputOptionsArgs>;
    }
    /**
     * Output location
     */
    interface JobOutputLocationArgs {
        /**
         * The Amazon S3 bucket name.
         */
        bucket: pulumi.Input<string>;
        bucketOwner?: pulumi.Input<string>;
        /**
         * The unique name of the object in the bucket.
         */
        key?: pulumi.Input<string>;
    }
    interface JobProfileConfigurationArgs {
        /**
         * List of configurations for column evaluations. ColumnStatisticsConfigurations are used to select evaluations and override parameters of evaluations for particular columns. When ColumnStatisticsConfigurations is undefined, the profile job will profile all supported columns and run all supported evaluations.
         */
        columnStatisticsConfigurations?: pulumi.Input<pulumi.Input<inputs.databrew.JobColumnStatisticsConfigurationArgs>[]>;
        /**
         * Configuration for inter-column evaluations. Configuration can be used to select evaluations and override parameters of evaluations. When configuration is undefined, the profile job will run all supported inter-column evaluations.
         */
        datasetStatisticsConfiguration?: pulumi.Input<inputs.databrew.JobStatisticsConfigurationArgs>;
        /**
         * Configuration of entity detection for a profile job. When undefined, entity detection is disabled.
         */
        entityDetectorConfiguration?: pulumi.Input<inputs.databrew.JobEntityDetectorConfigurationArgs>;
        /**
         * List of column selectors. ProfileColumns can be used to select columns from the dataset. When ProfileColumns is undefined, the profile job will profile all supported columns.
         */
        profileColumns?: pulumi.Input<pulumi.Input<inputs.databrew.JobColumnSelectorArgs>[]>;
    }
    interface JobRecipeArgs {
        /**
         * Recipe name
         */
        name: pulumi.Input<string>;
        /**
         * Recipe version
         */
        version?: pulumi.Input<string>;
    }
    /**
     * S3 Output location
     */
    interface JobS3LocationArgs {
        /**
         * The Amazon S3 bucket name.
         */
        bucket: pulumi.Input<string>;
        /**
         * The AWS account ID of the bucket owner.
         */
        bucketOwner?: pulumi.Input<string>;
        /**
         * The unique name of the object in the bucket.
         */
        key?: pulumi.Input<string>;
    }
    interface JobS3TableOutputOptionsArgs {
        /**
         * Represents an Amazon S3 location (bucket name and object key) where DataBrew can write output from a job.
         */
        location: pulumi.Input<inputs.databrew.JobS3LocationArgs>;
    }
    /**
     * Job Sample
     */
    interface JobSampleArgs {
        /**
         * A value that determines whether the profile job is run on the entire dataset or a specified number of rows. This value must be one of the following:
         *
         * - FULL_DATASET - The profile job is run on the entire dataset.
         * - CUSTOM_ROWS - The profile job is run on the number of rows specified in the `Size` parameter.
         */
        mode?: pulumi.Input<enums.databrew.JobSampleMode>;
        /**
         * The `Size` parameter is only required when the mode is CUSTOM_ROWS. The profile job is run on the specified number of rows. The maximum value for size is Long.MAX_VALUE.
         *
         * Long.MAX_VALUE = 9223372036854775807
         */
        size?: pulumi.Input<number>;
    }
    interface JobStatisticOverrideArgs {
        /**
         * A map that includes overrides of an evaluation’s parameters.
         */
        parameters: pulumi.Input<{
            [key: string]: pulumi.Input<string>;
        }>;
        /**
         * The name of an evaluation
         */
        statistic: pulumi.Input<string>;
    }
    interface JobStatisticsConfigurationArgs {
        /**
         * List of included evaluations. When the list is undefined, all supported evaluations will be included.
         */
        includedStatistics?: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * List of overrides for evaluations.
         */
        overrides?: pulumi.Input<pulumi.Input<inputs.databrew.JobStatisticOverrideArgs>[]>;
    }
    /**
     * Configuration to attach Rulesets to the job
     */
    interface JobValidationConfigurationArgs {
        /**
         * Arn of the Ruleset
         */
        rulesetArn: pulumi.Input<string>;
        /**
         * Mode of data quality validation. Default mode is "CHECK_ALL" which verifies all rules defined in the selected ruleset.
         */
        validationMode?: pulumi.Input<enums.databrew.JobValidationMode>;
    }
    interface ProjectSampleArgs {
        /**
         * Sample size
         */
        size?: pulumi.Input<number>;
        /**
         * Sample type
         */
        type: pulumi.Input<enums.databrew.ProjectSampleType>;
    }
    interface RecipeActionArgs {
        /**
         * Step action operation
         */
        operation: pulumi.Input<string>;
        /**
         * Contextual parameters for the transformation.
         */
        parameters?: pulumi.Input<inputs.databrew.RecipeParametersArgs | {
            [key: string]: pulumi.Input<string>;
        }>;
    }
    /**
     * Condition expressions applied to the step action
     */
    interface RecipeConditionExpressionArgs {
        /**
         * Input condition to be applied to the target column
         */
        condition: pulumi.Input<string>;
        /**
         * Name of the target column
         */
        targetColumn: pulumi.Input<string>;
        /**
         * Value of the condition
         */
        value?: pulumi.Input<string>;
    }
    interface RecipeDataCatalogInputDefinitionArgs {
        /**
         * Catalog id
         */
        catalogId?: pulumi.Input<string>;
        /**
         * Database name
         */
        databaseName?: pulumi.Input<string>;
        /**
         * Table name
         */
        tableName?: pulumi.Input<string>;
        tempDirectory?: pulumi.Input<inputs.databrew.RecipeS3LocationArgs>;
    }
    interface RecipeParametersArgs {
        aggregateFunction?: pulumi.Input<string>;
        base?: pulumi.Input<string>;
        caseStatement?: pulumi.Input<string>;
        categoryMap?: pulumi.Input<string>;
        charsToRemove?: pulumi.Input<string>;
        collapseConsecutiveWhitespace?: pulumi.Input<string>;
        columnDataType?: pulumi.Input<string>;
        columnRange?: pulumi.Input<string>;
        count?: pulumi.Input<string>;
        customCharacters?: pulumi.Input<string>;
        customStopWords?: pulumi.Input<string>;
        customValue?: pulumi.Input<string>;
        datasetsColumns?: pulumi.Input<string>;
        dateAddValue?: pulumi.Input<string>;
        dateTimeFormat?: pulumi.Input<string>;
        dateTimeParameters?: pulumi.Input<string>;
        deleteOtherRows?: pulumi.Input<string>;
        delimiter?: pulumi.Input<string>;
        endPattern?: pulumi.Input<string>;
        endPosition?: pulumi.Input<string>;
        endValue?: pulumi.Input<string>;
        expandContractions?: pulumi.Input<string>;
        exponent?: pulumi.Input<string>;
        falseString?: pulumi.Input<string>;
        groupByAggFunctionOptions?: pulumi.Input<string>;
        groupByColumns?: pulumi.Input<string>;
        hiddenColumns?: pulumi.Input<string>;
        ignoreCase?: pulumi.Input<string>;
        includeInSplit?: pulumi.Input<string>;
        /**
         * Input
         */
        input?: pulumi.Input<inputs.databrew.RecipeParametersInputPropertiesArgs>;
        interval?: pulumi.Input<string>;
        isText?: pulumi.Input<string>;
        joinKeys?: pulumi.Input<string>;
        joinType?: pulumi.Input<string>;
        leftColumns?: pulumi.Input<string>;
        limit?: pulumi.Input<string>;
        lowerBound?: pulumi.Input<string>;
        mapType?: pulumi.Input<string>;
        modeType?: pulumi.Input<string>;
        multiLine?: pulumi.Input<boolean>;
        numRows?: pulumi.Input<string>;
        numRowsAfter?: pulumi.Input<string>;
        numRowsBefore?: pulumi.Input<string>;
        orderByColumn?: pulumi.Input<string>;
        orderByColumns?: pulumi.Input<string>;
        other?: pulumi.Input<string>;
        pattern?: pulumi.Input<string>;
        patternOption1?: pulumi.Input<string>;
        patternOption2?: pulumi.Input<string>;
        patternOptions?: pulumi.Input<string>;
        period?: pulumi.Input<string>;
        position?: pulumi.Input<string>;
        removeAllPunctuation?: pulumi.Input<string>;
        removeAllQuotes?: pulumi.Input<string>;
        removeAllWhitespace?: pulumi.Input<string>;
        removeCustomCharacters?: pulumi.Input<string>;
        removeCustomValue?: pulumi.Input<string>;
        removeLeadingAndTrailingPunctuation?: pulumi.Input<string>;
        removeLeadingAndTrailingQuotes?: pulumi.Input<string>;
        removeLeadingAndTrailingWhitespace?: pulumi.Input<string>;
        removeLetters?: pulumi.Input<string>;
        removeNumbers?: pulumi.Input<string>;
        removeSourceColumn?: pulumi.Input<string>;
        removeSpecialCharacters?: pulumi.Input<string>;
        rightColumns?: pulumi.Input<string>;
        sampleSize?: pulumi.Input<string>;
        sampleType?: pulumi.Input<string>;
        secondInput?: pulumi.Input<string>;
        secondaryInputs?: pulumi.Input<pulumi.Input<inputs.databrew.RecipeSecondaryInputArgs>[]>;
        sheetIndexes?: pulumi.Input<pulumi.Input<number>[]>;
        sheetNames?: pulumi.Input<pulumi.Input<string>[]>;
        sourceColumn?: pulumi.Input<string>;
        sourceColumn1?: pulumi.Input<string>;
        sourceColumn2?: pulumi.Input<string>;
        sourceColumns?: pulumi.Input<string>;
        startColumnIndex?: pulumi.Input<string>;
        startPattern?: pulumi.Input<string>;
        startPosition?: pulumi.Input<string>;
        startValue?: pulumi.Input<string>;
        stemmingMode?: pulumi.Input<string>;
        stepCount?: pulumi.Input<string>;
        stepIndex?: pulumi.Input<string>;
        stopWordsMode?: pulumi.Input<string>;
        strategy?: pulumi.Input<string>;
        targetColumn?: pulumi.Input<string>;
        targetColumnNames?: pulumi.Input<string>;
        targetDateFormat?: pulumi.Input<string>;
        targetIndex?: pulumi.Input<string>;
        timeZone?: pulumi.Input<string>;
        tokenizerPattern?: pulumi.Input<string>;
        trueString?: pulumi.Input<string>;
        udfLang?: pulumi.Input<string>;
        units?: pulumi.Input<string>;
        unpivotColumn?: pulumi.Input<string>;
        upperBound?: pulumi.Input<string>;
        useNewDataFrame?: pulumi.Input<string>;
        value?: pulumi.Input<string>;
        value1?: pulumi.Input<string>;
        value2?: pulumi.Input<string>;
        valueColumn?: pulumi.Input<string>;
        viewFrame?: pulumi.Input<string>;
    }
    /**
     * Input
     */
    interface RecipeParametersInputPropertiesArgs {
        dataCatalogInputDefinition?: pulumi.Input<inputs.databrew.RecipeDataCatalogInputDefinitionArgs>;
        s3InputDefinition?: pulumi.Input<inputs.databrew.RecipeS3LocationArgs>;
    }
    /**
     * Input location
     */
    interface RecipeS3LocationArgs {
        bucket: pulumi.Input<string>;
        key?: pulumi.Input<string>;
    }
    /**
     * Secondary input
     */
    interface RecipeSecondaryInputArgs {
        dataCatalogInputDefinition?: pulumi.Input<inputs.databrew.RecipeDataCatalogInputDefinitionArgs>;
        s3InputDefinition?: pulumi.Input<inputs.databrew.RecipeS3LocationArgs>;
    }
    interface RecipeStepArgs {
        /**
         * The particular action to be performed in the recipe step.
         */
        action: pulumi.Input<inputs.databrew.RecipeActionArgs>;
        /**
         * Condition expressions applied to the step action
         */
        conditionExpressions?: pulumi.Input<pulumi.Input<inputs.databrew.RecipeConditionExpressionArgs>[]>;
    }
    /**
     * Selector of a column from a dataset for profile job configuration. One selector includes either a column name or a regular expression
     */
    interface RulesetColumnSelectorArgs {
        /**
         * The name of a column from a dataset
         */
        name?: pulumi.Input<string>;
        /**
         * A regular expression for selecting a column from a dataset
         */
        regex?: pulumi.Input<string>;
    }
    /**
     * Data quality rule for a target resource (dataset)
     */
    interface RulesetRuleArgs {
        /**
         * The expression which includes column references, condition names followed by variable references, possibly grouped and combined with other conditions. For example, `(:col1 starts_with :prefix1 or :col1 starts_with :prefix2) and (:col1 ends_with :suffix1 or :col1 ends_with :suffix2)` . Column and value references are substitution variables that should start with the ':' symbol. Depending on the context, substitution variables' values can be either an actual value or a column name. These values are defined in the SubstitutionMap. If a CheckExpression starts with a column reference, then ColumnSelectors in the rule should be null. If ColumnSelectors has been defined, then there should be no columnn reference in the left side of a condition, for example, `is_between :val1 and :val2` .
         */
        checkExpression: pulumi.Input<string>;
        /**
         * List of column selectors. Selectors can be used to select columns using a name or regular expression from the dataset. Rule will be applied to selected columns.
         */
        columnSelectors?: pulumi.Input<pulumi.Input<inputs.databrew.RulesetColumnSelectorArgs>[]>;
        /**
         * A value that specifies whether the rule is disabled. Once a rule is disabled, a profile job will not validate it during a job run. Default value is false.
         */
        disabled?: pulumi.Input<boolean>;
        /**
         * Name of the rule
         */
        name: pulumi.Input<string>;
        /**
         * The map of substitution variable names to their values used in a check expression. Variable names should start with a ':' (colon). Variable values can either be actual values or column names. To differentiate between the two, column names should be enclosed in backticks, for example, `":col1": "`Column A`".`
         */
        substitutionMap?: pulumi.Input<pulumi.Input<inputs.databrew.RulesetSubstitutionValueArgs>[]>;
        /**
         * The threshold used with a non-aggregate check expression. Non-aggregate check expressions will be applied to each row in a specific column, and the threshold will be used to determine whether the validation succeeds.
         */
        threshold?: pulumi.Input<inputs.databrew.RulesetThresholdArgs>;
    }
    /**
     * A key-value pair to associate expression's substitution variable names with their values
     */
    interface RulesetSubstitutionValueArgs {
        /**
         * Value or column name
         */
        value: pulumi.Input<string>;
        /**
         * Variable name
         */
        valueReference: pulumi.Input<string>;
    }
    interface RulesetThresholdArgs {
        /**
         * The type of a threshold. Used for comparison of an actual count of rows that satisfy the rule to the threshold value.
         */
        type?: pulumi.Input<enums.databrew.RulesetThresholdType>;
        /**
         * Unit of threshold value. Can be either a COUNT or PERCENTAGE of the full sample size used for validation.
         */
        unit?: pulumi.Input<enums.databrew.RulesetThresholdUnit>;
        /**
         * The value of a threshold.
         */
        value: pulumi.Input<number>;
    }
}
export declare namespace datapipeline {
    interface PipelineFieldArgs {
        /**
         * Specifies the name of a field for a particular object. To view valid values for a particular field, see Pipeline Object Reference in the AWS Data Pipeline Developer Guide.
         */
        key: pulumi.Input<string>;
        /**
         * A field value that you specify as an identifier of another object in the same pipeline definition.
         */
        refValue?: pulumi.Input<string>;
        /**
         * A field value that you specify as a string. To view valid values for a particular field, see Pipeline Object Reference in the AWS Data Pipeline Developer Guide.
         */
        stringValue?: pulumi.Input<string>;
    }
    interface PipelineObjectArgs {
        /**
         * Key-value pairs that define the properties of the object.
         */
        fields: pulumi.Input<pulumi.Input<inputs.datapipeline.PipelineFieldArgs>[]>;
        /**
         * The ID of the object.
         */
        id: pulumi.Input<string>;
        /**
         * The name of the object.
         */
        name: pulumi.Input<string>;
    }
    interface PipelineParameterAttributeArgs {
        /**
         * The field identifier.
         */
        key: pulumi.Input<string>;
        /**
         * The field value, expressed as a String.
         */
        stringValue: pulumi.Input<string>;
    }
    interface PipelineParameterObjectArgs {
        /**
         * The attributes of the parameter object.
         */
        attributes: pulumi.Input<pulumi.Input<inputs.datapipeline.PipelineParameterAttributeArgs>[]>;
        /**
         * The ID of the parameter object.
         */
        id: pulumi.Input<string>;
    }
    interface PipelineParameterValueArgs {
        /**
         * The ID of the parameter value.
         */
        id: pulumi.Input<string>;
        /**
         * The field value, expressed as a String.
         */
        stringValue: pulumi.Input<string>;
    }
}
export declare namespace datasync {
    /**
     * Specifies the shared access signature (SAS) that DataSync uses to access your Azure Blob Storage container.
     */
    interface LocationAzureBlobAzureBlobSasConfigurationArgs {
        /**
         * Specifies the shared access signature (SAS) token, which indicates the permissions DataSync needs to access your Azure Blob Storage container.
         */
        azureBlobSasToken: pulumi.Input<string>;
    }
    /**
     * The subnet and security group that DataSync uses to access target EFS file system.
     */
    interface LocationEfsEc2ConfigArgs {
        /**
         * The Amazon Resource Names (ARNs) of the security groups that are configured for the Amazon EC2 resource.
         */
        securityGroupArns: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * The ARN of the subnet that DataSync uses to access the target EFS file system.
         */
        subnetArn: pulumi.Input<string>;
    }
    /**
     * NFS protocol configuration for FSx ONTAP file system.
     */
    interface LocationFSxOntapNfsArgs {
        /**
         * Specifies how DataSync can access a location using the NFS protocol.
         */
        mountOptions: pulumi.Input<inputs.datasync.LocationFSxOntapNfsMountOptionsArgs>;
    }
    /**
     * The NFS mount options that DataSync can use to mount your NFS share.
     */
    interface LocationFSxOntapNfsMountOptionsArgs {
        /**
         * The specific NFS version that you want DataSync to use to mount your NFS share.
         */
        version?: pulumi.Input<enums.datasync.LocationFSxOntapNfsMountOptionsVersion>;
    }
    /**
     * Configuration settings for NFS or SMB protocol.
     */
    interface LocationFSxOntapProtocolArgs {
        /**
         * Specifies the Network File System (NFS) protocol configuration that DataSync uses to access your FSx for ONTAP file system's storage virtual machine (SVM).
         */
        nfs?: pulumi.Input<inputs.datasync.LocationFSxOntapNfsArgs>;
        /**
         * Specifies the Server Message Block (SMB) protocol configuration that DataSync uses to access your FSx for ONTAP file system's SVM.
         */
        smb?: pulumi.Input<inputs.datasync.LocationFSxOntapSmbArgs>;
    }
    /**
     * SMB protocol configuration for FSx ONTAP file system.
     */
    interface LocationFSxOntapSmbArgs {
        /**
         * The name of the Windows domain that the SMB server belongs to.
         */
        domain?: pulumi.Input<string>;
        /**
         * Specifies how DataSync can access a location using the SMB protocol.
         */
        mountOptions: pulumi.Input<inputs.datasync.LocationFSxOntapSmbMountOptionsArgs>;
        /**
         * The password of the user who can mount the share and has the permissions to access files and folders in the SMB share.
         */
        password: pulumi.Input<string>;
        /**
         * The user who can mount the share, has the permissions to access files and folders in the SMB share.
         */
        user: pulumi.Input<string>;
    }
    /**
     * The mount options used by DataSync to access the SMB server.
     */
    interface LocationFSxOntapSmbMountOptionsArgs {
        /**
         * The specific SMB version that you want DataSync to use to mount your SMB share.
         */
        version?: pulumi.Input<enums.datasync.LocationFSxOntapSmbMountOptionsVersion>;
    }
    /**
     * The NFS mount options that DataSync can use to mount your NFS share.
     */
    interface LocationFSxOpenZfsMountOptionsArgs {
        /**
         * The specific NFS version that you want DataSync to use to mount your NFS share.
         */
        version?: pulumi.Input<enums.datasync.LocationFSxOpenZfsMountOptionsVersion>;
    }
    /**
     * FSx OpenZFS file system NFS protocol information
     */
    interface LocationFSxOpenZfsNfsArgs {
        /**
         * Represents the mount options that are available for DataSync to access an NFS location.
         */
        mountOptions: pulumi.Input<inputs.datasync.LocationFSxOpenZfsMountOptionsArgs>;
    }
    /**
     * Configuration settings for an NFS or SMB protocol, currently only support NFS
     */
    interface LocationFSxOpenZfsProtocolArgs {
        /**
         * Represents the Network File System (NFS) protocol that DataSync uses to access your FSx for OpenZFS file system.
         */
        nfs?: pulumi.Input<inputs.datasync.LocationFSxOpenZfsNfsArgs>;
    }
    /**
     * HDFS Name Node IP and port information.
     */
    interface LocationHdfsNameNodeArgs {
        /**
         * The DNS name or IP address of the Name Node in the customer's on premises HDFS cluster.
         */
        hostname: pulumi.Input<string>;
        /**
         * The port on which the Name Node is listening on for client requests.
         */
        port: pulumi.Input<number>;
    }
    /**
     * Configuration information for RPC Protection and Data Transfer Protection. These parameters can be set to AUTHENTICATION, INTEGRITY, or PRIVACY. The default value is PRIVACY.
     */
    interface LocationHdfsQopConfigurationArgs {
        /**
         * Configuration for Data Transfer Protection.
         */
        dataTransferProtection?: pulumi.Input<enums.datasync.LocationHdfsQopConfigurationDataTransferProtection>;
        /**
         * Configuration for RPC Protection.
         */
        rpcProtection?: pulumi.Input<enums.datasync.LocationHdfsQopConfigurationRpcProtection>;
    }
    /**
     * The NFS mount options that DataSync can use to mount your NFS share.
     */
    interface LocationNfsMountOptionsArgs {
        /**
         * The specific NFS version that you want DataSync to use to mount your NFS share.
         */
        version?: pulumi.Input<enums.datasync.LocationNfsMountOptionsVersion>;
    }
    /**
     * Contains a list of Amazon Resource Names (ARNs) of agents that are used to connect an NFS server.
     */
    interface LocationNfsOnPremConfigArgs {
        /**
         * ARN(s) of the agent(s) to use for an NFS location.
         */
        agentArns: pulumi.Input<pulumi.Input<string>[]>;
    }
    /**
     * The Amazon Resource Name (ARN) of the AWS IAM role that is used to access an Amazon S3 bucket.
     */
    interface LocationS3s3ConfigArgs {
        /**
         * The ARN of the IAM role of the Amazon S3 bucket.
         */
        bucketAccessRoleArn: pulumi.Input<string>;
    }
    /**
     * The mount options used by DataSync to access the SMB server.
     */
    interface LocationSmbMountOptionsArgs {
        /**
         * The specific SMB version that you want DataSync to use to mount your SMB share.
         */
        version?: pulumi.Input<enums.datasync.LocationSmbMountOptionsVersion>;
    }
    /**
     * The server name and network port required to connect with the management interface of the on-premises storage system.
     */
    interface StorageSystemServerConfigurationArgs {
        /**
         * The domain name or IP address of the storage system's management interface.
         */
        serverHostname: pulumi.Input<string>;
        /**
         * The network port needed to access the system's management interface
         */
        serverPort?: pulumi.Input<number>;
    }
    /**
     * The username and password for accessing your on-premises storage system's management interface.
     */
    interface StorageSystemServerCredentialsArgs {
        /**
         * The password for your storage system's management interface
         */
        password: pulumi.Input<string>;
        /**
         * The username for your storage system's management interface.
         */
        username: pulumi.Input<string>;
    }
    /**
     * Specifies which files folders and objects to include or exclude when transferring files from source to destination.
     */
    interface TaskFilterRuleArgs {
        /**
         * The type of filter rule to apply. AWS DataSync only supports the SIMPLE_PATTERN rule type.
         */
        filterType?: pulumi.Input<enums.datasync.TaskFilterRuleFilterType>;
        /**
         * A single filter string that consists of the patterns to include or exclude. The patterns are delimited by "|".
         */
        value?: pulumi.Input<string>;
    }
    /**
     * Configures a manifest, which is a list of files or objects that you want DataSync to transfer.
     */
    interface TaskManifestConfigArgs {
        /**
         * Specifies what DataSync uses the manifest for.
         */
        action?: pulumi.Input<enums.datasync.TaskManifestConfigAction>;
        /**
         * Specifies the file format of your manifest.
         */
        format?: pulumi.Input<enums.datasync.TaskManifestConfigFormat>;
        /**
         * Specifies the manifest that you want DataSync to use and where it's hosted.
         */
        source: pulumi.Input<inputs.datasync.TaskManifestConfigSourcePropertiesArgs>;
    }
    /**
     * Specifies the manifest that you want DataSync to use and where it's hosted.
     */
    interface TaskManifestConfigSourcePropertiesArgs {
        s3?: pulumi.Input<inputs.datasync.TaskManifestConfigSourceS3Args>;
    }
    /**
     * Specifies the S3 bucket where you're hosting the manifest that you want AWS DataSync to use.
     */
    interface TaskManifestConfigSourceS3Args {
        /**
         * Specifies the AWS Identity and Access Management (IAM) role that allows DataSync to access your manifest.
         */
        bucketAccessRoleArn?: pulumi.Input<string>;
        /**
         * Specifies the Amazon S3 object key of your manifest.
         */
        manifestObjectPath?: pulumi.Input<string>;
        /**
         * Specifies the object version ID of the manifest that you want DataSync to use.
         */
        manifestObjectVersionId?: pulumi.Input<string>;
        /**
         * Specifies the Amazon Resource Name (ARN) of the S3 bucket where you're hosting your manifest.
         */
        s3BucketArn?: pulumi.Input<string>;
    }
    /**
     * Represents the options that are available to control the behavior of a StartTaskExecution operation.
     */
    interface TaskOptionsArgs {
        /**
         * A file metadata value that shows the last time a file was accessed (that is, when the file was read or written to).
         */
        atime?: pulumi.Input<enums.datasync.TaskOptionsAtime>;
        /**
         * A value that limits the bandwidth used by AWS DataSync.
         */
        bytesPerSecond?: pulumi.Input<number>;
        /**
         * The group ID (GID) of the file's owners.
         */
        gid?: pulumi.Input<enums.datasync.TaskOptionsGid>;
        /**
         * A value that determines the types of logs that DataSync publishes to a log stream in the Amazon CloudWatch log group that you provide.
         */
        logLevel?: pulumi.Input<enums.datasync.TaskOptionsLogLevel>;
        /**
         * A value that indicates the last time that a file was modified (that is, a file was written to) before the PREPARING phase.
         */
        mtime?: pulumi.Input<enums.datasync.TaskOptionsMtime>;
        /**
         * A value that determines whether object tags should be read from the source object store and written to the destination object store.
         */
        objectTags?: pulumi.Input<enums.datasync.TaskOptionsObjectTags>;
        /**
         * A value that determines whether files at the destination should be overwritten or preserved when copying files.
         */
        overwriteMode?: pulumi.Input<enums.datasync.TaskOptionsOverwriteMode>;
        /**
         * A value that determines which users or groups can access a file for a specific purpose such as reading, writing, or execution of the file.
         */
        posixPermissions?: pulumi.Input<enums.datasync.TaskOptionsPosixPermissions>;
        /**
         * A value that specifies whether files in the destination that don't exist in the source file system should be preserved.
         */
        preserveDeletedFiles?: pulumi.Input<enums.datasync.TaskOptionsPreserveDeletedFiles>;
        /**
         * A value that determines whether AWS DataSync should preserve the metadata of block and character devices in the source file system, and recreate the files with that device name and metadata on the destination.
         */
        preserveDevices?: pulumi.Input<enums.datasync.TaskOptionsPreserveDevices>;
        /**
         * A value that determines which components of the SMB security descriptor are copied during transfer.
         */
        securityDescriptorCopyFlags?: pulumi.Input<enums.datasync.TaskOptionsSecurityDescriptorCopyFlags>;
        /**
         * A value that determines whether tasks should be queued before executing the tasks.
         */
        taskQueueing?: pulumi.Input<enums.datasync.TaskOptionsTaskQueueing>;
        /**
         * A value that determines whether DataSync transfers only the data and metadata that differ between the source and the destination location, or whether DataSync transfers all the content from the source, without comparing to the destination location.
         */
        transferMode?: pulumi.Input<enums.datasync.TaskOptionsTransferMode>;
        /**
         * The user ID (UID) of the file's owner.
         */
        uid?: pulumi.Input<enums.datasync.TaskOptionsUid>;
        /**
         * A value that determines whether a data integrity verification should be performed at the end of a task execution after all data and metadata have been transferred.
         */
        verifyMode?: pulumi.Input<enums.datasync.TaskOptionsVerifyMode>;
    }
    /**
     * Specifies how you want to configure a task report, which provides detailed information about for your Datasync transfer.
     */
    interface TaskReportConfigArgs {
        /**
         * Specifies where DataSync uploads your task report.
         */
        destination: pulumi.Input<inputs.datasync.TaskReportConfigDestinationPropertiesArgs>;
        /**
         * Specifies whether your task report includes the new version of each object transferred into an S3 bucket, this only applies if you enable versioning on your bucket.
         */
        objectVersionIds?: pulumi.Input<enums.datasync.TaskReportConfigObjectVersionIds>;
        /**
         * Specifies the type of task report that you want.
         */
        outputType: pulumi.Input<enums.datasync.TaskReportConfigOutputType>;
        /**
         * Customizes the reporting level for aspects of your task report. For example, your report might generally only include errors, but you could specify that you want a list of successes and errors just for the files that Datasync attempted to delete in your destination location.
         */
        overrides?: pulumi.Input<inputs.datasync.TaskReportConfigOverridesPropertiesArgs>;
        /**
         * Specifies whether you want your task report to include only what went wrong with your transfer or a list of what succeeded and didn't.
         */
        reportLevel?: pulumi.Input<enums.datasync.TaskReportConfigReportLevel>;
    }
    /**
     * Specifies where DataSync uploads your task report.
     */
    interface TaskReportConfigDestinationPropertiesArgs {
        s3?: pulumi.Input<inputs.datasync.TaskReportConfigDestinationS3Args>;
    }
    /**
     * Specifies the Amazon S3 bucket where DataSync uploads your task report.
     */
    interface TaskReportConfigDestinationS3Args {
        /**
         * Specifies the Amazon Resource Name (ARN) of the IAM policy that allows Datasync to upload a task report to your S3 bucket.
         */
        bucketAccessRoleArn?: pulumi.Input<string>;
        /**
         * Specifies the ARN of the S3 bucket where Datasync uploads your report.
         */
        s3BucketArn?: pulumi.Input<string>;
        /**
         * Specifies a bucket prefix for your report.
         */
        subdirectory?: pulumi.Input<string>;
    }
    /**
     * Customizes the reporting level for aspects of your task report. For example, your report might generally only include errors, but you could specify that you want a list of successes and errors just for the files that Datasync attempted to delete in your destination location.
     */
    interface TaskReportConfigOverridesPropertiesArgs {
        /**
         * Specifies the level of reporting for the files, objects, and directories that Datasync attempted to delete in your destination location. This only applies if you configure your task to delete data in the destination that isn't in the source.
         */
        deleted?: pulumi.Input<inputs.datasync.TaskReportConfigOverridesPropertiesDeletedPropertiesArgs>;
        /**
         * Specifies the level of reporting for the files, objects, and directories that Datasync attempted to skip during your transfer.
         */
        skipped?: pulumi.Input<inputs.datasync.TaskReportConfigOverridesPropertiesSkippedPropertiesArgs>;
        /**
         * Specifies the level of reporting for the files, objects, and directories that Datasync attempted to transfer.
         */
        transferred?: pulumi.Input<inputs.datasync.TaskReportConfigOverridesPropertiesTransferredPropertiesArgs>;
        /**
         * Specifies the level of reporting for the files, objects, and directories that Datasync attempted to verify at the end of your transfer. This only applies if you configure your task to verify data during and after the transfer (which Datasync does by default)
         */
        verified?: pulumi.Input<inputs.datasync.TaskReportConfigOverridesPropertiesVerifiedPropertiesArgs>;
    }
    /**
     * Specifies the level of reporting for the files, objects, and directories that Datasync attempted to delete in your destination location. This only applies if you configure your task to delete data in the destination that isn't in the source.
     */
    interface TaskReportConfigOverridesPropertiesDeletedPropertiesArgs {
        /**
         * Specifies whether you want your task report to include only what went wrong with your transfer or a list of what succeeded and didn't.
         */
        reportLevel?: pulumi.Input<enums.datasync.TaskReportConfigOverridesPropertiesDeletedPropertiesReportLevel>;
    }
    /**
     * Specifies the level of reporting for the files, objects, and directories that Datasync attempted to skip during your transfer.
     */
    interface TaskReportConfigOverridesPropertiesSkippedPropertiesArgs {
        /**
         * Specifies whether you want your task report to include only what went wrong with your transfer or a list of what succeeded and didn't.
         */
        reportLevel?: pulumi.Input<enums.datasync.TaskReportConfigOverridesPropertiesSkippedPropertiesReportLevel>;
    }
    /**
     * Specifies the level of reporting for the files, objects, and directories that Datasync attempted to transfer.
     */
    interface TaskReportConfigOverridesPropertiesTransferredPropertiesArgs {
        /**
         * Specifies whether you want your task report to include only what went wrong with your transfer or a list of what succeeded and didn't.
         */
        reportLevel?: pulumi.Input<enums.datasync.TaskReportConfigOverridesPropertiesTransferredPropertiesReportLevel>;
    }
    /**
     * Specifies the level of reporting for the files, objects, and directories that Datasync attempted to verify at the end of your transfer. This only applies if you configure your task to verify data during and after the transfer (which Datasync does by default)
     */
    interface TaskReportConfigOverridesPropertiesVerifiedPropertiesArgs {
        /**
         * Specifies whether you want your task report to include only what went wrong with your transfer or a list of what succeeded and didn't.
         */
        reportLevel?: pulumi.Input<enums.datasync.TaskReportConfigOverridesPropertiesVerifiedPropertiesReportLevel>;
    }
    /**
     * Specifies the schedule you want your task to use for repeated executions.
     */
    interface TaskScheduleArgs {
        /**
         * A cron expression that specifies when AWS DataSync initiates a scheduled transfer from a source to a destination location
         */
        scheduleExpression?: pulumi.Input<string>;
        /**
         * Specifies status of a schedule.
         */
        status?: pulumi.Input<enums.datasync.TaskScheduleStatus>;
    }
}
export declare namespace datazone {
    /**
     * Athena Properties Input
     */
    interface ConnectionAthenaPropertiesInputArgs {
        workgroupName: pulumi.Input<string>;
    }
    /**
     * Authentication Configuration Input
     */
    interface ConnectionAuthenticationConfigurationInputArgs {
        authenticationType?: pulumi.Input<enums.datazone.ConnectionAuthenticationType>;
        basicAuthenticationCredentials?: pulumi.Input<inputs.datazone.ConnectionBasicAuthenticationCredentialsArgs>;
        customAuthenticationCredentials?: pulumi.Input<{
            [key: string]: pulumi.Input<string>;
        }>;
        kmsKeyArn?: pulumi.Input<string>;
        oAuth2Properties?: pulumi.Input<inputs.datazone.ConnectionOAuth2PropertiesArgs>;
        secretArn?: pulumi.Input<string>;
    }
    /**
     * Authorization Code Properties
     */
    interface ConnectionAuthorizationCodePropertiesArgs {
        authorizationCode?: pulumi.Input<string>;
        redirectUri?: pulumi.Input<string>;
    }
    /**
     * AWS Location of project
     */
    interface ConnectionAwsLocationArgs {
        /**
         * The access role of a connection.
         */
        accessRole?: pulumi.Input<string>;
        /**
         * The account ID of a connection.
         */
        awsAccountId?: pulumi.Input<string>;
        /**
         * The Region of a connection.
         */
        awsRegion?: pulumi.Input<string>;
        /**
         * The IAM connection ID of a connection.
         */
        iamConnectionId?: pulumi.Input<string>;
    }
    /**
     * Basic Authentication Credentials
     */
    interface ConnectionBasicAuthenticationCredentialsArgs {
        password?: pulumi.Input<string>;
        userName?: pulumi.Input<string>;
    }
    /**
     * Glue Connection Input
     */
    interface ConnectionGlueConnectionInputArgs {
        athenaProperties?: pulumi.Input<{
            [key: string]: pulumi.Input<string>;
        }>;
        authenticationConfiguration?: pulumi.Input<inputs.datazone.ConnectionAuthenticationConfigurationInputArgs>;
        connectionProperties?: pulumi.Input<{
            [key: string]: pulumi.Input<string>;
        }>;
        connectionType?: pulumi.Input<string>;
        description?: pulumi.Input<string>;
        matchCriteria?: pulumi.Input<string>;
        name?: pulumi.Input<string>;
        physicalConnectionRequirements?: pulumi.Input<inputs.datazone.ConnectionPhysicalConnectionRequirementsArgs>;
        pythonProperties?: pulumi.Input<{
            [key: string]: pulumi.Input<string>;
        }>;
        sparkProperties?: pulumi.Input<{
            [key: string]: pulumi.Input<string>;
        }>;
        validateCredentials?: pulumi.Input<boolean>;
        validateForComputeEnvironments?: pulumi.Input<pulumi.Input<string>[]>;
    }
    /**
     * Glue OAuth2 Credentials
     */
    interface ConnectionGlueOAuth2CredentialsArgs {
        accessToken?: pulumi.Input<string>;
        jwtToken?: pulumi.Input<string>;
        refreshToken?: pulumi.Input<string>;
        userManagedClientApplicationClientSecret?: pulumi.Input<string>;
    }
    /**
     * Glue Properties Input
     */
    interface ConnectionGluePropertiesInputArgs {
        glueConnectionInput?: pulumi.Input<inputs.datazone.ConnectionGlueConnectionInputArgs>;
    }
    /**
     * HyperPod Properties Input
     */
    interface ConnectionHyperPodPropertiesInputArgs {
        clusterName: pulumi.Input<string>;
    }
    /**
     * IAM Properties Input
     */
    interface ConnectionIamPropertiesInputArgs {
        glueLineageSyncEnabled?: pulumi.Input<boolean>;
    }
    /**
     * Lineage Sync Schedule
     */
    interface ConnectionLineageSyncScheduleArgs {
        schedule?: pulumi.Input<string>;
    }
    /**
     * OAuth2 Client Application
     */
    interface ConnectionOAuth2ClientApplicationArgs {
        awsManagedClientApplicationReference?: pulumi.Input<string>;
        userManagedClientApplicationClientId?: pulumi.Input<string>;
    }
    /**
     * OAuth2 Properties
     */
    interface ConnectionOAuth2PropertiesArgs {
        authorizationCodeProperties?: pulumi.Input<inputs.datazone.ConnectionAuthorizationCodePropertiesArgs>;
        oAuth2ClientApplication?: pulumi.Input<inputs.datazone.ConnectionOAuth2ClientApplicationArgs>;
        oAuth2Credentials?: pulumi.Input<inputs.datazone.ConnectionGlueOAuth2CredentialsArgs>;
        oAuth2GrantType?: pulumi.Input<enums.datazone.ConnectionOAuth2GrantType>;
        tokenUrl?: pulumi.Input<string>;
        tokenUrlParametersMap?: pulumi.Input<{
            [key: string]: pulumi.Input<string>;
        }>;
    }
    /**
     * Physical Connection Requirements
     */
    interface ConnectionPhysicalConnectionRequirementsArgs {
        availabilityZone?: pulumi.Input<string>;
        securityGroupIdList?: pulumi.Input<pulumi.Input<string>[]>;
        subnetId?: pulumi.Input<string>;
        subnetIdList?: pulumi.Input<pulumi.Input<string>[]>;
    }
    interface ConnectionPropertiesInput0PropertiesArgs {
        athenaProperties: pulumi.Input<inputs.datazone.ConnectionAthenaPropertiesInputArgs>;
    }
    interface ConnectionPropertiesInput1PropertiesArgs {
        glueProperties: pulumi.Input<inputs.datazone.ConnectionGluePropertiesInputArgs>;
    }
    interface ConnectionPropertiesInput2PropertiesArgs {
        hyperPodProperties: pulumi.Input<inputs.datazone.ConnectionHyperPodPropertiesInputArgs>;
    }
    interface ConnectionPropertiesInput3PropertiesArgs {
        iamProperties: pulumi.Input<inputs.datazone.ConnectionIamPropertiesInputArgs>;
    }
    interface ConnectionPropertiesInput4PropertiesArgs {
        redshiftProperties: pulumi.Input<inputs.datazone.ConnectionRedshiftPropertiesInputArgs>;
    }
    interface ConnectionPropertiesInput5PropertiesArgs {
        sparkEmrProperties: pulumi.Input<inputs.datazone.ConnectionSparkEmrPropertiesInputArgs>;
    }
    interface ConnectionPropertiesInput6PropertiesArgs {
        sparkGlueProperties: pulumi.Input<inputs.datazone.ConnectionSparkGluePropertiesInputArgs>;
    }
    interface ConnectionRedshiftCredentials0PropertiesArgs {
        secretArn: pulumi.Input<string>;
    }
    interface ConnectionRedshiftCredentials1PropertiesArgs {
        usernamePassword: pulumi.Input<inputs.datazone.ConnectionUsernamePasswordArgs>;
    }
    /**
     * Redshift Lineage Sync Configuration Input
     */
    interface ConnectionRedshiftLineageSyncConfigurationInputArgs {
        enabled?: pulumi.Input<boolean>;
        schedule?: pulumi.Input<inputs.datazone.ConnectionLineageSyncScheduleArgs>;
    }
    /**
     * Redshift Properties Input
     */
    interface ConnectionRedshiftPropertiesInputArgs {
        credentials?: pulumi.Input<inputs.datazone.ConnectionRedshiftCredentials0PropertiesArgs | inputs.datazone.ConnectionRedshiftCredentials1PropertiesArgs>;
        databaseName?: pulumi.Input<string>;
        host?: pulumi.Input<string>;
        lineageSync?: pulumi.Input<inputs.datazone.ConnectionRedshiftLineageSyncConfigurationInputArgs>;
        port?: pulumi.Input<number>;
        storage?: pulumi.Input<inputs.datazone.ConnectionRedshiftStorageProperties0PropertiesArgs | inputs.datazone.ConnectionRedshiftStorageProperties1PropertiesArgs>;
    }
    interface ConnectionRedshiftStorageProperties0PropertiesArgs {
        clusterName: pulumi.Input<string>;
    }
    interface ConnectionRedshiftStorageProperties1PropertiesArgs {
        workgroupName: pulumi.Input<string>;
    }
    /**
     * Spark EMR Properties Input.
     */
    interface ConnectionSparkEmrPropertiesInputArgs {
        computeArn?: pulumi.Input<string>;
        instanceProfileArn?: pulumi.Input<string>;
        javaVirtualEnv?: pulumi.Input<string>;
        logUri?: pulumi.Input<string>;
        pythonVirtualEnv?: pulumi.Input<string>;
        runtimeRole?: pulumi.Input<string>;
        trustedCertificatesS3Uri?: pulumi.Input<string>;
    }
    /**
     * Spark Glue Args.
     */
    interface ConnectionSparkGlueArgsArgs {
        connection?: pulumi.Input<string>;
    }
    /**
     * Spark Glue Properties Input.
     */
    interface ConnectionSparkGluePropertiesInputArgs {
        additionalArgs?: pulumi.Input<inputs.datazone.ConnectionSparkGlueArgsArgs>;
        glueConnectionName?: pulumi.Input<string>;
        glueVersion?: pulumi.Input<string>;
        idleTimeout?: pulumi.Input<number>;
        javaVirtualEnv?: pulumi.Input<string>;
        numberOfWorkers?: pulumi.Input<number>;
        pythonVirtualEnv?: pulumi.Input<string>;
        workerType?: pulumi.Input<string>;
    }
    /**
     * The username and password to be used for authentication.
     */
    interface ConnectionUsernamePasswordArgs {
        password: pulumi.Input<string>;
        username: pulumi.Input<string>;
    }
    /**
     * Specifies the configuration of the data source. It can be set to either glueRunConfiguration or redshiftRunConfiguration or sageMakerRunConfiguration.
     */
    interface DataSourceConfigurationInput0PropertiesArgs {
        glueRunConfiguration?: pulumi.Input<inputs.datazone.DataSourceGlueRunConfigurationInputArgs>;
    }
    /**
     * Specifies the configuration of the data source. It can be set to either glueRunConfiguration or redshiftRunConfiguration or sageMakerRunConfiguration.
     */
    interface DataSourceConfigurationInput1PropertiesArgs {
        redshiftRunConfiguration?: pulumi.Input<inputs.datazone.DataSourceRedshiftRunConfigurationInputArgs>;
    }
    /**
     * Specifies the configuration of the data source. It can be set to either glueRunConfiguration or redshiftRunConfiguration or sageMakerRunConfiguration.
     */
    interface DataSourceConfigurationInput2PropertiesArgs {
        sageMakerRunConfiguration?: pulumi.Input<inputs.datazone.DataSourceSageMakerRunConfigurationInputArgs>;
    }
    /**
     * The search filter expression.
     */
    interface DataSourceFilterExpressionArgs {
        expression: pulumi.Input<string>;
        type: pulumi.Input<enums.datazone.DataSourceFilterExpressionType>;
    }
    /**
     * The details of a metadata form.
     */
    interface DataSourceFormInputArgs {
        /**
         * The content of the metadata form.
         */
        content?: pulumi.Input<string>;
        /**
         * The name of the metadata form.
         */
        formName: pulumi.Input<string>;
        /**
         * The ID of the metadata form type.
         */
        typeIdentifier?: pulumi.Input<string>;
        /**
         * The revision of the metadata form type.
         */
        typeRevision?: pulumi.Input<string>;
    }
    interface DataSourceGlueRunConfigurationInputArgs {
        /**
         * Specifies whether to automatically import data quality metrics as part of the data source run.
         */
        autoImportDataQualityResult?: pulumi.Input<boolean>;
        /**
         * The catalog name in the AWS Glue run configuration.
         */
        catalogName?: pulumi.Input<string>;
        /**
         * The data access role included in the configuration details of the AWS Glue data source.
         */
        dataAccessRole?: pulumi.Input<string>;
        /**
         * The relational filter configurations included in the configuration details of the AWS Glue data source.
         */
        relationalFilterConfigurations: pulumi.Input<pulumi.Input<inputs.datazone.DataSourceRelationalFilterConfigurationArgs>[]>;
    }
    /**
     * The recommendation to be updated as part of the UpdateDataSource action.
     */
    interface DataSourceRecommendationConfigurationArgs {
        /**
         * Specifies whether automatic business name generation is to be enabled or not as part of the recommendation configuration.
         */
        enableBusinessNameGeneration?: pulumi.Input<boolean>;
    }
    /**
     * The name of an Amazon Redshift cluster.
     */
    interface DataSourceRedshiftClusterStorageArgs {
        /**
         * The name of an Amazon Redshift cluster.
         */
        clusterName: pulumi.Input<string>;
    }
    /**
     * The ARN of a secret manager for an Amazon Redshift cluster.
     */
    interface DataSourceRedshiftCredentialConfigurationArgs {
        /**
         * The ARN of a secret manager for an Amazon Redshift cluster.
         */
        secretManagerArn: pulumi.Input<string>;
    }
    /**
     * The configuration details of the Amazon Redshift data source.
     */
    interface DataSourceRedshiftRunConfigurationInputArgs {
        /**
         * The data access role included in the configuration details of the Amazon Redshift data source.
         */
        dataAccessRole?: pulumi.Input<string>;
        /**
         * The details of the credentials required to access an Amazon Redshift cluster.
         */
        redshiftCredentialConfiguration?: pulumi.Input<inputs.datazone.DataSourceRedshiftCredentialConfigurationArgs>;
        /**
         * The details of the Amazon Redshift storage as part of the configuration of an Amazon Redshift data source run.
         */
        redshiftStorage?: pulumi.Input<inputs.datazone.DataSourceRedshiftStorage0PropertiesArgs | inputs.datazone.DataSourceRedshiftStorage1PropertiesArgs>;
        relationalFilterConfigurations: pulumi.Input<pulumi.Input<inputs.datazone.DataSourceRelationalFilterConfigurationArgs>[]>;
    }
    /**
     * The details of the Amazon Redshift Serverless workgroup storage.
     */
    interface DataSourceRedshiftServerlessStorageArgs {
        /**
         * The name of the Amazon Redshift Serverless workgroup.
         */
        workgroupName: pulumi.Input<string>;
    }
    /**
     * The details of the Amazon Redshift cluster source.
     */
    interface DataSourceRedshiftStorage0PropertiesArgs {
        redshiftClusterSource: pulumi.Input<inputs.datazone.DataSourceRedshiftClusterStorageArgs>;
    }
    /**
     * The details of the Amazon Redshift Serverless workgroup source.
     */
    interface DataSourceRedshiftStorage1PropertiesArgs {
        redshiftServerlessSource: pulumi.Input<inputs.datazone.DataSourceRedshiftServerlessStorageArgs>;
    }
    /**
     * The relational filter configuration for the data source.
     */
    interface DataSourceRelationalFilterConfigurationArgs {
        /**
         * The database name specified in the relational filter configuration for the data source.
         */
        databaseName: pulumi.Input<string>;
        /**
         * The filter expressions specified in the relational filter configuration for the data source.
         */
        filterExpressions?: pulumi.Input<pulumi.Input<inputs.datazone.DataSourceFilterExpressionArgs>[]>;
        /**
         * The schema name specified in the relational filter configuration for the data source.
         */
        schemaName?: pulumi.Input<string>;
    }
    /**
     * The configuration details of the Amazon SageMaker data source.
     */
    interface DataSourceSageMakerRunConfigurationInputArgs {
        /**
         * The tracking assets of the Amazon SageMaker run.
         */
        trackingAssets: pulumi.Input<{
            [key: string]: any;
        }>;
    }
    /**
     * The schedule of the data source runs.
     */
    interface DataSourceScheduleConfigurationArgs {
        /**
         * The schedule of the data source runs.
         */
        schedule?: pulumi.Input<string>;
        /**
         * The timezone of the data source run.
         */
        timezone?: pulumi.Input<string>;
    }
    /**
     * The single-sign on configuration of the Amazon DataZone domain.
     */
    interface DomainSingleSignOnArgs {
        idcInstanceArn?: pulumi.Input<string>;
        /**
         * The type of single sign-on in Amazon DataZone.
         */
        type?: pulumi.Input<enums.datazone.DomainAuthType>;
        /**
         * The single sign-on user assignment in Amazon DataZone.
         */
        userAssignment?: pulumi.Input<enums.datazone.DomainUserAssignment>;
    }
    /**
     * The parameters of the console link specified as part of the environment action
     */
    interface EnvironmentActionsAwsConsoleLinkParametersArgs {
        /**
         * The URI of the console link specified as part of the environment action.
         */
        uri?: pulumi.Input<string>;
    }
    interface EnvironmentBlueprintConfigurationRegionalParameterArgs {
        /**
         * A string to string map containing parameters for the region.
         */
        parameters?: pulumi.Input<{
            [key: string]: pulumi.Input<string>;
        }>;
        /**
         * The region specified in the environment parameter.
         */
        region?: pulumi.Input<string>;
    }
    /**
     * The parameter details of an environment.
     */
    interface EnvironmentParameterArgs {
        /**
         * The name of an environment parameter.
         */
        name?: pulumi.Input<string>;
        /**
         * The value of an environment parameter.
         */
        value?: pulumi.Input<string>;
    }
    /**
     * The parameter details of an environment profile.
     */
    interface EnvironmentProfileEnvironmentParameterArgs {
        /**
         * The name of an environment profile parameter.
         */
        name?: pulumi.Input<string>;
        /**
         * The value of an environment profile parameter.
         */
        value?: pulumi.Input<string>;
    }
    interface ProjectMembershipMember0PropertiesArgs {
        userIdentifier: pulumi.Input<string>;
    }
    interface ProjectMembershipMember1PropertiesArgs {
        groupIdentifier: pulumi.Input<string>;
    }
    /**
     * The details of the subscription target configuration.
     */
    interface SubscriptionTargetFormArgs {
        /**
         * The content of the subscription target configuration.
         */
        content: pulumi.Input<string>;
        /**
         * The form name included in the subscription target configuration.
         */
        formName: pulumi.Input<string>;
    }
}
export declare namespace deadline {
    interface FleetAcceleratorCapabilitiesArgs {
        count?: pulumi.Input<inputs.deadline.FleetAcceleratorCountRangeArgs>;
        selections: pulumi.Input<pulumi.Input<inputs.deadline.FleetAcceleratorSelectionArgs>[]>;
    }
    interface FleetAcceleratorCountRangeArgs {
        max?: pulumi.Input<number>;
        min: pulumi.Input<number>;
    }
    interface FleetAcceleratorSelectionArgs {
        name: pulumi.Input<enums.deadline.FleetAcceleratorSelectionName>;
        runtime?: pulumi.Input<string>;
    }
    interface FleetAcceleratorTotalMemoryMiBRangeArgs {
        max?: pulumi.Input<number>;
        min: pulumi.Input<number>;
    }
    interface FleetAmountCapabilityArgs {
        /**
         * The maximum amount of the fleet worker capability.
         */
        max?: pulumi.Input<number>;
        /**
         * The minimum amount of fleet worker capability.
         */
        min: pulumi.Input<number>;
        /**
         * The name of the fleet capability.
         */
        name: pulumi.Input<string>;
    }
    interface FleetAttributeCapabilityArgs {
        /**
         * The name of the fleet attribute capability for the worker.
         */
        name: pulumi.Input<string>;
        /**
         * The number of fleet attribute capabilities.
         */
        values: pulumi.Input<pulumi.Input<string>[]>;
    }
    interface FleetConfiguration0PropertiesArgs {
        customerManaged: pulumi.Input<inputs.deadline.FleetCustomerManagedFleetConfigurationArgs>;
    }
    interface FleetConfiguration1PropertiesArgs {
        serviceManagedEc2: pulumi.Input<inputs.deadline.FleetServiceManagedEc2FleetConfigurationArgs>;
    }
    interface FleetCustomerManagedFleetConfigurationArgs {
        mode: pulumi.Input<enums.deadline.FleetAutoScalingMode>;
        storageProfileId?: pulumi.Input<string>;
        workerCapabilities: pulumi.Input<inputs.deadline.FleetCustomerManagedWorkerCapabilitiesArgs>;
    }
    interface FleetCustomerManagedWorkerCapabilitiesArgs {
        acceleratorCount?: pulumi.Input<inputs.deadline.FleetAcceleratorCountRangeArgs>;
        acceleratorTotalMemoryMiB?: pulumi.Input<inputs.deadline.FleetAcceleratorTotalMemoryMiBRangeArgs>;
        acceleratorTypes?: pulumi.Input<pulumi.Input<enums.deadline.FleetAcceleratorType>[]>;
        cpuArchitectureType: pulumi.Input<enums.deadline.FleetCpuArchitectureType>;
        customAmounts?: pulumi.Input<pulumi.Input<inputs.deadline.FleetAmountCapabilityArgs>[]>;
        customAttributes?: pulumi.Input<pulumi.Input<inputs.deadline.FleetAttributeCapabilityArgs>[]>;
        memoryMiB: pulumi.Input<inputs.deadline.FleetMemoryMiBRangeArgs>;
        osFamily: pulumi.Input<enums.deadline.FleetCustomerManagedFleetOperatingSystemFamily>;
        vCpuCount: pulumi.Input<inputs.deadline.FleetVCpuCountRangeArgs>;
    }
    interface FleetEc2EbsVolumeArgs {
        iops?: pulumi.Input<number>;
        sizeGiB?: pulumi.Input<number>;
        throughputMiB?: pulumi.Input<number>;
    }
    interface FleetMemoryMiBRangeArgs {
        max?: pulumi.Input<number>;
        min: pulumi.Input<number>;
    }
    interface FleetServiceManagedEc2FleetConfigurationArgs {
        instanceCapabilities: pulumi.Input<inputs.deadline.FleetServiceManagedEc2InstanceCapabilitiesArgs>;
        instanceMarketOptions: pulumi.Input<inputs.deadline.FleetServiceManagedEc2InstanceMarketOptionsArgs>;
    }
    interface FleetServiceManagedEc2InstanceCapabilitiesArgs {
        acceleratorCapabilities?: pulumi.Input<inputs.deadline.FleetAcceleratorCapabilitiesArgs>;
        allowedInstanceTypes?: pulumi.Input<pulumi.Input<string>[]>;
        cpuArchitectureType: pulumi.Input<enums.deadline.FleetCpuArchitectureType>;
        customAmounts?: pulumi.Input<pulumi.Input<inputs.deadline.FleetAmountCapabilityArgs>[]>;
        customAttributes?: pulumi.Input<pulumi.Input<inputs.deadline.FleetAttributeCapabilityArgs>[]>;
        excludedInstanceTypes?: pulumi.Input<pulumi.Input<string>[]>;
        memoryMiB: pulumi.Input<inputs.deadline.FleetMemoryMiBRangeArgs>;
        osFamily: pulumi.Input<enums.deadline.FleetServiceManagedFleetOperatingSystemFamily>;
        rootEbsVolume?: pulumi.Input<inputs.deadline.FleetEc2EbsVolumeArgs>;
        vCpuCount: pulumi.Input<inputs.deadline.FleetVCpuCountRangeArgs>;
    }
    interface FleetServiceManagedEc2InstanceMarketOptionsArgs {
        type: pulumi.Input<enums.deadline.FleetEc2MarketType>;
    }
    interface FleetVCpuCountRangeArgs {
        max?: pulumi.Input<number>;
        min: pulumi.Input<number>;
    }
    interface QueueJobAttachmentSettingsArgs {
        /**
         * The root prefix.
         */
        rootPrefix: pulumi.Input<string>;
        /**
         * The Amazon S3 bucket name.
         */
        s3BucketName: pulumi.Input<string>;
    }
    interface QueueJobRunAsUserArgs {
        /**
         * The user and group that the jobs in the queue run as.
         */
        posix?: pulumi.Input<inputs.deadline.QueuePosixUserArgs>;
        /**
         * Specifies whether the job should run using the queue's system user or if the job should run using the worker agent system user.
         */
        runAs: pulumi.Input<enums.deadline.QueueRunAs>;
        /**
         * Identifies a Microsoft Windows user.
         */
        windows?: pulumi.Input<inputs.deadline.QueueWindowsUserArgs>;
    }
    interface QueuePosixUserArgs {
        /**
         * The name of the POSIX user's group.
         */
        group: pulumi.Input<string>;
        /**
         * The name of the POSIX user.
         */
        user: pulumi.Input<string>;
    }
    interface QueueWindowsUserArgs {
        /**
         * The password ARN for the Windows user.
         */
        passwordArn: pulumi.Input<string>;
        /**
         * The user.
         */
        user: pulumi.Input<string>;
    }
    interface StorageProfileFileSystemLocationArgs {
        /**
         * The location name.
         */
        name: pulumi.Input<string>;
        /**
         * The file path.
         */
        path: pulumi.Input<string>;
        /**
         * The type of file.
         */
        type: pulumi.Input<enums.deadline.StorageProfileFileSystemLocationType>;
    }
}
export declare namespace detective {
}
export declare namespace devicefarm {
    /**
     * Represents a condition for a device pool.
     */
    interface DevicePoolRuleArgs {
        /**
         * The rule's stringified attribute.
         */
        attribute?: pulumi.Input<enums.devicefarm.DevicePoolRuleAttribute>;
        /**
         * Specifies how Device Farm compares the rule's attribute to the value.
         */
        operator?: pulumi.Input<enums.devicefarm.DevicePoolRuleOperator>;
        /**
         * The rule's value.
         */
        value?: pulumi.Input<string>;
    }
    /**
     * The VPC security groups and subnets that are attached to a project
     */
    interface ProjectVpcConfigArgs {
        /**
         * An array of security group Ids in your Amazon VPC
         */
        securityGroupIds: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * A array of subnet IDs in your Amazon VPC.
         */
        subnetIds: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * The ID of the Amazon VPC
         */
        vpcId: pulumi.Input<string>;
    }
    /**
     * The VPC security groups and subnets that are attached to a TestGrid project.
     */
    interface TestGridProjectVpcConfigArgs {
        /**
         * A list of VPC security group IDs in your Amazon VPC.
         */
        securityGroupIds: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * A list of VPC subnet IDs in your Amazon VPC.
         */
        subnetIds: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * A list of VPC IDs.
         *
         * Each VPC is given a unique ID upon creation.
         */
        vpcId: pulumi.Input<string>;
    }
}
export declare namespace devopsguru {
    /**
     * Information about notification channels you have configured with DevOps Guru.
     */
    interface NotificationChannelConfigArgs {
        /**
         * The filter configurations for the Amazon SNS notification topic you use with DevOps Guru. If you do not provide filter configurations, the default configurations are to receive notifications for all message types of `High` or `Medium` severity.
         */
        filters?: pulumi.Input<inputs.devopsguru.NotificationChannelNotificationFilterConfigArgs>;
        /**
         * Information about a notification channel configured in DevOps Guru to send notifications when insights are created.
         *
         * If you use an Amazon SNS topic in another account, you must attach a policy to it that grants DevOps Guru permission to send it notifications. DevOps Guru adds the required policy on your behalf to send notifications using Amazon SNS in your account. DevOps Guru only supports standard SNS topics. For more information, see [Permissions for Amazon SNS topics](https://docs.aws.amazon.com/devops-guru/latest/userguide/sns-required-permissions.html) .
         *
         * If you use an Amazon SNS topic that is encrypted by an AWS Key Management Service customer-managed key (CMK), then you must add permissions to the CMK. For more information, see [Permissions for AWS KMS–encrypted Amazon SNS topics](https://docs.aws.amazon.com/devops-guru/latest/userguide/sns-kms-permissions.html) .
         */
        sns?: pulumi.Input<inputs.devopsguru.NotificationChannelSnsChannelConfigArgs>;
    }
    /**
     * Information about filters of a notification channel configured in DevOpsGuru to filter for insights.
     */
    interface NotificationChannelNotificationFilterConfigArgs {
        /**
         * The events that you want to receive notifications for. For example, you can choose to receive notifications only when the severity level is upgraded or a new insight is created.
         */
        messageTypes?: pulumi.Input<pulumi.Input<enums.devopsguru.NotificationChannelNotificationMessageType>[]>;
        /**
         * The severity levels that you want to receive notifications for. For example, you can choose to receive notifications only for insights with `HIGH` and `MEDIUM` severity levels. For more information, see [Understanding insight severities](https://docs.aws.amazon.com/devops-guru/latest/userguide/working-with-insights.html#understanding-insights-severities) .
         */
        severities?: pulumi.Input<pulumi.Input<enums.devopsguru.NotificationChannelInsightSeverity>[]>;
    }
    /**
     * Information about a notification channel configured in DevOps Guru to send notifications when insights are created.
     */
    interface NotificationChannelSnsChannelConfigArgs {
        /**
         * The Amazon Resource Name (ARN) of an Amazon Simple Notification Service topic.
         */
        topicArn?: pulumi.Input<string>;
    }
    /**
     * CloudFormation resource for DevOps Guru to monitor
     */
    interface ResourceCollectionCloudFormationCollectionFilterArgs {
        /**
         * An array of CloudFormation stack names.
         */
        stackNames?: pulumi.Input<pulumi.Input<string>[]>;
    }
    /**
     * Information about a filter used to specify which AWS resources are analyzed for anomalous behavior by DevOps Guru.
     */
    interface ResourceCollectionFilterArgs {
        /**
         * Information about AWS CloudFormation stacks. You can use up to 1000 stacks to specify which AWS resources in your account to analyze. For more information, see [Stacks](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/stacks.html) in the *AWS CloudFormation User Guide* .
         */
        cloudFormation?: pulumi.Input<inputs.devopsguru.ResourceCollectionCloudFormationCollectionFilterArgs>;
        /**
         * The AWS tags used to filter the resources in the resource collection.
         *
         * Tags help you identify and organize your AWS resources. Many AWS services support tagging, so you can assign the same tag to resources from different services to indicate that the resources are related. For example, you can assign the same tag to an Amazon DynamoDB table resource that you assign to an AWS Lambda function. For more information about using tags, see the [Tagging best practices](https://docs.aws.amazon.com/whitepapers/latest/tagging-best-practices/tagging-best-practices.html) whitepaper.
         *
         * Each AWS tag has two parts.
         *
         * - A tag *key* (for example, `CostCenter` , `Environment` , `Project` , or `Secret` ). Tag *keys* are case-sensitive.
         * - A field known as a tag *value* (for example, `111122223333` , `Production` , or a team name). Omitting the tag *value* is the same as using an empty string. Like tag *keys* , tag *values* are case-sensitive. The tag value is a required property when AppBoundaryKey is specified.
         *
         * Together these are known as *key* - *value* pairs.
         *
         * > The string used for a *key* in a tag that you use to define your resource coverage must begin with the prefix `Devops-guru-` . The tag *key* might be `DevOps-Guru-deployment-application` or `devops-guru-rds-application` . When you create a *key* , the case of characters in the *key* can be whatever you choose. After you create a *key* , it is case-sensitive. For example, DevOps Guru works with a *key* named `devops-guru-rds` and a *key* named `DevOps-Guru-RDS` , and these act as two different *keys* . Possible *key* / *value* pairs in your application might be `Devops-Guru-production-application/RDS` or `Devops-Guru-production-application/containers` .
         */
        tags?: pulumi.Input<pulumi.Input<inputs.devopsguru.ResourceCollectionTagCollectionArgs>[]>;
    }
    /**
     * Tagged resource for DevOps Guru to monitor
     */
    interface ResourceCollectionTagCollectionArgs {
        /**
         * A Tag key for DevOps Guru app boundary.
         */
        appBoundaryKey?: pulumi.Input<string>;
        /**
         * Tag values of DevOps Guru app boundary.
         */
        tagValues?: pulumi.Input<pulumi.Input<string>[]>;
    }
}
export declare namespace directoryservice {
    interface SimpleAdVpcSettingsArgs {
        /**
         * The identifiers of the subnets for the directory servers. The two subnets must be in different Availability Zones. AWS Directory Service specifies a directory server and a DNS server in each of these subnets.
         */
        subnetIds: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * The identifier of the VPC in which to create the directory.
         */
        vpcId: pulumi.Input<string>;
    }
}
export declare namespace dms {
    interface DataMigrationSettingsArgs {
        /**
         * The property specifies whether to enable the Cloudwatch log.
         */
        cloudwatchLogsEnabled?: pulumi.Input<boolean>;
        /**
         * The number of parallel jobs that trigger parallel threads to unload the tables from the source, and then load them to the target.
         */
        numberOfJobs?: pulumi.Input<number>;
        /**
         * The property specifies the rules of selecting objects for data migration.
         */
        selectionRules?: pulumi.Input<string>;
    }
    interface DataMigrationSourceDataSettingsArgs {
        /**
         * The property is a point in the database engine's log that defines a time where you can begin CDC.
         */
        cdcStartPosition?: pulumi.Input<string>;
        /**
         * The property indicates the start time for a change data capture (CDC) operation. The value is server time in UTC format.
         */
        cdcStartTime?: pulumi.Input<string>;
        /**
         * The property indicates the stop time for a change data capture (CDC) operation. The value is server time in UTC format.
         */
        cdcStopTime?: pulumi.Input<string>;
        /**
         * The property sets the name of a previously created logical replication slot for a change data capture (CDC) load of the source instance.
         */
        slotName?: pulumi.Input<string>;
    }
    /**
     * It is an object that describes Source and Target DataProviders and credentials for connecting to databases that are used in MigrationProject
     */
    interface MigrationProjectDataProviderDescriptorArgs {
        /**
         * The Amazon Resource Name (ARN) of the data provider.
         */
        dataProviderArn?: pulumi.Input<string>;
        dataProviderIdentifier?: pulumi.Input<string>;
        /**
         * The user-friendly name of the data provider.
         */
        dataProviderName?: pulumi.Input<string>;
        /**
         * The ARN of the role used to access AWS Secrets Manager.
         */
        secretsManagerAccessRoleArn?: pulumi.Input<string>;
        /**
         * The identifier of the AWS Secrets Manager Secret used to store access credentials for the data provider.
         */
        secretsManagerSecretId?: pulumi.Input<string>;
    }
    /**
     * Configuration parameters for provisioning a AWS DMS Serverless replication
     */
    interface ReplicationConfigComputeConfigArgs {
        /**
         * The Availability Zone where the AWS DMS Serverless replication using this configuration will run. The default value is a random, system-chosen Availability Zone in the configuration's AWS Region , for example, `"us-west-2"` . You can't set this parameter if the `MultiAZ` parameter is set to `true` .
         */
        availabilityZone?: pulumi.Input<string>;
        /**
         * A list of custom DNS name servers supported for the AWS DMS Serverless replication to access your source or target database. This list overrides the default name servers supported by the AWS DMS Serverless replication. You can specify a comma-separated list of internet addresses for up to four DNS name servers. For example: `"1.1.1.1,2.2.2.2,3.3.3.3,4.4.4.4"`
         */
        dnsNameServers?: pulumi.Input<string>;
        /**
         * An AWS Key Management Service ( AWS KMS ) key Amazon Resource Name (ARN) that is used to encrypt the data during AWS DMS Serverless replication.
         *
         * If you don't specify a value for the `KmsKeyId` parameter, AWS DMS uses your default encryption key.
         *
         * AWS KMS creates the default encryption key for your Amazon Web Services account. Your AWS account has a different default encryption key for each AWS Region .
         */
        kmsKeyId?: pulumi.Input<string>;
        /**
         * Specifies the maximum value of the AWS DMS capacity units (DCUs) for which a given AWS DMS Serverless replication can be provisioned. A single DCU is 2GB of RAM, with 1 DCU as the minimum value allowed. The list of valid DCU values includes 1, 2, 4, 8, 16, 32, 64, 128, 192, 256, and 384. So, the maximum value that you can specify for AWS DMS Serverless is 384. The `MaxCapacityUnits` parameter is the only DCU parameter you are required to specify.
         */
        maxCapacityUnits: pulumi.Input<number>;
        /**
         * Specifies the minimum value of the AWS DMS capacity units (DCUs) for which a given AWS DMS Serverless replication can be provisioned. A single DCU is 2GB of RAM, with 1 DCU as the minimum value allowed. The list of valid DCU values includes 1, 2, 4, 8, 16, 32, 64, 128, 192, 256, and 384. So, the minimum DCU value that you can specify for AWS DMS Serverless is 1. If you don't set this value, AWS DMS sets this parameter to the minimum DCU value allowed, 1. If there is no current source activity, AWS DMS scales down your replication until it reaches the value specified in `MinCapacityUnits` .
         */
        minCapacityUnits?: pulumi.Input<number>;
        /**
         * Specifies whether the AWS DMS Serverless replication is a Multi-AZ deployment. You can't set the `AvailabilityZone` parameter if the `MultiAZ` parameter is set to `true` .
         */
        multiAz?: pulumi.Input<boolean>;
        /**
         * The weekly time range during which system maintenance can occur for the AWS DMS Serverless replication, in Universal Coordinated Time (UTC). The format is `ddd:hh24:mi-ddd:hh24:mi` .
         *
         * The default is a 30-minute window selected at random from an 8-hour block of time per AWS Region . This maintenance occurs on a random day of the week. Valid values for days of the week include `Mon` , `Tue` , `Wed` , `Thu` , `Fri` , `Sat` , and `Sun` .
         *
         * Constraints include a minimum 30-minute window.
         */
        preferredMaintenanceWindow?: pulumi.Input<string>;
        /**
         * Specifies a subnet group identifier to associate with the AWS DMS Serverless replication.
         */
        replicationSubnetGroupId?: pulumi.Input<string>;
        /**
         * Specifies the virtual private cloud (VPC) security group to use with the AWS DMS Serverless replication. The VPC security group must work with the VPC containing the replication.
         */
        vpcSecurityGroupIds?: pulumi.Input<pulumi.Input<string>[]>;
    }
    /**
     * The property describes schema conversion application attributes for the migration project.
     */
    interface SchemaConversionApplicationAttributesPropertiesArgs {
        s3BucketPath?: pulumi.Input<string>;
        s3BucketRoleArn?: pulumi.Input<string>;
    }
    /**
     * The property identifies the exact type of settings for the data provider.
     */
    interface SettingsPropertiesArgs {
        /**
         * DocDbSettings property identifier.
         */
        docDbSettings?: pulumi.Input<inputs.dms.SettingsPropertiesDocDbSettingsPropertiesArgs>;
        /**
         * IbmDb2LuwSettings property identifier.
         */
        ibmDb2LuwSettings?: pulumi.Input<inputs.dms.SettingsPropertiesIbmDb2LuwSettingsPropertiesArgs>;
        /**
         * IbmDb2zOsSettings property identifier.
         */
        ibmDb2zOsSettings?: pulumi.Input<inputs.dms.SettingsPropertiesIbmDb2zOsSettingsPropertiesArgs>;
        /**
         * MariaDbSettings property identifier.
         */
        mariaDbSettings?: pulumi.Input<inputs.dms.SettingsPropertiesMariaDbSettingsPropertiesArgs>;
        /**
         * MicrosoftSqlServerSettings property identifier.
         */
        microsoftSqlServerSettings?: pulumi.Input<inputs.dms.SettingsPropertiesMicrosoftSqlServerSettingsPropertiesArgs>;
        /**
         * MongoDbSettings property identifier.
         */
        mongoDbSettings?: pulumi.Input<inputs.dms.SettingsPropertiesMongoDbSettingsPropertiesArgs>;
        /**
         * MySqlSettings property identifier.
         */
        mySqlSettings?: pulumi.Input<inputs.dms.SettingsPropertiesMySqlSettingsPropertiesArgs>;
        /**
         * OracleSettings property identifier.
         */
        oracleSettings?: pulumi.Input<inputs.dms.SettingsPropertiesOracleSettingsPropertiesArgs>;
        /**
         * PostgreSqlSettings property identifier.
         */
        postgreSqlSettings?: pulumi.Input<inputs.dms.SettingsPropertiesPostgreSqlSettingsPropertiesArgs>;
        /**
         * RedshiftSettings property identifier.
         */
        redshiftSettings?: pulumi.Input<inputs.dms.SettingsPropertiesRedshiftSettingsPropertiesArgs>;
    }
    /**
     * DocDbSettings property identifier.
     */
    interface SettingsPropertiesDocDbSettingsPropertiesArgs {
        certificateArn?: pulumi.Input<string>;
        databaseName: pulumi.Input<string>;
        port: pulumi.Input<number>;
        serverName: pulumi.Input<string>;
        sslMode?: pulumi.Input<enums.dms.DataProviderMongoDbSslModeValue>;
    }
    /**
     * IbmDb2LuwSettings property identifier.
     */
    interface SettingsPropertiesIbmDb2LuwSettingsPropertiesArgs {
        certificateArn?: pulumi.Input<string>;
        databaseName: pulumi.Input<string>;
        port: pulumi.Input<number>;
        serverName: pulumi.Input<string>;
        sslMode: pulumi.Input<enums.dms.DataProviderDb2SslModeValue>;
    }
    /**
     * IbmDb2zOsSettings property identifier.
     */
    interface SettingsPropertiesIbmDb2zOsSettingsPropertiesArgs {
        certificateArn?: pulumi.Input<string>;
        databaseName: pulumi.Input<string>;
        port: pulumi.Input<number>;
        serverName: pulumi.Input<string>;
        sslMode: pulumi.Input<enums.dms.DataProviderDb2SslModeValue>;
    }
    /**
     * MariaDbSettings property identifier.
     */
    interface SettingsPropertiesMariaDbSettingsPropertiesArgs {
        certificateArn?: pulumi.Input<string>;
        port: pulumi.Input<number>;
        serverName: pulumi.Input<string>;
        sslMode: pulumi.Input<enums.dms.DataProviderDmsSslModeValue>;
    }
    /**
     * MicrosoftSqlServerSettings property identifier.
     */
    interface SettingsPropertiesMicrosoftSqlServerSettingsPropertiesArgs {
        certificateArn?: pulumi.Input<string>;
        databaseName: pulumi.Input<string>;
        port: pulumi.Input<number>;
        serverName: pulumi.Input<string>;
        sslMode: pulumi.Input<enums.dms.DataProviderDmsSslModeValue>;
    }
    /**
     * MongoDbSettings property identifier.
     */
    interface SettingsPropertiesMongoDbSettingsPropertiesArgs {
        authMechanism?: pulumi.Input<enums.dms.DataProviderMongoDbAuthMechanism>;
        authSource?: pulumi.Input<string>;
        authType?: pulumi.Input<enums.dms.DataProviderMongoDbAuthType>;
        certificateArn?: pulumi.Input<string>;
        databaseName?: pulumi.Input<string>;
        port: pulumi.Input<number>;
        serverName: pulumi.Input<string>;
        sslMode?: pulumi.Input<enums.dms.DataProviderMongoDbSslModeValue>;
    }
    /**
     * MySqlSettings property identifier.
     */
    interface SettingsPropertiesMySqlSettingsPropertiesArgs {
        certificateArn?: pulumi.Input<string>;
        port: pulumi.Input<number>;
        serverName: pulumi.Input<string>;
        sslMode: pulumi.Input<enums.dms.DataProviderDmsSslModeValue>;
    }
    /**
     * OracleSettings property identifier.
     */
    interface SettingsPropertiesOracleSettingsPropertiesArgs {
        asmServer?: pulumi.Input<string>;
        certificateArn?: pulumi.Input<string>;
        databaseName: pulumi.Input<string>;
        port: pulumi.Input<number>;
        secretsManagerOracleAsmAccessRoleArn?: pulumi.Input<string>;
        secretsManagerOracleAsmSecretId?: pulumi.Input<string>;
        secretsManagerSecurityDbEncryptionAccessRoleArn?: pulumi.Input<string>;
        secretsManagerSecurityDbEncryptionSecretId?: pulumi.Input<string>;
        serverName: pulumi.Input<string>;
        sslMode: pulumi.Input<enums.dms.DataProviderDmsSslModeValue>;
    }
    /**
     * PostgreSqlSettings property identifier.
     */
    interface SettingsPropertiesPostgreSqlSettingsPropertiesArgs {
        certificateArn?: pulumi.Input<string>;
        databaseName: pulumi.Input<string>;
        port: pulumi.Input<number>;
        serverName: pulumi.Input<string>;
        sslMode: pulumi.Input<enums.dms.DataProviderDmsSslModeValue>;
    }
    /**
     * RedshiftSettings property identifier.
     */
    interface SettingsPropertiesRedshiftSettingsPropertiesArgs {
        databaseName: pulumi.Input<string>;
        port: pulumi.Input<number>;
        serverName: pulumi.Input<string>;
    }
}
export declare namespace docdbelastic {
}
export declare namespace dsql {
}
export declare namespace dynamodb {
    interface GlobalTableAttributeDefinitionArgs {
        /**
         * A name for the attribute.
         */
        attributeName: pulumi.Input<string>;
        /**
         * The data type for the attribute, where:
         *
         * - `S` - the attribute is of type String
         * - `N` - the attribute is of type Number
         * - `B` - the attribute is of type Binary
         */
        attributeType: pulumi.Input<string>;
    }
    interface GlobalTableCapacityAutoScalingSettingsArgs {
        /**
         * The maximum provisioned capacity units for the global table.
         */
        maxCapacity: pulumi.Input<number>;
        /**
         * The minimum provisioned capacity units for the global table.
         */
        minCapacity: pulumi.Input<number>;
        /**
         * When switching billing mode from `PAY_PER_REQUEST` to `PROVISIONED` , DynamoDB requires you to specify read and write capacity unit values for the table and for each global secondary index. These values will be applied to all replicas. The table will use these provisioned values until CloudFormation creates the autoscaling policies you configured in your template. CloudFormation cannot determine what capacity the table and its global secondary indexes will require in this time period, since they are application-dependent.
         *
         * If you want to switch a table's billing mode from `PAY_PER_REQUEST` to `PROVISIONED` , you must specify a value for this property for each autoscaled resource. If you specify different values for the same resource in different regions, CloudFormation will use the highest value found in either the `SeedCapacity` or `ReadCapacityUnits` properties. For example, if your global secondary index `myGSI` has a `SeedCapacity` of 10 in us-east-1 and a fixed `ReadCapacityUnits` of 20 in eu-west-1, CloudFormation will initially set the read capacity for `myGSI` to 20. Note that if you disable `ScaleIn` for `myGSI` in us-east-1, its read capacity units might not be set back to 10.
         *
         * You must also specify a value for `SeedCapacity` when you plan to switch a table's billing mode from `PROVISIONED` to `PAY_PER_REQUEST` , because CloudFormation might need to roll back the operation (reverting the billing mode to `PROVISIONED` ) and this cannot succeed without specifying a value for `SeedCapacity` .
         */
        seedCapacity?: pulumi.Input<number>;
        /**
         * Defines a target tracking scaling policy.
         */
        targetTrackingScalingPolicyConfiguration: pulumi.Input<inputs.dynamodb.GlobalTableTargetTrackingScalingPolicyConfigurationArgs>;
    }
    interface GlobalTableContributorInsightsSpecificationArgs {
        /**
         * Indicates whether CloudWatch Contributor Insights are to be enabled (true) or disabled (false).
         */
        enabled: pulumi.Input<boolean>;
    }
    interface GlobalTableGlobalSecondaryIndexArgs {
        /**
         * The name of the global secondary index. The name must be unique among all other indexes on this table.
         */
        indexName: pulumi.Input<string>;
        /**
         * The complete key schema for a global secondary index, which consists of one or more pairs of attribute names and key types:
         *
         * - `HASH` - partition key
         * - `RANGE` - sort key
         *
         * > The partition key of an item is also known as its *hash attribute* . The term "hash attribute" derives from DynamoDB's usage of an internal hash function to evenly distribute data items across partitions, based on their partition key values.
         * >
         * > The sort key of an item is also known as its *range attribute* . The term "range attribute" derives from the way DynamoDB stores items with the same partition key physically close together, in sorted order by the sort key value.
         */
        keySchema: pulumi.Input<pulumi.Input<inputs.dynamodb.GlobalTableKeySchemaArgs>[]>;
        /**
         * Represents attributes that are copied (projected) from the table into the global secondary index. These are in addition to the primary key attributes and index key attributes, which are automatically projected.
         */
        projection: pulumi.Input<inputs.dynamodb.GlobalTableProjectionArgs>;
        /**
         * Represents the warm throughput value (in read units per second and write units per second) for the specified secondary index. If you use this parameter, you must specify `ReadUnitsPerSecond` , `WriteUnitsPerSecond` , or both.
         */
        warmThroughput?: pulumi.Input<inputs.dynamodb.GlobalTableWarmThroughputArgs>;
        /**
         * Sets the write request settings for a global table or a global secondary index. You can only specify this setting if your resource uses the `PAY_PER_REQUEST` `BillingMode` .
         */
        writeOnDemandThroughputSettings?: pulumi.Input<inputs.dynamodb.GlobalTableWriteOnDemandThroughputSettingsArgs>;
        /**
         * Defines write capacity settings for the global secondary index. You must specify a value for this property if the table's `BillingMode` is `PROVISIONED` . All replicas will have the same write capacity settings for this global secondary index.
         */
        writeProvisionedThroughputSettings?: pulumi.Input<inputs.dynamodb.GlobalTableWriteProvisionedThroughputSettingsArgs>;
    }
    interface GlobalTableKeySchemaArgs {
        /**
         * The name of a key attribute.
         */
        attributeName: pulumi.Input<string>;
        /**
         * The role that this key attribute will assume:
         *
         * - `HASH` - partition key
         * - `RANGE` - sort key
         *
         * > The partition key of an item is also known as its *hash attribute* . The term "hash attribute" derives from DynamoDB's usage of an internal hash function to evenly distribute data items across partitions, based on their partition key values.
         * >
         * > The sort key of an item is also known as its *range attribute* . The term "range attribute" derives from the way DynamoDB stores items with the same partition key physically close together, in sorted order by the sort key value.
         */
        keyType: pulumi.Input<string>;
    }
    interface GlobalTableKinesisStreamSpecificationArgs {
        /**
         * The precision for the time and date that the stream was created.
         */
        approximateCreationDateTimePrecision?: pulumi.Input<enums.dynamodb.GlobalTableKinesisStreamSpecificationApproximateCreationDateTimePrecision>;
        /**
         * The ARN for a specific Kinesis data stream.
         */
        streamArn: pulumi.Input<string>;
    }
    interface GlobalTableLocalSecondaryIndexArgs {
        /**
         * The name of the local secondary index. The name must be unique among all other indexes on this table.
         */
        indexName: pulumi.Input<string>;
        /**
         * The complete key schema for the local secondary index, consisting of one or more pairs of attribute names and key types:
         *
         * - `HASH` - partition key
         * - `RANGE` - sort key
         *
         * > The partition key of an item is also known as its *hash attribute* . The term "hash attribute" derives from DynamoDB's usage of an internal hash function to evenly distribute data items across partitions, based on their partition key values.
         * >
         * > The sort key of an item is also known as its *range attribute* . The term "range attribute" derives from the way DynamoDB stores items with the same partition key physically close together, in sorted order by the sort key value.
         */
        keySchema: pulumi.Input<pulumi.Input<inputs.dynamodb.GlobalTableKeySchemaArgs>[]>;
        /**
         * Represents attributes that are copied (projected) from the table into the local secondary index. These are in addition to the primary key attributes and index key attributes, which are automatically projected.
         */
        projection: pulumi.Input<inputs.dynamodb.GlobalTableProjectionArgs>;
    }
    interface GlobalTablePointInTimeRecoverySpecificationArgs {
        /**
         * Indicates whether point in time recovery is enabled (true) or disabled (false) on the table.
         */
        pointInTimeRecoveryEnabled?: pulumi.Input<boolean>;
        /**
         * The number of preceding days for which continuous backups are taken and maintained. Your table data is only recoverable to any point-in-time from within the configured recovery period. This parameter is optional. If no value is provided, the value will default to 35.
         */
        recoveryPeriodInDays?: pulumi.Input<number>;
    }
    interface GlobalTableProjectionArgs {
        /**
         * Represents the non-key attribute names which will be projected into the index.
         *
         * For global and local secondary indexes, the total count of `NonKeyAttributes` summed across all of the secondary indexes, must not exceed 100. If you project the same attribute into two different indexes, this counts as two distinct attributes when determining the total. This limit only applies when you specify the ProjectionType of `INCLUDE` . You still can specify the ProjectionType of `ALL` to project all attributes from the source table, even if the table has more than 100 attributes.
         */
        nonKeyAttributes?: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * The set of attributes that are projected into the index:
         *
         * - `KEYS_ONLY` - Only the index and primary keys are projected into the index.
         * - `INCLUDE` - In addition to the attributes described in `KEYS_ONLY` , the secondary index will include other non-key attributes that you specify.
         * - `ALL` - All of the table attributes are projected into the index.
         *
         * When using the DynamoDB console, `ALL` is selected by default.
         */
        projectionType?: pulumi.Input<string>;
    }
    interface GlobalTableReadOnDemandThroughputSettingsArgs {
        /**
         * Maximum number of read request units for the specified replica of a global table.
         */
        maxReadRequestUnits?: pulumi.Input<number>;
    }
    interface GlobalTableReadProvisionedThroughputSettingsArgs {
        /**
         * Specifies auto scaling settings for the replica table or global secondary index.
         */
        readCapacityAutoScalingSettings?: pulumi.Input<inputs.dynamodb.GlobalTableCapacityAutoScalingSettingsArgs>;
        /**
         * Specifies a fixed read capacity for the replica table or global secondary index.
         */
        readCapacityUnits?: pulumi.Input<number>;
    }
    interface GlobalTableReplicaGlobalSecondaryIndexSpecificationArgs {
        /**
         * Updates the status for contributor insights for a specific table or index. CloudWatch Contributor Insights for DynamoDB graphs display the partition key and (if applicable) sort key of frequently accessed items and frequently throttled items in plaintext. If you require the use of AWS Key Management Service (KMS) to encrypt this table’s partition key and sort key data with an AWS managed key or customer managed key, you should not enable CloudWatch Contributor Insights for DynamoDB for this table.
         */
        contributorInsightsSpecification?: pulumi.Input<inputs.dynamodb.GlobalTableContributorInsightsSpecificationArgs>;
        /**
         * The name of the global secondary index. The name must be unique among all other indexes on this table.
         */
        indexName: pulumi.Input<string>;
        /**
         * Sets the read request settings for a replica global secondary index. You can only specify this setting if your resource uses the `PAY_PER_REQUEST` `BillingMode` .
         */
        readOnDemandThroughputSettings?: pulumi.Input<inputs.dynamodb.GlobalTableReadOnDemandThroughputSettingsArgs>;
        /**
         * Allows you to specify the read capacity settings for a replica global secondary index when the `BillingMode` is set to `PROVISIONED` .
         */
        readProvisionedThroughputSettings?: pulumi.Input<inputs.dynamodb.GlobalTableReadProvisionedThroughputSettingsArgs>;
    }
    interface GlobalTableReplicaSpecificationArgs {
        /**
         * The settings used to enable or disable CloudWatch Contributor Insights for the specified replica. When not specified, defaults to contributor insights disabled for the replica.
         */
        contributorInsightsSpecification?: pulumi.Input<inputs.dynamodb.GlobalTableContributorInsightsSpecificationArgs>;
        /**
         * Determines if a replica is protected from deletion. When enabled, the table cannot be deleted by any user or process. This setting is disabled by default. For more information, see [Using deletion protection](https://docs.aws.amazon.com/amazondynamodb/latest/developerguide/WorkingWithTables.Basics.html#WorkingWithTables.Basics.DeletionProtection) in the *Amazon DynamoDB Developer Guide* .
         */
        deletionProtectionEnabled?: pulumi.Input<boolean>;
        /**
         * Defines additional settings for the global secondary indexes of this replica.
         */
        globalSecondaryIndexes?: pulumi.Input<pulumi.Input<inputs.dynamodb.GlobalTableReplicaGlobalSecondaryIndexSpecificationArgs>[]>;
        /**
         * Defines the Kinesis Data Streams configuration for the specified replica.
         */
        kinesisStreamSpecification?: pulumi.Input<inputs.dynamodb.GlobalTableKinesisStreamSpecificationArgs>;
        /**
         * The settings used to enable point in time recovery. When not specified, defaults to point in time recovery disabled for the replica.
         */
        pointInTimeRecoverySpecification?: pulumi.Input<inputs.dynamodb.GlobalTablePointInTimeRecoverySpecificationArgs>;
        /**
         * Sets read request settings for the replica table.
         */
        readOnDemandThroughputSettings?: pulumi.Input<inputs.dynamodb.GlobalTableReadOnDemandThroughputSettingsArgs>;
        /**
         * Defines read capacity settings for the replica table.
         */
        readProvisionedThroughputSettings?: pulumi.Input<inputs.dynamodb.GlobalTableReadProvisionedThroughputSettingsArgs>;
        /**
         * The region in which this replica exists.
         */
        region: pulumi.Input<string>;
        /**
         * Represents the DynamoDB Streams configuration for a global table replica.
         */
        replicaStreamSpecification?: pulumi.Input<inputs.dynamodb.GlobalTableReplicaStreamSpecificationArgs>;
        /**
         * A resource-based policy document that contains permissions to add to the specified replica of a DynamoDB global table. Resource-based policies let you define access permissions by specifying who has access to each resource, and the actions they are allowed to perform on each resource.
         *
         * In a CloudFormation template, you can provide the policy in JSON or YAML format because CloudFormation converts YAML to JSON before submitting it to DynamoDB . For more information about resource-based policies, see [Using resource-based policies for DynamoDB](https://docs.aws.amazon.com/amazondynamodb/latest/developerguide/access-control-resource-based.html) and [Resource-based policy examples](https://docs.aws.amazon.com/amazondynamodb/latest/developerguide/rbac-examples.html) .
         */
        resourcePolicy?: pulumi.Input<inputs.dynamodb.GlobalTableResourcePolicyArgs>;
        /**
         * Allows you to specify a customer-managed key for the replica. When using customer-managed keys for server-side encryption, this property must have a value in all replicas.
         */
        sseSpecification?: pulumi.Input<inputs.dynamodb.GlobalTableReplicaSseSpecificationArgs>;
        /**
         * The table class of the specified table. Valid values are `STANDARD` and `STANDARD_INFREQUENT_ACCESS` .
         */
        tableClass?: pulumi.Input<string>;
        /**
         * An array of key-value pairs to apply to this replica.
         *
         * For more information, see [Tag](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-resource-tags.html) .
         */
        tags?: pulumi.Input<pulumi.Input<inputs.dynamodb.GlobalTableTagArgs>[]>;
    }
    interface GlobalTableReplicaSseSpecificationArgs {
        /**
         * The AWS KMS key that should be used for the AWS KMS encryption. To specify a key, use its key ID, Amazon Resource Name (ARN), alias name, or alias ARN. Note that you should only provide this parameter if the key is different from the default DynamoDB key `alias/aws/dynamodb` .
         */
        kmsMasterKeyId: pulumi.Input<string>;
    }
    interface GlobalTableReplicaStreamSpecificationArgs {
        /**
         * A resource-based policy document that contains the permissions for the specified stream of a DynamoDB global table replica. Resource-based policies let you define access permissions by specifying who has access to each resource, and the actions they are allowed to perform on each resource.
         *
         * In a CloudFormation template, you can provide the policy in JSON or YAML format because CloudFormation converts YAML to JSON before submitting it to DynamoDB . For more information about resource-based policies, see [Using resource-based policies for DynamoDB](https://docs.aws.amazon.com/amazondynamodb/latest/developerguide/access-control-resource-based.html) and [Resource-based policy examples](https://docs.aws.amazon.com/amazondynamodb/latest/developerguide/rbac-examples.html) .
         *
         * You can update the `ResourcePolicy` property if you've specified more than one table using the [AWS ::DynamoDB::GlobalTable](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-dynamodb-globaltable.html) resource.
         */
        resourcePolicy: pulumi.Input<inputs.dynamodb.GlobalTableResourcePolicyArgs>;
    }
    interface GlobalTableResourcePolicyArgs {
        /**
         * A resource-based policy document that contains permissions to add to the specified DynamoDB table, its indexes, and stream. In a CloudFormation template, you can provide the policy in JSON or YAML format because CloudFormation converts YAML to JSON before submitting it to DynamoDB . For more information about resource-based policies, see [Using resource-based policies for DynamoDB](https://docs.aws.amazon.com/amazondynamodb/latest/developerguide/access-control-resource-based.html) and [Resource-based policy examples](https://docs.aws.amazon.com/amazondynamodb/latest/developerguide/rbac-examples.html) .
         */
        policyDocument: any;
    }
    interface GlobalTableSseSpecificationArgs {
        /**
         * Indicates whether server-side encryption is performed using an AWS managed key or an AWS owned key. If enabled (true), server-side encryption type is set to KMS and an AWS managed key is used ( AWS KMS charges apply). If disabled (false) or not specified,server-side encryption is set to an AWS owned key. If you choose to use KMS encryption, you can also use customer managed KMS keys by specifying them in the `ReplicaSpecification.SSESpecification` object. You cannot mix AWS managed and customer managed KMS keys.
         */
        sseEnabled: pulumi.Input<boolean>;
        /**
         * Server-side encryption type. The only supported value is:
         *
         * - `KMS` - Server-side encryption that uses AWS Key Management Service . The key is stored in your account and is managed by AWS KMS ( AWS KMS charges apply).
         */
        sseType?: pulumi.Input<string>;
    }
    interface GlobalTableStreamSpecificationArgs {
        /**
         * When an item in the table is modified, `StreamViewType` determines what information is written to the stream for this table. Valid values for `StreamViewType` are:
         *
         * - `KEYS_ONLY` - Only the key attributes of the modified item are written to the stream.
         * - `NEW_IMAGE` - The entire item, as it appears after it was modified, is written to the stream.
         * - `OLD_IMAGE` - The entire item, as it appeared before it was modified, is written to the stream.
         * - `NEW_AND_OLD_IMAGES` - Both the new and the old item images of the item are written to the stream.
         */
        streamViewType: pulumi.Input<string>;
    }
    interface GlobalTableTagArgs {
        /**
         * The key of the tag. Tag keys are case sensitive. Each DynamoDB table can only have up to one tag with the same key. If you try to add an existing tag (same key), the existing tag value will be updated to the new value.
         */
        key: pulumi.Input<string>;
        /**
         * The value of the tag. Tag values are case-sensitive and can be null.
         */
        value: pulumi.Input<string>;
    }
    interface GlobalTableTargetTrackingScalingPolicyConfigurationArgs {
        /**
         * Indicates whether scale in by the target tracking scaling policy is disabled. The default value is `false` .
         */
        disableScaleIn?: pulumi.Input<boolean>;
        /**
         * The amount of time, in seconds, after a scale-in activity completes before another scale-in activity can start.
         */
        scaleInCooldown?: pulumi.Input<number>;
        /**
         * The amount of time, in seconds, after a scale-out activity completes before another scale-out activity can start.
         */
        scaleOutCooldown?: pulumi.Input<number>;
        /**
         * Defines a target value for the scaling policy.
         */
        targetValue: pulumi.Input<number>;
    }
    interface GlobalTableTimeToLiveSpecificationArgs {
        /**
         * The name of the attribute used to store the expiration time for items in the table.
         *
         * Currently, you cannot directly change the attribute name used to evaluate time to live. In order to do so, you must first disable time to live, and then re-enable it with the new attribute name. It can take up to one hour for changes to time to live to take effect. If you attempt to modify time to live within that time window, your stack operation might be delayed.
         */
        attributeName?: pulumi.Input<string>;
        /**
         * Indicates whether TTL is to be enabled (true) or disabled (false) on the table.
         */
        enabled: pulumi.Input<boolean>;
    }
    interface GlobalTableWarmThroughputArgs {
        /**
         * Represents the number of read operations your base table can instantaneously support.
         */
        readUnitsPerSecond?: pulumi.Input<number>;
        /**
         * Represents the number of write operations your base table can instantaneously support.
         */
        writeUnitsPerSecond?: pulumi.Input<number>;
    }
    interface GlobalTableWriteOnDemandThroughputSettingsArgs {
        /**
         * Maximum number of write request settings for the specified replica of a global table.
         */
        maxWriteRequestUnits?: pulumi.Input<number>;
    }
    interface GlobalTableWriteProvisionedThroughputSettingsArgs {
        /**
         * Specifies auto scaling settings for the replica table or global secondary index.
         */
        writeCapacityAutoScalingSettings?: pulumi.Input<inputs.dynamodb.GlobalTableCapacityAutoScalingSettingsArgs>;
    }
    /**
     * Represents an attribute for describing the schema for the table and indexes.
     */
    interface TableAttributeDefinitionArgs {
        /**
         * A name for the attribute.
         */
        attributeName: pulumi.Input<string>;
        /**
         * The data type for the attribute, where:
         *   +   ``S`` - the attribute is of type String
         *   +   ``N`` - the attribute is of type Number
         *   +   ``B`` - the attribute is of type Binary
         */
        attributeType: pulumi.Input<string>;
    }
    /**
     * The settings used to enable or disable CloudWatch Contributor Insights.
     */
    interface TableContributorInsightsSpecificationArgs {
        /**
         * Indicates whether CloudWatch Contributor Insights are to be enabled (true) or disabled (false).
         */
        enabled: pulumi.Input<boolean>;
    }
    /**
     * The options for imported source files in CSV format. The values are Delimiter and HeaderList.
     */
    interface TableCsvArgs {
        /**
         * The delimiter used for separating items in the CSV file being imported.
         */
        delimiter?: pulumi.Input<string>;
        /**
         * List of the headers used to specify a common header for all source CSV files being imported. If this field is specified then the first line of each CSV file is treated as data instead of the header. If this field is not specified the the first line of each CSV file is treated as the header.
         */
        headerList?: pulumi.Input<pulumi.Input<string>[]>;
    }
    /**
     * Represents the properties of a global secondary index.
     */
    interface TableGlobalSecondaryIndexArgs {
        /**
         * The settings used to enable or disable CloudWatch Contributor Insights for the specified global secondary index.
         */
        contributorInsightsSpecification?: pulumi.Input<inputs.dynamodb.TableContributorInsightsSpecificationArgs>;
        /**
         * The name of the global secondary index. The name must be unique among all other indexes on this table.
         */
        indexName: pulumi.Input<string>;
        /**
         * The complete key schema for a global secondary index, which consists of one or more pairs of attribute names and key types:
         *   +   ``HASH`` - partition key
         *   +   ``RANGE`` - sort key
         *
         *   The partition key of an item is also known as its *hash attribute*. The term "hash attribute" derives from DynamoDB's usage of an internal hash function to evenly distribute data items across partitions, based on their partition key values.
         *  The sort key of an item is also known as its *range attribute*. The term "range attribute" derives from the way DynamoDB stores items with the same partition key physically close together, in sorted order by the sort key value.
         */
        keySchema: pulumi.Input<pulumi.Input<inputs.dynamodb.TableKeySchemaArgs>[]>;
        /**
         * The maximum number of read and write units for the specified global secondary index. If you use this parameter, you must specify ``MaxReadRequestUnits``, ``MaxWriteRequestUnits``, or both.
         */
        onDemandThroughput?: pulumi.Input<inputs.dynamodb.TableOnDemandThroughputArgs>;
        /**
         * Represents attributes that are copied (projected) from the table into the global secondary index. These are in addition to the primary key attributes and index key attributes, which are automatically projected.
         */
        projection: pulumi.Input<inputs.dynamodb.TableProjectionArgs>;
        /**
         * Represents the provisioned throughput settings for the specified global secondary index.
         *  For current minimum and maximum provisioned throughput values, see [Service, Account, and Table Quotas](https://docs.aws.amazon.com/amazondynamodb/latest/developerguide/Limits.html) in the *Amazon DynamoDB Developer Guide*.
         */
        provisionedThroughput?: pulumi.Input<inputs.dynamodb.TableProvisionedThroughputArgs>;
        /**
         * Represents the warm throughput value (in read units per second and write units per second) for the specified secondary index. If you use this parameter, you must specify ``ReadUnitsPerSecond``, ``WriteUnitsPerSecond``, or both.
         */
        warmThroughput?: pulumi.Input<inputs.dynamodb.TableWarmThroughputArgs>;
    }
    /**
     * Specifies the properties of data being imported from the S3 bucket source to the table.
     */
    interface TableImportSourceSpecificationArgs {
        /**
         * Type of compression to be used on the input coming from the imported table.
         */
        inputCompressionType?: pulumi.Input<string>;
        /**
         * The format of the source data. Valid values for ``ImportFormat`` are ``CSV``, ``DYNAMODB_JSON`` or ``ION``.
         */
        inputFormat: pulumi.Input<string>;
        /**
         * Additional properties that specify how the input is formatted,
         */
        inputFormatOptions?: pulumi.Input<inputs.dynamodb.TableInputFormatOptionsArgs>;
        /**
         * The S3 bucket that provides the source for the import.
         */
        s3BucketSource: pulumi.Input<inputs.dynamodb.TableS3BucketSourceArgs>;
    }
    /**
     * The format options for the data that was imported into the target table. There is one value, CsvOption.
     */
    interface TableInputFormatOptionsArgs {
        /**
         * The options for imported source files in CSV format. The values are Delimiter and HeaderList.
         */
        csv?: pulumi.Input<inputs.dynamodb.TableCsvArgs>;
    }
    /**
     * Represents *a single element* of a key schema. A key schema specifies the attributes that make up the primary key of a table, or the key attributes of an index.
     *  A ``KeySchemaElement`` represents exactly one attribute of the primary key. For example, a simple primary key would be represented by one ``KeySchemaElement`` (for the partition key). A composite primary key would require one ``KeySchemaElement`` for the partition key, and another ``KeySchemaElement`` for the sort key.
     *  A ``KeySchemaElement`` must be a scalar, top-level attribute (not a nested attribute). The data type must be one of String, Number, or Binary. The attribute cannot be nested within a List or a Map.
     */
    interface TableKeySchemaArgs {
        /**
         * The name of a key attribute.
         */
        attributeName: pulumi.Input<string>;
        /**
         * The role that this key attribute will assume:
         *   +   ``HASH`` - partition key
         *   +   ``RANGE`` - sort key
         *
         *   The partition key of an item is also known as its *hash attribute*. The term "hash attribute" derives from DynamoDB's usage of an internal hash function to evenly distribute data items across partitions, based on their partition key values.
         *  The sort key of an item is also known as its *range attribute*. The term "range attribute" derives from the way DynamoDB stores items with the same partition key physically close together, in sorted order by the sort key value.
         */
        keyType: pulumi.Input<string>;
    }
    /**
     * The Kinesis Data Streams configuration for the specified table.
     */
    interface TableKinesisStreamSpecificationArgs {
        /**
         * The precision for the time and date that the stream was created.
         */
        approximateCreationDateTimePrecision?: pulumi.Input<enums.dynamodb.TableKinesisStreamSpecificationApproximateCreationDateTimePrecision>;
        /**
         * The ARN for a specific Kinesis data stream.
         *  Length Constraints: Minimum length of 37. Maximum length of 1024.
         */
        streamArn: pulumi.Input<string>;
    }
    /**
     * Represents the properties of a local secondary index. A local secondary index can only be created when its parent table is created.
     */
    interface TableLocalSecondaryIndexArgs {
        /**
         * The name of the local secondary index. The name must be unique among all other indexes on this table.
         */
        indexName: pulumi.Input<string>;
        /**
         * The complete key schema for the local secondary index, consisting of one or more pairs of attribute names and key types:
         *   +   ``HASH`` - partition key
         *   +   ``RANGE`` - sort key
         *
         *   The partition key of an item is also known as its *hash attribute*. The term "hash attribute" derives from DynamoDB's usage of an internal hash function to evenly distribute data items across partitions, based on their partition key values.
         *  The sort key of an item is also known as its *range attribute*. The term "range attribute" derives from the way DynamoDB stores items with the same partition key physically close together, in sorted order by the sort key value.
         */
        keySchema: pulumi.Input<pulumi.Input<inputs.dynamodb.TableKeySchemaArgs>[]>;
        /**
         * Represents attributes that are copied (projected) from the table into the local secondary index. These are in addition to the primary key attributes and index key attributes, which are automatically projected.
         */
        projection: pulumi.Input<inputs.dynamodb.TableProjectionArgs>;
    }
    /**
     * Sets the maximum number of read and write units for the specified on-demand table. If you use this property, you must specify ``MaxReadRequestUnits``, ``MaxWriteRequestUnits``, or both.
     */
    interface TableOnDemandThroughputArgs {
        /**
         * Maximum number of read request units for the specified table.
         *  To specify a maximum ``OnDemandThroughput`` on your table, set the value of ``MaxReadRequestUnits`` as greater than or equal to 1. To remove the maximum ``OnDemandThroughput`` that is currently set on your table, set the value of ``MaxReadRequestUnits`` to -1.
         */
        maxReadRequestUnits?: pulumi.Input<number>;
        /**
         * Maximum number of write request units for the specified table.
         *  To specify a maximum ``OnDemandThroughput`` on your table, set the value of ``MaxWriteRequestUnits`` as greater than or equal to 1. To remove the maximum ``OnDemandThroughput`` that is currently set on your table, set the value of ``MaxWriteRequestUnits`` to -1.
         */
        maxWriteRequestUnits?: pulumi.Input<number>;
    }
    /**
     * The settings used to enable point in time recovery.
     */
    interface TablePointInTimeRecoverySpecificationArgs {
        /**
         * Indicates whether point in time recovery is enabled (true) or disabled (false) on the table.
         */
        pointInTimeRecoveryEnabled?: pulumi.Input<boolean>;
        /**
         * The number of preceding days for which continuous backups are taken and maintained. Your table data is only recoverable to any point-in-time from within the configured recovery period. This parameter is optional. If no value is provided, the value will default to 35.
         */
        recoveryPeriodInDays?: pulumi.Input<number>;
    }
    /**
     * Represents attributes that are copied (projected) from the table into an index. These are in addition to the primary key attributes and index key attributes, which are automatically projected.
     */
    interface TableProjectionArgs {
        /**
         * Represents the non-key attribute names which will be projected into the index.
         *  For global and local secondary indexes, the total count of ``NonKeyAttributes`` summed across all of the secondary indexes, must not exceed 100. If you project the same attribute into two different indexes, this counts as two distinct attributes when determining the total. This limit only applies when you specify the ProjectionType of ``INCLUDE``. You still can specify the ProjectionType of ``ALL`` to project all attributes from the source table, even if the table has more than 100 attributes.
         */
        nonKeyAttributes?: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * The set of attributes that are projected into the index:
         *   +   ``KEYS_ONLY`` - Only the index and primary keys are projected into the index.
         *   +   ``INCLUDE`` - In addition to the attributes described in ``KEYS_ONLY``, the secondary index will include other non-key attributes that you specify.
         *   +   ``ALL`` - All of the table attributes are projected into the index.
         *
         *  When using the DynamoDB console, ``ALL`` is selected by default.
         */
        projectionType?: pulumi.Input<string>;
    }
    /**
     * Throughput for the specified table, which consists of values for ``ReadCapacityUnits`` and ``WriteCapacityUnits``. For more information about the contents of a provisioned throughput structure, see [Table ProvisionedThroughput](https://docs.aws.amazon.com/amazondynamodb/latest/APIReference/API_ProvisionedThroughput.html).
     */
    interface TableProvisionedThroughputArgs {
        /**
         * The maximum number of strongly consistent reads consumed per second before DynamoDB returns a ``ThrottlingException``. For more information, see [Specifying Read and Write Requirements](https://docs.aws.amazon.com/amazondynamodb/latest/developerguide/ProvisionedThroughput.html) in the *Amazon DynamoDB Developer Guide*.
         *  If read/write capacity mode is ``PAY_PER_REQUEST`` the value is set to 0.
         */
        readCapacityUnits: pulumi.Input<number>;
        /**
         * The maximum number of writes consumed per second before DynamoDB returns a ``ThrottlingException``. For more information, see [Specifying Read and Write Requirements](https://docs.aws.amazon.com/amazondynamodb/latest/developerguide/ProvisionedThroughput.html) in the *Amazon DynamoDB Developer Guide*.
         *  If read/write capacity mode is ``PAY_PER_REQUEST`` the value is set to 0.
         */
        writeCapacityUnits: pulumi.Input<number>;
    }
    /**
     * Creates or updates a resource-based policy document that contains the permissions for DDB resources, such as a table, its indexes, and stream. Resource-based policies let you define access permissions by specifying who has access to each resource, and the actions they are allowed to perform on each resource.
     *  In a CFNshort template, you can provide the policy in JSON or YAML format because CFNshort converts YAML to JSON before submitting it to DDB. For more information about resource-based policies, see [Using resource-based policies for](https://docs.aws.amazon.com/amazondynamodb/latest/developerguide/access-control-resource-based.html) and [Resource-based policy examples](https://docs.aws.amazon.com/amazondynamodb/latest/developerguide/rbac-examples.html).
     *  While defining resource-based policies in your CFNshort templates, the following considerations apply:
     *   +  The maximum size supported for a resource-based policy document in JSON format is 20 KB. DDB counts whitespaces when calculating the size of a policy against this limit.
     *   +  Resource-based policies don't support [drift detection](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/using-cfn-stack-drift.html#). If you update a policy outside of the CFNshort stack template, you'll need to update the CFNshort stack with the changes.
     *   +  Resource-based policies don't support out-of-band changes. If you add, update, or delete a policy outside of the CFNshort template, the change won't be overwritten if there are no changes to the policy within the template.
     *  For example, say that your template contains a resource-based policy, which you later update outside of the template. If you don't make any changes to the policy in the template, the updated policy in DDB won’t be synced with the policy in the template.
     *  Conversely, say that your template doesn’t contain a resource-based policy, but you add a policy outside of the template. This policy won’t be removed from DDB as long as you don’t add it to the template. When you add a policy to the template and update the stack, the existing policy in DDB will be updated to match the one defined in the template.
     *
     *  For a full list of all considerations, see [Resource-based policy considerations](https://docs.aws.amazon.com/amazondynamodb/latest/developerguide/rbac-considerations.html).
     */
    interface TableResourcePolicyArgs {
        /**
         * A resource-based policy document that contains permissions to add to the specified DDB table, index, or both. In a CFNshort template, you can provide the policy in JSON or YAML format because CFNshort converts YAML to JSON before submitting it to DDB. For more information about resource-based policies, see [Using resource-based policies for](https://docs.aws.amazon.com/amazondynamodb/latest/developerguide/access-control-resource-based.html) and [Resource-based policy examples](https://docs.aws.amazon.com/amazondynamodb/latest/developerguide/rbac-examples.html).
         */
        policyDocument: any;
    }
    /**
     * The S3 bucket that is being imported from.
     */
    interface TableS3BucketSourceArgs {
        /**
         * The S3 bucket that is being imported from.
         */
        s3Bucket: pulumi.Input<string>;
        /**
         * The account number of the S3 bucket that is being imported from. If the bucket is owned by the requester this is optional.
         */
        s3BucketOwner?: pulumi.Input<string>;
        /**
         * The key prefix shared by all S3 Objects that are being imported.
         */
        s3KeyPrefix?: pulumi.Input<string>;
    }
    /**
     * Represents the settings used to enable server-side encryption.
     */
    interface TableSseSpecificationArgs {
        /**
         * The KMS key that should be used for the KMS encryption. To specify a key, use its key ID, Amazon Resource Name (ARN), alias name, or alias ARN. Note that you should only provide this parameter if the key is different from the default DynamoDB key ``alias/aws/dynamodb``.
         */
        kmsMasterKeyId?: pulumi.Input<string>;
        /**
         * Indicates whether server-side encryption is done using an AWS managed key or an AWS owned key. If enabled (true), server-side encryption type is set to ``KMS`` and an AWS managed key is used (KMS charges apply). If disabled (false) or not specified, server-side encryption is set to AWS owned key.
         */
        sseEnabled: pulumi.Input<boolean>;
        /**
         * Server-side encryption type. The only supported value is:
         *   +   ``KMS`` - Server-side encryption that uses KMSlong. The key is stored in your account and is managed by KMS (KMS charges apply).
         */
        sseType?: pulumi.Input<string>;
    }
    /**
     * Represents the DynamoDB Streams configuration for a table in DynamoDB.
     */
    interface TableStreamSpecificationArgs {
        /**
         * Creates or updates a resource-based policy document that contains the permissions for DDB resources, such as a table's streams. Resource-based policies let you define access permissions by specifying who has access to each resource, and the actions they are allowed to perform on each resource.
         *  In a CFNshort template, you can provide the policy in JSON or YAML format because CFNshort converts YAML to JSON before submitting it to DDB. For more information about resource-based policies, see [Using resource-based policies for](https://docs.aws.amazon.com/amazondynamodb/latest/developerguide/access-control-resource-based.html) and [Resource-based policy examples](https://docs.aws.amazon.com/amazondynamodb/latest/developerguide/rbac-examples.html).
         */
        resourcePolicy?: pulumi.Input<inputs.dynamodb.TableResourcePolicyArgs>;
        /**
         * When an item in the table is modified, ``StreamViewType`` determines what information is written to the stream for this table. Valid values for ``StreamViewType`` are:
         *   +   ``KEYS_ONLY`` - Only the key attributes of the modified item are written to the stream.
         *   +   ``NEW_IMAGE`` - The entire item, as it appears after it was modified, is written to the stream.
         *   +   ``OLD_IMAGE`` - The entire item, as it appeared before it was modified, is written to the stream.
         *   +   ``NEW_AND_OLD_IMAGES`` - Both the new and the old item images of the item are written to the stream.
         */
        streamViewType: pulumi.Input<string>;
    }
    /**
     * Represents the settings used to enable or disable Time to Live (TTL) for the specified table.
     */
    interface TableTimeToLiveSpecificationArgs {
        /**
         * The name of the TTL attribute used to store the expiration time for items in the table.
         *    +  The ``AttributeName`` property is required when enabling the TTL, or when TTL is already enabled.
         *   +  To update this property, you must first disable TTL and then enable TTL with the new attribute name.
         */
        attributeName?: pulumi.Input<string>;
        /**
         * Indicates whether TTL is to be enabled (true) or disabled (false) on the table.
         */
        enabled: pulumi.Input<boolean>;
    }
    /**
     * Provides visibility into the number of read and write operations your table or secondary index can instantaneously support. The settings can be modified using the ``UpdateTable`` operation to meet the throughput requirements of an upcoming peak event.
     */
    interface TableWarmThroughputArgs {
        /**
         * Represents the number of read operations your base table can instantaneously support.
         */
        readUnitsPerSecond?: pulumi.Input<number>;
        /**
         * Represents the number of write operations your base table can instantaneously support.
         */
        writeUnitsPerSecond?: pulumi.Input<number>;
    }
}
export declare namespace ec2 {
    interface CapacityReservationFleetInstanceTypeSpecificationArgs {
        /**
         * The Availability Zone in which the Capacity Reservation Fleet reserves the capacity. A Capacity Reservation Fleet can't span Availability Zones. All instance type specifications that you specify for the Fleet must use the same Availability Zone.
         */
        availabilityZone?: pulumi.Input<string>;
        /**
         * The ID of the Availability Zone in which the Capacity Reservation Fleet reserves the capacity. A Capacity Reservation Fleet can't span Availability Zones. All instance type specifications that you specify for the Fleet must use the same Availability Zone.
         */
        availabilityZoneId?: pulumi.Input<string>;
        /**
         * Indicates whether the Capacity Reservation Fleet supports EBS-optimized instances types. This optimization provides dedicated throughput to Amazon EBS and an optimized configuration stack to provide optimal I/O performance. This optimization isn't available with all instance types. Additional usage charges apply when using EBS-optimized instance types.
         */
        ebsOptimized?: pulumi.Input<boolean>;
        /**
         * The type of operating system for which the Capacity Reservation Fleet reserves capacity.
         */
        instancePlatform?: pulumi.Input<string>;
        /**
         * The instance type for which the Capacity Reservation Fleet reserves capacity.
         */
        instanceType?: pulumi.Input<string>;
        /**
         * The priority to assign to the instance type. This value is used to determine which of the instance types specified for the Fleet should be prioritized for use. A lower value indicates a high priority. For more information, see [Instance type priority](https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/crfleet-concepts.html#instance-priority) in the *Amazon EC2 User Guide* .
         */
        priority?: pulumi.Input<number>;
        /**
         * The number of capacity units provided by the specified instance type. This value, together with the total target capacity that you specify for the Fleet determine the number of instances for which the Fleet reserves capacity. Both values are based on units that make sense for your workload. For more information, see [Total target capacity](https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/crfleet-concepts.html#target-capacity) in the Amazon EC2 User Guide.
         *
         * Valid Range: Minimum value of `0.001` . Maximum value of `99.999` .
         */
        weight?: pulumi.Input<number>;
    }
    interface CapacityReservationFleetTagArgs {
        /**
         * The tag key.
         */
        key: pulumi.Input<string>;
        /**
         * The tag value.
         */
        value: pulumi.Input<string>;
    }
    interface CapacityReservationFleetTagSpecificationArgs {
        /**
         * The type of resource to tag on creation. Specify `capacity-reservation-fleet` .
         *
         * To tag a resource after it has been created, see [CreateTags](https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_CreateTags.html) .
         */
        resourceType?: pulumi.Input<string>;
        /**
         * The tags to apply to the resource.
         */
        tags?: pulumi.Input<pulumi.Input<inputs.ec2.CapacityReservationFleetTagArgs>[]>;
    }
    interface CapacityReservationTagArgs {
        /**
         * The tag key.
         */
        key: pulumi.Input<string>;
        /**
         * The tag value.
         */
        value: pulumi.Input<string>;
    }
    interface CapacityReservationTagSpecificationArgs {
        /**
         * The type of resource to tag. Specify `capacity-reservation` .
         */
        resourceType?: pulumi.Input<string>;
        /**
         * The tags to apply to the resource.
         */
        tags?: pulumi.Input<pulumi.Input<inputs.ec2.CapacityReservationTagArgs>[]>;
    }
    /**
     * The CPU options for the instance.
     */
    interface CpuOptionsPropertiesArgs {
        /**
         * The number of CPU cores for the instance.
         */
        coreCount?: pulumi.Input<number>;
        /**
         * The number of threads per CPU core.
         */
        threadsPerCore?: pulumi.Input<number>;
    }
    /**
     * The credit option for CPU usage of the burstable performance instance. Valid values are standard and unlimited.
     */
    interface CreditSpecificationPropertiesArgs {
        /**
         * The credit option for CPU usage of the instance.
         *
         * Valid values: `standard` | `unlimited`
         *
         * T3 instances with `host` tenancy do not support the `unlimited` CPU credit option.
         */
        cpuCredits?: pulumi.Input<string>;
    }
    /**
     * The destination options.
     */
    interface DestinationOptionsPropertiesArgs {
        /**
         * The format for the flow log. The default is `plain-text` .
         */
        fileFormat: pulumi.Input<enums.ec2.FlowLogDestinationOptionsPropertiesFileFormat>;
        /**
         * Indicates whether to use Hive-compatible prefixes for flow logs stored in Amazon S3. The default is `false` .
         */
        hiveCompatiblePartitions: pulumi.Input<boolean>;
        /**
         * Indicates whether to partition the flow log per hour. This reduces the cost and response time for queries. The default is `false` .
         */
        perHourPartition: pulumi.Input<boolean>;
    }
    interface Ec2FleetAcceleratorCountRequestArgs {
        /**
         * The maximum number of accelerators. To specify no maximum limit, omit this parameter. To exclude accelerator-enabled instance types, set `Max` to `0` .
         */
        max?: pulumi.Input<number>;
        /**
         * The minimum number of accelerators. To specify no minimum limit, omit this parameter.
         */
        min?: pulumi.Input<number>;
    }
    interface Ec2FleetAcceleratorTotalMemoryMiBRequestArgs {
        /**
         * The maximum amount of accelerator memory, in MiB. To specify no maximum limit, omit this parameter.
         */
        max?: pulumi.Input<number>;
        /**
         * The minimum amount of accelerator memory, in MiB. To specify no minimum limit, omit this parameter.
         */
        min?: pulumi.Input<number>;
    }
    interface Ec2FleetBaselineEbsBandwidthMbpsRequestArgs {
        /**
         * The maximum baseline bandwidth, in Mbps. To specify no maximum limit, omit this parameter.
         */
        max?: pulumi.Input<number>;
        /**
         * The minimum baseline bandwidth, in Mbps. To specify no minimum limit, omit this parameter.
         */
        min?: pulumi.Input<number>;
    }
    interface Ec2FleetBaselinePerformanceFactorsRequestArgs {
        /**
         * The CPU performance to consider, using an instance family as the baseline reference.
         */
        cpu?: pulumi.Input<inputs.ec2.Ec2FleetCpuPerformanceFactorRequestArgs>;
    }
    interface Ec2FleetCapacityRebalanceArgs {
        /**
         * The replacement strategy to use. Only available for fleets of type `maintain` .
         *
         * `launch` - EC2 Fleet launches a replacement Spot Instance when a rebalance notification is emitted for an existing Spot Instance in the fleet. EC2 Fleet does not terminate the instances that receive a rebalance notification. You can terminate the old instances, or you can leave them running. You are charged for all instances while they are running.
         *
         * `launch-before-terminate` - EC2 Fleet launches a replacement Spot Instance when a rebalance notification is emitted for an existing Spot Instance in the fleet, and then, after a delay that you specify (in `TerminationDelay` ), terminates the instances that received a rebalance notification.
         */
        replacementStrategy?: pulumi.Input<enums.ec2.Ec2FleetCapacityRebalanceReplacementStrategy>;
        /**
         * The amount of time (in seconds) that Amazon EC2 waits before terminating the old Spot Instance after launching a new replacement Spot Instance.
         *
         * Required when `ReplacementStrategy` is set to `launch-before-terminate` .
         *
         * Not valid when `ReplacementStrategy` is set to `launch` .
         *
         * Valid values: Minimum value of `120` seconds. Maximum value of `7200` seconds.
         */
        terminationDelay?: pulumi.Input<number>;
    }
    interface Ec2FleetCapacityReservationOptionsRequestArgs {
        /**
         * Indicates whether to use unused Capacity Reservations for fulfilling On-Demand capacity.
         *
         * If you specify `use-capacity-reservations-first` , the fleet uses unused Capacity Reservations to fulfill On-Demand capacity up to the target On-Demand capacity. If multiple instance pools have unused Capacity Reservations, the On-Demand allocation strategy ( `lowest-price` or `prioritized` ) is applied. If the number of unused Capacity Reservations is less than the On-Demand target capacity, the remaining On-Demand target capacity is launched according to the On-Demand allocation strategy ( `lowest-price` or `prioritized` ).
         *
         * If you do not specify a value, the fleet fulfils the On-Demand capacity according to the chosen On-Demand allocation strategy.
         */
        usageStrategy?: pulumi.Input<enums.ec2.Ec2FleetCapacityReservationOptionsRequestUsageStrategy>;
    }
    interface Ec2FleetCpuPerformanceFactorRequestArgs {
        /**
         * Specify an instance family to use as the baseline reference for CPU performance. All instance types that match your specified attributes will be compared against the CPU performance of the referenced instance family, regardless of CPU manufacturer or architecture differences.
         *
         * > Currently, only one instance family can be specified in the list.
         */
        references?: pulumi.Input<pulumi.Input<inputs.ec2.Ec2FleetPerformanceFactorReferenceRequestArgs>[]>;
    }
    interface Ec2FleetFleetLaunchTemplateConfigRequestArgs {
        /**
         * The launch template to use. You must specify either the launch template ID or launch template name in the request.
         */
        launchTemplateSpecification?: pulumi.Input<inputs.ec2.Ec2FleetFleetLaunchTemplateSpecificationRequestArgs>;
        /**
         * Any parameters that you specify override the same parameters in the launch template.
         *
         * For fleets of type `request` and `maintain` , a maximum of 300 items is allowed across all launch templates.
         */
        overrides?: pulumi.Input<pulumi.Input<inputs.ec2.Ec2FleetFleetLaunchTemplateOverridesRequestArgs>[]>;
    }
    interface Ec2FleetFleetLaunchTemplateOverridesRequestArgs {
        /**
         * The Availability Zone in which to launch the instances.
         */
        availabilityZone?: pulumi.Input<string>;
        /**
         * The attributes for the instance types. When you specify instance attributes, Amazon EC2 will identify instance types with those attributes.
         *
         * > If you specify `InstanceRequirements` , you can't specify `InstanceType` .
         */
        instanceRequirements?: pulumi.Input<inputs.ec2.Ec2FleetInstanceRequirementsRequestArgs>;
        /**
         * The instance type.
         *
         * `mac1.metal` is not supported as a launch template override.
         *
         * > If you specify `InstanceType` , you can't specify `InstanceRequirements` .
         */
        instanceType?: pulumi.Input<string>;
        /**
         * The maximum price per unit hour that you are willing to pay for a Spot Instance. We do not recommend using this parameter because it can lead to increased interruptions. If you do not specify this parameter, you will pay the current Spot price.
         *
         * > If you specify a maximum price, your instances will be interrupted more frequently than if you do not specify this parameter.
         * >
         * > If you specify a maximum price, it must be more than USD $0.001. Specifying a value below USD $0.001 will result in an `InvalidParameterValue` error message.
         */
        maxPrice?: pulumi.Input<string>;
        /**
         * The location where the instance launched, if applicable.
         */
        placement?: pulumi.Input<inputs.ec2.Ec2FleetPlacementArgs>;
        /**
         * The priority for the launch template override. The highest priority is launched first.
         *
         * If the On-Demand `AllocationStrategy` is set to `prioritized` , EC2 Fleet uses priority to determine which launch template override to use first in fulfilling On-Demand capacity.
         *
         * If the Spot `AllocationStrategy` is set to `capacity-optimized-prioritized` , EC2 Fleet uses priority on a best-effort basis to determine which launch template override to use in fulfilling Spot capacity, but optimizes for capacity first.
         *
         * Valid values are whole numbers starting at `0` . The lower the number, the higher the priority. If no number is set, the launch template override has the lowest priority. You can set the same priority for different launch template overrides.
         */
        priority?: pulumi.Input<number>;
        /**
         * The IDs of the subnets in which to launch the instances. Separate multiple subnet IDs using commas (for example, `subnet-1234abcdeexample1, subnet-0987cdef6example2` ). A request of type `instant` can have only one subnet ID.
         */
        subnetId?: pulumi.Input<string>;
        /**
         * The number of units provided by the specified instance type. These are the same units that you chose to set the target capacity in terms of instances, or a performance characteristic such as vCPUs, memory, or I/O.
         *
         * If the target capacity divided by this value is not a whole number, Amazon EC2 rounds the number of instances to the next whole number. If this value is not specified, the default is 1.
         *
         * > When specifying weights, the price used in the `lowest-price` and `price-capacity-optimized` allocation strategies is per *unit* hour (where the instance price is divided by the specified weight). However, if all the specified weights are above the requested `TargetCapacity` , resulting in only 1 instance being launched, the price used is per *instance* hour.
         */
        weightedCapacity?: pulumi.Input<number>;
    }
    interface Ec2FleetFleetLaunchTemplateSpecificationRequestArgs {
        /**
         * The ID of the launch template.
         *
         * You must specify the `LaunchTemplateId` or the `LaunchTemplateName` , but not both.
         */
        launchTemplateId?: pulumi.Input<string>;
        /**
         * The name of the launch template.
         *
         * You must specify the `LaunchTemplateName` or the `LaunchTemplateId` , but not both.
         */
        launchTemplateName?: pulumi.Input<string>;
        /**
         * The launch template version number, `$Latest` , or `$Default` . You must specify a value, otherwise the request fails.
         *
         * If the value is `$Latest` , Amazon EC2 uses the latest version of the launch template.
         *
         * If the value is `$Default` , Amazon EC2 uses the default version of the launch template.
         */
        version: pulumi.Input<string>;
    }
    interface Ec2FleetInstanceRequirementsRequestArgs {
        /**
         * The minimum and maximum number of accelerators (GPUs, FPGAs, or AWS Inferentia chips) on an instance.
         *
         * To exclude accelerator-enabled instance types, set `Max` to `0` .
         *
         * Default: No minimum or maximum limits
         */
        acceleratorCount?: pulumi.Input<inputs.ec2.Ec2FleetAcceleratorCountRequestArgs>;
        /**
         * Indicates whether instance types must have accelerators by specific manufacturers.
         *
         * - For instance types with AWS devices, specify `amazon-web-services` .
         * - For instance types with AMD devices, specify `amd` .
         * - For instance types with Habana devices, specify `habana` .
         * - For instance types with NVIDIA devices, specify `nvidia` .
         * - For instance types with Xilinx devices, specify `xilinx` .
         *
         * Default: Any manufacturer
         */
        acceleratorManufacturers?: pulumi.Input<pulumi.Input<enums.ec2.Ec2FleetInstanceRequirementsRequestAcceleratorManufacturersItem>[]>;
        /**
         * The accelerators that must be on the instance type.
         *
         * - For instance types with NVIDIA A10G GPUs, specify `a10g` .
         * - For instance types with NVIDIA A100 GPUs, specify `a100` .
         * - For instance types with NVIDIA H100 GPUs, specify `h100` .
         * - For instance types with AWS Inferentia chips, specify `inferentia` .
         * - For instance types with NVIDIA GRID K520 GPUs, specify `k520` .
         * - For instance types with NVIDIA K80 GPUs, specify `k80` .
         * - For instance types with NVIDIA M60 GPUs, specify `m60` .
         * - For instance types with AMD Radeon Pro V520 GPUs, specify `radeon-pro-v520` .
         * - For instance types with NVIDIA T4 GPUs, specify `t4` .
         * - For instance types with NVIDIA T4G GPUs, specify `t4g` .
         * - For instance types with Xilinx VU9P FPGAs, specify `vu9p` .
         * - For instance types with NVIDIA V100 GPUs, specify `v100` .
         *
         * Default: Any accelerator
         */
        acceleratorNames?: pulumi.Input<pulumi.Input<enums.ec2.Ec2FleetInstanceRequirementsRequestAcceleratorNamesItem>[]>;
        /**
         * The minimum and maximum amount of total accelerator memory, in MiB.
         *
         * Default: No minimum or maximum limits
         */
        acceleratorTotalMemoryMiB?: pulumi.Input<inputs.ec2.Ec2FleetAcceleratorTotalMemoryMiBRequestArgs>;
        /**
         * The accelerator types that must be on the instance type.
         *
         * - For instance types with FPGA accelerators, specify `fpga` .
         * - For instance types with GPU accelerators, specify `gpu` .
         *
         * Default: Any accelerator type
         */
        acceleratorTypes?: pulumi.Input<pulumi.Input<enums.ec2.Ec2FleetInstanceRequirementsRequestAcceleratorTypesItem>[]>;
        /**
         * The instance types to apply your specified attributes against. All other instance types are ignored, even if they match your specified attributes.
         *
         * You can use strings with one or more wild cards, represented by an asterisk ( `*` ), to allow an instance type, size, or generation. The following are examples: `m5.8xlarge` , `c5*.*` , `m5a.*` , `r*` , `*3*` .
         *
         * For example, if you specify `c5*` ,Amazon EC2 will allow the entire C5 instance family, which includes all C5a and C5n instance types. If you specify `m5a.*` , Amazon EC2 will allow all the M5a instance types, but not the M5n instance types.
         *
         * > If you specify `AllowedInstanceTypes` , you can't specify `ExcludedInstanceTypes` .
         *
         * Default: All instance types
         */
        allowedInstanceTypes?: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * Indicates whether bare metal instance types must be included, excluded, or required.
         *
         * - To include bare metal instance types, specify `included` .
         * - To require only bare metal instance types, specify `required` .
         * - To exclude bare metal instance types, specify `excluded` .
         *
         * Default: `excluded`
         */
        bareMetal?: pulumi.Input<enums.ec2.Ec2FleetInstanceRequirementsRequestBareMetal>;
        /**
         * The minimum and maximum baseline bandwidth to Amazon EBS, in Mbps. For more information, see [Amazon EBS–optimized instances](https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/ebs-optimized.html) in the *Amazon EC2 User Guide* .
         *
         * Default: No minimum or maximum limits
         */
        baselineEbsBandwidthMbps?: pulumi.Input<inputs.ec2.Ec2FleetBaselineEbsBandwidthMbpsRequestArgs>;
        /**
         * The baseline performance to consider, using an instance family as a baseline reference. The instance family establishes the lowest acceptable level of performance. Amazon EC2 uses this baseline to guide instance type selection, but there is no guarantee that the selected instance types will always exceed the baseline for every application. Currently, this parameter only supports CPU performance as a baseline performance factor. For more information, see [Performance protection](https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/ec2-fleet-attribute-based-instance-type-selection.html#ec2fleet-abis-performance-protection) in the *Amazon EC2 User Guide* .
         */
        baselinePerformanceFactors?: pulumi.Input<inputs.ec2.Ec2FleetBaselinePerformanceFactorsRequestArgs>;
        /**
         * Indicates whether burstable performance T instance types are included, excluded, or required. For more information, see [Burstable performance instances](https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/burstable-performance-instances.html) .
         *
         * - To include burstable performance instance types, specify `included` .
         * - To require only burstable performance instance types, specify `required` .
         * - To exclude burstable performance instance types, specify `excluded` .
         *
         * Default: `excluded`
         */
        burstablePerformance?: pulumi.Input<enums.ec2.Ec2FleetInstanceRequirementsRequestBurstablePerformance>;
        /**
         * The CPU manufacturers to include.
         *
         * - For instance types with Intel CPUs, specify `intel` .
         * - For instance types with AMD CPUs, specify `amd` .
         * - For instance types with AWS CPUs, specify `amazon-web-services` .
         * - For instance types with Apple CPUs, specify `apple` .
         *
         * > Don't confuse the CPU manufacturer with the CPU architecture. Instances will be launched with a compatible CPU architecture based on the Amazon Machine Image (AMI) that you specify in your launch template.
         *
         * Default: Any manufacturer
         */
        cpuManufacturers?: pulumi.Input<pulumi.Input<enums.ec2.Ec2FleetInstanceRequirementsRequestCpuManufacturersItem>[]>;
        /**
         * The instance types to exclude.
         *
         * You can use strings with one or more wild cards, represented by an asterisk ( `*` ), to exclude an instance family, type, size, or generation. The following are examples: `m5.8xlarge` , `c5*.*` , `m5a.*` , `r*` , `*3*` .
         *
         * For example, if you specify `c5*` ,Amazon EC2 will exclude the entire C5 instance family, which includes all C5a and C5n instance types. If you specify `m5a.*` , Amazon EC2 will exclude all the M5a instance types, but not the M5n instance types.
         *
         * > If you specify `ExcludedInstanceTypes` , you can't specify `AllowedInstanceTypes` .
         *
         * Default: No excluded instance types
         */
        excludedInstanceTypes?: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * Indicates whether current or previous generation instance types are included. The current generation instance types are recommended for use. Current generation instance types are typically the latest two to three generations in each instance family. For more information, see [Instance types](https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/instance-types.html) in the *Amazon EC2 User Guide* .
         *
         * For current generation instance types, specify `current` .
         *
         * For previous generation instance types, specify `previous` .
         *
         * Default: Current and previous generation instance types
         */
        instanceGenerations?: pulumi.Input<pulumi.Input<enums.ec2.Ec2FleetInstanceRequirementsRequestInstanceGenerationsItem>[]>;
        /**
         * Indicates whether instance types with instance store volumes are included, excluded, or required. For more information, [Amazon EC2 instance store](https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/InstanceStorage.html) in the *Amazon EC2 User Guide* .
         *
         * - To include instance types with instance store volumes, specify `included` .
         * - To require only instance types with instance store volumes, specify `required` .
         * - To exclude instance types with instance store volumes, specify `excluded` .
         *
         * Default: `included`
         */
        localStorage?: pulumi.Input<enums.ec2.Ec2FleetInstanceRequirementsRequestLocalStorage>;
        /**
         * The type of local storage that is required.
         *
         * - For instance types with hard disk drive (HDD) storage, specify `hdd` .
         * - For instance types with solid state drive (SSD) storage, specify `ssd` .
         *
         * Default: `hdd` and `ssd`
         */
        localStorageTypes?: pulumi.Input<pulumi.Input<enums.ec2.Ec2FleetInstanceRequirementsRequestLocalStorageTypesItem>[]>;
        /**
         * [Price protection] The price protection threshold for Spot Instances, as a percentage of an identified On-Demand price. The identified On-Demand price is the price of the lowest priced current generation C, M, or R instance type with your specified attributes. If no current generation C, M, or R instance type matches your attributes, then the identified price is from the lowest priced current generation instance types, and failing that, from the lowest priced previous generation instance types that match your attributes. When Amazon EC2 selects instance types with your attributes, it will exclude instance types whose price exceeds your specified threshold.
         *
         * The parameter accepts an integer, which Amazon EC2 interprets as a percentage.
         *
         * If you set `TargetCapacityUnitType` to `vcpu` or `memory-mib` , the price protection threshold is based on the per vCPU or per memory price instead of the per instance price.
         *
         * > Only one of `SpotMaxPricePercentageOverLowestPrice` or `MaxSpotPriceAsPercentageOfOptimalOnDemandPrice` can be specified. If you don't specify either, Amazon EC2 will automatically apply optimal price protection to consistently select from a wide range of instance types. To indicate no price protection threshold for Spot Instances, meaning you want to consider all instance types that match your attributes, include one of these parameters and specify a high value, such as `999999` .
         */
        maxSpotPriceAsPercentageOfOptimalOnDemandPrice?: pulumi.Input<number>;
        /**
         * The minimum and maximum amount of memory per vCPU, in GiB.
         *
         * Default: No minimum or maximum limits
         */
        memoryGiBPerVCpu?: pulumi.Input<inputs.ec2.Ec2FleetMemoryGiBPerVCpuRequestArgs>;
        /**
         * The minimum and maximum amount of memory, in MiB.
         */
        memoryMiB?: pulumi.Input<inputs.ec2.Ec2FleetMemoryMiBRequestArgs>;
        /**
         * The minimum and maximum amount of baseline network bandwidth, in gigabits per second (Gbps). For more information, see [Amazon EC2 instance network bandwidth](https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/ec2-instance-network-bandwidth.html) in the *Amazon EC2 User Guide* .
         *
         * Default: No minimum or maximum limits
         */
        networkBandwidthGbps?: pulumi.Input<inputs.ec2.Ec2FleetNetworkBandwidthGbpsRequestArgs>;
        /**
         * The minimum and maximum number of network interfaces.
         *
         * Default: No minimum or maximum limits
         */
        networkInterfaceCount?: pulumi.Input<inputs.ec2.Ec2FleetNetworkInterfaceCountRequestArgs>;
        /**
         * [Price protection] The price protection threshold for On-Demand Instances, as a percentage higher than an identified On-Demand price. The identified On-Demand price is the price of the lowest priced current generation C, M, or R instance type with your specified attributes. When Amazon EC2 selects instance types with your attributes, it will exclude instance types whose price exceeds your specified threshold.
         *
         * The parameter accepts an integer, which Amazon EC2 interprets as a percentage.
         *
         * To indicate no price protection threshold, specify a high value, such as `999999` .
         *
         * This parameter is not supported for [GetSpotPlacementScores](https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_GetSpotPlacementScores.html) and [GetInstanceTypesFromInstanceRequirements](https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_GetInstanceTypesFromInstanceRequirements.html) .
         *
         * > If you set `TargetCapacityUnitType` to `vcpu` or `memory-mib` , the price protection threshold is applied based on the per-vCPU or per-memory price instead of the per-instance price.
         *
         * Default: `20`
         */
        onDemandMaxPricePercentageOverLowestPrice?: pulumi.Input<number>;
        /**
         * Indicates whether instance types must support hibernation for On-Demand Instances.
         *
         * This parameter is not supported for [GetSpotPlacementScores](https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_GetSpotPlacementScores.html) .
         *
         * Default: `false`
         */
        requireHibernateSupport?: pulumi.Input<boolean>;
        /**
         * [Price protection] The price protection threshold for Spot Instances, as a percentage higher than an identified Spot price. The identified Spot price is the Spot price of the lowest priced current generation C, M, or R instance type with your specified attributes. If no current generation C, M, or R instance type matches your attributes, then the identified Spot price is from the lowest priced current generation instance types, and failing that, from the lowest priced previous generation instance types that match your attributes. When Amazon EC2 selects instance types with your attributes, it will exclude instance types whose Spot price exceeds your specified threshold.
         *
         * The parameter accepts an integer, which Amazon EC2 interprets as a percentage.
         *
         * If you set `TargetCapacityUnitType` to `vcpu` or `memory-mib` , the price protection threshold is applied based on the per-vCPU or per-memory price instead of the per-instance price.
         *
         * This parameter is not supported for [GetSpotPlacementScores](https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_GetSpotPlacementScores.html) and [GetInstanceTypesFromInstanceRequirements](https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_GetInstanceTypesFromInstanceRequirements.html) .
         *
         * > Only one of `SpotMaxPricePercentageOverLowestPrice` or `MaxSpotPriceAsPercentageOfOptimalOnDemandPrice` can be specified. If you don't specify either, Amazon EC2 will automatically apply optimal price protection to consistently select from a wide range of instance types. To indicate no price protection threshold for Spot Instances, meaning you want to consider all instance types that match your attributes, include one of these parameters and specify a high value, such as `999999` .
         *
         * Default: `100`
         */
        spotMaxPricePercentageOverLowestPrice?: pulumi.Input<number>;
        /**
         * The minimum and maximum amount of total local storage, in GB.
         *
         * Default: No minimum or maximum limits
         */
        totalLocalStorageGb?: pulumi.Input<inputs.ec2.Ec2FleetTotalLocalStorageGbRequestArgs>;
        /**
         * The minimum and maximum number of vCPUs.
         */
        vCpuCount?: pulumi.Input<inputs.ec2.Ec2FleetVCpuCountRangeRequestArgs>;
    }
    interface Ec2FleetMaintenanceStrategiesArgs {
        /**
         * The strategy to use when Amazon EC2 emits a signal that your Spot Instance is at an elevated risk of being interrupted.
         */
        capacityRebalance?: pulumi.Input<inputs.ec2.Ec2FleetCapacityRebalanceArgs>;
    }
    interface Ec2FleetMemoryGiBPerVCpuRequestArgs {
        /**
         * The maximum amount of memory per vCPU, in GiB. To specify no maximum limit, omit this parameter.
         */
        max?: pulumi.Input<number>;
        /**
         * The minimum amount of memory per vCPU, in GiB. To specify no minimum limit, omit this parameter.
         */
        min?: pulumi.Input<number>;
    }
    interface Ec2FleetMemoryMiBRequestArgs {
        /**
         * The maximum amount of memory, in MiB. To specify no maximum limit, omit this parameter.
         */
        max?: pulumi.Input<number>;
        /**
         * The minimum amount of memory, in MiB. To specify no minimum limit, specify `0` .
         */
        min?: pulumi.Input<number>;
    }
    interface Ec2FleetNetworkBandwidthGbpsRequestArgs {
        /**
         * The maximum amount of network bandwidth, in Gbps. To specify no maximum limit, omit this parameter.
         */
        max?: pulumi.Input<number>;
        /**
         * The minimum amount of network bandwidth, in Gbps. To specify no minimum limit, omit this parameter.
         */
        min?: pulumi.Input<number>;
    }
    interface Ec2FleetNetworkInterfaceCountRequestArgs {
        /**
         * The maximum number of network interfaces. To specify no maximum limit, omit this parameter.
         */
        max?: pulumi.Input<number>;
        /**
         * The minimum number of network interfaces. To specify no minimum limit, omit this parameter.
         */
        min?: pulumi.Input<number>;
    }
    interface Ec2FleetOnDemandOptionsRequestArgs {
        /**
         * The strategy that determines the order of the launch template overrides to use in fulfilling On-Demand capacity.
         *
         * `lowest-price` - EC2 Fleet uses price to determine the order, launching the lowest price first.
         *
         * `prioritized` - EC2 Fleet uses the priority that you assigned to each launch template override, launching the highest priority first.
         *
         * Default: `lowest-price`
         */
        allocationStrategy?: pulumi.Input<string>;
        /**
         * The strategy for using unused Capacity Reservations for fulfilling On-Demand capacity.
         *
         * Supported only for fleets of type `instant` .
         */
        capacityReservationOptions?: pulumi.Input<inputs.ec2.Ec2FleetCapacityReservationOptionsRequestArgs>;
        /**
         * The maximum amount per hour for On-Demand Instances that you're willing to pay.
         *
         * > If your fleet includes T instances that are configured as `unlimited` , and if their average CPU usage exceeds the baseline utilization, you will incur a charge for surplus credits. The `MaxTotalPrice` does not account for surplus credits, and, if you use surplus credits, your final cost might be higher than what you specified for `MaxTotalPrice` . For more information, see [Surplus credits can incur charges](https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/burstable-performance-instances-unlimited-mode-concepts.html#unlimited-mode-surplus-credits) in the *Amazon EC2 User Guide* .
         */
        maxTotalPrice?: pulumi.Input<string>;
        /**
         * The minimum target capacity for On-Demand Instances in the fleet. If this minimum capacity isn't reached, no instances are launched.
         *
         * Constraints: Maximum value of `1000` . Supported only for fleets of type `instant` .
         *
         * At least one of the following must be specified: `SingleAvailabilityZone` | `SingleInstanceType`
         */
        minTargetCapacity?: pulumi.Input<number>;
        /**
         * Indicates that the fleet launches all On-Demand Instances into a single Availability Zone.
         *
         * Supported only for fleets of type `instant` .
         */
        singleAvailabilityZone?: pulumi.Input<boolean>;
        /**
         * Indicates that the fleet uses a single instance type to launch all On-Demand Instances in the fleet.
         *
         * Supported only for fleets of type `instant` .
         */
        singleInstanceType?: pulumi.Input<boolean>;
    }
    interface Ec2FleetPerformanceFactorReferenceRequestArgs {
        /**
         * The instance family to use as a baseline reference.
         *
         * > Ensure that you specify the correct value for the instance family. The instance family is everything before the period ( `.` ) in the instance type name. For example, in the instance type `c6i.large` , the instance family is `c6i` , not `c6` . For more information, see [Amazon EC2 instance type naming conventions](https://docs.aws.amazon.com/ec2/latest/instancetypes/instance-type-names.html) in *Amazon EC2 Instance Types* .
         *
         * The following instance families are *not supported* for performance protection:
         *
         * - `c1`
         * - `g3` | `g3s`
         * - `hpc7g`
         * - `m1` | `m2`
         * - `mac1` | `mac2` | `mac2-m1ultra` | `mac2-m2` | `mac2-m2pro`
         * - `p3dn` | `p4d` | `p5`
         * - `t1`
         * - `u-12tb1` | `u-18tb1` | `u-24tb1` | `u-3tb1` | `u-6tb1` | `u-9tb1` | `u7i-12tb` | `u7in-16tb` | `u7in-24tb` | `u7in-32tb`
         *
         * If you enable performance protection by specifying a supported instance family, the returned instance types will exclude the above unsupported instance families.
         *
         * If you specify an unsupported instance family as a value for baseline performance, the API returns an empty response response for [GetInstanceTypesFromInstanceRequirements](https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_GetInstanceTypesFromInstanceRequirements.html) and an exception for [CreateFleet](https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_CreateFleet.html) , [RequestSpotFleet](https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_RequestSpotFleet.html) , [ModifyFleet](https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_ModifyFleet.html) , and [ModifySpotFleetRequest](https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_ModifySpotFleetRequest.html) .
         */
        instanceFamily?: pulumi.Input<string>;
    }
    interface Ec2FleetPlacementArgs {
        /**
         * The affinity setting for the instance on the Dedicated Host.
         *
         * This parameter is not supported for [CreateFleet](https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_CreateFleet) or [ImportInstance](https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_ImportInstance.html) .
         */
        affinity?: pulumi.Input<string>;
        /**
         * The Availability Zone of the instance.
         *
         * If not specified, an Availability Zone will be automatically chosen for you based on the load balancing criteria for the Region.
         *
         * This parameter is not supported for [CreateFleet](https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_CreateFleet) .
         */
        availabilityZone?: pulumi.Input<string>;
        /**
         * The name of the placement group that the instance is in. If you specify `GroupName` , you can't specify `GroupId` .
         */
        groupName?: pulumi.Input<string>;
        /**
         * The ID of the Dedicated Host on which the instance resides.
         *
         * This parameter is not supported for [CreateFleet](https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_CreateFleet) or [ImportInstance](https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_ImportInstance.html) .
         */
        hostId?: pulumi.Input<string>;
        /**
         * The ARN of the host resource group in which to launch the instances.
         *
         * If you specify this parameter, either omit the *Tenancy* parameter or set it to `host` .
         *
         * This parameter is not supported for [CreateFleet](https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_CreateFleet) .
         */
        hostResourceGroupArn?: pulumi.Input<string>;
        /**
         * The number of the partition that the instance is in. Valid only if the placement group strategy is set to `partition` .
         *
         * This parameter is not supported for [CreateFleet](https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_CreateFleet) .
         */
        partitionNumber?: pulumi.Input<number>;
        /**
         * Reserved for future use.
         */
        spreadDomain?: pulumi.Input<string>;
        /**
         * The tenancy of the instance. An instance with a tenancy of `dedicated` runs on single-tenant hardware.
         *
         * This parameter is not supported for [CreateFleet](https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_CreateFleet) . The `host` tenancy is not supported for [ImportInstance](https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_ImportInstance.html) or for T3 instances that are configured for the `unlimited` CPU credit option.
         */
        tenancy?: pulumi.Input<string>;
    }
    interface Ec2FleetSpotOptionsRequestArgs {
        /**
         * Indicates how to allocate the target Spot Instance capacity across the Spot Instance pools specified by the EC2 Fleet.
         *
         * If the allocation strategy is `lowestPrice` , EC2 Fleet launches instances from the Spot Instance pools with the lowest price. This is the default allocation strategy.
         *
         * If the allocation strategy is `diversified` , EC2 Fleet launches instances from all the Spot Instance pools that you specify.
         *
         * If the allocation strategy is `capacityOptimized` , EC2 Fleet launches instances from Spot Instance pools that are optimally chosen based on the available Spot Instance capacity.
         *
         * *Allowed Values* : `lowestPrice` | `diversified` | `capacityOptimized` | `capacityOptimizedPrioritized`
         */
        allocationStrategy?: pulumi.Input<enums.ec2.Ec2FleetSpotOptionsRequestAllocationStrategy>;
        /**
         * The behavior when a Spot Instance is interrupted.
         *
         * Default: `terminate`
         */
        instanceInterruptionBehavior?: pulumi.Input<enums.ec2.Ec2FleetSpotOptionsRequestInstanceInterruptionBehavior>;
        /**
         * The number of Spot pools across which to allocate your target Spot capacity. Supported only when Spot `AllocationStrategy` is set to `lowest-price` . EC2 Fleet selects the cheapest Spot pools and evenly allocates your target Spot capacity across the number of Spot pools that you specify.
         *
         * Note that EC2 Fleet attempts to draw Spot Instances from the number of pools that you specify on a best effort basis. If a pool runs out of Spot capacity before fulfilling your target capacity, EC2 Fleet will continue to fulfill your request by drawing from the next cheapest pool. To ensure that your target capacity is met, you might receive Spot Instances from more than the number of pools that you specified. Similarly, if most of the pools have no Spot capacity, you might receive your full target capacity from fewer than the number of pools that you specified.
         */
        instancePoolsToUseCount?: pulumi.Input<number>;
        /**
         * The strategies for managing your Spot Instances that are at an elevated risk of being interrupted.
         */
        maintenanceStrategies?: pulumi.Input<inputs.ec2.Ec2FleetMaintenanceStrategiesArgs>;
        /**
         * The maximum amount per hour for Spot Instances that you're willing to pay. We do not recommend using this parameter because it can lead to increased interruptions. If you do not specify this parameter, you will pay the current Spot price.
         *
         * > If you specify a maximum price, your Spot Instances will be interrupted more frequently than if you do not specify this parameter. > If your fleet includes T instances that are configured as `unlimited` , and if their average CPU usage exceeds the baseline utilization, you will incur a charge for surplus credits. The `MaxTotalPrice` does not account for surplus credits, and, if you use surplus credits, your final cost might be higher than what you specified for `MaxTotalPrice` . For more information, see [Surplus credits can incur charges](https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/burstable-performance-instances-unlimited-mode-concepts.html#unlimited-mode-surplus-credits) in the *Amazon EC2 User Guide* .
         */
        maxTotalPrice?: pulumi.Input<string>;
        /**
         * The minimum target capacity for Spot Instances in the fleet. If this minimum capacity isn't reached, no instances are launched.
         *
         * Constraints: Maximum value of `1000` . Supported only for fleets of type `instant` .
         *
         * At least one of the following must be specified: `SingleAvailabilityZone` | `SingleInstanceType`
         */
        minTargetCapacity?: pulumi.Input<number>;
        /**
         * Indicates that the fleet launches all Spot Instances into a single Availability Zone.
         *
         * Supported only for fleets of type `instant` .
         */
        singleAvailabilityZone?: pulumi.Input<boolean>;
        /**
         * Indicates that the fleet uses a single instance type to launch all Spot Instances in the fleet.
         *
         * Supported only for fleets of type `instant` .
         */
        singleInstanceType?: pulumi.Input<boolean>;
    }
    interface Ec2FleetTagArgs {
        /**
         * The tag key.
         */
        key: pulumi.Input<string>;
        /**
         * The tag value.
         */
        value: pulumi.Input<string>;
    }
    interface Ec2FleetTagSpecificationArgs {
        /**
         * The type of resource to tag.
         */
        resourceType?: pulumi.Input<enums.ec2.Ec2FleetTagSpecificationResourceType>;
        /**
         * The tags to apply to the resource.
         */
        tags?: pulumi.Input<pulumi.Input<inputs.ec2.Ec2FleetTagArgs>[]>;
    }
    interface Ec2FleetTargetCapacitySpecificationRequestArgs {
        /**
         * The default target capacity type.
         */
        defaultTargetCapacityType?: pulumi.Input<enums.ec2.Ec2FleetTargetCapacitySpecificationRequestDefaultTargetCapacityType>;
        /**
         * The number of On-Demand units to request.
         */
        onDemandTargetCapacity?: pulumi.Input<number>;
        /**
         * The number of Spot units to request.
         */
        spotTargetCapacity?: pulumi.Input<number>;
        /**
         * The unit for the target capacity. You can specify this parameter only when using attributed-based instance type selection.
         *
         * Default: `units` (the number of instances)
         */
        targetCapacityUnitType?: pulumi.Input<enums.ec2.Ec2FleetTargetCapacitySpecificationRequestTargetCapacityUnitType>;
        /**
         * The number of units to request, filled using the default target capacity type.
         */
        totalTargetCapacity: pulumi.Input<number>;
    }
    interface Ec2FleetTotalLocalStorageGbRequestArgs {
        /**
         * The maximum amount of total local storage, in GB. To specify no maximum limit, omit this parameter.
         */
        max?: pulumi.Input<number>;
        /**
         * The minimum amount of total local storage, in GB. To specify no minimum limit, omit this parameter.
         */
        min?: pulumi.Input<number>;
    }
    interface Ec2FleetVCpuCountRangeRequestArgs {
        /**
         * The maximum number of vCPUs. To specify no maximum limit, omit this parameter.
         */
        max?: pulumi.Input<number>;
        /**
         * The minimum number of vCPUs. To specify no minimum limit, specify `0` .
         */
        min?: pulumi.Input<number>;
    }
    /**
     * Indicates whether the instance is enabled for AWS Nitro Enclaves.
     */
    interface EnclaveOptionsPropertiesArgs {
        /**
         * If this parameter is set to true, the instance is enabled for AWS Nitro Enclaves; otherwise, it is not enabled for AWS Nitro Enclaves.
         */
        enabled?: pulumi.Input<boolean>;
    }
    /**
     * Indicates whether an instance is enabled for hibernation.
     */
    interface HibernationOptionsPropertiesArgs {
        /**
         * If you set this parameter to true, your instance is enabled for hibernation.
         */
        configured?: pulumi.Input<boolean>;
    }
    interface InstanceAssociationParameterArgs {
        /**
         * The name of an input parameter that is in the associated SSM document.
         */
        key: pulumi.Input<string>;
        /**
         * The value of an input parameter.
         */
        value: pulumi.Input<pulumi.Input<string>[]>;
    }
    interface InstanceBlockDeviceMappingArgs {
        /**
         * The device name (for example, /dev/sdh or xvdh).
         */
        deviceName: pulumi.Input<string>;
        /**
         * Parameters used to automatically set up EBS volumes when the instance is launched.
         */
        ebs?: pulumi.Input<inputs.ec2.InstanceEbsArgs>;
        /**
         * To omit the device from the block device mapping, specify an empty string.
         *
         * > After the instance is running, modifying this parameter results in instance [replacement](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/using-cfn-updating-stacks-update-behaviors.html#update-replacement) .
         */
        noDevice?: any;
        /**
         * The virtual device name ( `ephemeral` N). The name must be in the form `ephemeral` *X* where *X* is a number starting from zero (0). For example, an instance type with 2 available instance store volumes can specify mappings for `ephemeral0` and `ephemeral1` . The number of available instance store volumes depends on the instance type. After you connect to the instance, you must mount the volume.
         *
         * NVMe instance store volumes are automatically enumerated and assigned a device name. Including them in your block device mapping has no effect.
         *
         * *Constraints* : For M3 instances, you must specify instance store volumes in the block device mapping for the instance. When you launch an M3 instance, we ignore any instance store volumes specified in the block device mapping for the AMI.
         *
         * > After the instance is running, modifying this parameter results in instance [replacement](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/using-cfn-updating-stacks-update-behaviors.html#update-replacement) .
         */
        virtualName?: pulumi.Input<string>;
    }
    interface InstanceEbsArgs {
        /**
         * Indicates whether the EBS volume is deleted on instance termination.
         */
        deleteOnTermination?: pulumi.Input<boolean>;
        /**
         * Indicates whether the volume should be encrypted.
         */
        encrypted?: pulumi.Input<boolean>;
        /**
         * The number of I/O operations per second (IOPS). For gp3, io1, and io2 volumes, this represents the number of IOPS that are provisioned for the volume. For gp2 volumes, this represents the baseline performance of the volume and the rate at which the volume accumulates I/O credits for bursting.
         */
        iops?: pulumi.Input<number>;
        /**
         * The identifier of the AWS Key Management Service (AWS KMS) customer managed CMK to use for Amazon EBS encryption. If KmsKeyId is specified, the encrypted state must be true. If the encrypted state is true but you do not specify KmsKeyId, your AWS managed CMK for EBS is used.
         */
        kmsKeyId?: pulumi.Input<string>;
        /**
         * The ID of the snapshot.
         */
        snapshotId?: pulumi.Input<string>;
        /**
         * The size of the volume, in GiBs. You must specify either a snapshot ID or a volume size. If you specify a snapshot, the default is the snapshot size. You can specify a volume size that is equal to or larger than the snapshot size.
         */
        volumeSize?: pulumi.Input<number>;
        /**
         * The volume type.
         */
        volumeType?: pulumi.Input<string>;
    }
    interface InstanceElasticGpuSpecificationArgs {
        /**
         * The type of Elastic Graphics accelerator.
         */
        type: pulumi.Input<string>;
    }
    interface InstanceElasticInferenceAcceleratorArgs {
        /**
         * The number of elastic inference accelerators to attach to the instance.
         */
        count?: pulumi.Input<number>;
        /**
         * The type of elastic inference accelerator.
         */
        type: pulumi.Input<string>;
    }
    /**
     * Specifies the ENA Express settings for the network interface that's attached to the instance.
     */
    interface InstanceEnaSrdSpecificationArgs {
        /**
         * Specifies whether ENA Express is enabled for the network interface when you launch an instance.
         */
        enaSrdEnabled?: pulumi.Input<boolean>;
        /**
         * Configures ENA Express for UDP network traffic.
         */
        enaSrdUdpSpecification?: pulumi.Input<inputs.ec2.InstanceEnaSrdUdpSpecificationArgs>;
    }
    /**
     * Contains ENA Express settings for UDP network traffic for the network interface that's attached to the instance.
     */
    interface InstanceEnaSrdUdpSpecificationArgs {
        /**
         * Indicates whether UDP traffic uses ENA Express for your instance.
         */
        enaSrdUdpEnabled?: pulumi.Input<boolean>;
    }
    interface InstanceIpv6AddressArgs {
        /**
         * The IPv6 address.
         */
        ipv6Address: pulumi.Input<string>;
    }
    interface InstanceLaunchTemplateSpecificationArgs {
        /**
         * The ID of the launch template. You must specify the LaunchTemplateName or the LaunchTemplateId, but not both.
         */
        launchTemplateId?: pulumi.Input<string>;
        /**
         * The name of the launch template. You must specify the LaunchTemplateName or the LaunchTemplateId, but not both.
         */
        launchTemplateName?: pulumi.Input<string>;
        /**
         * The version number of the launch template.
         */
        version?: pulumi.Input<string>;
    }
    interface InstanceLicenseSpecificationArgs {
        /**
         * The Amazon Resource Name (ARN) of the license configuration.
         */
        licenseConfigurationArn: pulumi.Input<string>;
    }
    interface InstanceNetworkInterfaceArgs {
        /**
         * Not currently supported by AWS CloudFormation.
         */
        associateCarrierIpAddress?: pulumi.Input<boolean>;
        /**
         * Indicates whether to assign a public IPv4 address to an instance you launch in a VPC.
         */
        associatePublicIpAddress?: pulumi.Input<boolean>;
        /**
         * If set to true, the interface is deleted when the instance is terminated.
         */
        deleteOnTermination?: pulumi.Input<boolean>;
        /**
         * The description of the network interface.
         */
        description?: pulumi.Input<string>;
        /**
         * The position of the network interface in the attachment order. A primary network interface has a device index of 0.
         */
        deviceIndex: pulumi.Input<string>;
        /**
         * Configures ENA Express for UDP network traffic.
         */
        enaSrdSpecification?: pulumi.Input<inputs.ec2.InstanceEnaSrdSpecificationArgs>;
        /**
         * The IDs of the security groups for the network interface.
         */
        groupSet?: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * A number of IPv6 addresses to assign to the network interface.
         */
        ipv6AddressCount?: pulumi.Input<number>;
        /**
         * The IPv6 addresses associated with the network interface.
         */
        ipv6Addresses?: pulumi.Input<pulumi.Input<inputs.ec2.InstanceIpv6AddressArgs>[]>;
        /**
         * The ID of the network interface.
         */
        networkInterfaceId?: pulumi.Input<string>;
        /**
         * The private IPv4 address of the network interface.
         */
        privateIpAddress?: pulumi.Input<string>;
        /**
         * One or more private IPv4 addresses to assign to the network interface.
         */
        privateIpAddresses?: pulumi.Input<pulumi.Input<inputs.ec2.InstancePrivateIpAddressSpecificationArgs>[]>;
        /**
         * The number of secondary private IPv4 addresses.
         */
        secondaryPrivateIpAddressCount?: pulumi.Input<number>;
        /**
         * The ID of the subnet.
         */
        subnetId?: pulumi.Input<string>;
    }
    interface InstancePrivateDnsNameOptionsArgs {
        /**
         * Indicates whether to respond to DNS queries for instance hostnames with DNS A records. For more information, see Amazon EC2 instance hostname types in the Amazon Elastic Compute Cloud User Guide.
         */
        enableResourceNameDnsARecord?: pulumi.Input<boolean>;
        /**
         * Indicates whether to respond to DNS queries for instance hostnames with DNS AAAA records. For more information, see Amazon EC2 instance hostname types in the Amazon Elastic Compute Cloud User Guide.
         */
        enableResourceNameDnsAaaaRecord?: pulumi.Input<boolean>;
        /**
         * The type of hostnames to assign to instances in the subnet at launch. For IPv4 only subnets, an instance DNS name must be based on the instance IPv4 address. For IPv6 only subnets, an instance DNS name must be based on the instance ID. For dual-stack subnets, you can specify whether DNS names use the instance IPv4 address or the instance ID. For more information, see Amazon EC2 instance hostname types in the Amazon Elastic Compute Cloud User Guide.
         */
        hostnameType?: pulumi.Input<enums.ec2.InstancePrivateDnsNameOptionsHostnameType>;
    }
    interface InstancePrivateIpAddressSpecificationArgs {
        /**
         * Indicates whether the private IPv4 address is the primary private IPv4 address. Only one IPv4 address can be designated as primary.
         */
        primary: pulumi.Input<boolean>;
        /**
         * The private IPv4 addresses.
         */
        privateIpAddress: pulumi.Input<string>;
    }
    interface InstanceSsmAssociationArgs {
        /**
         * The input parameter values to use with the associated SSM document.
         */
        associationParameters?: pulumi.Input<pulumi.Input<inputs.ec2.InstanceAssociationParameterArgs>[]>;
        /**
         * The name of an SSM document to associate with the instance.
         */
        documentName: pulumi.Input<string>;
    }
    interface InstanceVolumeArgs {
        /**
         * The device name (for example, /dev/sdh or xvdh).
         */
        device: pulumi.Input<string>;
        /**
         * The ID of the EBS volume. The volume and instance must be within the same Availability Zone.
         */
        volumeId: pulumi.Input<string>;
    }
    /**
     * The regions IPAM is enabled for. Allows pools to be created in these regions, as well as enabling monitoring
     */
    interface IpamOperatingRegionArgs {
        /**
         * The name of the region.
         */
        regionName: pulumi.Input<string>;
    }
    /**
     * If your IPAM is integrated with AWS Organizations and you add an organizational unit (OU) exclusion, IPAM will not manage the IP addresses in accounts in that OU exclusion.
     */
    interface IpamOrganizationalUnitExclusionArgs {
        /**
         * An AWS Organizations entity path. Build the path for the OU(s) using AWS Organizations IDs separated by a '/'. Include all child OUs by ending the path with '/*'.
         */
        organizationsEntityPath: pulumi.Input<string>;
    }
    /**
     * An address space to be inserted into this pool. All allocations must be made from this address space.
     */
    interface IpamPoolProvisionedCidrArgs {
        /**
         * The CIDR provisioned to the IPAM pool. A CIDR is a representation of an IP address and its associated network mask (or netmask) and refers to a range of IP addresses. An IPv4 CIDR example is `10.24.34.0/23` . An IPv6 CIDR example is `2001:DB8::/32` .
         */
        cidr: pulumi.Input<string>;
    }
    /**
     * The resource associated with this pool's space. Depending on the ResourceType, setting a SourceResource changes which space can be provisioned in this pool and which types of resources can receive allocations
     */
    interface IpamPoolSourceResourceArgs {
        /**
         * The source resource ID.
         */
        resourceId: pulumi.Input<string>;
        /**
         * The source resource owner.
         */
        resourceOwner: pulumi.Input<string>;
        /**
         * The source resource Region.
         */
        resourceRegion: pulumi.Input<string>;
        /**
         * The source resource type.
         */
        resourceType: pulumi.Input<string>;
    }
    /**
     * A key-value pair to associate with a resource.
     */
    interface IpamPoolTagArgs {
        /**
         * The key name of the tag. You can specify a value that is 1 to 128 Unicode characters in length and cannot be prefixed with aws:. You can use any of the following characters: the set of Unicode letters, digits, whitespace, _, ., /, =, +, and -.
         */
        key: pulumi.Input<string>;
        /**
         * The value for the tag. You can specify a value that is 0 to 256 Unicode characters in length and cannot be prefixed with aws:. You can use any of the following characters: the set of Unicode letters, digits, whitespace, _, ., /, =, +, and -.
         */
        value: pulumi.Input<string>;
    }
    /**
     * The regions IPAM Resource Discovery is enabled for. Allows for monitoring.
     */
    interface IpamResourceDiscoveryIpamOperatingRegionArgs {
        /**
         * The name of the region.
         */
        regionName: pulumi.Input<string>;
    }
    /**
     * If your IPAM is integrated with AWS Organizations and you add an organizational unit (OU) exclusion, IPAM will not manage the IP addresses in accounts in that OU exclusion.
     */
    interface IpamResourceDiscoveryOrganizationalUnitExclusionArgs {
        /**
         * An AWS Organizations entity path. Build the path for the OU(s) using AWS Organizations IDs separated by a '/'. Include all child OUs by ending the path with '/*'.
         */
        organizationsEntityPath: pulumi.Input<string>;
    }
    /**
     * The minimum and maximum number of accelerators (GPUs, FPGAs, or AWS Inferentia chips) on an instance.
     */
    interface LaunchTemplateAcceleratorCountArgs {
        /**
         * The maximum number of accelerators. To specify no maximum limit, omit this parameter. To exclude accelerator-enabled instance types, set ``Max`` to ``0``.
         */
        max?: pulumi.Input<number>;
        /**
         * The minimum number of accelerators. To specify no minimum limit, omit this parameter.
         */
        min?: pulumi.Input<number>;
    }
    /**
     * The minimum and maximum amount of total accelerator memory, in MiB.
     */
    interface LaunchTemplateAcceleratorTotalMemoryMiBArgs {
        /**
         * The maximum amount of accelerator memory, in MiB. To specify no maximum limit, omit this parameter.
         */
        max?: pulumi.Input<number>;
        /**
         * The minimum amount of accelerator memory, in MiB. To specify no minimum limit, omit this parameter.
         */
        min?: pulumi.Input<number>;
    }
    /**
     * The minimum and maximum baseline bandwidth to Amazon EBS, in Mbps. For more information, see [Amazon EBS–optimized instances](https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/ebs-optimized.html) in the *Amazon EC2 User Guide*.
     */
    interface LaunchTemplateBaselineEbsBandwidthMbpsArgs {
        /**
         * The maximum baseline bandwidth, in Mbps. To specify no maximum limit, omit this parameter.
         */
        max?: pulumi.Input<number>;
        /**
         * The minimum baseline bandwidth, in Mbps. To specify no minimum limit, omit this parameter.
         */
        min?: pulumi.Input<number>;
    }
    /**
     * The baseline performance to consider, using an instance family as a baseline reference. The instance family establishes the lowest acceptable level of performance. Amazon EC2 uses this baseline to guide instance type selection, but there is no guarantee that the selected instance types will always exceed the baseline for every application.
     *  Currently, this parameter only supports CPU performance as a baseline performance factor. For example, specifying ``c6i`` would use the CPU performance of the ``c6i`` family as the baseline reference.
     */
    interface LaunchTemplateBaselinePerformanceFactorsArgs {
        /**
         * The CPU performance to consider, using an instance family as the baseline reference.
         */
        cpu?: pulumi.Input<inputs.ec2.LaunchTemplateCpuArgs>;
    }
    /**
     * Specifies a block device mapping for a launch template. You must specify ``DeviceName`` plus exactly one of the following properties: ``Ebs``, ``NoDevice``, or ``VirtualName``.
     *   ``BlockDeviceMapping`` is a property of [AWS::EC2::LaunchTemplate LaunchTemplateData](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-ec2-launchtemplate-launchtemplatedata.html).
     */
    interface LaunchTemplateBlockDeviceMappingArgs {
        /**
         * The device name (for example, /dev/sdh or xvdh).
         */
        deviceName?: pulumi.Input<string>;
        /**
         * Parameters used to automatically set up EBS volumes when the instance is launched.
         */
        ebs?: pulumi.Input<inputs.ec2.LaunchTemplateEbsArgs>;
        /**
         * To omit the device from the block device mapping, specify an empty string.
         */
        noDevice?: pulumi.Input<string>;
        /**
         * The virtual device name (ephemeralN). Instance store volumes are numbered starting from 0. An instance type with 2 available instance store volumes can specify mappings for ephemeral0 and ephemeral1. The number of available instance store volumes depends on the instance type. After you connect to the instance, you must mount the volume.
         */
        virtualName?: pulumi.Input<string>;
    }
    /**
     * Specifies an instance's Capacity Reservation targeting option. You can specify only one option at a time.
     *   ``CapacityReservationSpecification`` is a property of [AWS::EC2::LaunchTemplate LaunchTemplateData](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-ec2-launchtemplate-launchtemplatedata.html).
     */
    interface LaunchTemplateCapacityReservationSpecificationArgs {
        /**
         * Indicates the instance's Capacity Reservation preferences. Possible preferences include:
         *   +   ``capacity-reservations-only`` - The instance will only run in a Capacity Reservation or Capacity Reservation group. If capacity isn't available, the instance will fail to launch.
         *   +   ``open`` - The instance can run in any ``open`` Capacity Reservation that has matching attributes (instance type, platform, Availability Zone, tenancy).
         *   +   ``none`` - The instance avoids running in a Capacity Reservation even if one is available. The instance runs in On-Demand capacity.
         */
        capacityReservationPreference?: pulumi.Input<string>;
        /**
         * Information about the target Capacity Reservation or Capacity Reservation group.
         */
        capacityReservationTarget?: pulumi.Input<inputs.ec2.LaunchTemplateCapacityReservationTargetArgs>;
    }
    /**
     * Specifies a target Capacity Reservation.
     *   ``CapacityReservationTarget`` is a property of the [Amazon EC2 LaunchTemplate LaunchTemplateData](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-ec2-launchtemplate-launchtemplatedata.html) property type.
     */
    interface LaunchTemplateCapacityReservationTargetArgs {
        /**
         * The ID of the Capacity Reservation in which to run the instance.
         */
        capacityReservationId?: pulumi.Input<string>;
        /**
         * The ARN of the Capacity Reservation resource group in which to run the instance.
         */
        capacityReservationResourceGroupArn?: pulumi.Input<string>;
    }
    /**
     * A security group connection tracking specification that enables you to set the idle timeout for connection tracking on an Elastic network interface. For more information, see [Connection tracking timeouts](https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/security-group-connection-tracking.html#connection-tracking-timeouts) in the *Amazon EC2 User Guide*.
     */
    interface LaunchTemplateConnectionTrackingSpecificationArgs {
        /**
         * Timeout (in seconds) for idle TCP connections in an established state. Min: 60 seconds. Max: 432000 seconds (5 days). Default: 432000 seconds. Recommended: Less than 432000 seconds.
         */
        tcpEstablishedTimeout?: pulumi.Input<number>;
        /**
         * Timeout (in seconds) for idle UDP flows classified as streams which have seen more than one request-response transaction. Min: 60 seconds. Max: 180 seconds (3 minutes). Default: 180 seconds.
         */
        udpStreamTimeout?: pulumi.Input<number>;
        /**
         * Timeout (in seconds) for idle UDP flows that have seen traffic only in a single direction or a single request-response transaction. Min: 30 seconds. Max: 60 seconds. Default: 30 seconds.
         */
        udpTimeout?: pulumi.Input<number>;
    }
    /**
     * Specifies the CPU performance to consider when using an instance family as the baseline reference.
     */
    interface LaunchTemplateCpuArgs {
        /**
         * The instance family to use as the baseline reference for CPU performance. All instance types that match your specified attributes are compared against the CPU performance of the referenced instance family, regardless of CPU manufacturer or architecture differences.
         */
        references?: pulumi.Input<pulumi.Input<inputs.ec2.LaunchTemplateReferenceArgs>[]>;
    }
    /**
     * Specifies the CPU options for an instance. For more information, see [Optimize CPU options](https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/instance-optimize-cpu.html) in the *User Guide*.
     *   ``CpuOptions`` is a property of [AWS::EC2::LaunchTemplate LaunchTemplateData](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-ec2-launchtemplate-launchtemplatedata.html).
     */
    interface LaunchTemplateCpuOptionsArgs {
        /**
         * Indicates whether to enable the instance for AMD SEV-SNP. AMD SEV-SNP is supported with M6a, R6a, and C6a instance types only. For more information, see [AMD SEV-SNP for Amazon EC2 instances](https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/sev-snp.html).
         */
        amdSevSnp?: pulumi.Input<enums.ec2.LaunchTemplateCpuOptionsAmdSevSnp>;
        /**
         * The number of CPU cores for the instance.
         */
        coreCount?: pulumi.Input<number>;
        /**
         * The number of threads per CPU core. To disable multithreading for the instance, specify a value of ``1``. Otherwise, specify the default value of ``2``.
         */
        threadsPerCore?: pulumi.Input<number>;
    }
    /**
     * Specifies the credit option for CPU usage of a T2, T3, or T3a instance.
     *   ``CreditSpecification`` is a property of [AWS::EC2::LaunchTemplate LaunchTemplateData](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-ec2-launchtemplate-launchtemplatedata.html).
     */
    interface LaunchTemplateCreditSpecificationArgs {
        /**
         * The credit option for CPU usage of a T instance.
         *  Valid values: ``standard`` | ``unlimited``
         */
        cpuCredits?: pulumi.Input<string>;
    }
    /**
     * The information to include in the launch template.
     *   You must specify at least one parameter for the launch template data.
     */
    interface LaunchTemplateDataArgs {
        /**
         * The block device mapping.
         */
        blockDeviceMappings?: pulumi.Input<pulumi.Input<inputs.ec2.LaunchTemplateBlockDeviceMappingArgs>[]>;
        /**
         * The Capacity Reservation targeting option. If you do not specify this parameter, the instance's Capacity Reservation preference defaults to ``open``, which enables it to run in any open Capacity Reservation that has matching attributes (instance type, platform, Availability Zone).
         */
        capacityReservationSpecification?: pulumi.Input<inputs.ec2.LaunchTemplateCapacityReservationSpecificationArgs>;
        /**
         * The CPU options for the instance. For more information, see [CPU options for Amazon EC2 instances](https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/instance-optimize-cpu.html) in the *Amazon EC2 User Guide*.
         */
        cpuOptions?: pulumi.Input<inputs.ec2.LaunchTemplateCpuOptionsArgs>;
        /**
         * The credit option for CPU usage of the instance. Valid only for T instances.
         */
        creditSpecification?: pulumi.Input<inputs.ec2.LaunchTemplateCreditSpecificationArgs>;
        /**
         * Indicates whether to enable the instance for stop protection. For more information, see [Enable stop protection for your EC2 instances](https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/ec2-stop-protection.html) in the *Amazon EC2 User Guide*.
         */
        disableApiStop?: pulumi.Input<boolean>;
        /**
         * Indicates whether termination protection is enabled for the instance. The default is ``false``, which means that you can terminate the instance using the Amazon EC2 console, command line tools, or API. You can enable termination protection when you launch an instance, while the instance is running, or while the instance is stopped.
         */
        disableApiTermination?: pulumi.Input<boolean>;
        /**
         * Indicates whether the instance is optimized for Amazon EBS I/O. This optimization provides dedicated throughput to Amazon EBS and an optimized configuration stack to provide optimal Amazon EBS I/O performance. This optimization isn't available with all instance types. Additional usage charges apply when using an EBS-optimized instance.
         */
        ebsOptimized?: pulumi.Input<boolean>;
        /**
         * Deprecated.
         *   Amazon Elastic Graphics reached end of life on January 8, 2024.
         */
        elasticGpuSpecifications?: pulumi.Input<pulumi.Input<inputs.ec2.LaunchTemplateElasticGpuSpecificationArgs>[]>;
        /**
         * Amazon Elastic Inference is no longer available.
         *   An elastic inference accelerator to associate with the instance. Elastic inference accelerators are a resource you can attach to your Amazon EC2 instances to accelerate your Deep Learning (DL) inference workloads.
         *  You cannot specify accelerators from different generations in the same request.
         */
        elasticInferenceAccelerators?: pulumi.Input<pulumi.Input<inputs.ec2.LaunchTemplateElasticInferenceAcceleratorArgs>[]>;
        /**
         * Indicates whether the instance is enabled for AWS Nitro Enclaves. For more information, see [What is Nitro Enclaves?](https://docs.aws.amazon.com/enclaves/latest/user/nitro-enclave.html) in the *Nitro Enclaves User Guide*.
         *  You can't enable AWS Nitro Enclaves and hibernation on the same instance.
         */
        enclaveOptions?: pulumi.Input<inputs.ec2.LaunchTemplateEnclaveOptionsArgs>;
        /**
         * Indicates whether an instance is enabled for hibernation. This parameter is valid only if the instance meets the [hibernation prerequisites](https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/hibernating-prerequisites.html). For more information, see [Hibernate your Amazon EC2 instance](https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/Hibernate.html) in the *Amazon EC2 User Guide*.
         */
        hibernationOptions?: pulumi.Input<inputs.ec2.LaunchTemplateHibernationOptionsArgs>;
        /**
         * The name or Amazon Resource Name (ARN) of an IAM instance profile.
         */
        iamInstanceProfile?: pulumi.Input<inputs.ec2.LaunchTemplateIamInstanceProfileArgs>;
        /**
         * The ID of the AMI. Alternatively, you can specify a Systems Manager parameter, which will resolve to an AMI ID on launch.
         *  Valid formats:
         *   +   ``ami-0ac394d6a3example``
         *   +   ``resolve:ssm:parameter-name``
         *   +   ``resolve:ssm:parameter-name:version-number``
         *   +   ``resolve:ssm:parameter-name:label``
         *
         *  For more information, see [Use a Systems Manager parameter to find an AMI](https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/finding-an-ami.html#using-systems-manager-parameter-to-find-AMI) in the *Amazon Elastic Compute Cloud User Guide*.
         */
        imageId?: pulumi.Input<string>;
        /**
         * Indicates whether an instance stops or terminates when you initiate shutdown from the instance (using the operating system command for system shutdown).
         *  Default: ``stop``
         */
        instanceInitiatedShutdownBehavior?: pulumi.Input<string>;
        /**
         * The market (purchasing) option for the instances.
         */
        instanceMarketOptions?: pulumi.Input<inputs.ec2.LaunchTemplateInstanceMarketOptionsArgs>;
        /**
         * The attributes for the instance types. When you specify instance attributes, Amazon EC2 will identify instance types with these attributes.
         *  You must specify ``VCpuCount`` and ``MemoryMiB``. All other attributes are optional. Any unspecified optional attribute is set to its default.
         *  When you specify multiple attributes, you get instance types that satisfy all of the specified attributes. If you specify multiple values for an attribute, you get instance types that satisfy any of the specified values.
         *  To limit the list of instance types from which Amazon EC2 can identify matching instance types, you can use one of the following parameters, but not both in the same request:
         *   +   ``AllowedInstanceTypes`` - The instance types to include in the list. All other instance types are ignored, even if they match your specified attributes.
         *   +   ``ExcludedInstanceTypes`` - The instance types to exclude from the list, even if they match your specified attributes.
         *
         *   If you specify ``InstanceRequirements``, you can't specify ``InstanceType``.
         *  Attribute-based instance type selection is only supported when using Auto Scaling groups, EC2 Fleet, and Spot Fleet to launch instances. If you plan to use the launch template in the [launch instance wizard](https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/ec2-launch-instance-wizard.html), or with the [RunInstances](https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_RunInstances.html) API or [AWS::EC2::Instance](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-ec2-instance.html) AWS CloudFormation resource, you can't specify ``InstanceRequirements``.
         *   For more information, see [Specify attributes for instance type selection for EC2 Fleet or Spot Fleet](https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/ec2-fleet-attribute-based-instance-type-selection.html) and [Spot placement score](https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/spot-placement-score.html) in the *Amazon EC2 User Guide*.
         */
        instanceRequirements?: pulumi.Input<inputs.ec2.LaunchTemplateInstanceRequirementsArgs>;
        /**
         * The instance type. For more information, see [Amazon EC2 instance types](https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/instance-types.html) in the *Amazon EC2 User Guide*.
         *  If you specify ``InstanceType``, you can't specify ``InstanceRequirements``.
         */
        instanceType?: pulumi.Input<string>;
        /**
         * The ID of the kernel.
         *  We recommend that you use PV-GRUB instead of kernels and RAM disks. For more information, see [User Provided Kernels](https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/UserProvidedkernels.html) in the *Amazon EC2 User Guide*.
         */
        kernelId?: pulumi.Input<string>;
        /**
         * The name of the key pair. You can create a key pair using [CreateKeyPair](https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_CreateKeyPair.html) or [ImportKeyPair](https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_ImportKeyPair.html).
         *   If you do not specify a key pair, you can't connect to the instance unless you choose an AMI that is configured to allow users another way to log in.
         */
        keyName?: pulumi.Input<string>;
        /**
         * The license configurations.
         */
        licenseSpecifications?: pulumi.Input<pulumi.Input<inputs.ec2.LaunchTemplateLicenseSpecificationArgs>[]>;
        /**
         * The maintenance options of your instance.
         */
        maintenanceOptions?: pulumi.Input<inputs.ec2.LaunchTemplateMaintenanceOptionsArgs>;
        /**
         * The metadata options for the instance. For more information, see [Configure the Instance Metadata Service options](https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/configuring-instance-metadata-options.html) in the *Amazon EC2 User Guide*.
         */
        metadataOptions?: pulumi.Input<inputs.ec2.LaunchTemplateMetadataOptionsArgs>;
        /**
         * The monitoring for the instance.
         */
        monitoring?: pulumi.Input<inputs.ec2.LaunchTemplateMonitoringArgs>;
        /**
         * The network interfaces for the instance.
         */
        networkInterfaces?: pulumi.Input<pulumi.Input<inputs.ec2.LaunchTemplateNetworkInterfaceArgs>[]>;
        /**
         * The settings for the network performance options for the instance. For more information, see [EC2 instance bandwidth weighting configuration](https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/configure-bandwidth-weighting.html).
         */
        networkPerformanceOptions?: pulumi.Input<inputs.ec2.LaunchTemplateNetworkPerformanceOptionsArgs>;
        /**
         * The placement for the instance.
         */
        placement?: pulumi.Input<inputs.ec2.LaunchTemplatePlacementArgs>;
        /**
         * The hostname type for EC2 instances launched into this subnet and how DNS A and AAAA record queries should be handled. For more information, see [Amazon EC2 instance hostname types](https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/ec2-instance-naming.html) in the *User Guide*.
         */
        privateDnsNameOptions?: pulumi.Input<inputs.ec2.LaunchTemplatePrivateDnsNameOptionsArgs>;
        /**
         * The ID of the RAM disk.
         *   We recommend that you use PV-GRUB instead of kernels and RAM disks. For more information, see [User provided kernels](https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/UserProvidedkernels.html) in the *Amazon EC2 User Guide*.
         */
        ramDiskId?: pulumi.Input<string>;
        /**
         * The IDs of the security groups. You can specify the IDs of existing security groups and references to resources created by the stack template.
         *  If you specify a network interface, you must specify any security groups as part of the network interface instead.
         */
        securityGroupIds?: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * The names of the security groups. For a nondefault VPC, you must use security group IDs instead.
         *  If you specify a network interface, you must specify any security groups as part of the network interface instead of using this parameter.
         */
        securityGroups?: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * The tags to apply to resources that are created during instance launch.
         *  To tag the launch template itself, use [TagSpecifications](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-ec2-launchtemplate.html#cfn-ec2-launchtemplate-tagspecifications).
         */
        tagSpecifications?: pulumi.Input<pulumi.Input<inputs.ec2.TagSpecificationArgs>[]>;
        /**
         * The user data to make available to the instance. You must provide base64-encoded text. User data is limited to 16 KB. For more information, see [Run commands when you launch an EC2 instance with user data input](https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/user-data.html) in the *Amazon EC2 User Guide*.
         *  If you are creating the launch template for use with BATCH, the user data must be provided in the [MIME multi-part archive format](https://docs.aws.amazon.com/https://cloudinit.readthedocs.io/en/latest/topics/format.html#mime-multi-part-archive). For more information, see [Amazon EC2 user data in launch templates](https://docs.aws.amazon.com/batch/latest/userguide/launch-templates.html#lt-user-data) in the *User Guide*.
         */
        userData?: pulumi.Input<string>;
    }
    /**
     * Parameters for a block device for an EBS volume in an Amazon EC2 launch template.
     *   ``Ebs`` is a property of [AWS::EC2::LaunchTemplate BlockDeviceMapping](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-ec2-launchtemplate-blockdevicemapping.html).
     */
    interface LaunchTemplateEbsArgs {
        /**
         * Indicates whether the EBS volume is deleted on instance termination.
         */
        deleteOnTermination?: pulumi.Input<boolean>;
        /**
         * Indicates whether the EBS volume is encrypted. Encrypted volumes can only be attached to instances that support Amazon EBS encryption. If you are creating a volume from a snapshot, you can't specify an encryption value.
         */
        encrypted?: pulumi.Input<boolean>;
        /**
         * The number of I/O operations per second (IOPS). For ``gp3``, ``io1``, and ``io2`` volumes, this represents the number of IOPS that are provisioned for the volume. For ``gp2`` volumes, this represents the baseline performance of the volume and the rate at which the volume accumulates I/O credits for bursting.
         *  The following are the supported values for each volume type:
         *   +   ``gp3``: 3,000 - 16,000 IOPS
         *   +   ``io1``: 100 - 64,000 IOPS
         *   +   ``io2``: 100 - 256,000 IOPS
         *
         *  For ``io2`` volumes, you can achieve up to 256,000 IOPS on [instances built on the Nitro System](https://docs.aws.amazon.com/ec2/latest/instancetypes/ec2-nitro-instances.html). On other instances, you can achieve performance up to 32,000 IOPS.
         *  This parameter is supported for ``io1``, ``io2``, and ``gp3`` volumes only.
         */
        iops?: pulumi.Input<number>;
        /**
         * Identifier (key ID, key alias, key ARN, or alias ARN) of the customer managed KMS key to use for EBS encryption.
         */
        kmsKeyId?: pulumi.Input<string>;
        /**
         * The ID of the snapshot.
         */
        snapshotId?: pulumi.Input<string>;
        /**
         * The throughput to provision for a ``gp3`` volume, with a maximum of 1,000 MiB/s.
         *  Valid Range: Minimum value of 125. Maximum value of 1000.
         */
        throughput?: pulumi.Input<number>;
        /**
         * The size of the volume, in GiBs. You must specify either a snapshot ID or a volume size. The following are the supported volumes sizes for each volume type:
         *   +   ``gp2`` and ``gp3``: 1 - 16,384 GiB
         *   +   ``io1``: 4 - 16,384 GiB
         *   +   ``io2``: 4 - 65,536 GiB
         *   +   ``st1`` and ``sc1``: 125 - 16,384 GiB
         *   +   ``standard``: 1 - 1024 GiB
         */
        volumeSize?: pulumi.Input<number>;
        /**
         * The volume type. For more information, see [Amazon EBS volume types](https://docs.aws.amazon.com/ebs/latest/userguide/ebs-volume-types.html) in the *Amazon EBS User Guide*.
         */
        volumeType?: pulumi.Input<string>;
    }
    /**
     * Amazon Elastic Graphics reached end of life on January 8, 2024.
     *   Specifies a specification for an Elastic GPU for an Amazon EC2 launch template.
     *   ``ElasticGpuSpecification`` is a property of [AWS::EC2::LaunchTemplate LaunchTemplateData](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-ec2-launchtemplate-launchtemplatedata.html).
     */
    interface LaunchTemplateElasticGpuSpecificationArgs {
        /**
         * The type of Elastic Graphics accelerator.
         */
        type?: pulumi.Input<string>;
    }
    /**
     * Amazon Elastic Inference is no longer available.
     *   Specifies an elastic inference accelerator.
     *   ``LaunchTemplateElasticInferenceAccelerator`` is a property of [AWS::EC2::LaunchTemplate LaunchTemplateData](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-ec2-launchtemplate-launchtemplatedata.html).
     */
    interface LaunchTemplateElasticInferenceAcceleratorArgs {
        /**
         * The number of elastic inference accelerators to attach to the instance.
         *  Default: 1
         */
        count?: pulumi.Input<number>;
        /**
         * The type of elastic inference accelerator. The possible values are eia1.medium, eia1.large, and eia1.xlarge.
         */
        type?: pulumi.Input<string>;
    }
    /**
     * ENA Express uses AWS Scalable Reliable Datagram (SRD) technology to increase the maximum bandwidth used per stream and minimize tail latency of network traffic between EC2 instances. With ENA Express, you can communicate between two EC2 instances in the same subnet within the same account, or in different accounts. Both sending and receiving instances must have ENA Express enabled.
     *  To improve the reliability of network packet delivery, ENA Express reorders network packets on the receiving end by default. However, some UDP-based applications are designed to handle network packets that are out of order to reduce the overhead for packet delivery at the network layer. When ENA Express is enabled, you can specify whether UDP network traffic uses it.
     */
    interface LaunchTemplateEnaSrdSpecificationArgs {
        /**
         * Indicates whether ENA Express is enabled for the network interface.
         */
        enaSrdEnabled?: pulumi.Input<boolean>;
        /**
         * Configures ENA Express for UDP network traffic.
         */
        enaSrdUdpSpecification?: pulumi.Input<inputs.ec2.LaunchTemplateEnaSrdUdpSpecificationArgs>;
    }
    /**
     * ENA Express is compatible with both TCP and UDP transport protocols. When it's enabled, TCP traffic automatically uses it. However, some UDP-based applications are designed to handle network packets that are out of order, without a need for retransmission, such as live video broadcasting or other near-real-time applications. For UDP traffic, you can specify whether to use ENA Express, based on your application environment needs.
     */
    interface LaunchTemplateEnaSrdUdpSpecificationArgs {
        /**
         * Indicates whether UDP traffic to and from the instance uses ENA Express. To specify this setting, you must first enable ENA Express.
         */
        enaSrdUdpEnabled?: pulumi.Input<boolean>;
    }
    /**
     * Indicates whether the instance is enabled for AWS Nitro Enclaves.
     */
    interface LaunchTemplateEnclaveOptionsArgs {
        /**
         * If this parameter is set to ``true``, the instance is enabled for AWS Nitro Enclaves; otherwise, it is not enabled for AWS Nitro Enclaves.
         */
        enabled?: pulumi.Input<boolean>;
    }
    /**
     * Specifies whether your instance is configured for hibernation. This parameter is valid only if the instance meets the [hibernation prerequisites](https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/Hibernate.html#hibernating-prerequisites). For more information, see [Hibernate Your Instance](https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/Hibernate.html) in the *Amazon EC2 User Guide*.
     *   ``HibernationOptions`` is a property of [AWS::EC2::LaunchTemplate LaunchTemplateData](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-ec2-launchtemplate-launchtemplatedata.html).
     */
    interface LaunchTemplateHibernationOptionsArgs {
        /**
         * If you set this parameter to ``true``, the instance is enabled for hibernation.
         *  Default: ``false``
         */
        configured?: pulumi.Input<boolean>;
    }
    /**
     * Specifies an IAM instance profile, which is a container for an IAM role for your instance. You can use an IAM role to distribute your AWS credentials to your instances.
     *  If you are creating the launch template for use with an ASlong group, you can specify either the name or the ARN of the instance profile, but not both.
     *   ``IamInstanceProfile`` is a property of [AWS::EC2::LaunchTemplate LaunchTemplateData](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-ec2-launchtemplate-launchtemplatedata.html).
     */
    interface LaunchTemplateIamInstanceProfileArgs {
        /**
         * The Amazon Resource Name (ARN) of the instance profile.
         */
        arn?: pulumi.Input<string>;
        /**
         * The name of the instance profile.
         */
        name?: pulumi.Input<string>;
    }
    /**
     * Specifies the market (purchasing) option for an instance.
     *   ``InstanceMarketOptions`` is a property of the [AWS::EC2::LaunchTemplate LaunchTemplateData](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-ec2-launchtemplate-launchtemplatedata.html).
     */
    interface LaunchTemplateInstanceMarketOptionsArgs {
        /**
         * The market type.
         */
        marketType?: pulumi.Input<string>;
        /**
         * The options for Spot Instances.
         */
        spotOptions?: pulumi.Input<inputs.ec2.LaunchTemplateSpotOptionsArgs>;
    }
    /**
     * The attributes for the instance types. When you specify instance attributes, Amazon EC2 will identify instance types with these attributes.
     *  You must specify ``VCpuCount`` and ``MemoryMiB``. All other attributes are optional. Any unspecified optional attribute is set to its default.
     *  When you specify multiple attributes, you get instance types that satisfy all of the specified attributes. If you specify multiple values for an attribute, you get instance types that satisfy any of the specified values.
     *  To limit the list of instance types from which Amazon EC2 can identify matching instance types, you can use one of the following parameters, but not both in the same request:
     *   +   ``AllowedInstanceTypes`` - The instance types to include in the list. All other instance types are ignored, even if they match your specified attributes.
     *   +   ``ExcludedInstanceTypes`` - The instance types to exclude from the list, even if they match your specified attributes.
     *
     *   If you specify ``InstanceRequirements``, you can't specify ``InstanceType``.
     *  Attribute-based instance type selection is only supported when using Auto Scaling groups, EC2 Fleet, and Spot Fleet to launch instances. If you plan to use the launch template in the [launch instance wizard](https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/ec2-launch-instance-wizard.html), or with the [RunInstances](https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_RunInstances.html) API or [AWS::EC2::Instance](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-ec2-instance.html) AWS CloudFormation resource, you can't specify ``InstanceRequirements``.
     *   For more information, see [Specify attributes for instance type selection for EC2 Fleet or Spot Fleet](https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/ec2-fleet-attribute-based-instance-type-selection.html) and [Spot placement score](https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/spot-placement-score.html) in the *Amazon EC2 User Guide*.
     */
    interface LaunchTemplateInstanceRequirementsArgs {
        /**
         * The minimum and maximum number of accelerators (GPUs, FPGAs, or AWS Inferentia chips) on an instance.
         *  To exclude accelerator-enabled instance types, set ``Max`` to ``0``.
         *  Default: No minimum or maximum limits
         */
        acceleratorCount?: pulumi.Input<inputs.ec2.LaunchTemplateAcceleratorCountArgs>;
        /**
         * Indicates whether instance types must have accelerators by specific manufacturers.
         *   +  For instance types with AWS devices, specify ``amazon-web-services``.
         *   +  For instance types with AMD devices, specify ``amd``.
         *   +  For instance types with Habana devices, specify ``habana``.
         *   +  For instance types with NVIDIA devices, specify ``nvidia``.
         *   +  For instance types with Xilinx devices, specify ``xilinx``.
         *
         *  Default: Any manufacturer
         */
        acceleratorManufacturers?: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * The accelerators that must be on the instance type.
         *   +  For instance types with NVIDIA A10G GPUs, specify ``a10g``.
         *   +  For instance types with NVIDIA A100 GPUs, specify ``a100``.
         *   +  For instance types with NVIDIA H100 GPUs, specify ``h100``.
         *   +  For instance types with AWS Inferentia chips, specify ``inferentia``.
         *   +  For instance types with NVIDIA GRID K520 GPUs, specify ``k520``.
         *   +  For instance types with NVIDIA K80 GPUs, specify ``k80``.
         *   +  For instance types with NVIDIA M60 GPUs, specify ``m60``.
         *   +  For instance types with AMD Radeon Pro V520 GPUs, specify ``radeon-pro-v520``.
         *   +  For instance types with NVIDIA T4 GPUs, specify ``t4``.
         *   +  For instance types with NVIDIA T4G GPUs, specify ``t4g``.
         *   +  For instance types with Xilinx VU9P FPGAs, specify ``vu9p``.
         *   +  For instance types with NVIDIA V100 GPUs, specify ``v100``.
         *
         *  Default: Any accelerator
         */
        acceleratorNames?: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * The minimum and maximum amount of total accelerator memory, in MiB.
         *  Default: No minimum or maximum limits
         */
        acceleratorTotalMemoryMiB?: pulumi.Input<inputs.ec2.LaunchTemplateAcceleratorTotalMemoryMiBArgs>;
        /**
         * The accelerator types that must be on the instance type.
         *   +  For instance types with FPGA accelerators, specify ``fpga``.
         *   +  For instance types with GPU accelerators, specify ``gpu``.
         *
         *  Default: Any accelerator type
         */
        acceleratorTypes?: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * The instance types to apply your specified attributes against. All other instance types are ignored, even if they match your specified attributes.
         *  You can use strings with one or more wild cards, represented by an asterisk (``*``), to allow an instance type, size, or generation. The following are examples: ``m5.8xlarge``, ``c5*.*``, ``m5a.*``, ``r*``, ``*3*``.
         *  For example, if you specify ``c5*``,Amazon EC2 will allow the entire C5 instance family, which includes all C5a and C5n instance types. If you specify ``m5a.*``, Amazon EC2 will allow all the M5a instance types, but not the M5n instance types.
         *   If you specify ``AllowedInstanceTypes``, you can't specify ``ExcludedInstanceTypes``.
         *   Default: All instance types
         */
        allowedInstanceTypes?: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * Indicates whether bare metal instance types must be included, excluded, or required.
         *   +  To include bare metal instance types, specify ``included``.
         *   +  To require only bare metal instance types, specify ``required``.
         *   +  To exclude bare metal instance types, specify ``excluded``.
         *
         *  Default: ``excluded``
         */
        bareMetal?: pulumi.Input<string>;
        /**
         * The minimum and maximum baseline bandwidth to Amazon EBS, in Mbps. For more information, see [Amazon EBS–optimized instances](https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/ebs-optimized.html) in the *Amazon EC2 User Guide*.
         *  Default: No minimum or maximum limits
         */
        baselineEbsBandwidthMbps?: pulumi.Input<inputs.ec2.LaunchTemplateBaselineEbsBandwidthMbpsArgs>;
        /**
         * The baseline performance to consider, using an instance family as a baseline reference. The instance family establishes the lowest acceptable level of performance. Amazon EC2 uses this baseline to guide instance type selection, but there is no guarantee that the selected instance types will always exceed the baseline for every application. Currently, this parameter only supports CPU performance as a baseline performance factor. For more information, see [Performance protection](https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/ec2-fleet-attribute-based-instance-type-selection.html#ec2fleet-abis-performance-protection) in the *Amazon EC2 User Guide*.
         */
        baselinePerformanceFactors?: pulumi.Input<inputs.ec2.LaunchTemplateBaselinePerformanceFactorsArgs>;
        /**
         * Indicates whether burstable performance T instance types are included, excluded, or required. For more information, see [Burstable performance instances](https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/burstable-performance-instances.html).
         *   +  To include burstable performance instance types, specify ``included``.
         *   +  To require only burstable performance instance types, specify ``required``.
         *   +  To exclude burstable performance instance types, specify ``excluded``.
         *
         *  Default: ``excluded``
         */
        burstablePerformance?: pulumi.Input<string>;
        /**
         * The CPU manufacturers to include.
         *   +  For instance types with Intel CPUs, specify ``intel``.
         *   +  For instance types with AMD CPUs, specify ``amd``.
         *   +  For instance types with AWS CPUs, specify ``amazon-web-services``.
         *   +  For instance types with Apple CPUs, specify ``apple``.
         *
         *   Don't confuse the CPU manufacturer with the CPU architecture. Instances will be launched with a compatible CPU architecture based on the Amazon Machine Image (AMI) that you specify in your launch template.
         *   Default: Any manufacturer
         */
        cpuManufacturers?: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * The instance types to exclude.
         *  You can use strings with one or more wild cards, represented by an asterisk (``*``), to exclude an instance type, size, or generation. The following are examples: ``m5.8xlarge``, ``c5*.*``, ``m5a.*``, ``r*``, ``*3*``.
         *  For example, if you specify ``c5*``,Amazon EC2 will exclude the entire C5 instance family, which includes all C5a and C5n instance types. If you specify ``m5a.*``, Amazon EC2 will exclude all the M5a instance types, but not the M5n instance types.
         *   If you specify ``ExcludedInstanceTypes``, you can't specify ``AllowedInstanceTypes``.
         *   Default: No excluded instance types
         */
        excludedInstanceTypes?: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * Indicates whether current or previous generation instance types are included. The current generation instance types are recommended for use. Current generation instance types are typically the latest two to three generations in each instance family. For more information, see [Instance types](https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/instance-types.html) in the *Amazon EC2 User Guide*.
         *  For current generation instance types, specify ``current``.
         *  For previous generation instance types, specify ``previous``.
         *  Default: Current and previous generation instance types
         */
        instanceGenerations?: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * Indicates whether instance types with instance store volumes are included, excluded, or required. For more information, [Amazon EC2 instance store](https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/InstanceStorage.html) in the *Amazon EC2 User Guide*.
         *   +  To include instance types with instance store volumes, specify ``included``.
         *   +  To require only instance types with instance store volumes, specify ``required``.
         *   +  To exclude instance types with instance store volumes, specify ``excluded``.
         *
         *  Default: ``included``
         */
        localStorage?: pulumi.Input<string>;
        /**
         * The type of local storage that is required.
         *   +  For instance types with hard disk drive (HDD) storage, specify ``hdd``.
         *   +  For instance types with solid state drive (SSD) storage, specify ``ssd``.
         *
         *  Default: ``hdd`` and ``ssd``
         */
        localStorageTypes?: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * [Price protection] The price protection threshold for Spot Instances, as a percentage of an identified On-Demand price. The identified On-Demand price is the price of the lowest priced current generation C, M, or R instance type with your specified attributes. If no current generation C, M, or R instance type matches your attributes, then the identified price is from the lowest priced current generation instance types, and failing that, from the lowest priced previous generation instance types that match your attributes. When Amazon EC2 selects instance types with your attributes, it will exclude instance types whose price exceeds your specified threshold.
         *  The parameter accepts an integer, which Amazon EC2 interprets as a percentage.
         *  If you set ``TargetCapacityUnitType`` to ``vcpu`` or ``memory-mib``, the price protection threshold is based on the per vCPU or per memory price instead of the per instance price.
         *   Only one of ``SpotMaxPricePercentageOverLowestPrice`` or ``MaxSpotPriceAsPercentageOfOptimalOnDemandPrice`` can be specified. If you don't specify either, Amazon EC2 will automatically apply optimal price protection to consistently select from a wide range of instance types. To indicate no price protection threshold for Spot Instances, meaning you want to consider all instance types that match your attributes, include one of these parameters and specify a high value, such as ``999999``.
         */
        maxSpotPriceAsPercentageOfOptimalOnDemandPrice?: pulumi.Input<number>;
        /**
         * The minimum and maximum amount of memory per vCPU, in GiB.
         *  Default: No minimum or maximum limits
         */
        memoryGiBPerVCpu?: pulumi.Input<inputs.ec2.LaunchTemplateMemoryGiBPerVCpuArgs>;
        /**
         * The minimum and maximum amount of memory, in MiB.
         */
        memoryMiB?: pulumi.Input<inputs.ec2.LaunchTemplateMemoryMiBArgs>;
        /**
         * The minimum and maximum amount of network bandwidth, in gigabits per second (Gbps).
         *  Default: No minimum or maximum limits
         */
        networkBandwidthGbps?: pulumi.Input<inputs.ec2.LaunchTemplateNetworkBandwidthGbpsArgs>;
        /**
         * The minimum and maximum number of network interfaces.
         *  Default: No minimum or maximum limits
         */
        networkInterfaceCount?: pulumi.Input<inputs.ec2.LaunchTemplateNetworkInterfaceCountArgs>;
        /**
         * [Price protection] The price protection threshold for On-Demand Instances, as a percentage higher than an identified On-Demand price. The identified On-Demand price is the price of the lowest priced current generation C, M, or R instance type with your specified attributes. When Amazon EC2 selects instance types with your attributes, it will exclude instance types whose price exceeds your specified threshold.
         *  The parameter accepts an integer, which Amazon EC2 interprets as a percentage.
         *  To turn off price protection, specify a high value, such as ``999999``.
         *  This parameter is not supported for [GetSpotPlacementScores](https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_GetSpotPlacementScores.html) and [GetInstanceTypesFromInstanceRequirements](https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_GetInstanceTypesFromInstanceRequirements.html).
         *   If you set ``TargetCapacityUnitType`` to ``vcpu`` or ``memory-mib``, the price protection threshold is applied based on the per-vCPU or per-memory price instead of the per-instance price.
         *   Default: ``20``
         */
        onDemandMaxPricePercentageOverLowestPrice?: pulumi.Input<number>;
        /**
         * Indicates whether instance types must support hibernation for On-Demand Instances.
         *  This parameter is not supported for [GetSpotPlacementScores](https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_GetSpotPlacementScores.html).
         *  Default: ``false``
         */
        requireHibernateSupport?: pulumi.Input<boolean>;
        /**
         * [Price protection] The price protection threshold for Spot Instances, as a percentage higher than an identified Spot price. The identified Spot price is the Spot price of the lowest priced current generation C, M, or R instance type with your specified attributes. If no current generation C, M, or R instance type matches your attributes, then the identified Spot price is from the lowest priced current generation instance types, and failing that, from the lowest priced previous generation instance types that match your attributes. When Amazon EC2 selects instance types with your attributes, it will exclude instance types whose Spot price exceeds your specified threshold.
         *  The parameter accepts an integer, which Amazon EC2 interprets as a percentage.
         *  If you set ``TargetCapacityUnitType`` to ``vcpu`` or ``memory-mib``, the price protection threshold is applied based on the per-vCPU or per-memory price instead of the per-instance price.
         *  This parameter is not supported for [GetSpotPlacementScores](https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_GetSpotPlacementScores.html) and [GetInstanceTypesFromInstanceRequirements](https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_GetInstanceTypesFromInstanceRequirements.html).
         *   Only one of ``SpotMaxPricePercentageOverLowestPrice`` or ``MaxSpotPriceAsPercentageOfOptimalOnDemandPrice`` can be specified. If you don't specify either, Amazon EC2 will automatically apply optimal price protection to consistently select from a wide range of instance types. To indicate no price protection threshold for Spot Instances, meaning you want to consider all instance types that match your attributes, include one of these parameters and specify a high value, such as ``999999``.
         *   Default: ``100``
         */
        spotMaxPricePercentageOverLowestPrice?: pulumi.Input<number>;
        /**
         * The minimum and maximum amount of total local storage, in GB.
         *  Default: No minimum or maximum limits
         */
        totalLocalStorageGb?: pulumi.Input<inputs.ec2.LaunchTemplateTotalLocalStorageGbArgs>;
        /**
         * The minimum and maximum number of vCPUs.
         */
        vCpuCount?: pulumi.Input<inputs.ec2.LaunchTemplateVCpuCountArgs>;
    }
    /**
     * Specifies an IPv4 prefix for a network interface.
     *   ``Ipv4PrefixSpecification`` is a property of [AWS::EC2::LaunchTemplate NetworkInterface](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-ec2-launchtemplate-networkinterface.html).
     */
    interface LaunchTemplateIpv4PrefixSpecificationArgs {
        /**
         * The IPv4 prefix. For information, see [Assigning prefixes to network interfaces](https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/ec2-prefix-eni.html) in the *Amazon EC2 User Guide*.
         */
        ipv4Prefix?: pulumi.Input<string>;
    }
    /**
     * Specifies an IPv6 address in an Amazon EC2 launch template.
     *   ``Ipv6Add`` is a property of [AWS::EC2::LaunchTemplate NetworkInterface](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-ec2-launchtemplate-networkinterface.html).
     */
    interface LaunchTemplateIpv6AddArgs {
        /**
         * One or more specific IPv6 addresses from the IPv6 CIDR block range of your subnet. You can't use this option if you're specifying a number of IPv6 addresses.
         */
        ipv6Address?: pulumi.Input<string>;
    }
    /**
     * Specifies an IPv6 prefix for a network interface.
     *   ``Ipv6PrefixSpecification`` is a property of [AWS::EC2::LaunchTemplate NetworkInterface](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-ec2-launchtemplate-networkinterface.html).
     */
    interface LaunchTemplateIpv6PrefixSpecificationArgs {
        /**
         * The IPv6 prefix.
         */
        ipv6Prefix?: pulumi.Input<string>;
    }
    /**
     * Specifies a license configuration for an instance.
     *   ``LicenseSpecification`` is a property of [AWS::EC2::LaunchTemplate LaunchTemplateData](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-ec2-launchtemplate-launchtemplatedata.html).
     */
    interface LaunchTemplateLicenseSpecificationArgs {
        /**
         * The Amazon Resource Name (ARN) of the license configuration.
         */
        licenseConfigurationArn?: pulumi.Input<string>;
    }
    /**
     * The maintenance options of your instance.
     */
    interface LaunchTemplateMaintenanceOptionsArgs {
        /**
         * Disables the automatic recovery behavior of your instance or sets it to default.
         */
        autoRecovery?: pulumi.Input<string>;
    }
    /**
     * The minimum and maximum amount of memory per vCPU, in GiB.
     */
    interface LaunchTemplateMemoryGiBPerVCpuArgs {
        /**
         * The maximum amount of memory per vCPU, in GiB. To specify no maximum limit, omit this parameter.
         */
        max?: pulumi.Input<number>;
        /**
         * The minimum amount of memory per vCPU, in GiB. To specify no minimum limit, omit this parameter.
         */
        min?: pulumi.Input<number>;
    }
    /**
     * The minimum and maximum amount of memory, in MiB.
     */
    interface LaunchTemplateMemoryMiBArgs {
        /**
         * The maximum amount of memory, in MiB. To specify no maximum limit, omit this parameter.
         */
        max?: pulumi.Input<number>;
        /**
         * The minimum amount of memory, in MiB. To specify no minimum limit, specify ``0``.
         */
        min?: pulumi.Input<number>;
    }
    /**
     * The metadata options for the instance. For more information, see [Instance metadata and user data](https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/ec2-instance-metadata.html) in the *Amazon EC2 User Guide*.
     *   ``MetadataOptions`` is a property of [AWS::EC2::LaunchTemplate LaunchTemplateData](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-ec2-launchtemplate-launchtemplatedata.html).
     */
    interface LaunchTemplateMetadataOptionsArgs {
        /**
         * Enables or disables the HTTP metadata endpoint on your instances. If the parameter is not specified, the default state is ``enabled``.
         *   If you specify a value of ``disabled``, you will not be able to access your instance metadata.
         */
        httpEndpoint?: pulumi.Input<string>;
        /**
         * Enables or disables the IPv6 endpoint for the instance metadata service.
         *  Default: ``disabled``
         */
        httpProtocolIpv6?: pulumi.Input<string>;
        /**
         * The desired HTTP PUT response hop limit for instance metadata requests. The larger the number, the further instance metadata requests can travel.
         *  Default: ``1``
         *  Possible values: Integers from 1 to 64
         */
        httpPutResponseHopLimit?: pulumi.Input<number>;
        /**
         * Indicates whether IMDSv2 is required.
         *   +   ``optional`` - IMDSv2 is optional. You can choose whether to send a session token in your instance metadata retrieval requests. If you retrieve IAM role credentials without a session token, you receive the IMDSv1 role credentials. If you retrieve IAM role credentials using a valid session token, you receive the IMDSv2 role credentials.
         *   +   ``required`` - IMDSv2 is required. You must send a session token in your instance metadata retrieval requests. With this option, retrieving the IAM role credentials always returns IMDSv2 credentials; IMDSv1 credentials are not available.
         *
         *  Default: If the value of ``ImdsSupport`` for the Amazon Machine Image (AMI) for your instance is ``v2.0``, the default is ``required``.
         */
        httpTokens?: pulumi.Input<string>;
        /**
         * Set to ``enabled`` to allow access to instance tags from the instance metadata. Set to ``disabled`` to turn off access to instance tags from the instance metadata. For more information, see [View tags for your EC2 instances using instance metadata](https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/work-with-tags-in-IMDS.html).
         *  Default: ``disabled``
         */
        instanceMetadataTags?: pulumi.Input<string>;
    }
    /**
     * Specifies whether detailed monitoring is enabled for an instance. For more information about detailed monitoring, see [Enable or turn off detailed monitoring for your instances](https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/using-cloudwatch-new.html) in the *User Guide*.
     *   ``Monitoring`` is a property of [AWS::EC2::LaunchTemplate LaunchTemplateData](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-ec2-launchtemplate-launchtemplatedata.html).
     */
    interface LaunchTemplateMonitoringArgs {
        /**
         * Specify ``true`` to enable detailed monitoring. Otherwise, basic monitoring is enabled.
         */
        enabled?: pulumi.Input<boolean>;
    }
    /**
     * The minimum and maximum amount of network bandwidth, in gigabits per second (Gbps).
     *   Setting the minimum bandwidth does not guarantee that your instance will achieve the minimum bandwidth. Amazon EC2 will identify instance types that support the specified minimum bandwidth, but the actual bandwidth of your instance might go below the specified minimum at times. For more information, see [Available instance bandwidth](https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/ec2-instance-network-bandwidth.html#available-instance-bandwidth) in the *Amazon EC2 User Guide*.
     */
    interface LaunchTemplateNetworkBandwidthGbpsArgs {
        /**
         * The maximum amount of network bandwidth, in Gbps. To specify no maximum limit, omit this parameter.
         */
        max?: pulumi.Input<number>;
        /**
         * The minimum amount of network bandwidth, in Gbps. If this parameter is not specified, there is no minimum limit.
         */
        min?: pulumi.Input<number>;
    }
    /**
     * Specifies the parameters for a network interface.
     *   ``NetworkInterface`` is a property of [AWS::EC2::LaunchTemplate LaunchTemplateData](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-ec2-launchtemplate-launchtemplatedata.html).
     */
    interface LaunchTemplateNetworkInterfaceArgs {
        /**
         * Associates a Carrier IP address with eth0 for a new network interface.
         *  Use this option when you launch an instance in a Wavelength Zone and want to associate a Carrier IP address with the network interface. For more information about Carrier IP addresses, see [Carrier IP addresses](https://docs.aws.amazon.com/wavelength/latest/developerguide/how-wavelengths-work.html#provider-owned-ip) in the *Developer Guide*.
         */
        associateCarrierIpAddress?: pulumi.Input<boolean>;
        /**
         * Associates a public IPv4 address with eth0 for a new network interface.
         *   AWS charges for all public IPv4 addresses, including public IPv4 addresses associated with running instances and Elastic IP addresses. For more information, see the *Public IPv4 Address* tab on the [Amazon VPC pricing page](https://docs.aws.amazon.com/vpc/pricing/).
         */
        associatePublicIpAddress?: pulumi.Input<boolean>;
        /**
         * A connection tracking specification for the network interface.
         */
        connectionTrackingSpecification?: pulumi.Input<inputs.ec2.LaunchTemplateConnectionTrackingSpecificationArgs>;
        /**
         * Indicates whether the network interface is deleted when the instance is terminated.
         */
        deleteOnTermination?: pulumi.Input<boolean>;
        /**
         * A description for the network interface.
         */
        description?: pulumi.Input<string>;
        /**
         * The device index for the network interface attachment. The primary network interface has a device index of 0. If the network interface is of type ``interface``, you must specify a device index.
         *  If you create a launch template that includes secondary network interfaces but no primary network interface, and you specify it using the ``LaunchTemplate`` property of ``AWS::EC2::Instance``, then you must include a primary network interface using the ``NetworkInterfaces`` property of ``AWS::EC2::Instance``.
         */
        deviceIndex?: pulumi.Input<number>;
        /**
         * The ENA Express configuration for the network interface.
         */
        enaSrdSpecification?: pulumi.Input<inputs.ec2.LaunchTemplateEnaSrdSpecificationArgs>;
        /**
         * The IDs of one or more security groups.
         */
        groups?: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * The type of network interface. To create an Elastic Fabric Adapter (EFA), specify ``efa`` or ``efa``. For more information, see [Elastic Fabric Adapter for AI/ML and HPC workloads on Amazon EC2](https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/efa.html) in the *Amazon EC2 User Guide*.
         *  If you are not creating an EFA, specify ``interface`` or omit this parameter.
         *  If you specify ``efa-only``, do not assign any IP addresses to the network interface. EFA-only network interfaces do not support IP addresses.
         *  Valid values: ``interface`` | ``efa`` | ``efa-only``
         */
        interfaceType?: pulumi.Input<string>;
        /**
         * The number of IPv4 prefixes to be automatically assigned to the network interface. You cannot use this option if you use the ``Ipv4Prefix`` option.
         */
        ipv4PrefixCount?: pulumi.Input<number>;
        /**
         * One or more IPv4 prefixes to be assigned to the network interface. You cannot use this option if you use the ``Ipv4PrefixCount`` option.
         */
        ipv4Prefixes?: pulumi.Input<pulumi.Input<inputs.ec2.LaunchTemplateIpv4PrefixSpecificationArgs>[]>;
        /**
         * The number of IPv6 addresses to assign to a network interface. Amazon EC2 automatically selects the IPv6 addresses from the subnet range. You can't use this option if specifying specific IPv6 addresses.
         */
        ipv6AddressCount?: pulumi.Input<number>;
        /**
         * One or more specific IPv6 addresses from the IPv6 CIDR block range of your subnet. You can't use this option if you're specifying a number of IPv6 addresses.
         */
        ipv6Addresses?: pulumi.Input<pulumi.Input<inputs.ec2.LaunchTemplateIpv6AddArgs>[]>;
        /**
         * The number of IPv6 prefixes to be automatically assigned to the network interface. You cannot use this option if you use the ``Ipv6Prefix`` option.
         */
        ipv6PrefixCount?: pulumi.Input<number>;
        /**
         * One or more IPv6 prefixes to be assigned to the network interface. You cannot use this option if you use the ``Ipv6PrefixCount`` option.
         */
        ipv6Prefixes?: pulumi.Input<pulumi.Input<inputs.ec2.LaunchTemplateIpv6PrefixSpecificationArgs>[]>;
        /**
         * The index of the network card. Some instance types support multiple network cards. The primary network interface must be assigned to network card index 0. The default is network card index 0.
         */
        networkCardIndex?: pulumi.Input<number>;
        /**
         * The ID of the network interface.
         */
        networkInterfaceId?: pulumi.Input<string>;
        /**
         * The primary IPv6 address of the network interface. When you enable an IPv6 GUA address to be a primary IPv6, the first IPv6 GUA will be made the primary IPv6 address until the instance is terminated or the network interface is detached. For more information about primary IPv6 addresses, see [RunInstances](https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_RunInstances.html).
         */
        primaryIpv6?: pulumi.Input<boolean>;
        /**
         * The primary private IPv4 address of the network interface.
         */
        privateIpAddress?: pulumi.Input<string>;
        /**
         * One or more private IPv4 addresses.
         */
        privateIpAddresses?: pulumi.Input<pulumi.Input<inputs.ec2.LaunchTemplatePrivateIpAddArgs>[]>;
        /**
         * The number of secondary private IPv4 addresses to assign to a network interface.
         */
        secondaryPrivateIpAddressCount?: pulumi.Input<number>;
        /**
         * The ID of the subnet for the network interface.
         */
        subnetId?: pulumi.Input<string>;
    }
    /**
     * The minimum and maximum number of network interfaces.
     */
    interface LaunchTemplateNetworkInterfaceCountArgs {
        /**
         * The maximum number of network interfaces. To specify no maximum limit, omit this parameter.
         */
        max?: pulumi.Input<number>;
        /**
         * The minimum number of network interfaces. To specify no minimum limit, omit this parameter.
         */
        min?: pulumi.Input<number>;
    }
    /**
     * Contains settings for the network performance options for the instance.
     */
    interface LaunchTemplateNetworkPerformanceOptionsArgs {
        /**
         * Specify the bandwidth weighting option to boost the associated type of baseline bandwidth, as follows:
         *   + default This option uses the standard bandwidth configuration for your instance type. + vpc-1 This option boosts your networking baseline bandwidth and reduces your EBS baseline bandwidth. + ebs-1 This option boosts your EBS baseline bandwidth and reduces your networking baseline bandwidth.
         */
        bandwidthWeighting?: pulumi.Input<string>;
    }
    /**
     * Specifies the placement of an instance.
     *   ``Placement`` is a property of [AWS::EC2::LaunchTemplate LaunchTemplateData](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-ec2-launchtemplate-launchtemplatedata.html).
     */
    interface LaunchTemplatePlacementArgs {
        /**
         * The affinity setting for an instance on a Dedicated Host.
         */
        affinity?: pulumi.Input<string>;
        /**
         * The Availability Zone for the instance.
         */
        availabilityZone?: pulumi.Input<string>;
        /**
         * The Group Id of a placement group. You must specify the Placement Group *Group Id* to launch an instance in a shared placement group.
         */
        groupId?: pulumi.Input<string>;
        /**
         * The name of the placement group for the instance.
         */
        groupName?: pulumi.Input<string>;
        /**
         * The ID of the Dedicated Host for the instance.
         */
        hostId?: pulumi.Input<string>;
        /**
         * The ARN of the host resource group in which to launch the instances. If you specify a host resource group ARN, omit the *Tenancy* parameter or set it to ``host``.
         */
        hostResourceGroupArn?: pulumi.Input<string>;
        /**
         * The number of the partition the instance should launch in. Valid only if the placement group strategy is set to ``partition``.
         */
        partitionNumber?: pulumi.Input<number>;
        /**
         * Reserved for future use.
         */
        spreadDomain?: pulumi.Input<string>;
        /**
         * The tenancy of the instance. An instance with a tenancy of dedicated runs on single-tenant hardware.
         */
        tenancy?: pulumi.Input<string>;
    }
    /**
     * The hostname type for EC2 instances launched into this subnet and how DNS A and AAAA record queries should be handled. For more information, see [Amazon EC2 instance hostname types](https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/ec2-instance-naming.html) in the *User Guide*.
     */
    interface LaunchTemplatePrivateDnsNameOptionsArgs {
        /**
         * Indicates whether to respond to DNS queries for instance hostnames with DNS A records.
         */
        enableResourceNameDnsARecord?: pulumi.Input<boolean>;
        /**
         * Indicates whether to respond to DNS queries for instance hostnames with DNS AAAA records.
         */
        enableResourceNameDnsAaaaRecord?: pulumi.Input<boolean>;
        /**
         * The type of hostname for EC2 instances. For IPv4 only subnets, an instance DNS name must be based on the instance IPv4 address. For IPv6 only subnets, an instance DNS name must be based on the instance ID. For dual-stack subnets, you can specify whether DNS names use the instance IPv4 address or the instance ID. For more information, see [Amazon EC2 instance hostname types](https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/ec2-instance-naming.html) in the *User Guide*.
         */
        hostnameType?: pulumi.Input<string>;
    }
    /**
     * Specifies a secondary private IPv4 address for a network interface.
     *   ``PrivateIpAdd`` is a property of [AWS::EC2::LaunchTemplate NetworkInterface](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-ec2-launchtemplate-networkinterface.html).
     */
    interface LaunchTemplatePrivateIpAddArgs {
        /**
         * Indicates whether the private IPv4 address is the primary private IPv4 address. Only one IPv4 address can be designated as primary.
         */
        primary?: pulumi.Input<boolean>;
        /**
         * The private IPv4 address.
         */
        privateIpAddress?: pulumi.Input<string>;
    }
    /**
     * Specifies an instance family to use as the baseline reference for CPU performance.
     */
    interface LaunchTemplateReferenceArgs {
        /**
         * The instance family to use as a baseline reference.
         *   Ensure that you specify the correct value for the instance family. The instance family is everything before the period (``.``) in the instance type name. For example, in the instance type ``c6i.large``, the instance family is ``c6i``, not ``c6``. For more information, see [Amazon EC2 instance type naming conventions](https://docs.aws.amazon.com/ec2/latest/instancetypes/instance-type-names.html) in *Amazon EC2 Instance Types*.
         *   The following instance families are *not supported* for performance protection:
         *   +   ``c1``
         *   +   ``g3`` | ``g3s``
         *   +   ``hpc7g``
         *   +   ``m1`` | ``m2``
         *   +   ``mac1`` | ``mac2`` | ``mac2-m1ultra`` | ``mac2-m2`` | ``mac2-m2pro``
         *   +   ``p3dn`` | ``p4d`` | ``p5``
         *   +   ``t1``
         *   +   ``u-12tb1`` | ``u-18tb1`` | ``u-24tb1`` | ``u-3tb1`` | ``u-6tb1`` | ``u-9tb1`` | ``u7i-12tb`` | ``u7in-16tb`` | ``u7in-24tb`` | ``u7in-32tb``
         *
         *  If you enable performance protection by specifying a supported instance family, the returned instance types will exclude the above unsupported instance families.
         */
        instanceFamily?: pulumi.Input<string>;
    }
    /**
     * Specifies options for Spot Instances.
     *   ``SpotOptions`` is a property of [AWS::EC2::LaunchTemplate InstanceMarketOptions](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-ec2-launchtemplate-launchtemplatedata-instancemarketoptions.html).
     */
    interface LaunchTemplateSpotOptionsArgs {
        /**
         * Deprecated.
         */
        blockDurationMinutes?: pulumi.Input<number>;
        /**
         * The behavior when a Spot Instance is interrupted. The default is ``terminate``.
         */
        instanceInterruptionBehavior?: pulumi.Input<string>;
        /**
         * The maximum hourly price you're willing to pay for a Spot Instance. We do not recommend using this parameter because it can lead to increased interruptions. If you do not specify this parameter, you will pay the current Spot price. If you do specify this parameter, it must be more than USD $0.001. Specifying a value below USD $0.001 will result in an ``InvalidParameterValue`` error message when the launch template is used to launch an instance.
         *   If you specify a maximum price, your Spot Instances will be interrupted more frequently than if you do not specify this parameter.
         */
        maxPrice?: pulumi.Input<string>;
        /**
         * The Spot Instance request type.
         *  If you are using Spot Instances with an Auto Scaling group, use ``one-time`` requests, as the ASlong service handles requesting new Spot Instances whenever the group is below its desired capacity.
         */
        spotInstanceType?: pulumi.Input<string>;
        /**
         * The end date of the request, in UTC format (*YYYY-MM-DD*T*HH:MM:SS*Z). Supported only for persistent requests.
         *   +  For a persistent request, the request remains active until the ``ValidUntil`` date and time is reached. Otherwise, the request remains active until you cancel it.
         *   +  For a one-time request, ``ValidUntil`` is not supported. The request remains active until all instances launch or you cancel the request.
         *
         *  Default: 7 days from the current date
         */
        validUntil?: pulumi.Input<string>;
    }
    /**
     * Specifies a tag. For more information, see [Resource tags](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-resource-tags.html).
     */
    interface LaunchTemplateTagArgs {
        /**
         * The tag key.
         */
        key: pulumi.Input<string>;
        /**
         * The tag value.
         */
        value: pulumi.Input<string>;
    }
    /**
     * Specifies the tags to apply to the launch template during creation.
     *  To specify the tags for the resources that are created during instance launch, use [AWS::EC2::LaunchTemplate TagSpecification](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-ec2-launchtemplate-tagspecification.html).
     *   ``LaunchTemplateTagSpecification`` is a property of [AWS::EC2::LaunchTemplate](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-ec2-launchtemplate.html).
     */
    interface LaunchTemplateTagSpecificationArgs {
        /**
         * The type of resource. To tag a launch template, ``ResourceType`` must be ``launch-template``.
         */
        resourceType?: pulumi.Input<string>;
        /**
         * The tags for the resource.
         */
        tags?: pulumi.Input<pulumi.Input<inputs.ec2.LaunchTemplateTagArgs>[]>;
    }
    /**
     * The minimum and maximum amount of total local storage, in GB.
     */
    interface LaunchTemplateTotalLocalStorageGbArgs {
        /**
         * The maximum amount of total local storage, in GB. To specify no maximum limit, omit this parameter.
         */
        max?: pulumi.Input<number>;
        /**
         * The minimum amount of total local storage, in GB. To specify no minimum limit, omit this parameter.
         */
        min?: pulumi.Input<number>;
    }
    /**
     * The minimum and maximum number of vCPUs.
     */
    interface LaunchTemplateVCpuCountArgs {
        /**
         * The maximum number of vCPUs. To specify no maximum limit, omit this parameter.
         */
        max?: pulumi.Input<number>;
        /**
         * The minimum number of vCPUs. To specify no minimum limit, specify ``0``.
         */
        min?: pulumi.Input<number>;
    }
    interface NetworkInsightsAccessScopeAccessScopePathRequestArgs {
        /**
         * The destination.
         */
        destination?: pulumi.Input<inputs.ec2.NetworkInsightsAccessScopePathStatementRequestArgs>;
        /**
         * The source.
         */
        source?: pulumi.Input<inputs.ec2.NetworkInsightsAccessScopePathStatementRequestArgs>;
        /**
         * The through resources.
         */
        throughResources?: pulumi.Input<pulumi.Input<inputs.ec2.NetworkInsightsAccessScopeThroughResourcesStatementRequestArgs>[]>;
    }
    interface NetworkInsightsAccessScopePacketHeaderStatementRequestArgs {
        /**
         * The destination addresses.
         */
        destinationAddresses?: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * The destination ports.
         */
        destinationPorts?: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * The destination prefix lists.
         */
        destinationPrefixLists?: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * The protocols.
         */
        protocols?: pulumi.Input<pulumi.Input<enums.ec2.NetworkInsightsAccessScopeProtocol>[]>;
        /**
         * The source addresses.
         */
        sourceAddresses?: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * The source ports.
         */
        sourcePorts?: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * The source prefix lists.
         */
        sourcePrefixLists?: pulumi.Input<pulumi.Input<string>[]>;
    }
    interface NetworkInsightsAccessScopePathStatementRequestArgs {
        /**
         * The packet header statement.
         */
        packetHeaderStatement?: pulumi.Input<inputs.ec2.NetworkInsightsAccessScopePacketHeaderStatementRequestArgs>;
        /**
         * The resource statement.
         */
        resourceStatement?: pulumi.Input<inputs.ec2.NetworkInsightsAccessScopeResourceStatementRequestArgs>;
    }
    interface NetworkInsightsAccessScopeResourceStatementRequestArgs {
        /**
         * The resource types.
         */
        resourceTypes?: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * The resources.
         */
        resources?: pulumi.Input<pulumi.Input<string>[]>;
    }
    interface NetworkInsightsAccessScopeThroughResourcesStatementRequestArgs {
        /**
         * The resource statement.
         */
        resourceStatement?: pulumi.Input<inputs.ec2.NetworkInsightsAccessScopeResourceStatementRequestArgs>;
    }
    interface NetworkInsightsPathFilterPortRangeArgs {
        /**
         * The first port in the range.
         */
        fromPort?: pulumi.Input<number>;
        /**
         * The last port in the range.
         */
        toPort?: pulumi.Input<number>;
    }
    interface NetworkInsightsPathPathFilterArgs {
        /**
         * The destination IPv4 address.
         */
        destinationAddress?: pulumi.Input<string>;
        /**
         * The destination port range.
         */
        destinationPortRange?: pulumi.Input<inputs.ec2.NetworkInsightsPathFilterPortRangeArgs>;
        /**
         * The source IPv4 address.
         */
        sourceAddress?: pulumi.Input<string>;
        /**
         * The source port range.
         */
        sourcePortRange?: pulumi.Input<inputs.ec2.NetworkInsightsPathFilterPortRangeArgs>;
    }
    /**
     * ENA Express uses AWS Scalable Reliable Datagram (SRD) technology to increase the maximum bandwidth used per stream and minimize tail latency of network traffic between EC2 instances. With ENA Express, you can communicate between two EC2 instances in the same subnet within the same account, or in different accounts. Both sending and receiving instances must have ENA Express enabled.
     *  To improve the reliability of network packet delivery, ENA Express reorders network packets on the receiving end by default. However, some UDP-based applications are designed to handle network packets that are out of order to reduce the overhead for packet delivery at the network layer. When ENA Express is enabled, you can specify whether UDP network traffic uses it.
     */
    interface NetworkInterfaceAttachmentEnaSrdSpecificationArgs {
        /**
         * Indicates whether ENA Express is enabled for the network interface.
         */
        enaSrdEnabled?: pulumi.Input<boolean>;
        /**
         * Configures ENA Express for UDP network traffic.
         */
        enaSrdUdpSpecification?: pulumi.Input<inputs.ec2.NetworkInterfaceAttachmentEnaSrdSpecificationEnaSrdUdpSpecificationPropertiesArgs>;
    }
    /**
     * Configures ENA Express for UDP network traffic.
     */
    interface NetworkInterfaceAttachmentEnaSrdSpecificationEnaSrdUdpSpecificationPropertiesArgs {
        enaSrdUdpEnabled?: pulumi.Input<boolean>;
    }
    interface NetworkInterfaceConnectionTrackingSpecificationArgs {
        /**
         * Timeout (in seconds) for idle TCP connections in an established state. Min: 60 seconds. Max: 432000 seconds (5 days). Default: 432000 seconds. Recommended: Less than 432000 seconds.
         */
        tcpEstablishedTimeout?: pulumi.Input<number>;
        /**
         * Timeout (in seconds) for idle UDP flows classified as streams which have seen more than one request-response transaction. Min: 60 seconds. Max: 180 seconds (3 minutes). Default: 180 seconds.
         */
        udpStreamTimeout?: pulumi.Input<number>;
        /**
         * Timeout (in seconds) for idle UDP flows that have seen traffic only in a single direction or a single request-response transaction. Min: 30 seconds. Max: 60 seconds. Default: 30 seconds.
         */
        udpTimeout?: pulumi.Input<number>;
    }
    interface NetworkInterfaceInstanceIpv6AddressArgs {
        /**
         * An IPv6 address to associate with the network interface.
         */
        ipv6Address: pulumi.Input<string>;
    }
    interface NetworkInterfaceIpv4PrefixSpecificationArgs {
        /**
         * The IPv4 prefix. For information, see [Assigning prefixes to network interfaces](https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/ec2-prefix-eni.html) in the *Amazon EC2 User Guide* .
         */
        ipv4Prefix: pulumi.Input<string>;
    }
    interface NetworkInterfaceIpv6PrefixSpecificationArgs {
        /**
         * The IPv6 prefix. For information, see [Assigning prefixes to Amazon EC2 network interfaces](https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/ec2-prefix-eni.html) in the *Amazon Elastic Compute Cloud User Guide* .
         */
        ipv6Prefix: pulumi.Input<string>;
    }
    interface NetworkInterfacePrivateIpAddressSpecificationArgs {
        /**
         * Sets the private IP address as the primary private address. You can set only one primary private IP address. If you don't specify a primary private IP address, Amazon EC2 automatically assigns a primary private IP address.
         */
        primary: pulumi.Input<boolean>;
        /**
         * The private IP address of the network interface.
         */
        privateIpAddress: pulumi.Input<string>;
    }
    /**
     * The options for the transit gateway vpc attachment.
     */
    interface OptionsPropertiesArgs {
        /**
         * Indicates whether to enable Ipv6 Support for Vpc Attachment. Valid Values: enable | disable
         */
        applianceModeSupport?: pulumi.Input<string>;
        /**
         * Indicates whether to enable DNS Support for Vpc Attachment. Valid Values: enable | disable
         */
        dnsSupport?: pulumi.Input<string>;
        /**
         * Indicates whether to enable Ipv6 Support for Vpc Attachment. Valid Values: enable | disable
         */
        ipv6Support?: pulumi.Input<string>;
        /**
         * Indicates whether to enable Security Group referencing support for Vpc Attachment. Valid values: enable | disable
         */
        securityGroupReferencingSupport?: pulumi.Input<string>;
    }
    interface PrefixListEntryArgs {
        /**
         * The CIDR block.
         */
        cidr: pulumi.Input<string>;
        /**
         * A description for the entry.
         *
         * Constraints: Up to 255 characters in length.
         */
        description?: pulumi.Input<string>;
    }
    /**
     * The hostname type for EC2 instances launched into this subnet and how DNS A and AAAA record queries to the instances should be handled. For more information, see [Amazon EC2 instance hostname types](https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/ec2-instance-naming.html) in the *User Guide*.
     *  Available options:
     *   +  EnableResourceNameDnsAAAARecord (true | false)
     *   +  EnableResourceNameDnsARecord (true | false)
     *   +  HostnameType (ip-name | resource-name)
     */
    interface PrivateDnsNameOptionsOnLaunchPropertiesArgs {
        /**
         * Indicates whether to respond to DNS queries for instance hostnames with DNS A records.
         */
        enableResourceNameDnsARecord?: pulumi.Input<boolean>;
        /**
         * Indicates whether to respond to DNS queries for instance hostname with DNS AAAA records.
         */
        enableResourceNameDnsAaaaRecord?: pulumi.Input<boolean>;
        /**
         * The type of hostname for EC2 instances. For IPv4 only subnets, an instance DNS name must be based on the instance IPv4 address. For IPv6 only subnets, an instance DNS name must be based on the instance ID. For dual-stack subnets, you can specify whether DNS names use the instance IPv4 address or the instance ID.
         */
        hostnameType?: pulumi.Input<string>;
    }
    /**
     * BGP Options
     */
    interface RouteServerPeerBgpOptionsArgs {
        /**
         * BGP ASN of the Route Server Peer
         */
        peerAsn?: pulumi.Input<number>;
        /**
         * BGP Liveness Detection
         */
        peerLivenessDetection?: pulumi.Input<enums.ec2.RouteServerPeerBgpOptionsPeerLivenessDetection>;
    }
    interface SecurityGroupEgressArgs {
        /**
         * The IPv4 address range, in CIDR format.
         *
         * You must specify exactly one of the following: `CidrIp` , `CidrIpv6` , `DestinationPrefixListId` , or `DestinationSecurityGroupId` .
         *
         * For examples of rules that you can add to security groups for specific access scenarios, see [Security group rules for different use cases](https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/security-group-rules-reference.html) in the *Amazon EC2 User Guide* .
         */
        cidrIp?: pulumi.Input<string>;
        /**
         * The IPv6 address range, in CIDR format.
         *
         * You must specify exactly one of the following: `CidrIp` , `CidrIpv6` , `DestinationPrefixListId` , or `DestinationSecurityGroupId` .
         *
         * For examples of rules that you can add to security groups for specific access scenarios, see [Security group rules for different use cases](https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/security-group-rules-reference.html) in the *Amazon EC2 User Guide* .
         */
        cidrIpv6?: pulumi.Input<string>;
        /**
         * A description for the security group rule.
         *
         * Constraints: Up to 255 characters in length. Allowed characters are a-z, A-Z, 0-9, spaces, and ._-:/()#,@[]+=;{}!$*
         */
        description?: pulumi.Input<string>;
        /**
         * The prefix list IDs for the destination AWS service. This is the AWS service that you want to access through a VPC endpoint from instances associated with the security group.
         *
         * You must specify exactly one of the following: `CidrIp` , `CidrIpv6` , `DestinationPrefixListId` , or `DestinationSecurityGroupId` .
         */
        destinationPrefixListId?: pulumi.Input<string>;
        /**
         * The ID of the destination VPC security group.
         *
         * You must specify exactly one of the following: `CidrIp` , `CidrIpv6` , `DestinationPrefixListId` , or `DestinationSecurityGroupId` .
         */
        destinationSecurityGroupId?: pulumi.Input<string>;
        /**
         * If the protocol is TCP or UDP, this is the start of the port range. If the protocol is ICMP or ICMPv6, this is the ICMP type or -1 (all ICMP types).
         */
        fromPort?: pulumi.Input<number>;
        /**
         * The IP protocol name ( `tcp` , `udp` , `icmp` , `icmpv6` ) or number (see [Protocol Numbers](https://docs.aws.amazon.com/http://www.iana.org/assignments/protocol-numbers/protocol-numbers.xhtml) ).
         *
         * Use `-1` to specify all protocols. When authorizing security group rules, specifying `-1` or a protocol number other than `tcp` , `udp` , `icmp` , or `icmpv6` allows traffic on all ports, regardless of any port range you specify. For `tcp` , `udp` , and `icmp` , you must specify a port range. For `icmpv6` , the port range is optional; if you omit the port range, traffic for all types and codes is allowed.
         */
        ipProtocol: pulumi.Input<string>;
        /**
         * If the protocol is TCP or UDP, this is the end of the port range. If the protocol is ICMP or ICMPv6, this is the ICMP code or -1 (all ICMP codes). If the start port is -1 (all ICMP types), then the end port must be -1 (all ICMP codes).
         */
        toPort?: pulumi.Input<number>;
    }
    interface SecurityGroupIngressArgs {
        /**
         * The IPv4 address range, in CIDR format.
         *
         * You must specify exactly one of the following: `CidrIp` , `CidrIpv6` , `SourcePrefixListId` , or `SourceSecurityGroupId` .
         *
         * For examples of rules that you can add to security groups for specific access scenarios, see [Security group rules for different use cases](https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/security-group-rules-reference.html) in the *Amazon EC2 User Guide* .
         */
        cidrIp?: pulumi.Input<string>;
        /**
         * The IPv6 address range, in CIDR format.
         *
         * You must specify exactly one of the following: `CidrIp` , `CidrIpv6` , `SourcePrefixListId` , or `SourceSecurityGroupId` .
         *
         * For examples of rules that you can add to security groups for specific access scenarios, see [Security group rules for different use cases](https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/security-group-rules-reference.html) in the *Amazon EC2 User Guide* .
         */
        cidrIpv6?: pulumi.Input<string>;
        /**
         * Updates the description of an ingress (inbound) security group rule. You can replace an existing description, or add a description to a rule that did not have one previously.
         *
         * Constraints: Up to 255 characters in length. Allowed characters are a-z, A-Z, 0-9, spaces, and ._-:/()#,@[]+=;{}!$*
         */
        description?: pulumi.Input<string>;
        /**
         * If the protocol is TCP or UDP, this is the start of the port range. If the protocol is ICMP or ICMPv6, this is the ICMP type or -1 (all ICMP types).
         */
        fromPort?: pulumi.Input<number>;
        /**
         * The IP protocol name ( `tcp` , `udp` , `icmp` , `icmpv6` ) or number (see [Protocol Numbers](https://docs.aws.amazon.com/http://www.iana.org/assignments/protocol-numbers/protocol-numbers.xhtml) ).
         *
         * Use `-1` to specify all protocols. When authorizing security group rules, specifying `-1` or a protocol number other than `tcp` , `udp` , `icmp` , or `icmpv6` allows traffic on all ports, regardless of any port range you specify. For `tcp` , `udp` , and `icmp` , you must specify a port range. For `icmpv6` , the port range is optional; if you omit the port range, traffic for all types and codes is allowed.
         */
        ipProtocol: pulumi.Input<string>;
        /**
         * The ID of a prefix list.
         */
        sourcePrefixListId?: pulumi.Input<string>;
        /**
         * The ID of the security group.
         */
        sourceSecurityGroupId?: pulumi.Input<string>;
        /**
         * [Default VPC] The name of the source security group. You must specify either the security group ID or the security group name. You can't specify the group name in combination with an IP address range. Creates rules that grant full ICMP, UDP, and TCP access.
         *
         * For security groups in a nondefault VPC, you must specify the group ID.
         */
        sourceSecurityGroupName?: pulumi.Input<string>;
        /**
         * [nondefault VPC] The AWS account ID for the source security group, if the source security group is in a different account. You can't specify this property with an IP address range. Creates rules that grant full ICMP, UDP, and TCP access.
         *
         * If you specify `SourceSecurityGroupName` or `SourceSecurityGroupId` and that security group is owned by a different account than the account creating the stack, you must specify the `SourceSecurityGroupOwnerId` ; otherwise, this property is optional.
         */
        sourceSecurityGroupOwnerId?: pulumi.Input<string>;
        /**
         * If the protocol is TCP or UDP, this is the end of the port range. If the protocol is ICMP or ICMPv6, this is the ICMP code or -1 (all ICMP codes). If the start port is -1 (all ICMP types), then the end port must be -1 (all ICMP codes).
         */
        toPort?: pulumi.Input<number>;
    }
    interface SpotFleetAcceleratorCountRequestArgs {
        /**
         * The maximum number of accelerators. To specify no maximum limit, omit this parameter. To exclude accelerator-enabled instance types, set `Max` to `0` .
         */
        max?: pulumi.Input<number>;
        /**
         * The minimum number of accelerators. To specify no minimum limit, omit this parameter.
         */
        min?: pulumi.Input<number>;
    }
    interface SpotFleetAcceleratorTotalMemoryMiBRequestArgs {
        /**
         * The maximum amount of accelerator memory, in MiB. To specify no maximum limit, omit this parameter.
         */
        max?: pulumi.Input<number>;
        /**
         * The minimum amount of accelerator memory, in MiB. To specify no minimum limit, omit this parameter.
         */
        min?: pulumi.Input<number>;
    }
    interface SpotFleetBaselineEbsBandwidthMbpsRequestArgs {
        /**
         * The maximum baseline bandwidth, in Mbps. To specify no maximum limit, omit this parameter.
         */
        max?: pulumi.Input<number>;
        /**
         * The minimum baseline bandwidth, in Mbps. To specify no minimum limit, omit this parameter.
         */
        min?: pulumi.Input<number>;
    }
    interface SpotFleetBaselinePerformanceFactorsRequestArgs {
        /**
         * The CPU performance to consider, using an instance family as the baseline reference.
         */
        cpu?: pulumi.Input<inputs.ec2.SpotFleetCpuPerformanceFactorRequestArgs>;
    }
    interface SpotFleetBlockDeviceMappingArgs {
        /**
         * The device name (for example, `/dev/sdh` or `xvdh` ).
         */
        deviceName: pulumi.Input<string>;
        /**
         * Parameters used to automatically set up EBS volumes when the instance is launched.
         */
        ebs?: pulumi.Input<inputs.ec2.SpotFleetEbsBlockDeviceArgs>;
        /**
         * To omit the device from the block device mapping, specify an empty string. When this property is specified, the device is removed from the block device mapping regardless of the assigned value.
         */
        noDevice?: pulumi.Input<string>;
        /**
         * The virtual device name ( `ephemeral` N). Instance store volumes are numbered starting from 0. An instance type with 2 available instance store volumes can specify mappings for `ephemeral0` and `ephemeral1` . The number of available instance store volumes depends on the instance type. After you connect to the instance, you must mount the volume.
         *
         * NVMe instance store volumes are automatically enumerated and assigned a device name. Including them in your block device mapping has no effect.
         *
         * Constraints: For M3 instances, you must specify instance store volumes in the block device mapping for the instance. When you launch an M3 instance, we ignore any instance store volumes specified in the block device mapping for the AMI.
         */
        virtualName?: pulumi.Input<string>;
    }
    interface SpotFleetClassicLoadBalancerArgs {
        /**
         * The name of the load balancer.
         */
        name: pulumi.Input<string>;
    }
    interface SpotFleetClassicLoadBalancersConfigArgs {
        /**
         * One or more Classic Load Balancers.
         */
        classicLoadBalancers: pulumi.Input<pulumi.Input<inputs.ec2.SpotFleetClassicLoadBalancerArgs>[]>;
    }
    interface SpotFleetCpuPerformanceFactorRequestArgs {
        /**
         * Specify an instance family to use as the baseline reference for CPU performance. All instance types that match your specified attributes will be compared against the CPU performance of the referenced instance family, regardless of CPU manufacturer or architecture differences.
         *
         * > Currently, only one instance family can be specified in the list.
         */
        references?: pulumi.Input<pulumi.Input<inputs.ec2.SpotFleetPerformanceFactorReferenceRequestArgs>[]>;
    }
    interface SpotFleetEbsBlockDeviceArgs {
        /**
         * Indicates whether the EBS volume is deleted on instance termination. For more information, see [Preserving Amazon EBS volumes on instance termination](https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/terminating-instances.html#preserving-volumes-on-termination) in the *Amazon EC2 User Guide* .
         */
        deleteOnTermination?: pulumi.Input<boolean>;
        /**
         * Indicates whether the encryption state of an EBS volume is changed while being restored from a backing snapshot. The effect of setting the encryption state to `true` depends on the volume origin (new or from a snapshot), starting encryption state, ownership, and whether encryption by default is enabled. For more information, see [Amazon EBS Encryption](https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/EBSEncryption.html#encryption-parameters) in the *Amazon EC2 User Guide* .
         *
         * In no case can you remove encryption from an encrypted volume.
         *
         * Encrypted volumes can only be attached to instances that support Amazon EBS encryption. For more information, see [Supported Instance Types](https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/EBSEncryption.html#EBSEncryption_supported_instances) .
         *
         * This parameter is not returned by [DescribeImageAttribute](https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DescribeImageAttribute.html) .
         */
        encrypted?: pulumi.Input<boolean>;
        /**
         * The number of I/O operations per second (IOPS). For `gp3` , `io1` , and `io2` volumes, this represents the number of IOPS that are provisioned for the volume. For `gp2` volumes, this represents the baseline performance of the volume and the rate at which the volume accumulates I/O credits for bursting.
         *
         * The following are the supported values for each volume type:
         *
         * - `gp3` : 3,000 - 16,000 IOPS
         * - `io1` : 100 - 64,000 IOPS
         * - `io2` : 100 - 256,000 IOPS
         *
         * For `io2` volumes, you can achieve up to 256,000 IOPS on [instances built on the Nitro System](https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/instance-types.html#ec2-nitro-instances) . On other instances, you can achieve performance up to 32,000 IOPS.
         *
         * This parameter is required for `io1` and `io2` volumes. The default for `gp3` volumes is 3,000 IOPS.
         */
        iops?: pulumi.Input<number>;
        /**
         * The ID of the snapshot.
         */
        snapshotId?: pulumi.Input<string>;
        /**
         * The size of the volume, in GiBs. You must specify either a snapshot ID or a volume size. If you specify a snapshot, the default is the snapshot size. You can specify a volume size that is equal to or larger than the snapshot size.
         *
         * The following are the supported sizes for each volume type:
         *
         * - `gp2` and `gp3` : 1 - 16,384 GiB
         * - `io1` : 4 - 16,384 GiB
         * - `io2` : 4 - 65,536 GiB
         * - `st1` and `sc1` : 125 - 16,384 GiB
         * - `standard` : 1 - 1024 GiB
         */
        volumeSize?: pulumi.Input<number>;
        /**
         * The volume type. For more information, see [Amazon EBS volume types](https://docs.aws.amazon.com/ebs/latest/userguide/ebs-volume-types.html) in the *Amazon EBS User Guide* .
         */
        volumeType?: pulumi.Input<enums.ec2.SpotFleetEbsBlockDeviceVolumeType>;
    }
    interface SpotFleetFleetLaunchTemplateSpecificationArgs {
        /**
         * The ID of the launch template.
         *
         * You must specify the `LaunchTemplateId` or the `LaunchTemplateName` , but not both.
         */
        launchTemplateId?: pulumi.Input<string>;
        /**
         * The name of the launch template.
         *
         * You must specify the `LaunchTemplateName` or the `LaunchTemplateId` , but not both.
         */
        launchTemplateName?: pulumi.Input<string>;
        /**
         * The version number of the launch template.
         *
         * Specifying `$Latest` or `$Default` for the template version number is not supported. However, you can specify `LatestVersionNumber` or `DefaultVersionNumber` using the `Fn::GetAtt` intrinsic function. For more information, see [Fn::GetAtt](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-ec2-launchtemplate.html#aws-resource-ec2-launchtemplate-return-values-fn--getatt) .
         */
        version: pulumi.Input<string>;
    }
    interface SpotFleetGroupIdentifierArgs {
        /**
         * The ID of the security group.
         */
        groupId: pulumi.Input<string>;
    }
    interface SpotFleetIamInstanceProfileSpecificationArgs {
        /**
         * The Amazon Resource Name (ARN) of the instance profile.
         */
        arn?: pulumi.Input<string>;
    }
    interface SpotFleetInstanceIpv6AddressArgs {
        /**
         * The IPv6 address.
         */
        ipv6Address: pulumi.Input<string>;
    }
    interface SpotFleetInstanceNetworkInterfaceSpecificationArgs {
        /**
         * Indicates whether to assign a public IPv4 address to an instance you launch in a VPC. The public IP address can only be assigned to a network interface for eth0, and can only be assigned to a new network interface, not an existing one. You cannot specify more than one network interface in the request. If launching into a default subnet, the default value is `true` .
         *
         * AWS charges for all public IPv4 addresses, including public IPv4 addresses associated with running instances and Elastic IP addresses. For more information, see the *Public IPv4 Address* tab on the [Amazon VPC pricing page](https://docs.aws.amazon.com/vpc/pricing/) .
         */
        associatePublicIpAddress?: pulumi.Input<boolean>;
        /**
         * Indicates whether the network interface is deleted when the instance is terminated.
         */
        deleteOnTermination?: pulumi.Input<boolean>;
        /**
         * The description of the network interface. Applies only if creating a network interface when launching an instance.
         */
        description?: pulumi.Input<string>;
        /**
         * The position of the network interface in the attachment order. A primary network interface has a device index of 0.
         *
         * If you specify a network interface when launching an instance, you must specify the device index.
         */
        deviceIndex?: pulumi.Input<number>;
        /**
         * The IDs of the security groups for the network interface. Applies only if creating a network interface when launching an instance.
         */
        groups?: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * A number of IPv6 addresses to assign to the network interface. Amazon EC2 chooses the IPv6 addresses from the range of the subnet. You cannot specify this option and the option to assign specific IPv6 addresses in the same request. You can specify this option if you've specified a minimum number of instances to launch.
         */
        ipv6AddressCount?: pulumi.Input<number>;
        /**
         * The IPv6 addresses to assign to the network interface. You cannot specify this option and the option to assign a number of IPv6 addresses in the same request. You cannot specify this option if you've specified a minimum number of instances to launch.
         */
        ipv6Addresses?: pulumi.Input<pulumi.Input<inputs.ec2.SpotFleetInstanceIpv6AddressArgs>[]>;
        /**
         * The ID of the network interface.
         *
         * If you are creating a Spot Fleet, omit this parameter because you can’t specify a network interface ID in a launch specification.
         */
        networkInterfaceId?: pulumi.Input<string>;
        /**
         * The private IPv4 addresses to assign to the network interface. Only one private IPv4 address can be designated as primary. You cannot specify this option if you're launching more than one instance in a [RunInstances](https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_RunInstances.html) request.
         */
        privateIpAddresses?: pulumi.Input<pulumi.Input<inputs.ec2.SpotFleetPrivateIpAddressSpecificationArgs>[]>;
        /**
         * The number of secondary private IPv4 addresses. You can’t specify this parameter and also specify a secondary private IP address using the `PrivateIpAddress` parameter.
         */
        secondaryPrivateIpAddressCount?: pulumi.Input<number>;
        /**
         * The ID of the subnet associated with the network interface.
         */
        subnetId?: pulumi.Input<string>;
    }
    interface SpotFleetInstanceRequirementsRequestArgs {
        /**
         * The minimum and maximum number of accelerators (GPUs, FPGAs, or AWS Inferentia chips) on an instance.
         *
         * To exclude accelerator-enabled instance types, set `Max` to `0` .
         *
         * Default: No minimum or maximum limits
         */
        acceleratorCount?: pulumi.Input<inputs.ec2.SpotFleetAcceleratorCountRequestArgs>;
        /**
         * Indicates whether instance types must have accelerators by specific manufacturers.
         *
         * - For instance types with AWS devices, specify `amazon-web-services` .
         * - For instance types with AMD devices, specify `amd` .
         * - For instance types with Habana devices, specify `habana` .
         * - For instance types with NVIDIA devices, specify `nvidia` .
         * - For instance types with Xilinx devices, specify `xilinx` .
         *
         * Default: Any manufacturer
         */
        acceleratorManufacturers?: pulumi.Input<pulumi.Input<enums.ec2.SpotFleetInstanceRequirementsRequestAcceleratorManufacturersItem>[]>;
        /**
         * The accelerators that must be on the instance type.
         *
         * - For instance types with NVIDIA A10G GPUs, specify `a10g` .
         * - For instance types with NVIDIA A100 GPUs, specify `a100` .
         * - For instance types with NVIDIA H100 GPUs, specify `h100` .
         * - For instance types with AWS Inferentia chips, specify `inferentia` .
         * - For instance types with NVIDIA GRID K520 GPUs, specify `k520` .
         * - For instance types with NVIDIA K80 GPUs, specify `k80` .
         * - For instance types with NVIDIA M60 GPUs, specify `m60` .
         * - For instance types with AMD Radeon Pro V520 GPUs, specify `radeon-pro-v520` .
         * - For instance types with NVIDIA T4 GPUs, specify `t4` .
         * - For instance types with NVIDIA T4G GPUs, specify `t4g` .
         * - For instance types with Xilinx VU9P FPGAs, specify `vu9p` .
         * - For instance types with NVIDIA V100 GPUs, specify `v100` .
         *
         * Default: Any accelerator
         */
        acceleratorNames?: pulumi.Input<pulumi.Input<enums.ec2.SpotFleetInstanceRequirementsRequestAcceleratorNamesItem>[]>;
        /**
         * The minimum and maximum amount of total accelerator memory, in MiB.
         *
         * Default: No minimum or maximum limits
         */
        acceleratorTotalMemoryMiB?: pulumi.Input<inputs.ec2.SpotFleetAcceleratorTotalMemoryMiBRequestArgs>;
        /**
         * The accelerator types that must be on the instance type.
         *
         * - For instance types with FPGA accelerators, specify `fpga` .
         * - For instance types with GPU accelerators, specify `gpu` .
         *
         * Default: Any accelerator type
         */
        acceleratorTypes?: pulumi.Input<pulumi.Input<enums.ec2.SpotFleetInstanceRequirementsRequestAcceleratorTypesItem>[]>;
        /**
         * The instance types to apply your specified attributes against. All other instance types are ignored, even if they match your specified attributes.
         *
         * You can use strings with one or more wild cards, represented by an asterisk ( `*` ), to allow an instance type, size, or generation. The following are examples: `m5.8xlarge` , `c5*.*` , `m5a.*` , `r*` , `*3*` .
         *
         * For example, if you specify `c5*` ,Amazon EC2 will allow the entire C5 instance family, which includes all C5a and C5n instance types. If you specify `m5a.*` , Amazon EC2 will allow all the M5a instance types, but not the M5n instance types.
         *
         * > If you specify `AllowedInstanceTypes` , you can't specify `ExcludedInstanceTypes` .
         *
         * Default: All instance types
         */
        allowedInstanceTypes?: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * Indicates whether bare metal instance types must be included, excluded, or required.
         *
         * - To include bare metal instance types, specify `included` .
         * - To require only bare metal instance types, specify `required` .
         * - To exclude bare metal instance types, specify `excluded` .
         *
         * Default: `excluded`
         */
        bareMetal?: pulumi.Input<enums.ec2.SpotFleetInstanceRequirementsRequestBareMetal>;
        /**
         * The minimum and maximum baseline bandwidth to Amazon EBS, in Mbps. For more information, see [Amazon EBS–optimized instances](https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/ebs-optimized.html) in the *Amazon EC2 User Guide* .
         *
         * Default: No minimum or maximum limits
         */
        baselineEbsBandwidthMbps?: pulumi.Input<inputs.ec2.SpotFleetBaselineEbsBandwidthMbpsRequestArgs>;
        /**
         * The baseline performance to consider, using an instance family as a baseline reference. The instance family establishes the lowest acceptable level of performance. Amazon EC2 uses this baseline to guide instance type selection, but there is no guarantee that the selected instance types will always exceed the baseline for every application. Currently, this parameter only supports CPU performance as a baseline performance factor. For more information, see [Performance protection](https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/ec2-fleet-attribute-based-instance-type-selection.html#ec2fleet-abis-performance-protection) in the *Amazon EC2 User Guide* .
         */
        baselinePerformanceFactors?: pulumi.Input<inputs.ec2.SpotFleetBaselinePerformanceFactorsRequestArgs>;
        /**
         * Indicates whether burstable performance T instance types are included, excluded, or required. For more information, see [Burstable performance instances](https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/burstable-performance-instances.html) .
         *
         * - To include burstable performance instance types, specify `included` .
         * - To require only burstable performance instance types, specify `required` .
         * - To exclude burstable performance instance types, specify `excluded` .
         *
         * Default: `excluded`
         */
        burstablePerformance?: pulumi.Input<enums.ec2.SpotFleetInstanceRequirementsRequestBurstablePerformance>;
        /**
         * The CPU manufacturers to include.
         *
         * - For instance types with Intel CPUs, specify `intel` .
         * - For instance types with AMD CPUs, specify `amd` .
         * - For instance types with AWS CPUs, specify `amazon-web-services` .
         * - For instance types with Apple CPUs, specify `apple` .
         *
         * > Don't confuse the CPU manufacturer with the CPU architecture. Instances will be launched with a compatible CPU architecture based on the Amazon Machine Image (AMI) that you specify in your launch template.
         *
         * Default: Any manufacturer
         */
        cpuManufacturers?: pulumi.Input<pulumi.Input<enums.ec2.SpotFleetInstanceRequirementsRequestCpuManufacturersItem>[]>;
        /**
         * The instance types to exclude.
         *
         * You can use strings with one or more wild cards, represented by an asterisk ( `*` ), to exclude an instance family, type, size, or generation. The following are examples: `m5.8xlarge` , `c5*.*` , `m5a.*` , `r*` , `*3*` .
         *
         * For example, if you specify `c5*` ,Amazon EC2 will exclude the entire C5 instance family, which includes all C5a and C5n instance types. If you specify `m5a.*` , Amazon EC2 will exclude all the M5a instance types, but not the M5n instance types.
         *
         * > If you specify `ExcludedInstanceTypes` , you can't specify `AllowedInstanceTypes` .
         *
         * Default: No excluded instance types
         */
        excludedInstanceTypes?: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * Indicates whether current or previous generation instance types are included. The current generation instance types are recommended for use. Current generation instance types are typically the latest two to three generations in each instance family. For more information, see [Instance types](https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/instance-types.html) in the *Amazon EC2 User Guide* .
         *
         * For current generation instance types, specify `current` .
         *
         * For previous generation instance types, specify `previous` .
         *
         * Default: Current and previous generation instance types
         */
        instanceGenerations?: pulumi.Input<pulumi.Input<enums.ec2.SpotFleetInstanceRequirementsRequestInstanceGenerationsItem>[]>;
        /**
         * Indicates whether instance types with instance store volumes are included, excluded, or required. For more information, [Amazon EC2 instance store](https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/InstanceStorage.html) in the *Amazon EC2 User Guide* .
         *
         * - To include instance types with instance store volumes, specify `included` .
         * - To require only instance types with instance store volumes, specify `required` .
         * - To exclude instance types with instance store volumes, specify `excluded` .
         *
         * Default: `included`
         */
        localStorage?: pulumi.Input<enums.ec2.SpotFleetInstanceRequirementsRequestLocalStorage>;
        /**
         * The type of local storage that is required.
         *
         * - For instance types with hard disk drive (HDD) storage, specify `hdd` .
         * - For instance types with solid state drive (SSD) storage, specify `ssd` .
         *
         * Default: `hdd` and `ssd`
         */
        localStorageTypes?: pulumi.Input<pulumi.Input<enums.ec2.SpotFleetInstanceRequirementsRequestLocalStorageTypesItem>[]>;
        /**
         * [Price protection] The price protection threshold for Spot Instances, as a percentage of an identified On-Demand price. The identified On-Demand price is the price of the lowest priced current generation C, M, or R instance type with your specified attributes. If no current generation C, M, or R instance type matches your attributes, then the identified price is from the lowest priced current generation instance types, and failing that, from the lowest priced previous generation instance types that match your attributes. When Amazon EC2 selects instance types with your attributes, it will exclude instance types whose price exceeds your specified threshold.
         *
         * The parameter accepts an integer, which Amazon EC2 interprets as a percentage.
         *
         * If you set `TargetCapacityUnitType` to `vcpu` or `memory-mib` , the price protection threshold is based on the per vCPU or per memory price instead of the per instance price.
         *
         * > Only one of `SpotMaxPricePercentageOverLowestPrice` or `MaxSpotPriceAsPercentageOfOptimalOnDemandPrice` can be specified. If you don't specify either, Amazon EC2 will automatically apply optimal price protection to consistently select from a wide range of instance types. To indicate no price protection threshold for Spot Instances, meaning you want to consider all instance types that match your attributes, include one of these parameters and specify a high value, such as `999999` .
         */
        maxSpotPriceAsPercentageOfOptimalOnDemandPrice?: pulumi.Input<number>;
        /**
         * The minimum and maximum amount of memory per vCPU, in GiB.
         *
         * Default: No minimum or maximum limits
         */
        memoryGiBPerVCpu?: pulumi.Input<inputs.ec2.SpotFleetMemoryGiBPerVCpuRequestArgs>;
        /**
         * The minimum and maximum amount of memory, in MiB.
         */
        memoryMiB?: pulumi.Input<inputs.ec2.SpotFleetMemoryMiBRequestArgs>;
        /**
         * The minimum and maximum amount of baseline network bandwidth, in gigabits per second (Gbps). For more information, see [Amazon EC2 instance network bandwidth](https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/ec2-instance-network-bandwidth.html) in the *Amazon EC2 User Guide* .
         *
         * Default: No minimum or maximum limits
         */
        networkBandwidthGbps?: pulumi.Input<inputs.ec2.SpotFleetNetworkBandwidthGbpsRequestArgs>;
        /**
         * The minimum and maximum number of network interfaces.
         *
         * Default: No minimum or maximum limits
         */
        networkInterfaceCount?: pulumi.Input<inputs.ec2.SpotFleetNetworkInterfaceCountRequestArgs>;
        /**
         * [Price protection] The price protection threshold for On-Demand Instances, as a percentage higher than an identified On-Demand price. The identified On-Demand price is the price of the lowest priced current generation C, M, or R instance type with your specified attributes. When Amazon EC2 selects instance types with your attributes, it will exclude instance types whose price exceeds your specified threshold.
         *
         * The parameter accepts an integer, which Amazon EC2 interprets as a percentage.
         *
         * To indicate no price protection threshold, specify a high value, such as `999999` .
         *
         * This parameter is not supported for [GetSpotPlacementScores](https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_GetSpotPlacementScores.html) and [GetInstanceTypesFromInstanceRequirements](https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_GetInstanceTypesFromInstanceRequirements.html) .
         *
         * > If you set `TargetCapacityUnitType` to `vcpu` or `memory-mib` , the price protection threshold is applied based on the per-vCPU or per-memory price instead of the per-instance price.
         *
         * Default: `20`
         */
        onDemandMaxPricePercentageOverLowestPrice?: pulumi.Input<number>;
        /**
         * Indicates whether instance types must support hibernation for On-Demand Instances.
         *
         * This parameter is not supported for [GetSpotPlacementScores](https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_GetSpotPlacementScores.html) .
         *
         * Default: `false`
         */
        requireHibernateSupport?: pulumi.Input<boolean>;
        /**
         * [Price protection] The price protection threshold for Spot Instances, as a percentage higher than an identified Spot price. The identified Spot price is the Spot price of the lowest priced current generation C, M, or R instance type with your specified attributes. If no current generation C, M, or R instance type matches your attributes, then the identified Spot price is from the lowest priced current generation instance types, and failing that, from the lowest priced previous generation instance types that match your attributes. When Amazon EC2 selects instance types with your attributes, it will exclude instance types whose Spot price exceeds your specified threshold.
         *
         * The parameter accepts an integer, which Amazon EC2 interprets as a percentage.
         *
         * If you set `TargetCapacityUnitType` to `vcpu` or `memory-mib` , the price protection threshold is applied based on the per-vCPU or per-memory price instead of the per-instance price.
         *
         * This parameter is not supported for [GetSpotPlacementScores](https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_GetSpotPlacementScores.html) and [GetInstanceTypesFromInstanceRequirements](https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_GetInstanceTypesFromInstanceRequirements.html) .
         *
         * > Only one of `SpotMaxPricePercentageOverLowestPrice` or `MaxSpotPriceAsPercentageOfOptimalOnDemandPrice` can be specified. If you don't specify either, Amazon EC2 will automatically apply optimal price protection to consistently select from a wide range of instance types. To indicate no price protection threshold for Spot Instances, meaning you want to consider all instance types that match your attributes, include one of these parameters and specify a high value, such as `999999` .
         *
         * Default: `100`
         */
        spotMaxPricePercentageOverLowestPrice?: pulumi.Input<number>;
        /**
         * The minimum and maximum amount of total local storage, in GB.
         *
         * Default: No minimum or maximum limits
         */
        totalLocalStorageGb?: pulumi.Input<inputs.ec2.SpotFleetTotalLocalStorageGbRequestArgs>;
        /**
         * The minimum and maximum number of vCPUs.
         */
        vCpuCount?: pulumi.Input<inputs.ec2.SpotFleetVCpuCountRangeRequestArgs>;
    }
    interface SpotFleetLaunchSpecificationArgs {
        /**
         * One or more block devices that are mapped to the Spot Instances. You can't specify both a snapshot ID and an encryption value. This is because only blank volumes can be encrypted on creation. If a snapshot is the basis for a volume, it is not blank and its encryption status is used for the volume encryption status.
         */
        blockDeviceMappings?: pulumi.Input<pulumi.Input<inputs.ec2.SpotFleetBlockDeviceMappingArgs>[]>;
        /**
         * Indicates whether the instances are optimized for EBS I/O. This optimization provides dedicated throughput to Amazon EBS and an optimized configuration stack to provide optimal EBS I/O performance. This optimization isn't available with all instance types. Additional usage charges apply when using an EBS Optimized instance.
         *
         * Default: `false`
         */
        ebsOptimized?: pulumi.Input<boolean>;
        /**
         * The IAM instance profile.
         */
        iamInstanceProfile?: pulumi.Input<inputs.ec2.SpotFleetIamInstanceProfileSpecificationArgs>;
        /**
         * The ID of the AMI.
         */
        imageId: pulumi.Input<string>;
        /**
         * The attributes for the instance types. When you specify instance attributes, Amazon EC2 will identify instance types with those attributes.
         *
         * > If you specify `InstanceRequirements` , you can't specify `InstanceType` .
         */
        instanceRequirements?: pulumi.Input<inputs.ec2.SpotFleetInstanceRequirementsRequestArgs>;
        /**
         * The instance type.
         */
        instanceType?: pulumi.Input<string>;
        /**
         * The ID of the kernel.
         */
        kernelId?: pulumi.Input<string>;
        /**
         * The name of the key pair.
         */
        keyName?: pulumi.Input<string>;
        /**
         * Enable or disable monitoring for the instances.
         */
        monitoring?: pulumi.Input<inputs.ec2.SpotFleetMonitoringArgs>;
        /**
         * The network interfaces.
         */
        networkInterfaces?: pulumi.Input<pulumi.Input<inputs.ec2.SpotFleetInstanceNetworkInterfaceSpecificationArgs>[]>;
        /**
         * The placement information.
         */
        placement?: pulumi.Input<inputs.ec2.SpotFleetSpotPlacementArgs>;
        /**
         * The ID of the RAM disk. Some kernels require additional drivers at launch. Check the kernel requirements for information about whether you need to specify a RAM disk. To find kernel requirements, refer to the AWS Resource Center and search for the kernel ID.
         */
        ramdiskId?: pulumi.Input<string>;
        /**
         * The security groups.
         *
         * If you specify a network interface, you must specify any security groups as part of the network interface instead of using this parameter.
         */
        securityGroups?: pulumi.Input<pulumi.Input<inputs.ec2.SpotFleetGroupIdentifierArgs>[]>;
        /**
         * The maximum price per unit hour that you are willing to pay for a Spot Instance. We do not recommend using this parameter because it can lead to increased interruptions. If you do not specify this parameter, you will pay the current Spot price.
         *
         * > If you specify a maximum price, your instances will be interrupted more frequently than if you do not specify this parameter.
         */
        spotPrice?: pulumi.Input<string>;
        /**
         * The IDs of the subnets in which to launch the instances. To specify multiple subnets, separate them using commas; for example, "subnet-1234abcdeexample1, subnet-0987cdef6example2".
         *
         * If you specify a network interface, you must specify any subnets as part of the network interface instead of using this parameter.
         */
        subnetId?: pulumi.Input<string>;
        /**
         * The tags to apply during creation.
         */
        tagSpecifications?: pulumi.Input<pulumi.Input<inputs.ec2.SpotFleetTagSpecificationArgs>[]>;
        /**
         * The base64-encoded user data that instances use when starting up. User data is limited to 16 KB.
         */
        userData?: pulumi.Input<string>;
        /**
         * The number of units provided by the specified instance type. These are the same units that you chose to set the target capacity in terms of instances, or a performance characteristic such as vCPUs, memory, or I/O.
         *
         * If the target capacity divided by this value is not a whole number, Amazon EC2 rounds the number of instances to the next whole number. If this value is not specified, the default is 1.
         *
         * > When specifying weights, the price used in the `lowestPrice` and `priceCapacityOptimized` allocation strategies is per *unit* hour (where the instance price is divided by the specified weight). However, if all the specified weights are above the requested `TargetCapacity` , resulting in only 1 instance being launched, the price used is per *instance* hour.
         */
        weightedCapacity?: pulumi.Input<number>;
    }
    interface SpotFleetLaunchTemplateConfigArgs {
        /**
         * The launch template to use. Make sure that the launch template does not contain the `NetworkInterfaceId` parameter because you can't specify a network interface ID in a Spot Fleet.
         */
        launchTemplateSpecification?: pulumi.Input<inputs.ec2.SpotFleetFleetLaunchTemplateSpecificationArgs>;
        /**
         * Any parameters that you specify override the same parameters in the launch template.
         */
        overrides?: pulumi.Input<pulumi.Input<inputs.ec2.SpotFleetLaunchTemplateOverridesArgs>[]>;
    }
    interface SpotFleetLaunchTemplateOverridesArgs {
        /**
         * The Availability Zone in which to launch the instances.
         */
        availabilityZone?: pulumi.Input<string>;
        /**
         * The instance requirements. When you specify instance requirements, Amazon EC2 will identify instance types with the provided requirements, and then use your On-Demand and Spot allocation strategies to launch instances from these instance types, in the same way as when you specify a list of instance types.
         *
         * > If you specify `InstanceRequirements` , you can't specify `InstanceType` .
         */
        instanceRequirements?: pulumi.Input<inputs.ec2.SpotFleetInstanceRequirementsRequestArgs>;
        /**
         * The instance type.
         */
        instanceType?: pulumi.Input<string>;
        /**
         * The priority for the launch template override. The highest priority is launched first.
         *
         * If `OnDemandAllocationStrategy` is set to `prioritized` , Spot Fleet uses priority to determine which launch template override to use first in fulfilling On-Demand capacity.
         *
         * If the Spot `AllocationStrategy` is set to `capacityOptimizedPrioritized` , Spot Fleet uses priority on a best-effort basis to determine which launch template override to use in fulfilling Spot capacity, but optimizes for capacity first.
         *
         * Valid values are whole numbers starting at `0` . The lower the number, the higher the priority. If no number is set, the launch template override has the lowest priority. You can set the same priority for different launch template overrides.
         */
        priority?: pulumi.Input<number>;
        /**
         * The maximum price per unit hour that you are willing to pay for a Spot Instance. We do not recommend using this parameter because it can lead to increased interruptions. If you do not specify this parameter, you will pay the current Spot price.
         *
         * > If you specify a maximum price, your instances will be interrupted more frequently than if you do not specify this parameter.
         */
        spotPrice?: pulumi.Input<string>;
        /**
         * The ID of the subnet in which to launch the instances.
         */
        subnetId?: pulumi.Input<string>;
        /**
         * The number of units provided by the specified instance type. These are the same units that you chose to set the target capacity in terms of instances, or a performance characteristic such as vCPUs, memory, or I/O.
         *
         * If the target capacity divided by this value is not a whole number, Amazon EC2 rounds the number of instances to the next whole number. If this value is not specified, the default is 1.
         *
         * > When specifying weights, the price used in the `lowestPrice` and `priceCapacityOptimized` allocation strategies is per *unit* hour (where the instance price is divided by the specified weight). However, if all the specified weights are above the requested `TargetCapacity` , resulting in only 1 instance being launched, the price used is per *instance* hour.
         */
        weightedCapacity?: pulumi.Input<number>;
    }
    interface SpotFleetLoadBalancersConfigArgs {
        /**
         * The Classic Load Balancers.
         */
        classicLoadBalancersConfig?: pulumi.Input<inputs.ec2.SpotFleetClassicLoadBalancersConfigArgs>;
        /**
         * The target groups.
         */
        targetGroupsConfig?: pulumi.Input<inputs.ec2.SpotFleetTargetGroupsConfigArgs>;
    }
    interface SpotFleetMemoryGiBPerVCpuRequestArgs {
        /**
         * The maximum amount of memory per vCPU, in GiB. To specify no maximum limit, omit this parameter.
         */
        max?: pulumi.Input<number>;
        /**
         * The minimum amount of memory per vCPU, in GiB. To specify no minimum limit, omit this parameter.
         */
        min?: pulumi.Input<number>;
    }
    interface SpotFleetMemoryMiBRequestArgs {
        /**
         * The maximum amount of memory, in MiB. To specify no maximum limit, omit this parameter.
         */
        max?: pulumi.Input<number>;
        /**
         * The minimum amount of memory, in MiB. To specify no minimum limit, specify `0` .
         */
        min?: pulumi.Input<number>;
    }
    interface SpotFleetMonitoringArgs {
        /**
         * Enables monitoring for the instance.
         *
         * Default: `false`
         */
        enabled?: pulumi.Input<boolean>;
    }
    interface SpotFleetNetworkBandwidthGbpsRequestArgs {
        /**
         * The maximum amount of network bandwidth, in Gbps. To specify no maximum limit, omit this parameter.
         */
        max?: pulumi.Input<number>;
        /**
         * The minimum amount of network bandwidth, in Gbps. To specify no minimum limit, omit this parameter.
         */
        min?: pulumi.Input<number>;
    }
    interface SpotFleetNetworkInterfaceCountRequestArgs {
        /**
         * The maximum number of network interfaces. To specify no maximum limit, omit this parameter.
         */
        max?: pulumi.Input<number>;
        /**
         * The minimum number of network interfaces. To specify no minimum limit, omit this parameter.
         */
        min?: pulumi.Input<number>;
    }
    interface SpotFleetPerformanceFactorReferenceRequestArgs {
        /**
         * The instance family to use as a baseline reference.
         *
         * > Ensure that you specify the correct value for the instance family. The instance family is everything before the period ( `.` ) in the instance type name. For example, in the instance type `c6i.large` , the instance family is `c6i` , not `c6` . For more information, see [Amazon EC2 instance type naming conventions](https://docs.aws.amazon.com/ec2/latest/instancetypes/instance-type-names.html) in *Amazon EC2 Instance Types* .
         *
         * The following instance families are *not supported* for performance protection:
         *
         * - `c1`
         * - `g3` | `g3s`
         * - `hpc7g`
         * - `m1` | `m2`
         * - `mac1` | `mac2` | `mac2-m1ultra` | `mac2-m2` | `mac2-m2pro`
         * - `p3dn` | `p4d` | `p5`
         * - `t1`
         * - `u-12tb1` | `u-18tb1` | `u-24tb1` | `u-3tb1` | `u-6tb1` | `u-9tb1` | `u7i-12tb` | `u7in-16tb` | `u7in-24tb` | `u7in-32tb`
         *
         * If you enable performance protection by specifying a supported instance family, the returned instance types will exclude the above unsupported instance families.
         *
         * If you specify an unsupported instance family as a value for baseline performance, the API returns an empty response for [GetInstanceTypesFromInstanceRequirements](https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_GetInstanceTypesFromInstanceRequirements.html) and an exception for [CreateFleet](https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_CreateFleet.html) , [RequestSpotFleet](https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_RequestSpotFleet.html) , [ModifyFleet](https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_ModifyFleet.html) , and [ModifySpotFleetRequest](https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_ModifySpotFleetRequest.html) .
         */
        instanceFamily?: pulumi.Input<string>;
    }
    interface SpotFleetPrivateIpAddressSpecificationArgs {
        /**
         * Indicates whether the private IPv4 address is the primary private IPv4 address. Only one IPv4 address can be designated as primary.
         */
        primary?: pulumi.Input<boolean>;
        /**
         * The private IPv4 address.
         */
        privateIpAddress: pulumi.Input<string>;
    }
    interface SpotFleetRequestConfigDataArgs {
        /**
         * The strategy that determines how to allocate the target Spot Instance capacity across the Spot Instance pools specified by the Spot Fleet launch configuration. For more information, see [Allocation strategies for Spot Instances](https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/spot-fleet-allocation-strategy.html) in the *Amazon EC2 User Guide* .
         *
         * - **priceCapacityOptimized (recommended)** - Spot Fleet identifies the pools with the highest capacity availability for the number of instances that are launching. This means that we will request Spot Instances from the pools that we believe have the lowest chance of interruption in the near term. Spot Fleet then requests Spot Instances from the lowest priced of these pools.
         * - **capacityOptimized** - Spot Fleet identifies the pools with the highest capacity availability for the number of instances that are launching. This means that we will request Spot Instances from the pools that we believe have the lowest chance of interruption in the near term. To give certain instance types a higher chance of launching first, use `capacityOptimizedPrioritized` . Set a priority for each instance type by using the `Priority` parameter for `LaunchTemplateOverrides` . You can assign the same priority to different `LaunchTemplateOverrides` . EC2 implements the priorities on a best-effort basis, but optimizes for capacity first. `capacityOptimizedPrioritized` is supported only if your Spot Fleet uses a launch template. Note that if the `OnDemandAllocationStrategy` is set to `prioritized` , the same priority is applied when fulfilling On-Demand capacity.
         * - **diversified** - Spot Fleet requests instances from all of the Spot Instance pools that you specify.
         * - **lowestPrice (not recommended)** - > We don't recommend the `lowestPrice` allocation strategy because it has the highest risk of interruption for your Spot Instances.
         *
         * Spot Fleet requests instances from the lowest priced Spot Instance pool that has available capacity. If the lowest priced pool doesn't have available capacity, the Spot Instances come from the next lowest priced pool that has available capacity. If a pool runs out of capacity before fulfilling your desired capacity, Spot Fleet will continue to fulfill your request by drawing from the next lowest priced pool. To ensure that your desired capacity is met, you might receive Spot Instances from several pools. Because this strategy only considers instance price and not capacity availability, it might lead to high interruption rates.
         *
         * Default: `lowestPrice`
         */
        allocationStrategy?: pulumi.Input<enums.ec2.SpotFleetRequestConfigDataAllocationStrategy>;
        /**
         * Reserved.
         */
        context?: pulumi.Input<string>;
        /**
         * Indicates whether running Spot Instances should be terminated if you decrease the target capacity of the Spot Fleet request below the current size of the Spot Fleet.
         *
         * Supported only for fleets of type `maintain` .
         */
        excessCapacityTerminationPolicy?: pulumi.Input<enums.ec2.SpotFleetRequestConfigDataExcessCapacityTerminationPolicy>;
        /**
         * The Amazon Resource Name (ARN) of an AWS Identity and Access Management (IAM) role that grants the Spot Fleet the permission to request, launch, terminate, and tag instances on your behalf. For more information, see [Spot Fleet Prerequisites](https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/spot-fleet-requests.html#spot-fleet-prerequisites) in the *Amazon EC2 User Guide* . Spot Fleet can terminate Spot Instances on your behalf when you cancel its Spot Fleet request or when the Spot Fleet request expires, if you set `TerminateInstancesWithExpiration` .
         */
        iamFleetRole: pulumi.Input<string>;
        /**
         * The behavior when a Spot Instance is interrupted. The default is `terminate` .
         */
        instanceInterruptionBehavior?: pulumi.Input<enums.ec2.SpotFleetRequestConfigDataInstanceInterruptionBehavior>;
        /**
         * The number of Spot pools across which to allocate your target Spot capacity. Valid only when Spot *AllocationStrategy* is set to `lowest-price` . Spot Fleet selects the cheapest Spot pools and evenly allocates your target Spot capacity across the number of Spot pools that you specify.
         *
         * Note that Spot Fleet attempts to draw Spot Instances from the number of pools that you specify on a best effort basis. If a pool runs out of Spot capacity before fulfilling your target capacity, Spot Fleet will continue to fulfill your request by drawing from the next cheapest pool. To ensure that your target capacity is met, you might receive Spot Instances from more than the number of pools that you specified. Similarly, if most of the pools have no Spot capacity, you might receive your full target capacity from fewer than the number of pools that you specified.
         */
        instancePoolsToUseCount?: pulumi.Input<number>;
        /**
         * The launch specifications for the Spot Fleet request. If you specify `LaunchSpecifications` , you can't specify `LaunchTemplateConfigs` .
         */
        launchSpecifications?: pulumi.Input<pulumi.Input<inputs.ec2.SpotFleetLaunchSpecificationArgs>[]>;
        /**
         * The launch template and overrides. If you specify `LaunchTemplateConfigs` , you can't specify `LaunchSpecifications` .
         */
        launchTemplateConfigs?: pulumi.Input<pulumi.Input<inputs.ec2.SpotFleetLaunchTemplateConfigArgs>[]>;
        /**
         * One or more Classic Load Balancers and target groups to attach to the Spot Fleet request. Spot Fleet registers the running Spot Instances with the specified Classic Load Balancers and target groups.
         *
         * With Network Load Balancers, Spot Fleet cannot register instances that have the following instance types: C1, CC1, CC2, CG1, CG2, CR1, CS1, G1, G2, HI1, HS1, M1, M2, M3, and T1.
         */
        loadBalancersConfig?: pulumi.Input<inputs.ec2.SpotFleetLoadBalancersConfigArgs>;
        /**
         * The order of the launch template overrides to use in fulfilling On-Demand capacity. If you specify `lowestPrice` , Spot Fleet uses price to determine the order, launching the lowest price first. If you specify `prioritized` , Spot Fleet uses the priority that you assign to each Spot Fleet launch template override, launching the highest priority first. If you do not specify a value, Spot Fleet defaults to `lowestPrice` .
         */
        onDemandAllocationStrategy?: pulumi.Input<string>;
        /**
         * The maximum amount per hour for On-Demand Instances that you're willing to pay. You can use the `onDemandMaxTotalPrice` parameter, the `spotMaxTotalPrice` parameter, or both parameters to ensure that your fleet cost does not exceed your budget. If you set a maximum price per hour for the On-Demand Instances and Spot Instances in your request, Spot Fleet will launch instances until it reaches the maximum amount you're willing to pay. When the maximum amount you're willing to pay is reached, the fleet stops launching instances even if it hasn’t met the target capacity.
         *
         * > If your fleet includes T instances that are configured as `unlimited` , and if their average CPU usage exceeds the baseline utilization, you will incur a charge for surplus credits. The `onDemandMaxTotalPrice` does not account for surplus credits, and, if you use surplus credits, your final cost might be higher than what you specified for `onDemandMaxTotalPrice` . For more information, see [Surplus credits can incur charges](https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/burstable-performance-instances-unlimited-mode-concepts.html#unlimited-mode-surplus-credits) in the *Amazon EC2 User Guide* .
         */
        onDemandMaxTotalPrice?: pulumi.Input<string>;
        /**
         * The number of On-Demand units to request. You can choose to set the target capacity in terms of instances or a performance characteristic that is important to your application workload, such as vCPUs, memory, or I/O. If the request type is `maintain` , you can specify a target capacity of 0 and add capacity later.
         */
        onDemandTargetCapacity?: pulumi.Input<number>;
        /**
         * Indicates whether Spot Fleet should replace unhealthy instances.
         */
        replaceUnhealthyInstances?: pulumi.Input<boolean>;
        /**
         * The strategies for managing your Spot Instances that are at an elevated risk of being interrupted.
         */
        spotMaintenanceStrategies?: pulumi.Input<inputs.ec2.SpotFleetSpotMaintenanceStrategiesArgs>;
        /**
         * The maximum amount per hour for Spot Instances that you're willing to pay. You can use the `spotMaxTotalPrice` parameter, the `onDemandMaxTotalPrice` parameter, or both parameters to ensure that your fleet cost does not exceed your budget. If you set a maximum price per hour for the On-Demand Instances and Spot Instances in your request, Spot Fleet will launch instances until it reaches the maximum amount you're willing to pay. When the maximum amount you're willing to pay is reached, the fleet stops launching instances even if it hasn’t met the target capacity.
         *
         * > If your fleet includes T instances that are configured as `unlimited` , and if their average CPU usage exceeds the baseline utilization, you will incur a charge for surplus credits. The `spotMaxTotalPrice` does not account for surplus credits, and, if you use surplus credits, your final cost might be higher than what you specified for `spotMaxTotalPrice` . For more information, see [Surplus credits can incur charges](https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/burstable-performance-instances-unlimited-mode-concepts.html#unlimited-mode-surplus-credits) in the *Amazon EC2 User Guide* .
         */
        spotMaxTotalPrice?: pulumi.Input<string>;
        /**
         * The maximum price per unit hour that you are willing to pay for a Spot Instance. We do not recommend using this parameter because it can lead to increased interruptions. If you do not specify this parameter, you will pay the current Spot price.
         *
         * > If you specify a maximum price, your instances will be interrupted more frequently than if you do not specify this parameter.
         */
        spotPrice?: pulumi.Input<string>;
        /**
         * The key-value pair for tagging the Spot Fleet request on creation. The value for `ResourceType` must be `spot-fleet-request` , otherwise the Spot Fleet request fails. To tag instances at launch, specify the tags in the [launch template](https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/ec2-launch-templates.html#create-launch-template) (valid only if you use `LaunchTemplateConfigs` ) or in the `[SpotFleetTagSpecification](https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_SpotFleetTagSpecification.html)` (valid only if you use `LaunchSpecifications` ). For information about tagging after launch, see [Tag your resources](https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/Using_Tags.html#tag-resources) .
         */
        tagSpecifications?: pulumi.Input<pulumi.Input<inputs.ec2.SpotFleetTagSpecificationArgs>[]>;
        /**
         * The number of units to request for the Spot Fleet. You can choose to set the target capacity in terms of instances or a performance characteristic that is important to your application workload, such as vCPUs, memory, or I/O. If the request type is `maintain` , you can specify a target capacity of 0 and add capacity later.
         */
        targetCapacity: pulumi.Input<number>;
        /**
         * The unit for the target capacity. You can specify this parameter only when using attribute-based instance type selection.
         *
         * Default: `units` (the number of instances)
         */
        targetCapacityUnitType?: pulumi.Input<enums.ec2.SpotFleetRequestConfigDataTargetCapacityUnitType>;
        /**
         * Indicates whether running Spot Instances are terminated when the Spot Fleet request expires.
         */
        terminateInstancesWithExpiration?: pulumi.Input<boolean>;
        /**
         * The type of request. Indicates whether the Spot Fleet only requests the target capacity or also attempts to maintain it. When this value is `request` , the Spot Fleet only places the required requests. It does not attempt to replenish Spot Instances if capacity is diminished, nor does it submit requests in alternative Spot pools if capacity is not available. When this value is `maintain` , the Spot Fleet maintains the target capacity. The Spot Fleet places the required requests to meet capacity and automatically replenishes any interrupted instances. Default: `maintain` . `instant` is listed but is not used by Spot Fleet.
         */
        type?: pulumi.Input<enums.ec2.SpotFleetRequestConfigDataType>;
        /**
         * The start date and time of the request, in UTC format ( *YYYY* - *MM* - *DD* T *HH* : *MM* : *SS* Z). By default, Amazon EC2 starts fulfilling the request immediately.
         */
        validFrom?: pulumi.Input<string>;
        /**
         * The end date and time of the request, in UTC format ( *YYYY* - *MM* - *DD* T *HH* : *MM* : *SS* Z). After the end date and time, no new Spot Instance requests are placed or able to fulfill the request. If no value is specified, the Spot Fleet request remains until you cancel it.
         */
        validUntil?: pulumi.Input<string>;
    }
    interface SpotFleetSpotCapacityRebalanceArgs {
        /**
         * The replacement strategy to use. Only available for fleets of type `maintain` .
         *
         * `launch` - Spot Fleet launches a new replacement Spot Instance when a rebalance notification is emitted for an existing Spot Instance in the fleet. Spot Fleet does not terminate the instances that receive a rebalance notification. You can terminate the old instances, or you can leave them running. You are charged for all instances while they are running.
         *
         * `launch-before-terminate` - Spot Fleet launches a new replacement Spot Instance when a rebalance notification is emitted for an existing Spot Instance in the fleet, and then, after a delay that you specify (in `TerminationDelay` ), terminates the instances that received a rebalance notification.
         */
        replacementStrategy?: pulumi.Input<enums.ec2.SpotFleetSpotCapacityRebalanceReplacementStrategy>;
        /**
         * The amount of time (in seconds) that Amazon EC2 waits before terminating the old Spot Instance after launching a new replacement Spot Instance.
         *
         * Required when `ReplacementStrategy` is set to `launch-before-terminate` .
         *
         * Not valid when `ReplacementStrategy` is set to `launch` .
         *
         * Valid values: Minimum value of `120` seconds. Maximum value of `7200` seconds.
         */
        terminationDelay?: pulumi.Input<number>;
    }
    interface SpotFleetSpotMaintenanceStrategiesArgs {
        /**
         * The Spot Instance replacement strategy to use when Amazon EC2 emits a signal that your Spot Instance is at an elevated risk of being interrupted. For more information, see [Capacity rebalancing](https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/spot-fleet-capacity-rebalance.html) in the *Amazon EC2 User Guide* .
         */
        capacityRebalance?: pulumi.Input<inputs.ec2.SpotFleetSpotCapacityRebalanceArgs>;
    }
    interface SpotFleetSpotPlacementArgs {
        /**
         * The Availability Zone.
         *
         * To specify multiple Availability Zones, separate them using commas; for example, "us-west-2a, us-west-2b".
         */
        availabilityZone?: pulumi.Input<string>;
        /**
         * The name of the placement group.
         */
        groupName?: pulumi.Input<string>;
        /**
         * The tenancy of the instance (if the instance is running in a VPC). An instance with a tenancy of `dedicated` runs on single-tenant hardware. The `host` tenancy is not supported for Spot Instances.
         */
        tenancy?: pulumi.Input<enums.ec2.SpotFleetSpotPlacementTenancy>;
    }
    interface SpotFleetTagArgs {
        /**
         * The tag key.
         */
        key: pulumi.Input<string>;
        /**
         * The tag value.
         */
        value: pulumi.Input<string>;
    }
    interface SpotFleetTagSpecificationArgs {
        /**
         * The type of resource. Currently, the only resource type that is supported is `instance` . To tag the Spot Fleet request on creation, use the `TagSpecifications` parameter in `[SpotFleetRequestConfigData](https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_SpotFleetRequestConfigData.html)` .
         */
        resourceType?: pulumi.Input<enums.ec2.SpotFleetTagSpecificationResourceType>;
        /**
         * The tags.
         */
        tags?: pulumi.Input<pulumi.Input<inputs.ec2.SpotFleetTagArgs>[]>;
    }
    interface SpotFleetTargetGroupArgs {
        /**
         * The Amazon Resource Name (ARN) of the target group.
         */
        arn: pulumi.Input<string>;
    }
    interface SpotFleetTargetGroupsConfigArgs {
        /**
         * One or more target groups.
         */
        targetGroups: pulumi.Input<pulumi.Input<inputs.ec2.SpotFleetTargetGroupArgs>[]>;
    }
    interface SpotFleetTotalLocalStorageGbRequestArgs {
        /**
         * The maximum amount of total local storage, in GB. To specify no maximum limit, omit this parameter.
         */
        max?: pulumi.Input<number>;
        /**
         * The minimum amount of total local storage, in GB. To specify no minimum limit, omit this parameter.
         */
        min?: pulumi.Input<number>;
    }
    interface SpotFleetVCpuCountRangeRequestArgs {
        /**
         * The maximum number of vCPUs. To specify no maximum limit, omit this parameter.
         */
        max?: pulumi.Input<number>;
        /**
         * The minimum number of vCPUs. To specify no minimum limit, specify `0` .
         */
        min?: pulumi.Input<number>;
    }
    /**
     * The configuration options for customer provided KMS encryption.
     */
    interface SseSpecificationPropertiesArgs {
        /**
         * Whether to encrypt the policy with the provided key or disable encryption
         */
        customerManagedKeyEnabled?: pulumi.Input<boolean>;
        /**
         * KMS Key Arn used to encrypt the group policy
         */
        kmsKeyArn?: pulumi.Input<string>;
    }
    /**
     * Specifies the tags to apply to resources that are created during instance launch.
     *   ``TagSpecification`` is a property type of [TagSpecifications](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-ec2-launchtemplate-launchtemplatedata.html#cfn-ec2-launchtemplate-launchtemplatedata-tagspecifications). [TagSpecifications](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-ec2-launchtemplate-launchtemplatedata.html#cfn-ec2-launchtemplate-launchtemplatedata-tagspecifications) is a property of [AWS::EC2::LaunchTemplate LaunchTemplateData](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-ec2-launchtemplate-launchtemplatedata.html).
     */
    interface TagSpecificationArgs {
        /**
         * The type of resource to tag. You can specify tags for the following resource types only: ``instance`` | ``volume`` | ``network-interface`` | ``spot-instances-request``. If the instance does not include the resource type that you specify, the instance launch fails. For example, not all instance types include a volume.
         *  To tag a resource after it has been created, see [CreateTags](https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_CreateTags.html).
         */
        resourceType?: pulumi.Input<string>;
        /**
         * The tags to apply to the resource.
         */
        tags?: pulumi.Input<pulumi.Input<inputs.ec2.LaunchTemplateTagArgs>[]>;
    }
    interface TransitGatewayConnectOptionsArgs {
        /**
         * The tunnel protocol.
         */
        protocol?: pulumi.Input<string>;
    }
    /**
     * The options for cidr type endpoint.
     */
    interface VerifiedAccessEndpointCidrOptionsArgs {
        /**
         * The IP address range, in CIDR notation.
         */
        cidr?: pulumi.Input<string>;
        /**
         * The list of port range.
         */
        portRanges?: pulumi.Input<pulumi.Input<inputs.ec2.VerifiedAccessEndpointPortRangeArgs>[]>;
        /**
         * The IP protocol.
         */
        protocol?: pulumi.Input<string>;
        /**
         * The IDs of the subnets.
         */
        subnetIds?: pulumi.Input<pulumi.Input<string>[]>;
    }
    /**
     * The load balancer details if creating the AWS Verified Access endpoint as load-balancertype.
     */
    interface VerifiedAccessEndpointLoadBalancerOptionsArgs {
        /**
         * The ARN of the load balancer.
         */
        loadBalancerArn?: pulumi.Input<string>;
        /**
         * The IP port number.
         */
        port?: pulumi.Input<number>;
        /**
         * The list of port range.
         */
        portRanges?: pulumi.Input<pulumi.Input<inputs.ec2.VerifiedAccessEndpointPortRangeArgs>[]>;
        /**
         * The IP protocol.
         */
        protocol?: pulumi.Input<string>;
        /**
         * The IDs of the subnets.
         */
        subnetIds?: pulumi.Input<pulumi.Input<string>[]>;
    }
    /**
     * The options for network-interface type endpoint.
     */
    interface VerifiedAccessEndpointNetworkInterfaceOptionsArgs {
        /**
         * The ID of the network interface.
         */
        networkInterfaceId?: pulumi.Input<string>;
        /**
         * The IP port number.
         */
        port?: pulumi.Input<number>;
        /**
         * The list of port ranges.
         */
        portRanges?: pulumi.Input<pulumi.Input<inputs.ec2.VerifiedAccessEndpointPortRangeArgs>[]>;
        /**
         * The IP protocol.
         */
        protocol?: pulumi.Input<string>;
    }
    /**
     * The IP port range.
     */
    interface VerifiedAccessEndpointPortRangeArgs {
        /**
         * The first port in the range.
         */
        fromPort?: pulumi.Input<number>;
        /**
         * The last port in the range.
         */
        toPort?: pulumi.Input<number>;
    }
    /**
     * The options for rds type endpoint.
     */
    interface VerifiedAccessEndpointRdsOptionsArgs {
        /**
         * The IP port number.
         */
        port?: pulumi.Input<number>;
        /**
         * The IP protocol.
         */
        protocol?: pulumi.Input<string>;
        /**
         * The ARN of the RDS DB cluster.
         */
        rdsDbClusterArn?: pulumi.Input<string>;
        /**
         * The ARN of the RDS DB instance.
         */
        rdsDbInstanceArn?: pulumi.Input<string>;
        /**
         * The ARN of the RDS DB proxy.
         */
        rdsDbProxyArn?: pulumi.Input<string>;
        /**
         * The RDS endpoint.
         */
        rdsEndpoint?: pulumi.Input<string>;
        /**
         * The IDs of the subnets.
         */
        subnetIds?: pulumi.Input<pulumi.Input<string>[]>;
    }
    /**
     * The configuration options for customer provided KMS encryption.
     */
    interface VerifiedAccessEndpointSseSpecificationArgs {
        /**
         * Whether to encrypt the policy with the provided key or disable encryption
         */
        customerManagedKeyEnabled?: pulumi.Input<boolean>;
        /**
         * KMS Key Arn used to encrypt the group policy
         */
        kmsKeyArn?: pulumi.Input<string>;
    }
    /**
     * The configuration options for customer provided KMS encryption.
     */
    interface VerifiedAccessGroupSseSpecificationArgs {
        /**
         * Whether to encrypt the policy with the provided key or disable encryption
         */
        customerManagedKeyEnabled?: pulumi.Input<boolean>;
        /**
         * KMS Key Arn used to encrypt the group policy
         */
        kmsKeyArn?: pulumi.Input<string>;
    }
    /**
     * The configuration options for AWS Verified Access instances.
     */
    interface VerifiedAccessInstanceVerifiedAccessLogsArgs {
        /**
         * Sends Verified Access logs to CloudWatch Logs.
         */
        cloudWatchLogs?: pulumi.Input<inputs.ec2.VerifiedAccessInstanceVerifiedAccessLogsCloudWatchLogsPropertiesArgs>;
        /**
         * Include claims from trust providers in Verified Access logs.
         */
        includeTrustContext?: pulumi.Input<boolean>;
        /**
         * Sends Verified Access logs to Kinesis.
         */
        kinesisDataFirehose?: pulumi.Input<inputs.ec2.VerifiedAccessInstanceVerifiedAccessLogsKinesisDataFirehosePropertiesArgs>;
        /**
         * Select log version for Verified Access logs.
         */
        logVersion?: pulumi.Input<string>;
        /**
         * Sends Verified Access logs to Amazon S3.
         */
        s3?: pulumi.Input<inputs.ec2.VerifiedAccessInstanceVerifiedAccessLogsS3PropertiesArgs>;
    }
    /**
     * Sends Verified Access logs to CloudWatch Logs.
     */
    interface VerifiedAccessInstanceVerifiedAccessLogsCloudWatchLogsPropertiesArgs {
        /**
         * Indicates whether logging is enabled.
         */
        enabled?: pulumi.Input<boolean>;
        /**
         * The ID of the CloudWatch Logs log group.
         */
        logGroup?: pulumi.Input<string>;
    }
    /**
     * Sends Verified Access logs to Kinesis.
     */
    interface VerifiedAccessInstanceVerifiedAccessLogsKinesisDataFirehosePropertiesArgs {
        /**
         * The ID of the delivery stream.
         */
        deliveryStream?: pulumi.Input<string>;
        /**
         * Indicates whether logging is enabled.
         */
        enabled?: pulumi.Input<boolean>;
    }
    /**
     * Sends Verified Access logs to Amazon S3.
     */
    interface VerifiedAccessInstanceVerifiedAccessLogsS3PropertiesArgs {
        /**
         * The bucket name.
         */
        bucketName?: pulumi.Input<string>;
        /**
         * The ID of the AWS account that owns the Amazon S3 bucket.
         */
        bucketOwner?: pulumi.Input<string>;
        /**
         * Indicates whether logging is enabled.
         */
        enabled?: pulumi.Input<boolean>;
        /**
         * The bucket prefix.
         */
        prefix?: pulumi.Input<string>;
    }
    /**
     * A Verified Access Trust Provider.
     */
    interface VerifiedAccessInstanceVerifiedAccessTrustProviderArgs {
        /**
         * The description of trust provider.
         */
        description?: pulumi.Input<string>;
        /**
         * The type of device-based trust provider.
         */
        deviceTrustProviderType?: pulumi.Input<string>;
        /**
         * The type of trust provider (user- or device-based).
         */
        trustProviderType?: pulumi.Input<string>;
        /**
         * The type of user-based trust provider.
         */
        userTrustProviderType?: pulumi.Input<string>;
        /**
         * The ID of the trust provider.
         */
        verifiedAccessTrustProviderId?: pulumi.Input<string>;
    }
    /**
     * The options for device identity based trust providers.
     */
    interface VerifiedAccessTrustProviderDeviceOptionsArgs {
        /**
         * URL Verified Access will use to verify authenticity of the device tokens.
         */
        publicSigningKeyUrl?: pulumi.Input<string>;
        /**
         * The ID of the tenant application with the device-identity provider.
         */
        tenantId?: pulumi.Input<string>;
    }
    /**
     * The OpenID Connect details for an oidc -type, user-identity based trust provider for L4.
     */
    interface VerifiedAccessTrustProviderNativeApplicationOidcOptionsArgs {
        /**
         * The OIDC authorization endpoint.
         */
        authorizationEndpoint?: pulumi.Input<string>;
        /**
         * The client identifier.
         */
        clientId?: pulumi.Input<string>;
        /**
         * The client secret.
         */
        clientSecret?: pulumi.Input<string>;
        /**
         * The OIDC issuer.
         */
        issuer?: pulumi.Input<string>;
        /**
         * The public signing key for endpoint
         */
        publicSigningKeyEndpoint?: pulumi.Input<string>;
        /**
         * OpenID Connect (OIDC) scopes are used by an application during authentication to authorize access to details of a user. Each scope returns a specific set of user attributes.
         */
        scope?: pulumi.Input<string>;
        /**
         * The OIDC token endpoint.
         */
        tokenEndpoint?: pulumi.Input<string>;
        /**
         * The OIDC user info endpoint.
         */
        userInfoEndpoint?: pulumi.Input<string>;
    }
    /**
     * The OpenID Connect details for an oidc -type, user-identity based trust provider.
     */
    interface VerifiedAccessTrustProviderOidcOptionsArgs {
        /**
         * The OIDC authorization endpoint.
         */
        authorizationEndpoint?: pulumi.Input<string>;
        /**
         * The client identifier.
         */
        clientId?: pulumi.Input<string>;
        /**
         * The client secret.
         */
        clientSecret?: pulumi.Input<string>;
        /**
         * The OIDC issuer.
         */
        issuer?: pulumi.Input<string>;
        /**
         * OpenID Connect (OIDC) scopes are used by an application during authentication to authorize access to details of a user. Each scope returns a specific set of user attributes.
         */
        scope?: pulumi.Input<string>;
        /**
         * The OIDC token endpoint.
         */
        tokenEndpoint?: pulumi.Input<string>;
        /**
         * The OIDC user info endpoint.
         */
        userInfoEndpoint?: pulumi.Input<string>;
    }
    /**
     * Describes the DNS options for an endpoint.
     */
    interface VpcEndpointDnsOptionsSpecificationArgs {
        /**
         * The DNS records created for the endpoint.
         */
        dnsRecordIpType?: pulumi.Input<enums.ec2.VpcEndpointDnsOptionsSpecificationDnsRecordIpType>;
        /**
         * Indicates whether to enable private DNS only for inbound endpoints. This option is available only for services that support both gateway and interface endpoints. It routes traffic that originates from the VPC to the gateway endpoint and traffic that originates from on-premises to the interface endpoint.
         */
        privateDnsOnlyForInboundResolverEndpoint?: pulumi.Input<enums.ec2.VpcEndpointDnsOptionsSpecificationPrivateDnsOnlyForInboundResolverEndpoint>;
    }
    /**
     * Options for sending VPN tunnel logs to CloudWatch.
     */
    interface VpnConnectionCloudwatchLogOptionsSpecificationArgs {
        /**
         * Enable or disable VPN tunnel logging feature. Default value is ``False``.
         *  Valid values: ``True`` | ``False``
         */
        logEnabled?: pulumi.Input<boolean>;
        /**
         * The Amazon Resource Name (ARN) of the CloudWatch log group to send logs to.
         */
        logGroupArn?: pulumi.Input<string>;
        /**
         * Set log format. Default format is ``json``.
         *  Valid values: ``json`` | ``text``
         */
        logOutputFormat?: pulumi.Input<enums.ec2.VpnConnectionCloudwatchLogOptionsSpecificationLogOutputFormat>;
    }
    /**
     * The IKE version that is permitted for the VPN tunnel.
     */
    interface VpnConnectionIkeVersionsRequestListValueArgs {
        /**
         * The IKE version.
         */
        value?: pulumi.Input<enums.ec2.VpnConnectionIkeVersionsRequestListValueValue>;
    }
    /**
     * Specifies the encryption algorithm for the VPN tunnel for phase 1 IKE negotiations.
     */
    interface VpnConnectionPhase1EncryptionAlgorithmsRequestListValueArgs {
        /**
         * The value for the encryption algorithm.
         */
        value?: pulumi.Input<enums.ec2.VpnConnectionPhase1EncryptionAlgorithmsRequestListValueValue>;
    }
    /**
     * Specifies the integrity algorithm for the VPN tunnel for phase 1 IKE negotiations.
     */
    interface VpnConnectionPhase1IntegrityAlgorithmsRequestListValueArgs {
        /**
         * The value for the integrity algorithm.
         */
        value?: pulumi.Input<enums.ec2.VpnConnectionPhase1IntegrityAlgorithmsRequestListValueValue>;
    }
    /**
     * Specifies a Diffie-Hellman group number for the VPN tunnel for phase 1 IKE negotiations.
     */
    interface VpnConnectionPhase1dhGroupNumbersRequestListValueArgs {
        /**
         * The Diffie-Hellmann group number.
         */
        value?: pulumi.Input<number>;
    }
    /**
     * Specifies the encryption algorithm for the VPN tunnel for phase 2 IKE negotiations.
     */
    interface VpnConnectionPhase2EncryptionAlgorithmsRequestListValueArgs {
        /**
         * The encryption algorithm.
         */
        value?: pulumi.Input<enums.ec2.VpnConnectionPhase2EncryptionAlgorithmsRequestListValueValue>;
    }
    /**
     * Specifies the integrity algorithm for the VPN tunnel for phase 2 IKE negotiations.
     */
    interface VpnConnectionPhase2IntegrityAlgorithmsRequestListValueArgs {
        /**
         * The integrity algorithm.
         */
        value?: pulumi.Input<enums.ec2.VpnConnectionPhase2IntegrityAlgorithmsRequestListValueValue>;
    }
    /**
     * Specifies a Diffie-Hellman group number for the VPN tunnel for phase 2 IKE negotiations.
     */
    interface VpnConnectionPhase2dhGroupNumbersRequestListValueArgs {
        /**
         * The Diffie-Hellmann group number.
         */
        value?: pulumi.Input<number>;
    }
    /**
     * Options for logging VPN tunnel activity.
     */
    interface VpnConnectionVpnTunnelLogOptionsSpecificationArgs {
        /**
         * Options for sending VPN tunnel logs to CloudWatch.
         */
        cloudwatchLogOptions?: pulumi.Input<inputs.ec2.VpnConnectionCloudwatchLogOptionsSpecificationArgs>;
    }
    /**
     * The tunnel options for a single VPN tunnel.
     */
    interface VpnConnectionVpnTunnelOptionsSpecificationArgs {
        /**
         * The action to take after DPD timeout occurs. Specify ``restart`` to restart the IKE initiation. Specify ``clear`` to end the IKE session.
         *  Valid Values: ``clear`` | ``none`` | ``restart``
         *  Default: ``clear``
         */
        dpdTimeoutAction?: pulumi.Input<enums.ec2.VpnConnectionVpnTunnelOptionsSpecificationDpdTimeoutAction>;
        /**
         * The number of seconds after which a DPD timeout occurs.
         *  Constraints: A value greater than or equal to 30.
         *  Default: ``30``
         */
        dpdTimeoutSeconds?: pulumi.Input<number>;
        /**
         * Turn on or off tunnel endpoint lifecycle control feature.
         */
        enableTunnelLifecycleControl?: pulumi.Input<boolean>;
        /**
         * The IKE versions that are permitted for the VPN tunnel.
         *  Valid values: ``ikev1`` | ``ikev2``
         */
        ikeVersions?: pulumi.Input<pulumi.Input<inputs.ec2.VpnConnectionIkeVersionsRequestListValueArgs>[]>;
        /**
         * Options for logging VPN tunnel activity.
         */
        logOptions?: pulumi.Input<inputs.ec2.VpnConnectionVpnTunnelLogOptionsSpecificationArgs>;
        /**
         * One or more encryption algorithms that are permitted for the VPN tunnel for phase 1 IKE negotiations.
         *  Valid values: ``AES128`` | ``AES256`` | ``AES128-GCM-16`` | ``AES256-GCM-16``
         */
        phase1EncryptionAlgorithms?: pulumi.Input<pulumi.Input<inputs.ec2.VpnConnectionPhase1EncryptionAlgorithmsRequestListValueArgs>[]>;
        /**
         * One or more integrity algorithms that are permitted for the VPN tunnel for phase 1 IKE negotiations.
         *  Valid values: ``SHA1`` | ``SHA2-256`` | ``SHA2-384`` | ``SHA2-512``
         */
        phase1IntegrityAlgorithms?: pulumi.Input<pulumi.Input<inputs.ec2.VpnConnectionPhase1IntegrityAlgorithmsRequestListValueArgs>[]>;
        /**
         * The lifetime for phase 1 of the IKE negotiation, in seconds.
         *  Constraints: A value between 900 and 28,800.
         *  Default: ``28800``
         */
        phase1LifetimeSeconds?: pulumi.Input<number>;
        /**
         * One or more Diffie-Hellman group numbers that are permitted for the VPN tunnel for phase 1 IKE negotiations.
         *  Valid values: ``2`` | ``14`` | ``15`` | ``16`` | ``17`` | ``18`` | ``19`` | ``20`` | ``21`` | ``22`` | ``23`` | ``24``
         */
        phase1dhGroupNumbers?: pulumi.Input<pulumi.Input<inputs.ec2.VpnConnectionPhase1dhGroupNumbersRequestListValueArgs>[]>;
        /**
         * One or more encryption algorithms that are permitted for the VPN tunnel for phase 2 IKE negotiations.
         *  Valid values: ``AES128`` | ``AES256`` | ``AES128-GCM-16`` | ``AES256-GCM-16``
         */
        phase2EncryptionAlgorithms?: pulumi.Input<pulumi.Input<inputs.ec2.VpnConnectionPhase2EncryptionAlgorithmsRequestListValueArgs>[]>;
        /**
         * One or more integrity algorithms that are permitted for the VPN tunnel for phase 2 IKE negotiations.
         *  Valid values: ``SHA1`` | ``SHA2-256`` | ``SHA2-384`` | ``SHA2-512``
         */
        phase2IntegrityAlgorithms?: pulumi.Input<pulumi.Input<inputs.ec2.VpnConnectionPhase2IntegrityAlgorithmsRequestListValueArgs>[]>;
        /**
         * The lifetime for phase 2 of the IKE negotiation, in seconds.
         *  Constraints: A value between 900 and 3,600. The value must be less than the value for ``Phase1LifetimeSeconds``.
         *  Default: ``3600``
         */
        phase2LifetimeSeconds?: pulumi.Input<number>;
        /**
         * One or more Diffie-Hellman group numbers that are permitted for the VPN tunnel for phase 2 IKE negotiations.
         *  Valid values: ``2`` | ``5`` | ``14`` | ``15`` | ``16`` | ``17`` | ``18`` | ``19`` | ``20`` | ``21`` | ``22`` | ``23`` | ``24``
         */
        phase2dhGroupNumbers?: pulumi.Input<pulumi.Input<inputs.ec2.VpnConnectionPhase2dhGroupNumbersRequestListValueArgs>[]>;
        /**
         * The pre-shared key (PSK) to establish initial authentication between the virtual private gateway and customer gateway.
         *  Constraints: Allowed characters are alphanumeric characters, periods (.), and underscores (_). Must be between 8 and 64 characters in length and cannot start with zero (0).
         */
        preSharedKey?: pulumi.Input<string>;
        /**
         * The percentage of the rekey window (determined by ``RekeyMarginTimeSeconds``) during which the rekey time is randomly selected.
         *  Constraints: A value between 0 and 100.
         *  Default: ``100``
         */
        rekeyFuzzPercentage?: pulumi.Input<number>;
        /**
         * The margin time, in seconds, before the phase 2 lifetime expires, during which the AWS side of the VPN connection performs an IKE rekey. The exact time of the rekey is randomly selected based on the value for ``RekeyFuzzPercentage``.
         *  Constraints: A value between 60 and half of ``Phase2LifetimeSeconds``.
         *  Default: ``270``
         */
        rekeyMarginTimeSeconds?: pulumi.Input<number>;
        /**
         * The number of packets in an IKE replay window.
         *  Constraints: A value between 64 and 2048.
         *  Default: ``1024``
         */
        replayWindowSize?: pulumi.Input<number>;
        /**
         * The action to take when the establishing the tunnel for the VPN connection. By default, your customer gateway device must initiate the IKE negotiation and bring up the tunnel. Specify ``start`` for AWS to initiate the IKE negotiation.
         *  Valid Values: ``add`` | ``start``
         *  Default: ``add``
         */
        startupAction?: pulumi.Input<enums.ec2.VpnConnectionVpnTunnelOptionsSpecificationStartupAction>;
        /**
         * The range of inside IP addresses for the tunnel. Any specified CIDR blocks must be unique across all VPN connections that use the same virtual private gateway.
         *  Constraints: A size /30 CIDR block from the ``169.254.0.0/16`` range. The following CIDR blocks are reserved and cannot be used:
         *   +   ``169.254.0.0/30``
         *   +   ``169.254.1.0/30``
         *   +   ``169.254.2.0/30``
         *   +   ``169.254.3.0/30``
         *   +   ``169.254.4.0/30``
         *   +   ``169.254.5.0/30``
         *   +   ``169.254.169.252/30``
         */
        tunnelInsideCidr?: pulumi.Input<string>;
        /**
         * The range of inside IPv6 addresses for the tunnel. Any specified CIDR blocks must be unique across all VPN connections that use the same transit gateway.
         *  Constraints: A size /126 CIDR block from the local ``fd00::/8`` range.
         */
        tunnelInsideIpv6Cidr?: pulumi.Input<string>;
    }
}
export declare namespace ecr {
    /**
     * The replication configuration for a registry.
     */
    interface ReplicationConfigurationArgs {
        /**
         * An array of objects representing the replication destinations and repository filters for a replication configuration.
         */
        rules: pulumi.Input<pulumi.Input<inputs.ecr.ReplicationConfigurationReplicationRuleArgs>[]>;
    }
    /**
     * An array of objects representing the destination for a replication rule.
     */
    interface ReplicationConfigurationReplicationDestinationArgs {
        /**
         * The Region to replicate to.
         */
        region: pulumi.Input<string>;
        /**
         * The AWS account ID of the Amazon ECR private registry to replicate to. When configuring cross-Region replication within your own registry, specify your own account ID.
         */
        registryId: pulumi.Input<string>;
    }
    /**
     * An array of objects representing the replication destinations and repository filters for a replication configuration.
     */
    interface ReplicationConfigurationReplicationRuleArgs {
        /**
         * An array of objects representing the destination for a replication rule.
         */
        destinations: pulumi.Input<pulumi.Input<inputs.ecr.ReplicationConfigurationReplicationDestinationArgs>[]>;
        /**
         * An array of objects representing the filters for a replication rule. Specifying a repository filter for a replication rule provides a method for controlling which repositories in a private registry are replicated.
         */
        repositoryFilters?: pulumi.Input<pulumi.Input<inputs.ecr.ReplicationConfigurationRepositoryFilterArgs>[]>;
    }
    /**
     * The filter settings used with image replication. Specifying a repository filter to a replication rule provides a method for controlling which repositories in a private registry are replicated. If no filters are added, the contents of all repositories are replicated.
     */
    interface ReplicationConfigurationRepositoryFilterArgs {
        /**
         * The repository filter details. When the ``PREFIX_MATCH`` filter type is specified, this value is required and should be the repository name prefix to configure replication for.
         */
        filter: pulumi.Input<string>;
        /**
         * The repository filter type. The only supported value is ``PREFIX_MATCH``, which is a repository name prefix specified with the ``filter`` parameter.
         */
        filterType: pulumi.Input<enums.ecr.ReplicationConfigurationFilterType>;
    }
    /**
     * The encryption configuration for the repository. This determines how the contents of your repository are encrypted at rest.
     *  By default, when no encryption configuration is set or the ``AES256`` encryption type is used, Amazon ECR uses server-side encryption with Amazon S3-managed encryption keys which encrypts your data at rest using an AES256 encryption algorithm. This does not require any action on your part.
     *  For more control over the encryption of the contents of your repository, you can use server-side encryption with KMSlong key stored in KMSlong (KMS) to encrypt your images. For more information, see [Amazon ECR encryption at rest](https://docs.aws.amazon.com/AmazonECR/latest/userguide/encryption-at-rest.html) in the *Amazon Elastic Container Registry User Guide*.
     */
    interface RepositoryCreationTemplateEncryptionConfigurationArgs {
        /**
         * The encryption type to use.
         *  If you use the ``KMS`` encryption type, the contents of the repository will be encrypted using server-side encryption with KMSlong key stored in KMS. When you use KMS to encrypt your data, you can either use the default AWS managed KMS key for Amazon ECR, or specify your own KMS key, which you already created.
         *  If you use the ``KMS_DSSE`` encryption type, the contents of the repository will be encrypted with two layers of encryption using server-side encryption with the KMS Management Service key stored in KMS. Similar to the ``KMS`` encryption type, you can either use the default AWS managed KMS key for Amazon ECR, or specify your own KMS key, which you've already created.
         *  If you use the ``AES256`` encryption type, Amazon ECR uses server-side encryption with Amazon S3-managed encryption keys which encrypts the images in the repository using an AES256 encryption algorithm.
         *  For more information, see [Amazon ECR encryption at rest](https://docs.aws.amazon.com/AmazonECR/latest/userguide/encryption-at-rest.html) in the *Amazon Elastic Container Registry User Guide*.
         */
        encryptionType: pulumi.Input<enums.ecr.RepositoryCreationTemplateEncryptionType>;
        /**
         * If you use the ``KMS`` encryption type, specify the KMS key to use for encryption. The alias, key ID, or full ARN of the KMS key can be specified. The key must exist in the same Region as the repository. If no key is specified, the default AWS managed KMS key for Amazon ECR will be used.
         */
        kmsKey?: pulumi.Input<string>;
    }
    /**
     * The metadata to apply to a resource to help you categorize and organize them. Each tag consists of a key and a value, both of which you define. Tag keys can have a maximum character length of 128 characters, and tag values can have a maximum length of 256 characters.
     */
    interface RepositoryCreationTemplateTagArgs {
        /**
         * One part of a key-value pair that make up a tag. A ``key`` is a general label that acts like a category for more specific tag values.
         */
        key: pulumi.Input<string>;
        /**
         * A ``value`` acts as a descriptor within a tag category (key).
         */
        value: pulumi.Input<string>;
    }
    /**
     * The encryption configuration for the repository. This determines how the contents of your repository are encrypted at rest.
     *  By default, when no encryption configuration is set or the ``AES256`` encryption type is used, Amazon ECR uses server-side encryption with Amazon S3-managed encryption keys which encrypts your data at rest using an AES256 encryption algorithm. This does not require any action on your part.
     *  For more control over the encryption of the contents of your repository, you can use server-side encryption with KMSlong key stored in KMSlong (KMS) to encrypt your images. For more information, see [Amazon ECR encryption at rest](https://docs.aws.amazon.com/AmazonECR/latest/userguide/encryption-at-rest.html) in the *Amazon Elastic Container Registry User Guide*.
     */
    interface RepositoryEncryptionConfigurationArgs {
        /**
         * The encryption type to use.
         *
         * If you use the `KMS` encryption type, the contents of the repository will be encrypted using server-side encryption with AWS Key Management Service key stored in AWS KMS . When you use AWS KMS to encrypt your data, you can either use the default AWS managed AWS KMS key for Amazon ECR, or specify your own AWS KMS key, which you already created.
         *
         * If you use the `KMS_DSSE` encryption type, the contents of the repository will be encrypted with two layers of encryption using server-side encryption with the AWS KMS Management Service key stored in AWS KMS . Similar to the `KMS` encryption type, you can either use the default AWS managed AWS KMS key for Amazon ECR, or specify your own AWS KMS key, which you've already created.
         *
         * If you use the `AES256` encryption type, Amazon ECR uses server-side encryption with Amazon S3-managed encryption keys which encrypts the images in the repository using an AES256 encryption algorithm.
         *
         * For more information, see [Amazon ECR encryption at rest](https://docs.aws.amazon.com/AmazonECR/latest/userguide/encryption-at-rest.html) in the *Amazon Elastic Container Registry User Guide* .
         */
        encryptionType: pulumi.Input<enums.ecr.RepositoryEncryptionType>;
        /**
         * If you use the ``KMS`` encryption type, specify the KMS key to use for encryption. The alias, key ID, or full ARN of the KMS key can be specified. The key must exist in the same Region as the repository. If no key is specified, the default AWS managed KMS key for Amazon ECR will be used.
         */
        kmsKey?: pulumi.Input<string>;
    }
    /**
     * The image scanning configuration for a repository.
     */
    interface RepositoryImageScanningConfigurationArgs {
        /**
         * The setting that determines whether images are scanned after being pushed to a repository. If set to ``true``, images will be scanned after being pushed. If this parameter is not specified, it will default to ``false`` and images will not be scanned unless a scan is manually started.
         */
        scanOnPush?: pulumi.Input<boolean>;
    }
    /**
     * The ``LifecyclePolicy`` property type specifies a lifecycle policy. For information about lifecycle policy syntax, see [Lifecycle policy template](https://docs.aws.amazon.com/AmazonECR/latest/userguide/LifecyclePolicies.html) in the *Amazon ECR User Guide*.
     */
    interface RepositoryLifecyclePolicyArgs {
        /**
         * The JSON repository policy text to apply to the repository.
         */
        lifecyclePolicyText?: pulumi.Input<string>;
        /**
         * The AWS account ID associated with the registry that contains the repository. If you do
         *  not specify a registry, the default registry is assumed.
         */
        registryId?: pulumi.Input<string>;
    }
}
export declare namespace ecs {
    interface CapacityProviderAutoScalingGroupProviderArgs {
        /**
         * The Amazon Resource Name (ARN) that identifies the Auto Scaling group, or the Auto Scaling group name.
         */
        autoScalingGroupArn: pulumi.Input<string>;
        /**
         * The managed draining option for the Auto Scaling group capacity provider. When you enable this, Amazon ECS manages and gracefully drains the EC2 container instances that are in the Auto Scaling group capacity provider.
         */
        managedDraining?: pulumi.Input<enums.ecs.CapacityProviderAutoScalingGroupProviderManagedDraining>;
        /**
         * The managed scaling settings for the Auto Scaling group capacity provider.
         */
        managedScaling?: pulumi.Input<inputs.ecs.CapacityProviderManagedScalingArgs>;
        /**
         * The managed termination protection setting to use for the Auto Scaling group capacity provider. This determines whether the Auto Scaling group has managed termination protection. The default is off.
         *
         * > When using managed termination protection, managed scaling must also be used otherwise managed termination protection doesn't work.
         *
         * When managed termination protection is on, Amazon ECS prevents the Amazon EC2 instances in an Auto Scaling group that contain tasks from being terminated during a scale-in action. The Auto Scaling group and each instance in the Auto Scaling group must have instance protection from scale-in actions on as well. For more information, see [Instance Protection](https://docs.aws.amazon.com/autoscaling/ec2/userguide/as-instance-termination.html#instance-protection) in the *AWS Auto Scaling User Guide* .
         *
         * When managed termination protection is off, your Amazon EC2 instances aren't protected from termination when the Auto Scaling group scales in.
         */
        managedTerminationProtection?: pulumi.Input<enums.ecs.CapacityProviderAutoScalingGroupProviderManagedTerminationProtection>;
    }
    /**
     * The managed scaling settings for the Auto Scaling group capacity provider.
     */
    interface CapacityProviderManagedScalingArgs {
        /**
         * The period of time, in seconds, after a newly launched Amazon EC2 instance can contribute to CloudWatch metrics for Auto Scaling group. If this parameter is omitted, the default value of `300` seconds is used.
         */
        instanceWarmupPeriod?: pulumi.Input<number>;
        /**
         * The maximum number of Amazon EC2 instances that Amazon ECS will scale out at one time. If this parameter is omitted, the default value of `10000` is used.
         */
        maximumScalingStepSize?: pulumi.Input<number>;
        /**
         * The minimum number of Amazon EC2 instances that Amazon ECS will scale out at one time. The scale in process is not affected by this parameter If this parameter is omitted, the default value of `1` is used.
         *
         * When additional capacity is required, Amazon ECS will scale up the minimum scaling step size even if the actual demand is less than the minimum scaling step size.
         *
         * If you use a capacity provider with an Auto Scaling group configured with more than one Amazon EC2 instance type or Availability Zone, Amazon ECS will scale up by the exact minimum scaling step size value and will ignore both the maximum scaling step size as well as the capacity demand.
         */
        minimumScalingStepSize?: pulumi.Input<number>;
        /**
         * Determines whether to use managed scaling for the capacity provider.
         */
        status?: pulumi.Input<enums.ecs.CapacityProviderManagedScalingStatus>;
        /**
         * The target capacity utilization as a percentage for the capacity provider. The specified value must be greater than `0` and less than or equal to `100` . For example, if you want the capacity provider to maintain 10% spare capacity, then that means the utilization is 90%, so use a `targetCapacity` of `90` . The default value of `100` percent results in the Amazon EC2 instances in your Auto Scaling group being completely used.
         */
        targetCapacity?: pulumi.Input<number>;
    }
    interface ClusterCapacityProviderAssociationsCapacityProviderStrategyArgs {
        base?: pulumi.Input<number>;
        capacityProvider: pulumi.Input<enums.ecs.ClusterCapacityProviderAssociationsCapacityProvider | string>;
        weight?: pulumi.Input<number>;
    }
    /**
     * The ``CapacityProviderStrategyItem`` property specifies the details of the default capacity provider strategy for the cluster. When services or tasks are run in the cluster with no launch type or capacity provider strategy specified, the default capacity provider strategy is used.
     */
    interface ClusterCapacityProviderStrategyItemArgs {
        /**
         * The *base* value designates how many tasks, at a minimum, to run on the specified capacity provider. Only one capacity provider in a capacity provider strategy can have a *base* defined. If no value is specified, the default value of ``0`` is used.
         */
        base?: pulumi.Input<number>;
        /**
         * The short name of the capacity provider.
         */
        capacityProvider?: pulumi.Input<string>;
        /**
         * The *weight* value designates the relative percentage of the total number of tasks launched that should use the specified capacity provider. The ``weight`` value is taken into consideration after the ``base`` value, if defined, is satisfied.
         *  If no ``weight`` value is specified, the default value of ``0`` is used. When multiple capacity providers are specified within a capacity provider strategy, at least one of the capacity providers must have a weight value greater than zero and any capacity providers with a weight of ``0`` can't be used to place tasks. If you specify multiple capacity providers in a strategy that all have a weight of ``0``, any ``RunTask`` or ``CreateService`` actions using the capacity provider strategy will fail.
         *  An example scenario for using weights is defining a strategy that contains two capacity providers and both have a weight of ``1``, then when the ``base`` is satisfied, the tasks will be split evenly across the two capacity providers. Using that same logic, if you specify a weight of ``1`` for *capacityProviderA* and a weight of ``4`` for *capacityProviderB*, then for every one task that's run using *capacityProviderA*, four tasks would use *capacityProviderB*.
         */
        weight?: pulumi.Input<number>;
    }
    /**
     * The execute command and managed storage configuration for the cluster.
     */
    interface ClusterConfigurationArgs {
        /**
         * The details of the execute command configuration.
         */
        executeCommandConfiguration?: pulumi.Input<inputs.ecs.ClusterExecuteCommandConfigurationArgs>;
        /**
         * The details of the managed storage configuration.
         */
        managedStorageConfiguration?: pulumi.Input<inputs.ecs.ClusterManagedStorageConfigurationArgs>;
    }
    /**
     * The details of the execute command configuration.
     */
    interface ClusterExecuteCommandConfigurationArgs {
        /**
         * Specify an KMSlong key ID to encrypt the data between the local client and the container.
         */
        kmsKeyId?: pulumi.Input<string>;
        /**
         * The log configuration for the results of the execute command actions. The logs can be sent to CloudWatch Logs or an Amazon S3 bucket. When ``logging=OVERRIDE`` is specified, a ``logConfiguration`` must be provided.
         */
        logConfiguration?: pulumi.Input<inputs.ecs.ClusterExecuteCommandLogConfigurationArgs>;
        /**
         * The log setting to use for redirecting logs for your execute command results. The following log settings are available.
         *   +   ``NONE``: The execute command session is not logged.
         *   +   ``DEFAULT``: The ``awslogs`` configuration in the task definition is used. If no logging parameter is specified, it defaults to this value. If no ``awslogs`` log driver is configured in the task definition, the output won't be logged.
         *   +   ``OVERRIDE``: Specify the logging details as a part of ``logConfiguration``. If the ``OVERRIDE`` logging option is specified, the ``logConfiguration`` is required.
         */
        logging?: pulumi.Input<string>;
    }
    /**
     * The log configuration for the results of the execute command actions. The logs can be sent to CloudWatch Logs or an Amazon S3 bucket.
     */
    interface ClusterExecuteCommandLogConfigurationArgs {
        /**
         * Determines whether to use encryption on the CloudWatch logs. If not specified, encryption will be off.
         */
        cloudWatchEncryptionEnabled?: pulumi.Input<boolean>;
        /**
         * The name of the CloudWatch log group to send logs to.
         *   The CloudWatch log group must already be created.
         */
        cloudWatchLogGroupName?: pulumi.Input<string>;
        /**
         * The name of the S3 bucket to send logs to.
         *   The S3 bucket must already be created.
         */
        s3BucketName?: pulumi.Input<string>;
        /**
         * Determines whether to use encryption on the S3 logs. If not specified, encryption is not used.
         */
        s3EncryptionEnabled?: pulumi.Input<boolean>;
        /**
         * An optional folder in the S3 bucket to place logs in.
         */
        s3KeyPrefix?: pulumi.Input<string>;
    }
    /**
     * The managed storage configuration for the cluster.
     */
    interface ClusterManagedStorageConfigurationArgs {
        /**
         * Specify the KMSlong key ID for the Fargate ephemeral storage.
         *  The key must be a single Region key.
         */
        fargateEphemeralStorageKmsKeyId?: pulumi.Input<string>;
        /**
         * Specify a KMSlong key ID to encrypt the managed storage.
         *  The key must be a single Region key.
         */
        kmsKeyId?: pulumi.Input<string>;
    }
    /**
     * Use this parameter to set a default Service Connect namespace. After you set a default Service Connect namespace, any new services with Service Connect turned on that are created in the cluster are added as client services in the namespace. This setting only applies to new services that set the ``enabled`` parameter to ``true`` in the ``ServiceConnectConfiguration``. You can set the namespace of each service individually in the ``ServiceConnectConfiguration`` to override this default parameter.
     *  Tasks that run in a namespace can use short names to connect to services in the namespace. Tasks can connect to services across all of the clusters in the namespace. Tasks connect through a managed proxy container that collects logs and metrics for increased visibility. Only the tasks that Amazon ECS services create are supported with Service Connect. For more information, see [Service Connect](https://docs.aws.amazon.com/AmazonECS/latest/developerguide/service-connect.html) in the *Amazon Elastic Container Service Developer Guide*.
     */
    interface ClusterServiceConnectDefaultsArgs {
        /**
         * The namespace name or full Amazon Resource Name (ARN) of the CMAPlong namespace that's used when you create a service and don't specify a Service Connect configuration. The namespace name can include up to 1024 characters. The name is case-sensitive. The name can't include greater than (>), less than (<), double quotation marks ("), or slash (/).
         *  If you enter an existing namespace name or ARN, then that namespace will be used. Any namespace type is supported. The namespace must be in this account and this AWS Region.
         *  If you enter a new name, a CMAPlong namespace will be created. Amazon ECS creates a CMAP namespace with the "API calls" method of instance discovery only. This instance discovery method is the "HTTP" namespace type in the CLIlong. Other types of instance discovery aren't used by Service Connect.
         *  If you update the cluster with an empty string ``""`` for the namespace name, the cluster configuration for Service Connect is removed. Note that the namespace will remain in CMAP and must be deleted separately.
         *  For more information about CMAPlong, see [Working with Services](https://docs.aws.amazon.com/cloud-map/latest/dg/working-with-services.html) in the *Developer Guide*.
         */
        namespace?: pulumi.Input<string>;
    }
    /**
     * The settings to use when creating a cluster. This parameter is used to turn on CloudWatch Container Insights with enhanced observability or CloudWatch Container Insights for a cluster.
     *  Container Insights with enhanced observability provides all the Container Insights metrics, plus additional task and container metrics. This version supports enhanced observability for Amazon ECS clusters using the Amazon EC2 and Fargate launch types. After you configure Container Insights with enhanced observability on Amazon ECS, Container Insights auto-collects detailed infrastructure telemetry from the cluster level down to the container level in your environment and displays these critical performance data in curated dashboards removing the heavy lifting in observability set-up.
     *  For more information, see [Monitor Amazon ECS containers using Container Insights with enhanced observability](https://docs.aws.amazon.com/AmazonECS/latest/developerguide/cloudwatch-container-insights.html) in the *Amazon Elastic Container Service Developer Guide*.
     */
    interface ClusterSettingsArgs {
        /**
         * The name of the cluster setting. The value is ``containerInsights`` .
         */
        name?: pulumi.Input<string>;
        /**
         * The value to set for the cluster setting. The supported values are ``enhanced``, ``enabled``, and ``disabled``.
         *  To use Container Insights with enhanced observability, set the ``containerInsights`` account setting to ``enhanced``.
         *  To use Container Insights, set the ``containerInsights`` account setting to ``enabled``.
         *  If a cluster value is specified, it will override the ``containerInsights`` value set with [PutAccountSetting](https://docs.aws.amazon.com/AmazonECS/latest/APIReference/API_PutAccountSetting.html) or [PutAccountSettingDefault](https://docs.aws.amazon.com/AmazonECS/latest/APIReference/API_PutAccountSettingDefault.html).
         */
        value?: pulumi.Input<string>;
    }
    /**
     * An object representing the networking details for a task or service. For example ``awsVpcConfiguration={subnets=["subnet-12344321"],securityGroups=["sg-12344321"]}``.
     */
    interface ServiceAwsVpcConfigurationArgs {
        /**
         * Whether the task's elastic network interface receives a public IP address.
         *  Consider the following when you set this value:
         *   +  When you use ``create-service`` or ``update-service``, the default is ``DISABLED``.
         *   +  When the service ``deploymentController`` is ``ECS``, the value must be ``DISABLED``.
         */
        assignPublicIp?: pulumi.Input<enums.ecs.ServiceAwsVpcConfigurationAssignPublicIp>;
        /**
         * The IDs of the security groups associated with the task or service. If you don't specify a security group, the default security group for the VPC is used. There's a limit of 5 security groups that can be specified.
         *   All specified security groups must be from the same VPC.
         */
        securityGroups?: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * The IDs of the subnets associated with the task or service. There's a limit of 16 subnets that can be specified.
         *   All specified subnets must be from the same VPC.
         */
        subnets?: pulumi.Input<pulumi.Input<string>[]>;
    }
    /**
     * The details of a capacity provider strategy. A capacity provider strategy can be set when using the ``RunTask`` or ``CreateService`` APIs or as the default capacity provider strategy for a cluster with the ``CreateCluster`` API.
     *  Only capacity providers that are already associated with a cluster and have an ``ACTIVE`` or ``UPDATING`` status can be used in a capacity provider strategy. The ``PutClusterCapacityProviders`` API is used to associate a capacity provider with a cluster.
     *  If specifying a capacity provider that uses an Auto Scaling group, the capacity provider must already be created. New Auto Scaling group capacity providers can be created with the ``CreateCapacityProvider`` API operation.
     *  To use an FARGATElong capacity provider, specify either the ``FARGATE`` or ``FARGATE_SPOT`` capacity providers. The FARGATElong capacity providers are available to all accounts and only need to be associated with a cluster to be used in a capacity provider strategy.
     */
    interface ServiceCapacityProviderStrategyItemArgs {
        /**
         * The *base* value designates how many tasks, at a minimum, to run on the specified capacity provider. Only one capacity provider in a capacity provider strategy can have a *base* defined. If no value is specified, the default value of ``0`` is used.
         */
        base?: pulumi.Input<number>;
        /**
         * The short name of the capacity provider.
         */
        capacityProvider?: pulumi.Input<string>;
        /**
         * The *weight* value designates the relative percentage of the total number of tasks launched that should use the specified capacity provider. The ``weight`` value is taken into consideration after the ``base`` value, if defined, is satisfied.
         *  If no ``weight`` value is specified, the default value of ``0`` is used. When multiple capacity providers are specified within a capacity provider strategy, at least one of the capacity providers must have a weight value greater than zero and any capacity providers with a weight of ``0`` can't be used to place tasks. If you specify multiple capacity providers in a strategy that all have a weight of ``0``, any ``RunTask`` or ``CreateService`` actions using the capacity provider strategy will fail.
         *  An example scenario for using weights is defining a strategy that contains two capacity providers and both have a weight of ``1``, then when the ``base`` is satisfied, the tasks will be split evenly across the two capacity providers. Using that same logic, if you specify a weight of ``1`` for *capacityProviderA* and a weight of ``4`` for *capacityProviderB*, then for every one task that's run using *capacityProviderA*, four tasks would use *capacityProviderB*.
         */
        weight?: pulumi.Input<number>;
    }
    /**
     * Each alias ("endpoint") is a fully-qualified name and port number that other tasks ("clients") can use to connect to this service.
     *  Each name and port mapping must be unique within the namespace.
     *  Tasks that run in a namespace can use short names to connect to services in the namespace. Tasks can connect to services across all of the clusters in the namespace. Tasks connect through a managed proxy container that collects logs and metrics for increased visibility. Only the tasks that Amazon ECS services create are supported with Service Connect. For more information, see [Service Connect](https://docs.aws.amazon.com/AmazonECS/latest/developerguide/service-connect.html) in the *Amazon Elastic Container Service Developer Guide*.
     */
    interface ServiceConnectClientAliasArgs {
        /**
         * The ``dnsName`` is the name that you use in the applications of client tasks to connect to this service. The name must be a valid DNS name but doesn't need to be fully-qualified. The name can include up to 127 characters. The name can include lowercase letters, numbers, underscores (_), hyphens (-), and periods (.). The name can't start with a hyphen.
         *  If this parameter isn't specified, the default value of ``discoveryName.namespace`` is used. If the ``discoveryName`` isn't specified, the port mapping name from the task definition is used in ``portName.namespace``.
         *  To avoid changing your applications in client Amazon ECS services, set this to the same name that the client application uses by default. For example, a few common names are ``database``, ``db``, or the lowercase name of a database, such as ``mysql`` or ``redis``. For more information, see [Service Connect](https://docs.aws.amazon.com/AmazonECS/latest/developerguide/service-connect.html) in the *Amazon Elastic Container Service Developer Guide*.
         */
        dnsName?: pulumi.Input<string>;
        /**
         * The listening port number for the Service Connect proxy. This port is available inside of all of the tasks within the same namespace.
         *  To avoid changing your applications in client Amazon ECS services, set this to the same port that the client application uses by default. For more information, see [Service Connect](https://docs.aws.amazon.com/AmazonECS/latest/developerguide/service-connect.html) in the *Amazon Elastic Container Service Developer Guide*.
         */
        port: pulumi.Input<number>;
    }
    /**
     * The Service Connect configuration of your Amazon ECS service. The configuration for this service to discover and connect to services, and be discovered by, and connected from, other services within a namespace.
     *  Tasks that run in a namespace can use short names to connect to services in the namespace. Tasks can connect to services across all of the clusters in the namespace. Tasks connect through a managed proxy container that collects logs and metrics for increased visibility. Only the tasks that Amazon ECS services create are supported with Service Connect. For more information, see [Service Connect](https://docs.aws.amazon.com/AmazonECS/latest/developerguide/service-connect.html) in the *Amazon Elastic Container Service Developer Guide*.
     */
    interface ServiceConnectConfigurationArgs {
        /**
         * Specifies whether to use Service Connect with this service.
         */
        enabled: pulumi.Input<boolean>;
        /**
         * The log configuration for the container. This parameter maps to ``LogConfig`` in the docker container create command and the ``--log-driver`` option to docker run.
         *  By default, containers use the same logging driver that the Docker daemon uses. However, the container might use a different logging driver than the Docker daemon by specifying a log driver configuration in the container definition.
         *  Understand the following when specifying a log configuration for your containers.
         *   +  Amazon ECS currently supports a subset of the logging drivers available to the Docker daemon. Additional log drivers may be available in future releases of the Amazon ECS container agent.
         *  For tasks on FARGATElong, the supported log drivers are ``awslogs``, ``splunk``, and ``awsfirelens``.
         *  For tasks hosted on Amazon EC2 instances, the supported log drivers are ``awslogs``, ``fluentd``, ``gelf``, ``json-file``, ``journald``,``syslog``, ``splunk``, and ``awsfirelens``.
         *   +  This parameter requires version 1.18 of the Docker Remote API or greater on your container instance.
         *   +  For tasks that are hosted on Amazon EC2 instances, the Amazon ECS container agent must register the available logging drivers with the ``ECS_AVAILABLE_LOGGING_DRIVERS`` environment variable before containers placed on that instance can use these log configuration options. For more information, see [Amazon ECS container agent configuration](https://docs.aws.amazon.com/AmazonECS/latest/developerguide/ecs-agent-config.html) in the *Amazon Elastic Container Service Developer Guide*.
         *   +  For tasks that are on FARGATElong, because you don't have access to the underlying infrastructure your tasks are hosted on, any additional software needed must be installed outside of the task. For example, the Fluentd output aggregators or a remote host running Logstash to send Gelf logs to.
         */
        logConfiguration?: pulumi.Input<inputs.ecs.ServiceLogConfigurationArgs>;
        /**
         * The namespace name or full Amazon Resource Name (ARN) of the CMAPlong namespace for use with Service Connect. The namespace must be in the same AWS Region as the Amazon ECS service and cluster. The type of namespace doesn't affect Service Connect. For more information about CMAPlong, see [Working with Services](https://docs.aws.amazon.com/cloud-map/latest/dg/working-with-services.html) in the *Developer Guide*.
         */
        namespace?: pulumi.Input<string>;
        /**
         * The list of Service Connect service objects. These are names and aliases (also known as endpoints) that are used by other Amazon ECS services to connect to this service.
         *  This field is not required for a "client" Amazon ECS service that's a member of a namespace only to connect to other services within the namespace. An example of this would be a frontend application that accepts incoming requests from either a load balancer that's attached to the service or by other means.
         *  An object selects a port from the task definition, assigns a name for the CMAPlong service, and a list of aliases (endpoints) and ports for client applications to refer to this service.
         */
        services?: pulumi.Input<pulumi.Input<inputs.ecs.ServiceConnectServiceArgs>[]>;
    }
    /**
     * The Service Connect service object configuration. For more information, see [Service Connect](https://docs.aws.amazon.com/AmazonECS/latest/developerguide/service-connect.html) in the *Amazon Elastic Container Service Developer Guide*.
     */
    interface ServiceConnectServiceArgs {
        /**
         * The list of client aliases for this Service Connect service. You use these to assign names that can be used by client applications. The maximum number of client aliases that you can have in this list is 1.
         *  Each alias ("endpoint") is a fully-qualified name and port number that other Amazon ECS tasks ("clients") can use to connect to this service.
         *  Each name and port mapping must be unique within the namespace.
         *  For each ``ServiceConnectService``, you must provide at least one ``clientAlias`` with one ``port``.
         */
        clientAliases?: pulumi.Input<pulumi.Input<inputs.ecs.ServiceConnectClientAliasArgs>[]>;
        /**
         * The ``discoveryName`` is the name of the new CMAP service that Amazon ECS creates for this Amazon ECS service. This must be unique within the CMAP namespace. The name can contain up to 64 characters. The name can include lowercase letters, numbers, underscores (_), and hyphens (-). The name can't start with a hyphen.
         *  If the ``discoveryName`` isn't specified, the port mapping name from the task definition is used in ``portName.namespace``.
         */
        discoveryName?: pulumi.Input<string>;
        /**
         * The port number for the Service Connect proxy to listen on.
         *  Use the value of this field to bypass the proxy for traffic on the port number specified in the named ``portMapping`` in the task definition of this application, and then use it in your VPC security groups to allow traffic into the proxy for this Amazon ECS service.
         *  In ``awsvpc`` mode and Fargate, the default value is the container port number. The container port number is in the ``portMapping`` in the task definition. In bridge mode, the default value is the ephemeral port of the Service Connect proxy.
         */
        ingressPortOverride?: pulumi.Input<number>;
        /**
         * The ``portName`` must match the name of one of the ``portMappings`` from all the containers in the task definition of this Amazon ECS service.
         */
        portName: pulumi.Input<string>;
        /**
         * A reference to an object that represents the configured timeouts for Service Connect.
         */
        timeout?: pulumi.Input<inputs.ecs.ServiceTimeoutConfigurationArgs>;
        /**
         * A reference to an object that represents a Transport Layer Security (TLS) configuration.
         */
        tls?: pulumi.Input<inputs.ecs.ServiceConnectTlsConfigurationArgs>;
    }
    /**
     * The certificate root authority that secures your service.
     */
    interface ServiceConnectTlsCertificateAuthorityArgs {
        /**
         * The ARN of the AWS Private Certificate Authority certificate.
         */
        awsPcaAuthorityArn?: pulumi.Input<string>;
    }
    /**
     * The key that encrypts and decrypts your resources for Service Connect TLS.
     */
    interface ServiceConnectTlsConfigurationArgs {
        /**
         * The signer certificate authority.
         */
        issuerCertificateAuthority: pulumi.Input<inputs.ecs.ServiceConnectTlsCertificateAuthorityArgs>;
        /**
         * The AWS Key Management Service key.
         */
        kmsKey?: pulumi.Input<string>;
        /**
         * The Amazon Resource Name (ARN) of the IAM role that's associated with the Service Connect TLS.
         */
        roleArn?: pulumi.Input<string>;
    }
    /**
     * One of the methods which provide a way for you to quickly identify when a deployment has failed, and then to optionally roll back the failure to the last working deployment.
     *  When the alarms are generated, Amazon ECS sets the service deployment to failed. Set the rollback parameter to have Amazon ECS to roll back your service to the last completed deployment after a failure.
     *  You can only use the ``DeploymentAlarms`` method to detect failures when the ``DeploymentController`` is set to ``ECS`` (rolling update).
     *  For more information, see [Rolling update](https://docs.aws.amazon.com/AmazonECS/latest/developerguide/deployment-type-ecs.html) in the *Amazon Elastic Container Service Developer Guide*.
     */
    interface ServiceDeploymentAlarmsArgs {
        /**
         * One or more CloudWatch alarm names. Use a "," to separate the alarms.
         */
        alarmNames: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * Determines whether to use the CloudWatch alarm option in the service deployment process.
         */
        enable: pulumi.Input<boolean>;
        /**
         * Determines whether to configure Amazon ECS to roll back the service if a service deployment fails. If rollback is used, when a service deployment fails, the service is rolled back to the last deployment that completed successfully.
         */
        rollback: pulumi.Input<boolean>;
    }
    /**
     * The deployment circuit breaker can only be used for services using the rolling update (``ECS``) deployment type.
     *   The *deployment circuit breaker* determines whether a service deployment will fail if the service can't reach a steady state. If it is turned on, a service deployment will transition to a failed state and stop launching new tasks. You can also configure Amazon ECS to roll back your service to the last completed deployment after a failure. For more information, see [Rolling update](https://docs.aws.amazon.com/AmazonECS/latest/developerguide/deployment-type-ecs.html) in the *Amazon Elastic Container Service Developer Guide*.
     *  For more information about API failure reasons, see [API failure reasons](https://docs.aws.amazon.com/AmazonECS/latest/developerguide/api_failures_messages.html) in the *Amazon Elastic Container Service Developer Guide*.
     */
    interface ServiceDeploymentCircuitBreakerArgs {
        /**
         * Determines whether to use the deployment circuit breaker logic for the service.
         */
        enable: pulumi.Input<boolean>;
        /**
         * Determines whether to configure Amazon ECS to roll back the service if a service deployment fails. If rollback is on, when a service deployment fails, the service is rolled back to the last deployment that completed successfully.
         */
        rollback: pulumi.Input<boolean>;
    }
    /**
     * Optional deployment parameters that control how many tasks run during a deployment and the ordering of stopping and starting tasks.
     */
    interface ServiceDeploymentConfigurationArgs {
        /**
         * Information about the CloudWatch alarms.
         */
        alarms?: pulumi.Input<inputs.ecs.ServiceDeploymentAlarmsArgs>;
        /**
         * The deployment circuit breaker can only be used for services using the rolling update (``ECS``) deployment type.
         *   The *deployment circuit breaker* determines whether a service deployment will fail if the service can't reach a steady state. If you use the deployment circuit breaker, a service deployment will transition to a failed state and stop launching new tasks. If you use the rollback option, when a service deployment fails, the service is rolled back to the last deployment that completed successfully. For more information, see [Rolling update](https://docs.aws.amazon.com/AmazonECS/latest/developerguide/deployment-type-ecs.html) in the *Amazon Elastic Container Service Developer Guide*
         */
        deploymentCircuitBreaker?: pulumi.Input<inputs.ecs.ServiceDeploymentCircuitBreakerArgs>;
        /**
         * If a service is using the rolling update (``ECS``) deployment type, the ``maximumPercent`` parameter represents an upper limit on the number of your service's tasks that are allowed in the ``RUNNING`` or ``PENDING`` state during a deployment, as a percentage of the ``desiredCount`` (rounded down to the nearest integer). This parameter enables you to define the deployment batch size. For example, if your service is using the ``REPLICA`` service scheduler and has a ``desiredCount`` of four tasks and a ``maximumPercent`` value of 200%, the scheduler may start four new tasks before stopping the four older tasks (provided that the cluster resources required to do this are available). The default ``maximumPercent`` value for a service using the ``REPLICA`` service scheduler is 200%.
         *  The Amazon ECS scheduler uses this parameter to replace unhealthy tasks by starting replacement tasks first and then stopping the unhealthy tasks, as long as cluster resources for starting replacement tasks are available. For more information about how the scheduler replaces unhealthy tasks, see [Amazon ECS services](https://docs.aws.amazon.com/AmazonECS/latest/developerguide/ecs_services.html).
         *  If a service is using either the blue/green (``CODE_DEPLOY``) or ``EXTERNAL`` deployment types, and tasks in the service use the EC2 launch type, the *maximum percent* value is set to the default value. The *maximum percent* value is used to define the upper limit on the number of the tasks in the service that remain in the ``RUNNING`` state while the container instances are in the ``DRAINING`` state.
         *   You can't specify a custom ``maximumPercent`` value for a service that uses either the blue/green (``CODE_DEPLOY``) or ``EXTERNAL`` deployment types and has tasks that use the EC2 launch type.
         *   If the service uses either the blue/green (``CODE_DEPLOY``) or ``EXTERNAL`` deployment types, and the tasks in the service use the Fargate launch type, the maximum percent value is not used. The value is still returned when describing your service.
         */
        maximumPercent?: pulumi.Input<number>;
        /**
         * If a service is using the rolling update (``ECS``) deployment type, the ``minimumHealthyPercent`` represents a lower limit on the number of your service's tasks that must remain in the ``RUNNING`` state during a deployment, as a percentage of the ``desiredCount`` (rounded up to the nearest integer). This parameter enables you to deploy without using additional cluster capacity. For example, if your service has a ``desiredCount`` of four tasks and a ``minimumHealthyPercent`` of 50%, the service scheduler may stop two existing tasks to free up cluster capacity before starting two new tasks.
         *   If any tasks are unhealthy and if ``maximumPercent`` doesn't allow the Amazon ECS scheduler to start replacement tasks, the scheduler stops the unhealthy tasks one-by-one — using the ``minimumHealthyPercent`` as a constraint — to clear up capacity to launch replacement tasks. For more information about how the scheduler replaces unhealthy tasks, see [Amazon ECS services](https://docs.aws.amazon.com/AmazonECS/latest/developerguide/ecs_services.html) .
         *  For services that *do not* use a load balancer, the following should be noted:
         *   +  A service is considered healthy if all essential containers within the tasks in the service pass their health checks.
         *   +  If a task has no essential containers with a health check defined, the service scheduler will wait for 40 seconds after a task reaches a ``RUNNING`` state before the task is counted towards the minimum healthy percent total.
         *   +  If a task has one or more essential containers with a health check defined, the service scheduler will wait for the task to reach a healthy status before counting it towards the minimum healthy percent total. A task is considered healthy when all essential containers within the task have passed their health checks. The amount of time the service scheduler can wait for is determined by the container health check settings.
         *
         *  For services that *do* use a load balancer, the following should be noted:
         *   +  If a task has no essential containers with a health check defined, the service scheduler will wait for the load balancer target group health check to return a healthy status before counting the task towards the minimum healthy percent total.
         *   +  If a task has an essential container with a health check defined, the service scheduler will wait for both the task to reach a healthy status and the load balancer target group health check to return a healthy status before counting the task towards the minimum healthy percent total.
         *
         *  The default value for a replica service for ``minimumHealthyPercent`` is 100%. The default ``minimumHealthyPercent`` value for a service using the ``DAEMON`` service schedule is 0% for the CLI, the AWS SDKs, and the APIs and 50% for the AWS Management Console.
         *  The minimum number of healthy tasks during a deployment is the ``desiredCount`` multiplied by the ``minimumHealthyPercent``/100, rounded up to the nearest integer value.
         *  If a service is using either the blue/green (``CODE_DEPLOY``) or ``EXTERNAL`` deployment types and is running tasks that use the EC2 launch type, the *minimum healthy percent* value is set to the default value. The *minimum healthy percent* value is used to define the lower limit on the number of the tasks in the service that remain in the ``RUNNING`` state while the container instances are in the ``DRAINING`` state.
         *   You can't specify a custom ``minimumHealthyPercent`` value for a service that uses either the blue/green (``CODE_DEPLOY``) or ``EXTERNAL`` deployment types and has tasks that use the EC2 launch type.
         *   If a service is using either the blue/green (``CODE_DEPLOY``) or ``EXTERNAL`` deployment types and is running tasks that use the Fargate launch type, the minimum healthy percent value is not used, although it is returned when describing your service.
         */
        minimumHealthyPercent?: pulumi.Input<number>;
    }
    /**
     * The deployment controller to use for the service.
     */
    interface ServiceDeploymentControllerArgs {
        /**
         * The deployment controller type to use. There are three deployment controller types available:
         *   + ECS The rolling update (ECS) deployment type involves replacing the current running version of the container with the latest version. The number of containers Amazon ECS adds or removes from the service during a rolling update is controlled by adjusting the minimum and maximum number of healthy tasks allowed during a service deployment, as specified in the DeploymentConfiguration. + CODE_DEPLOY The blue/green (CODE_DEPLOY) deployment type uses the blue/green deployment model powered by , which allows you to verify a new deployment of a service before sending production traffic to it. + EXTERNAL The external (EXTERNAL) deployment type enables you to use any third-party deployment controller for full control over the deployment process for an Amazon ECS service.
         */
        type?: pulumi.Input<enums.ecs.ServiceDeploymentControllerType>;
    }
    /**
     * The tag specifications of an Amazon EBS volume.
     */
    interface ServiceEbsTagSpecificationArgs {
        /**
         * Determines whether to propagate the tags from the task definition to
         * the Amazon EBS volume. Tags can only propagate to a ``SERVICE`` specified in
         * ``ServiceVolumeConfiguration``. If no value is specified, the tags aren't
         * propagated.
         */
        propagateTags?: pulumi.Input<enums.ecs.ServiceEbsTagSpecificationPropagateTags>;
        /**
         * The type of volume resource.
         */
        resourceType: pulumi.Input<string>;
        /**
         * The tags applied to this Amazon EBS volume. ``AmazonECSCreated`` and ``AmazonECSManaged`` are reserved tags that can't be used.
         */
        tags?: pulumi.Input<pulumi.Input<inputs.ecs.ServiceTagArgs>[]>;
    }
    /**
     * The ``LoadBalancer`` property specifies details on a load balancer that is used with a service.
     *  If the service is using the ``CODE_DEPLOY`` deployment controller, the service is required to use either an Application Load Balancer or Network Load Balancer. When you are creating an ACDlong deployment group, you specify two target groups (referred to as a ``targetGroupPair``). Each target group binds to a separate task set in the deployment. The load balancer can also have up to two listeners, a required listener for production traffic and an optional listener that allows you to test new revisions of the service before routing production traffic to it.
     *  Services with tasks that use the ``awsvpc`` network mode (for example, those with the Fargate launch type) only support Application Load Balancers and Network Load Balancers. Classic Load Balancers are not supported. Also, when you create any target groups for these services, you must choose ``ip`` as the target type, not ``instance``. Tasks that use the ``awsvpc`` network mode are associated with an elastic network interface, not an Amazon EC2 instance.
     */
    interface ServiceLoadBalancerArgs {
        /**
         * The name of the container (as it appears in a container definition) to associate with the load balancer.
         *  You need to specify the container name when configuring the target group for an Amazon ECS load balancer.
         */
        containerName?: pulumi.Input<string>;
        /**
         * The port on the container to associate with the load balancer. This port must correspond to a ``containerPort`` in the task definition the tasks in the service are using. For tasks that use the EC2 launch type, the container instance they're launched on must allow ingress traffic on the ``hostPort`` of the port mapping.
         */
        containerPort?: pulumi.Input<number>;
        /**
         * The name of the load balancer to associate with the Amazon ECS service or task set.
         *  If you are using an Application Load Balancer or a Network Load Balancer the load balancer name parameter should be omitted.
         */
        loadBalancerName?: pulumi.Input<string>;
        /**
         * The full Amazon Resource Name (ARN) of the Elastic Load Balancing target group or groups associated with a service or task set.
         *  A target group ARN is only specified when using an Application Load Balancer or Network Load Balancer.
         *  For services using the ``ECS`` deployment controller, you can specify one or multiple target groups. For more information, see [Registering multiple target groups with a service](https://docs.aws.amazon.com/AmazonECS/latest/developerguide/register-multiple-targetgroups.html) in the *Amazon Elastic Container Service Developer Guide*.
         *  For services using the ``CODE_DEPLOY`` deployment controller, you're required to define two target groups for the load balancer. For more information, see [Blue/green deployment with CodeDeploy](https://docs.aws.amazon.com/AmazonECS/latest/developerguide/deployment-type-bluegreen.html) in the *Amazon Elastic Container Service Developer Guide*.
         *   If your service's task definition uses the ``awsvpc`` network mode, you must choose ``ip`` as the target type, not ``instance``. Do this when creating your target groups because tasks that use the ``awsvpc`` network mode are associated with an elastic network interface, not an Amazon EC2 instance. This network mode is required for the Fargate launch type.
         */
        targetGroupArn?: pulumi.Input<string>;
    }
    /**
     * The log configuration for the container. This parameter maps to ``LogConfig`` in the docker container create command and the ``--log-driver`` option to docker run.
     *  By default, containers use the same logging driver that the Docker daemon uses. However, the container might use a different logging driver than the Docker daemon by specifying a log driver configuration in the container definition.
     *  Understand the following when specifying a log configuration for your containers.
     *   +  Amazon ECS currently supports a subset of the logging drivers available to the Docker daemon. Additional log drivers may be available in future releases of the Amazon ECS container agent.
     *  For tasks on FARGATElong, the supported log drivers are ``awslogs``, ``splunk``, and ``awsfirelens``.
     *  For tasks hosted on Amazon EC2 instances, the supported log drivers are ``awslogs``, ``fluentd``, ``gelf``, ``json-file``, ``journald``,``syslog``, ``splunk``, and ``awsfirelens``.
     *   +  This parameter requires version 1.18 of the Docker Remote API or greater on your container instance.
     *   +  For tasks that are hosted on Amazon EC2 instances, the Amazon ECS container agent must register the available logging drivers with the ``ECS_AVAILABLE_LOGGING_DRIVERS`` environment variable before containers placed on that instance can use these log configuration options. For more information, see [Amazon ECS container agent configuration](https://docs.aws.amazon.com/AmazonECS/latest/developerguide/ecs-agent-config.html) in the *Amazon Elastic Container Service Developer Guide*.
     *   +  For tasks that are on FARGATElong, because you don't have access to the underlying infrastructure your tasks are hosted on, any additional software needed must be installed outside of the task. For example, the Fluentd output aggregators or a remote host running Logstash to send Gelf logs to.
     */
    interface ServiceLogConfigurationArgs {
        /**
         * The log driver to use for the container.
         *  For tasks on FARGATElong, the supported log drivers are ``awslogs``, ``splunk``, and ``awsfirelens``.
         *  For tasks hosted on Amazon EC2 instances, the supported log drivers are ``awslogs``, ``fluentd``, ``gelf``, ``json-file``, ``journald``, ``syslog``, ``splunk``, and ``awsfirelens``.
         *  For more information about using the ``awslogs`` log driver, see [Send Amazon ECS logs to CloudWatch](https://docs.aws.amazon.com/AmazonECS/latest/developerguide/using_awslogs.html) in the *Amazon Elastic Container Service Developer Guide*.
         *  For more information about using the ``awsfirelens`` log driver, see [Send Amazon ECS logs to an service or Partner](https://docs.aws.amazon.com/AmazonECS/latest/developerguide/using_firelens.html).
         *   If you have a custom driver that isn't listed, you can fork the Amazon ECS container agent project that's [available on GitHub](https://docs.aws.amazon.com/https://github.com/aws/amazon-ecs-agent) and customize it to work with that driver. We encourage you to submit pull requests for changes that you would like to have included. However, we don't currently provide support for running modified copies of this software.
         */
        logDriver?: pulumi.Input<string>;
        /**
         * The configuration options to send to the log driver.
         *  The options you can specify depend on the log driver. Some of the options you can specify when you use the ``awslogs`` log driver to route logs to Amazon CloudWatch include the following:
         *   + awslogs-create-group Required: No Specify whether you want the log group to be created automatically. If this option isn't specified, it defaults to false. Your IAM policy must include the logs:CreateLogGroup permission before you attempt to use awslogs-create-group. + awslogs-region Required: Yes Specify the Region that the awslogs log driver is to send your Docker logs to. You can choose to send all of your logs from clusters in different Regions to a single region in CloudWatch Logs. This is so that they're all visible in one location. Otherwise, you can separate them by Region for more granularity. Make sure that the specified log group exists in the Region that you specify with this option. + awslogs-group Required: Yes Make sure to specify a log group that the awslogs log driver sends its log streams to. + awslogs-stream-prefix Required: Yes, when using the Fargate launch type.Optional for the EC2 launch type, required for the Fargate launch type. Use the awslogs-stream-prefix option to associate a log stream with the specified prefix, the container name, and the ID of the Amazon ECS task that the container belongs to. If you specify a prefix with this option, then the log stream takes the format prefix-name/container-name/ecs-task-id. If you don't specify a prefix with this option, then the log stream is named after the container ID that's assigned by the Docker daemon on the container instance. Because it's difficult to trace logs back to the container that sent them with just the Docker container ID (which is only available on the container instance), we recommend that you specify a prefix with this option. For Amazon ECS services, you can use the service name as the prefix. Doing so, you can trace log streams to the service that the container belongs to, the name of the container that sent them, and the ID of the task that the container belongs to. You must specify a stream-prefix for your logs to have your logs appear in the Log pane when using the Amazon ECS console. + awslogs-datetime-format Required: No This option defines a multiline start pattern in Python strftime format. A log message consists of a line that matches the pattern and any following lines that don’t match the pattern. The matched line is the delimiter between log messages. One example of a use case for using this format is for parsing output such as a stack dump, which might otherwise be logged in multiple entries. The correct pattern allows it to be captured in a single entry. For more information, see awslogs-datetime-format. You cannot configure both the awslogs-datetime-format and awslogs-multiline-pattern options. Multiline logging performs regular expression parsing and matching of all log messages. This might have a negative impact on logging performance. + awslogs-multiline-pattern Required: No This option defines a multiline start pattern that uses a regular expression. A log message consists of a line that matches the pattern and any following lines that don’t match the pattern. The matched line is the delimiter between log messages. For more information, see awslogs-multiline-pattern. This option is ignored if awslogs-datetime-format is also configured. You cannot configure both the awslogs-datetime-format and awslogs-multiline-pattern options. Multiline logging performs regular expression parsing and matching of all log messages. This might have a negative impact on logging performance. + mode Required: No Valid values: non-blocking | blocking This option defines the delivery mode of log messages from the container to CloudWatch Logs. The delivery mode you choose affects application availability when the flow of logs from container to CloudWatch is interrupted. If you use the blocking mode and the flow of logs to CloudWatch is interrupted, calls from container code to write to the stdout and stderr streams will block. The logging thread of the application will block as a result. This may cause the application to become unresponsive and lead to container healthcheck failure. If you use the non-blocking mode, the container's logs are instead stored in an in-memory intermediate buffer configured with the max-buffer-size option. This prevents the application from becoming unresponsive when logs cannot be sent to CloudWatch. We recommend using this mode if you want to ensure service availability and are okay with some log loss. For more information, see Preventing log loss with non-blocking mode in the awslogs container log driver. + max-buffer-size Required: No Default value: 1m When non-blocking mode is used, the max-buffer-size log option controls the size of the buffer that's used for intermediate message storage. Make sure to specify an adequate buffer size based on your application. When the buffer fills up, further logs cannot be stored. Logs that cannot be stored are lost.
         *  To route logs using the ``splunk`` log router, you need to specify a ``splunk-token`` and a ``splunk-url``.
         *  When you use the ``awsfirelens`` log router to route logs to an AWS Service or AWS Partner Network destination for log storage and analytics, you can set the ``log-driver-buffer-limit`` option to limit the number of events that are buffered in memory, before being sent to the log router container. It can help to resolve potential log loss issue because high throughput might result in memory running out for the buffer inside of Docker.
         *  Other options you can specify when using ``awsfirelens`` to route logs depend on the destination. When you export logs to Amazon Data Firehose, you can specify the AWS Region with ``region`` and a name for the log stream with ``delivery_stream``.
         *  When you export logs to Amazon Kinesis Data Streams, you can specify an AWS Region with ``region`` and a data stream name with ``stream``.
         *   When you export logs to Amazon OpenSearch Service, you can specify options like ``Name``, ``Host`` (OpenSearch Service endpoint without protocol), ``Port``, ``Index``, ``Type``, ``Aws_auth``, ``Aws_region``, ``Suppress_Type_Name``, and ``tls``. For more information, see [Under the hood: FireLens for Amazon ECS Tasks](https://docs.aws.amazon.com/containers/under-the-hood-firelens-for-amazon-ecs-tasks/).
         *  When you export logs to Amazon S3, you can specify the bucket using the ``bucket`` option. You can also specify ``region``, ``total_file_size``, ``upload_timeout``, and ``use_put_object`` as options.
         *  This parameter requires version 1.19 of the Docker Remote API or greater on your container instance. To check the Docker Remote API version on your container instance, log in to your container instance and run the following command: ``sudo docker version --format '{{.Server.APIVersion}}'``
         */
        options?: pulumi.Input<{
            [key: string]: pulumi.Input<string>;
        }>;
        /**
         * The secrets to pass to the log configuration. For more information, see [Specifying sensitive data](https://docs.aws.amazon.com/AmazonECS/latest/developerguide/specifying-sensitive-data.html) in the *Amazon Elastic Container Service Developer Guide*.
         */
        secretOptions?: pulumi.Input<pulumi.Input<inputs.ecs.ServiceSecretArgs>[]>;
    }
    /**
     * The configuration for the Amazon EBS volume that Amazon ECS creates and manages on your behalf. These settings are used to create each Amazon EBS volume, with one volume created for each task in the service. For information about the supported launch types and operating systems, see [Supported operating systems and launch types](https://docs.aws.amazon.com/AmazonECS/latest/developerguide/ebs-volumes.html#ebs-volumes-configuration) in the*Amazon Elastic Container Service Developer Guide*.
     *  Many of these parameters map 1:1 with the Amazon EBS ``CreateVolume`` API request parameters.
     */
    interface ServiceManagedEbsVolumeConfigurationArgs {
        /**
         * Indicates whether the volume should be encrypted. If no value is specified, encryption is turned on by default. This parameter maps 1:1 with the ``Encrypted`` parameter of the [CreateVolume API](https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_CreateVolume.html) in the *Amazon EC2 API Reference*.
         */
        encrypted?: pulumi.Input<boolean>;
        /**
         * The filesystem type for the volume. For volumes created from a snapshot, you must specify the same filesystem type that the volume was using when the snapshot was created. If there is a filesystem type mismatch, the task will fail to start.
         *  The available Linux filesystem types are
         *  ``ext3``, ``ext4``, and ``xfs``. If no value is specified, the ``xfs`` filesystem type is used by default.
         *  The available Windows filesystem types are ``NTFS``.
         */
        filesystemType?: pulumi.Input<string>;
        /**
         * The number of I/O operations per second (IOPS). For ``gp3``, ``io1``, and ``io2`` volumes, this represents the number of IOPS that are provisioned for the volume. For ``gp2`` volumes, this represents the baseline performance of the volume and the rate at which the volume accumulates I/O credits for bursting.
         *  The following are the supported values for each volume type.
         *   +   ``gp3``: 3,000 - 16,000 IOPS
         *   +   ``io1``: 100 - 64,000 IOPS
         *   +   ``io2``: 100 - 256,000 IOPS
         *
         *  This parameter is required for ``io1`` and ``io2`` volume types. The default for ``gp3`` volumes is ``3,000 IOPS``. This parameter is not supported for ``st1``, ``sc1``, or ``standard`` volume types.
         *  This parameter maps 1:1 with the ``Iops`` parameter of the [CreateVolume API](https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_CreateVolume.html) in the *Amazon EC2 API Reference*.
         */
        iops?: pulumi.Input<number>;
        /**
         * The Amazon Resource Name (ARN) identifier of the AWS Key Management Service key to use for Amazon EBS encryption. When encryption is turned on and no AWS Key Management Service key is specified, the default AWS managed key for Amazon EBS volumes is used. This parameter maps 1:1 with the ``KmsKeyId`` parameter of the [CreateVolume API](https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_CreateVolume.html) in the *Amazon EC2 API Reference*.
         *    AWS authenticates the AWS Key Management Service key asynchronously. Therefore, if you specify an ID, alias, or ARN that is invalid, the action can appear to complete, but eventually fails.
         */
        kmsKeyId?: pulumi.Input<string>;
        /**
         * The ARN of the IAM role to associate with this volume. This is the Amazon ECS infrastructure IAM role that is used to manage your AWS infrastructure. We recommend using the Amazon ECS-managed ``AmazonECSInfrastructureRolePolicyForVolumes`` IAM policy with this role. For more information, see [Amazon ECS infrastructure IAM role](https://docs.aws.amazon.com/AmazonECS/latest/developerguide/infrastructure_IAM_role.html) in the *Amazon ECS Developer Guide*.
         */
        roleArn: pulumi.Input<string>;
        /**
         * The size of the volume in GiB. You must specify either a volume size or a snapshot ID. If you specify a snapshot ID, the snapshot size is used for the volume size by default. You can optionally specify a volume size greater than or equal to the snapshot size. This parameter maps 1:1 with the ``Size`` parameter of the [CreateVolume API](https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_CreateVolume.html) in the *Amazon EC2 API Reference*.
         *  The following are the supported volume size values for each volume type.
         *   +   ``gp2`` and ``gp3``: 1-16,384
         *   +   ``io1`` and ``io2``: 4-16,384
         *   +   ``st1`` and ``sc1``: 125-16,384
         *   +   ``standard``: 1-1,024
         */
        sizeInGiB?: pulumi.Input<number>;
        /**
         * The snapshot that Amazon ECS uses to create the volume. You must specify either a snapshot ID or a volume size. This parameter maps 1:1 with the ``SnapshotId`` parameter of the [CreateVolume API](https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_CreateVolume.html) in the *Amazon EC2 API Reference*.
         */
        snapshotId?: pulumi.Input<string>;
        /**
         * The tags to apply to the volume. Amazon ECS applies service-managed tags by default. This parameter maps 1:1 with the ``TagSpecifications.N`` parameter of the [CreateVolume API](https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_CreateVolume.html) in the *Amazon EC2 API Reference*.
         */
        tagSpecifications?: pulumi.Input<pulumi.Input<inputs.ecs.ServiceEbsTagSpecificationArgs>[]>;
        /**
         * The throughput to provision for a volume, in MiB/s, with a maximum of 1,000 MiB/s. This parameter maps 1:1 with the ``Throughput`` parameter of the [CreateVolume API](https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_CreateVolume.html) in the *Amazon EC2 API Reference*.
         *   This parameter is only supported for the ``gp3`` volume type.
         */
        throughput?: pulumi.Input<number>;
        /**
         * The volume type. This parameter maps 1:1 with the ``VolumeType`` parameter of the [CreateVolume API](https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_CreateVolume.html) in the *Amazon EC2 API Reference*. For more information, see [Amazon EBS volume types](https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/ebs-volume-types.html) in the *Amazon EC2 User Guide*.
         *  The following are the supported volume types.
         *   +  General Purpose SSD: ``gp2``|``gp3``
         *   +  Provisioned IOPS SSD: ``io1``|``io2``
         *   +  Throughput Optimized HDD: ``st1``
         *   +  Cold HDD: ``sc1``
         *   +  Magnetic: ``standard``
         *   The magnetic volume type is not supported on Fargate.
         */
        volumeType?: pulumi.Input<string>;
    }
    /**
     * The network configuration for a task or service.
     */
    interface ServiceNetworkConfigurationArgs {
        /**
         * The VPC subnets and security groups that are associated with a task.
         *   All specified subnets and security groups must be from the same VPC.
         */
        awsvpcConfiguration?: pulumi.Input<inputs.ecs.ServiceAwsVpcConfigurationArgs>;
    }
    /**
     * An object representing a constraint on task placement. For more information, see [Task placement constraints](https://docs.aws.amazon.com/AmazonECS/latest/developerguide/task-placement-constraints.html) in the *Amazon Elastic Container Service Developer Guide*.
     *   If you're using the Fargate launch type, task placement constraints aren't supported.
     */
    interface ServicePlacementConstraintArgs {
        /**
         * A cluster query language expression to apply to the constraint. The expression can have a maximum length of 2000 characters. You can't specify an expression if the constraint type is ``distinctInstance``. For more information, see [Cluster query language](https://docs.aws.amazon.com/AmazonECS/latest/developerguide/cluster-query-language.html) in the *Amazon Elastic Container Service Developer Guide*.
         */
        expression?: pulumi.Input<string>;
        /**
         * The type of constraint. Use ``distinctInstance`` to ensure that each task in a particular group is running on a different container instance. Use ``memberOf`` to restrict the selection to a group of valid candidates.
         */
        type: pulumi.Input<enums.ecs.ServicePlacementConstraintType>;
    }
    /**
     * The task placement strategy for a task or service. For more information, see [Task placement strategies](https://docs.aws.amazon.com/AmazonECS/latest/developerguide/task-placement-strategies.html) in the *Amazon Elastic Container Service Developer Guide*.
     */
    interface ServicePlacementStrategyArgs {
        /**
         * The field to apply the placement strategy against. For the ``spread`` placement strategy, valid values are ``instanceId`` (or ``host``, which has the same effect), or any platform or custom attribute that's applied to a container instance, such as ``attribute:ecs.availability-zone``. For the ``binpack`` placement strategy, valid values are ``cpu`` and ``memory``. For the ``random`` placement strategy, this field is not used.
         */
        field?: pulumi.Input<string>;
        /**
         * The type of placement strategy. The ``random`` placement strategy randomly places tasks on available candidates. The ``spread`` placement strategy spreads placement across available candidates evenly based on the ``field`` parameter. The ``binpack`` strategy places tasks on available candidates that have the least available amount of the resource that's specified with the ``field`` parameter. For example, if you binpack on memory, a task is placed on the instance with the least amount of remaining memory but still enough to run the task.
         */
        type: pulumi.Input<enums.ecs.ServicePlacementStrategyType>;
    }
    /**
     * The details for the service registry.
     *  Each service may be associated with one service registry. Multiple service registries for each service are not supported.
     *  When you add, update, or remove the service registries configuration, Amazon ECS starts a new deployment. New tasks are registered and deregistered to the updated service registry configuration.
     */
    interface ServiceRegistryArgs {
        /**
         * The container name value to be used for your service discovery service. It's already specified in the task definition. If the task definition that your service task specifies uses the ``bridge`` or ``host`` network mode, you must specify a ``containerName`` and ``containerPort`` combination from the task definition. If the task definition that your service task specifies uses the ``awsvpc`` network mode and a type SRV DNS record is used, you must specify either a ``containerName`` and ``containerPort`` combination or a ``port`` value. However, you can't specify both.
         */
        containerName?: pulumi.Input<string>;
        /**
         * The port value to be used for your service discovery service. It's already specified in the task definition. If the task definition your service task specifies uses the ``bridge`` or ``host`` network mode, you must specify a ``containerName`` and ``containerPort`` combination from the task definition. If the task definition your service task specifies uses the ``awsvpc`` network mode and a type SRV DNS record is used, you must specify either a ``containerName`` and ``containerPort`` combination or a ``port`` value. However, you can't specify both.
         */
        containerPort?: pulumi.Input<number>;
        /**
         * The port value used if your service discovery service specified an SRV record. This field might be used if both the ``awsvpc`` network mode and SRV records are used.
         */
        port?: pulumi.Input<number>;
        /**
         * The Amazon Resource Name (ARN) of the service registry. The currently supported service registry is CMAP. For more information, see [CreateService](https://docs.aws.amazon.com/cloud-map/latest/api/API_CreateService.html).
         */
        registryArn?: pulumi.Input<string>;
    }
    /**
     * An object representing the secret to expose to your container. Secrets can be exposed to a container in the following ways:
     *   +  To inject sensitive data into your containers as environment variables, use the ``secrets`` container definition parameter.
     *   +  To reference sensitive information in the log configuration of a container, use the ``secretOptions`` container definition parameter.
     *
     *  For more information, see [Specifying sensitive data](https://docs.aws.amazon.com/AmazonECS/latest/developerguide/specifying-sensitive-data.html) in the *Amazon Elastic Container Service Developer Guide*.
     */
    interface ServiceSecretArgs {
        /**
         * The name of the secret.
         */
        name: pulumi.Input<string>;
        /**
         * The secret to expose to the container. The supported values are either the full ARN of the ASMlong secret or the full ARN of the parameter in the SSM Parameter Store.
         *  For information about the require IAMlong permissions, see [Required IAM permissions for Amazon ECS secrets](https://docs.aws.amazon.com/AmazonECS/latest/developerguide/specifying-sensitive-data-secrets.html#secrets-iam) (for Secrets Manager) or [Required IAM permissions for Amazon ECS secrets](https://docs.aws.amazon.com/AmazonECS/latest/developerguide/specifying-sensitive-data-parameters.html) (for Systems Manager Parameter store) in the *Amazon Elastic Container Service Developer Guide*.
         *   If the SSM Parameter Store parameter exists in the same Region as the task you're launching, then you can use either the full ARN or name of the parameter. If the parameter exists in a different Region, then the full ARN must be specified.
         */
        valueFrom: pulumi.Input<string>;
    }
    /**
     * The metadata that you apply to a resource to help you categorize and organize them. Each tag consists of a key and an optional value. You define them.
     *  The following basic restrictions apply to tags:
     *   +  Maximum number of tags per resource - 50
     *   +  For each resource, each tag key must be unique, and each tag key can have only one value.
     *   +  Maximum key length - 128 Unicode characters in UTF-8
     *   +  Maximum value length - 256 Unicode characters in UTF-8
     *   +  If your tagging schema is used across multiple services and resources, remember that other services may have restrictions on allowed characters. Generally allowed characters are: letters, numbers, and spaces representable in UTF-8, and the following characters: + - = . _ : / @.
     *   +  Tag keys and values are case-sensitive.
     *   +  Do not use ``aws:``, ``AWS:``, or any upper or lowercase combination of such as a prefix for either keys or values as it is reserved for AWS use. You cannot edit or delete tag keys or values with this prefix. Tags with this prefix do not count against your tags per resource limit.
     *
     *  In order to tag a service that has the following ARN format, you need to migrate the service to the long ARN. You must use the API, CLI or console to migrate the service ARN. For more information, see [Migrate an short service ARN to a long ARN](https://docs.aws.amazon.com/AmazonECS/latest/developerguide/service-arn-migration.html) in the *Developer Guide*.
     *   ``arn:aws:ecs:region:aws_account_id:service/service-name``
     *  After the migration is complete, the following are true:
     *   +   The service ARN is: ``arn:aws:ecs:region:aws_account_id:service/cluster-name/service-name``
     *   +  You can use CFN to tag the service as you would a service with a long ARN format.
     *   +  When the ``PhysicalResourceId`` in the CFN stack represents a service, the value does not change and will be the short service ARN.
     */
    interface ServiceTagArgs {
        /**
         * One part of a key-value pair that make up a tag. A ``key`` is a general label that acts like a category for more specific tag values.
         */
        key?: pulumi.Input<string>;
        /**
         * The optional part of a key-value pair that make up a tag. A ``value`` acts as a descriptor within a tag category (key).
         */
        value?: pulumi.Input<string>;
    }
    /**
     * An object that represents the timeout configurations for Service Connect.
     *   If ``idleTimeout`` is set to a time that is less than ``perRequestTimeout``, the connection will close when the ``idleTimeout`` is reached and not the ``perRequestTimeout``.
     */
    interface ServiceTimeoutConfigurationArgs {
        /**
         * The amount of time in seconds a connection will stay active while idle. A value of ``0`` can be set to disable ``idleTimeout``.
         *  The ``idleTimeout`` default for ``HTTP``/``HTTP2``/``GRPC`` is 5 minutes.
         *  The ``idleTimeout`` default for ``TCP`` is 1 hour.
         */
        idleTimeoutSeconds?: pulumi.Input<number>;
        /**
         * The amount of time waiting for the upstream to respond with a complete response per request. A value of ``0`` can be set to disable ``perRequestTimeout``. ``perRequestTimeout`` can only be set if Service Connect ``appProtocol`` isn't ``TCP``. Only ``idleTimeout`` is allowed for ``TCP`` ``appProtocol``.
         */
        perRequestTimeoutSeconds?: pulumi.Input<number>;
    }
    /**
     * The configuration for a volume specified in the task definition as a volume that is configured at launch time. Currently, the only supported volume type is an Amazon EBS volume.
     */
    interface ServiceVolumeConfigurationArgs {
        /**
         * The configuration for the Amazon EBS volume that Amazon ECS creates and manages on your behalf. These settings are used to create each Amazon EBS volume, with one volume created for each task in the service. The Amazon EBS volumes are visible in your account in the Amazon EC2 console once they are created.
         */
        managedEbsVolume?: pulumi.Input<inputs.ecs.ServiceManagedEbsVolumeConfigurationArgs>;
        /**
         * The name of the volume. This value must match the volume name from the ``Volume`` object in the task definition.
         */
        name: pulumi.Input<string>;
    }
    /**
     * The VPC Lattice configuration for your service that holds the information for the target group(s) Amazon ECS tasks will be registered to.
     */
    interface ServiceVpcLatticeConfigurationArgs {
        /**
         * The name of the port mapping to register in the VPC Lattice target group. This is the name of the ``portMapping`` you defined in your task definition.
         */
        portName: pulumi.Input<string>;
        /**
         * The ARN of the IAM role to associate with this VPC Lattice configuration. This is the Amazon ECS
         *  infrastructure IAM role that is used to manage your VPC Lattice infrastructure.
         */
        roleArn: pulumi.Input<string>;
        /**
         * The full Amazon Resource Name (ARN) of the target group or groups associated with the VPC Lattice configuration that the Amazon ECS tasks will be registered to.
         */
        targetGroupArn: pulumi.Input<string>;
    }
    /**
     * The authorization configuration details for the Amazon EFS file system.
     */
    interface TaskDefinitionAuthorizationConfigArgs {
        /**
         * The Amazon EFS access point ID to use. If an access point is specified, the root directory value specified in the ``EFSVolumeConfiguration`` must either be omitted or set to ``/`` which will enforce the path set on the EFS access point. If an access point is used, transit encryption must be on in the ``EFSVolumeConfiguration``. For more information, see [Working with Amazon EFS access points](https://docs.aws.amazon.com/efs/latest/ug/efs-access-points.html) in the *Amazon Elastic File System User Guide*.
         */
        accessPointId?: pulumi.Input<string>;
        /**
         * Determines whether to use the Amazon ECS task role defined in a task definition when mounting the Amazon EFS file system. If it is turned on, transit encryption must be turned on in the ``EFSVolumeConfiguration``. If this parameter is omitted, the default value of ``DISABLED`` is used. For more information, see [Using Amazon EFS access points](https://docs.aws.amazon.com/AmazonECS/latest/developerguide/efs-volumes.html#efs-volume-accesspoints) in the *Amazon Elastic Container Service Developer Guide*.
         */
        iam?: pulumi.Input<enums.ecs.TaskDefinitionAuthorizationConfigIam>;
    }
    /**
     * The ``ContainerDefinition`` property specifies a container definition. Container definitions are used in task definitions to describe the different containers that are launched as part of a task.
     */
    interface TaskDefinitionContainerDefinitionArgs {
        /**
         * The command that's passed to the container. This parameter maps to ``Cmd`` in the docker container create command and the ``COMMAND`` parameter to docker run. If there are multiple arguments, each argument is a separated string in the array.
         */
        command?: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * The number of ``cpu`` units reserved for the container. This parameter maps to ``CpuShares`` in the docker container create commandand the ``--cpu-shares`` option to docker run.
         *  This field is optional for tasks using the Fargate launch type, and the only requirement is that the total amount of CPU reserved for all containers within a task be lower than the task-level ``cpu`` value.
         *   You can determine the number of CPU units that are available per EC2 instance type by multiplying the vCPUs listed for that instance type on the [Amazon EC2 Instances](https://docs.aws.amazon.com/ec2/instance-types/) detail page by 1,024.
         *   Linux containers share unallocated CPU units with other containers on the container instance with the same ratio as their allocated amount. For example, if you run a single-container task on a single-core instance type with 512 CPU units specified for that container, and that's the only task running on the container instance, that container could use the full 1,024 CPU unit share at any given time. However, if you launched another copy of the same task on that container instance, each task is guaranteed a minimum of 512 CPU units when needed. Moreover, each container could float to higher CPU usage if the other container was not using it. If both tasks were 100% active all of the time, they would be limited to 512 CPU units.
         *  On Linux container instances, the Docker daemon on the container instance uses the CPU value to calculate the relative CPU share ratios for running containers. The minimum valid CPU share value that the Linux kernel allows is 2, and the maximum valid CPU share value that the Linux kernel allows is 262144. However, the CPU parameter isn't required, and you can use CPU values below 2 or above 262144 in your container definitions. For CPU values below 2 (including null) or above 262144, the behavior varies based on your Amazon ECS container agent version:
         *   +   *Agent versions less than or equal to 1.1.0:* Null and zero CPU values are passed to Docker as 0, which Docker then converts to 1,024 CPU shares. CPU values of 1 are passed to Docker as 1, which the Linux kernel converts to two CPU shares.
         *   +   *Agent versions greater than or equal to 1.2.0:* Null, zero, and CPU values of 1 are passed to Docker as 2.
         *   +   *Agent versions greater than or equal to 1.84.0:* CPU values greater than 256 vCPU are passed to Docker as 256, which is equivalent to 262144 CPU shares.
         *
         *  On Windows container instances, the CPU limit is enforced as an absolute limit, or a quota. Windows containers only have access to the specified amount of CPU that's described in the task definition. A null or zero CPU value is passed to Docker as ``0``, which Windows interprets as 1% of one CPU.
         */
        cpu?: pulumi.Input<number>;
        /**
         * A list of ARNs in SSM or Amazon S3 to a credential spec (``CredSpec``) file that configures the container for Active Directory authentication. We recommend that you use this parameter instead of the ``dockerSecurityOptions``. The maximum number of ARNs is 1.
         *  There are two formats for each ARN.
         *   + credentialspecdomainless:MyARN You use credentialspecdomainless:MyARN to provide a CredSpec with an additional section for a secret in . You provide the login credentials to the domain in the secret. Each task that runs on any container instance can join different domains. You can use this format without joining the container instance to a domain. + credentialspec:MyARN You use credentialspec:MyARN to provide a CredSpec for a single domain. You must join the container instance to the domain before you start any tasks that use this task definition.
         *  In both formats, replace ``MyARN`` with the ARN in SSM or Amazon S3.
         *  If you provide a ``credentialspecdomainless:MyARN``, the ``credspec`` must provide a ARN in ASMlong for a secret containing the username, password, and the domain to connect to. For better security, the instance isn't joined to the domain for domainless authentication. Other applications on the instance can't use the domainless credentials. You can use this parameter to run tasks on the same instance, even it the tasks need to join different domains. For more information, see [Using gMSAs for Windows Containers](https://docs.aws.amazon.com/AmazonECS/latest/developerguide/windows-gmsa.html) and [Using gMSAs for Linux Containers](https://docs.aws.amazon.com/AmazonECS/latest/developerguide/linux-gmsa.html).
         */
        credentialSpecs?: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * The dependencies defined for container startup and shutdown. A container can contain multiple dependencies. When a dependency is defined for container startup, for container shutdown it is reversed.
         *  For tasks using the EC2 launch type, the container instances require at least version 1.26.0 of the container agent to turn on container dependencies. However, we recommend using the latest container agent version. For information about checking your agent version and updating to the latest version, see [Updating the Amazon ECS Container Agent](https://docs.aws.amazon.com/AmazonECS/latest/developerguide/ecs-agent-update.html) in the *Amazon Elastic Container Service Developer Guide*. If you're using an Amazon ECS-optimized Linux AMI, your instance needs at least version 1.26.0-1 of the ``ecs-init`` package. If your container instances are launched from version ``20190301`` or later, then they contain the required versions of the container agent and ``ecs-init``. For more information, see [Amazon ECS-optimized Linux AMI](https://docs.aws.amazon.com/AmazonECS/latest/developerguide/ecs-optimized_AMI.html) in the *Amazon Elastic Container Service Developer Guide*.
         *  For tasks using the Fargate launch type, the task or service requires the following platforms:
         *   +  Linux platform version ``1.3.0`` or later.
         *   +  Windows platform version ``1.0.0`` or later.
         *
         *  If the task definition is used in a blue/green deployment that uses [AWS::CodeDeploy::DeploymentGroup BlueGreenDeploymentConfiguration](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-codedeploy-deploymentgroup-bluegreendeploymentconfiguration.html), the ``dependsOn`` parameter is not supported. For more information see [Issue #680](https://docs.aws.amazon.com/https://github.com/aws-cloudformation/cloudformation-coverage-roadmap/issues/680) on the on the GitHub website.
         */
        dependsOn?: pulumi.Input<pulumi.Input<inputs.ecs.TaskDefinitionContainerDependencyArgs>[]>;
        /**
         * When this parameter is true, networking is off within the container. This parameter maps to ``NetworkDisabled`` in the docker container create command.
         *   This parameter is not supported for Windows containers.
         */
        disableNetworking?: pulumi.Input<boolean>;
        /**
         * A list of DNS search domains that are presented to the container. This parameter maps to ``DnsSearch`` in the docker container create command and the ``--dns-search`` option to docker run.
         *   This parameter is not supported for Windows containers.
         */
        dnsSearchDomains?: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * A list of DNS servers that are presented to the container. This parameter maps to ``Dns`` in the docker container create command and the ``--dns`` option to docker run.
         *   This parameter is not supported for Windows containers.
         */
        dnsServers?: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * A key/value map of labels to add to the container. This parameter maps to ``Labels`` in the docker container create command and the ``--label`` option to docker run. This parameter requires version 1.18 of the Docker Remote API or greater on your container instance. To check the Docker Remote API version on your container instance, log in to your container instance and run the following command: ``sudo docker version --format '{{.Server.APIVersion}}'``
         */
        dockerLabels?: pulumi.Input<{
            [key: string]: pulumi.Input<string>;
        }>;
        /**
         * A list of strings to provide custom configuration for multiple security systems. This field isn't valid for containers in tasks using the Fargate launch type.
         *  For Linux tasks on EC2, this parameter can be used to reference custom labels for SELinux and AppArmor multi-level security systems.
         *  For any tasks on EC2, this parameter can be used to reference a credential spec file that configures a container for Active Directory authentication. For more information, see [Using gMSAs for Windows Containers](https://docs.aws.amazon.com/AmazonECS/latest/developerguide/windows-gmsa.html) and [Using gMSAs for Linux Containers](https://docs.aws.amazon.com/AmazonECS/latest/developerguide/linux-gmsa.html) in the *Amazon Elastic Container Service Developer Guide*.
         *  This parameter maps to ``SecurityOpt`` in the docker container create command and the ``--security-opt`` option to docker run.
         *   The Amazon ECS container agent running on a container instance must register with the ``ECS_SELINUX_CAPABLE=true`` or ``ECS_APPARMOR_CAPABLE=true`` environment variables before containers placed on that instance can use these security options. For more information, see [Amazon ECS Container Agent Configuration](https://docs.aws.amazon.com/AmazonECS/latest/developerguide/ecs-agent-config.html) in the *Amazon Elastic Container Service Developer Guide*.
         *   Valid values: "no-new-privileges" | "apparmor:PROFILE" | "label:value" | "credentialspec:CredentialSpecFilePath"
         */
        dockerSecurityOptions?: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * Early versions of the Amazon ECS container agent don't properly handle ``entryPoint`` parameters. If you have problems using ``entryPoint``, update your container agent or enter your commands and arguments as ``command`` array items instead.
         *   The entry point that's passed to the container. This parameter maps to ``Entrypoint`` in the docker container create command and the ``--entrypoint`` option to docker run.
         */
        entryPoint?: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * The environment variables to pass to a container. This parameter maps to ``Env`` in the docker container create command and the ``--env`` option to docker run.
         *   We don't recommend that you use plaintext environment variables for sensitive information, such as credential data.
         */
        environment?: pulumi.Input<pulumi.Input<inputs.ecs.TaskDefinitionKeyValuePairArgs>[]>;
        /**
         * A list of files containing the environment variables to pass to a container. This parameter maps to the ``--env-file`` option to docker run.
         *  You can specify up to ten environment files. The file must have a ``.env`` file extension. Each line in an environment file contains an environment variable in ``VARIABLE=VALUE`` format. Lines beginning with ``#`` are treated as comments and are ignored.
         *  If there are environment variables specified using the ``environment`` parameter in a container definition, they take precedence over the variables contained within an environment file. If multiple environment files are specified that contain the same variable, they're processed from the top down. We recommend that you use unique variable names. For more information, see [Specifying Environment Variables](https://docs.aws.amazon.com/AmazonECS/latest/developerguide/taskdef-envfiles.html) in the *Amazon Elastic Container Service Developer Guide*.
         */
        environmentFiles?: pulumi.Input<pulumi.Input<inputs.ecs.TaskDefinitionEnvironmentFileArgs>[]>;
        /**
         * If the ``essential`` parameter of a container is marked as ``true``, and that container fails or stops for any reason, all other containers that are part of the task are stopped. If the ``essential`` parameter of a container is marked as ``false``, its failure doesn't affect the rest of the containers in a task. If this parameter is omitted, a container is assumed to be essential.
         *  All tasks must have at least one essential container. If you have an application that's composed of multiple containers, group containers that are used for a common purpose into components, and separate the different components into multiple task definitions. For more information, see [Application Architecture](https://docs.aws.amazon.com/AmazonECS/latest/developerguide/application_architecture.html) in the *Amazon Elastic Container Service Developer Guide*.
         */
        essential?: pulumi.Input<boolean>;
        /**
         * A list of hostnames and IP address mappings to append to the ``/etc/hosts`` file on the container. This parameter maps to ``ExtraHosts`` in the docker container create command and the ``--add-host`` option to docker run.
         *   This parameter isn't supported for Windows containers or tasks that use the ``awsvpc`` network mode.
         */
        extraHosts?: pulumi.Input<pulumi.Input<inputs.ecs.TaskDefinitionHostEntryArgs>[]>;
        /**
         * The FireLens configuration for the container. This is used to specify and configure a log router for container logs. For more information, see [Custom Log Routing](https://docs.aws.amazon.com/AmazonECS/latest/developerguide/using_firelens.html) in the *Amazon Elastic Container Service Developer Guide*.
         */
        firelensConfiguration?: pulumi.Input<inputs.ecs.TaskDefinitionFirelensConfigurationArgs>;
        /**
         * The container health check command and associated configuration parameters for the container. This parameter maps to ``HealthCheck`` in the docker container create command and the ``HEALTHCHECK`` parameter of docker run.
         */
        healthCheck?: pulumi.Input<inputs.ecs.TaskDefinitionHealthCheckArgs>;
        /**
         * The hostname to use for your container. This parameter maps to ``Hostname`` in the docker container create command and the ``--hostname`` option to docker run.
         *   The ``hostname`` parameter is not supported if you're using the ``awsvpc`` network mode.
         */
        hostname?: pulumi.Input<string>;
        /**
         * The image used to start a container. This string is passed directly to the Docker daemon. By default, images in the Docker Hub registry are available. Other repositories are specified with either ``repository-url/image:tag`` or ``repository-url/image@digest``. Up to 255 letters (uppercase and lowercase), numbers, hyphens, underscores, colons, periods, forward slashes, and number signs are allowed. This parameter maps to ``Image`` in the docker container create command and the ``IMAGE`` parameter of docker run.
         *   +  When a new task starts, the Amazon ECS container agent pulls the latest version of the specified image and tag for the container to use. However, subsequent updates to a repository image aren't propagated to already running tasks.
         *   +  Images in Amazon ECR repositories can be specified by either using the full ``registry/repository:tag`` or ``registry/repository@digest``. For example, ``012345678910.dkr.ecr.<region-name>.amazonaws.com/<repository-name>:latest`` or ``012345678910.dkr.ecr.<region-name>.amazonaws.com/<repository-name>@sha256:94afd1f2e64d908bc90dbca0035a5b567EXAMPLE``.
         *   +  Images in official repositories on Docker Hub use a single name (for example, ``ubuntu`` or ``mongo``).
         *   +  Images in other repositories on Docker Hub are qualified with an organization name (for example, ``amazon/amazon-ecs-agent``).
         *   +  Images in other online repositories are qualified further by a domain name (for example, ``quay.io/assemblyline/ubuntu``).
         */
        image: pulumi.Input<string>;
        /**
         * When this parameter is ``true``, you can deploy containerized applications that require ``stdin`` or a ``tty`` to be allocated. This parameter maps to ``OpenStdin`` in the docker container create command and the ``--interactive`` option to docker run.
         */
        interactive?: pulumi.Input<boolean>;
        /**
         * The ``links`` parameter allows containers to communicate with each other without the need for port mappings. This parameter is only supported if the network mode of a task definition is ``bridge``. The ``name:internalName`` construct is analogous to ``name:alias`` in Docker links. Up to 255 letters (uppercase and lowercase), numbers, underscores, and hyphens are allowed.. This parameter maps to ``Links`` in the docker container create command and the ``--link`` option to docker run.
         *   This parameter is not supported for Windows containers.
         *    Containers that are collocated on a single container instance may be able to communicate with each other without requiring links or host port mappings. Network isolation is achieved on the container instance using security groups and VPC settings.
         */
        links?: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * Linux-specific modifications that are applied to the container, such as Linux kernel capabilities. For more information see [KernelCapabilities](https://docs.aws.amazon.com/AmazonECS/latest/APIReference/API_KernelCapabilities.html).
         *   This parameter is not supported for Windows containers.
         */
        linuxParameters?: pulumi.Input<inputs.ecs.TaskDefinitionLinuxParametersArgs>;
        /**
         * The log configuration specification for the container.
         *  This parameter maps to ``LogConfig`` in the docker Create a container command and the ``--log-driver`` option to docker run. By default, containers use the same logging driver that the Docker daemon uses. However, the container may use a different logging driver than the Docker daemon by specifying a log driver with this parameter in the container definition. To use a different logging driver for a container, the log system must be configured properly on the container instance (or on a different log server for remote logging options). For more information on the options for different supported log drivers, see [Configure logging drivers](https://docs.aws.amazon.com/https://docs.docker.com/engine/admin/logging/overview/) in the Docker documentation.
         *   Amazon ECS currently supports a subset of the logging drivers available to the Docker daemon (shown in the [LogConfiguration](https://docs.aws.amazon.com/AmazonECS/latest/APIReference/API_LogConfiguration.html) data type). Additional log drivers may be available in future releases of the Amazon ECS container agent.
         *   This parameter requires version 1.18 of the Docker Remote API or greater on your container instance. To check the Docker Remote API version on your container instance, log in to your container instance and run the following command: ``sudo docker version --format '{{.Server.APIVersion}}'``
         *   The Amazon ECS container agent running on a container instance must register the logging drivers available on that instance with the ``ECS_AVAILABLE_LOGGING_DRIVERS`` environment variable before containers placed on that instance can use these log configuration options. For more information, see [Container Agent Configuration](https://docs.aws.amazon.com/AmazonECS/latest/developerguide/ecs-agent-config.html) in the *Developer Guide*.
         */
        logConfiguration?: pulumi.Input<inputs.ecs.TaskDefinitionLogConfigurationArgs>;
        /**
         * The amount (in MiB) of memory to present to the container. If your container attempts to exceed the memory specified here, the container is killed. The total amount of memory reserved for all containers within a task must be lower than the task ``memory`` value, if one is specified. This parameter maps to ``Memory`` in the [Create a container](https://docs.aws.amazon.com/https://docs.docker.com/engine/api/v1.35/#operation/ContainerCreate) section of the [Docker Remote API](https://docs.aws.amazon.com/https://docs.docker.com/engine/api/v1.35/) and the ``--memory`` option to [docker run](https://docs.aws.amazon.com/https://docs.docker.com/engine/reference/run/#security-configuration).
         *  If using the Fargate launch type, this parameter is optional.
         *  If using the EC2 launch type, you must specify either a task-level memory value or a container-level memory value. If you specify both a container-level ``memory`` and ``memoryReservation`` value, ``memory`` must be greater than ``memoryReservation``. If you specify ``memoryReservation``, then that value is subtracted from the available memory resources for the container instance where the container is placed. Otherwise, the value of ``memory`` is used.
         *  The Docker 20.10.0 or later daemon reserves a minimum of 6 MiB of memory for a container, so you should not specify fewer than 6 MiB of memory for your containers.
         *  The Docker 19.03.13-ce or earlier daemon reserves a minimum of 4 MiB of memory for a container, so you should not specify fewer than 4 MiB of memory for your containers.
         */
        memory?: pulumi.Input<number>;
        /**
         * The soft limit (in MiB) of memory to reserve for the container. When system memory is under heavy contention, Docker attempts to keep the container memory to this soft limit. However, your container can consume more memory when it needs to, up to either the hard limit specified with the ``memory`` parameter (if applicable), or all of the available memory on the container instance, whichever comes first. This parameter maps to ``MemoryReservation`` in the docker container create command and the ``--memory-reservation`` option to docker run.
         *  If a task-level memory value is not specified, you must specify a non-zero integer for one or both of ``memory`` or ``memoryReservation`` in a container definition. If you specify both, ``memory`` must be greater than ``memoryReservation``. If you specify ``memoryReservation``, then that value is subtracted from the available memory resources for the container instance where the container is placed. Otherwise, the value of ``memory`` is used.
         *  For example, if your container normally uses 128 MiB of memory, but occasionally bursts to 256 MiB of memory for short periods of time, you can set a ``memoryReservation`` of 128 MiB, and a ``memory`` hard limit of 300 MiB. This configuration would allow the container to only reserve 128 MiB of memory from the remaining resources on the container instance, but also allow the container to consume more memory resources when needed.
         *  The Docker 20.10.0 or later daemon reserves a minimum of 6 MiB of memory for a container. So, don't specify less than 6 MiB of memory for your containers.
         *  The Docker 19.03.13-ce or earlier daemon reserves a minimum of 4 MiB of memory for a container. So, don't specify less than 4 MiB of memory for your containers.
         */
        memoryReservation?: pulumi.Input<number>;
        /**
         * The mount points for data volumes in your container.
         *  This parameter maps to ``Volumes`` in the docker container create command and the ``--volume`` option to docker run.
         *  Windows containers can mount whole directories on the same drive as ``$env:ProgramData``. Windows containers can't mount directories on a different drive, and mount point can't be across drives.
         */
        mountPoints?: pulumi.Input<pulumi.Input<inputs.ecs.TaskDefinitionMountPointArgs>[]>;
        /**
         * The name of a container. If you're linking multiple containers together in a task definition, the ``name`` of one container can be entered in the ``links`` of another container to connect the containers. Up to 255 letters (uppercase and lowercase), numbers, underscores, and hyphens are allowed. This parameter maps to ``name`` in the docker container create command and the ``--name`` option to docker run.
         */
        name: pulumi.Input<string>;
        /**
         * The list of port mappings for the container. Port mappings allow containers to access ports on the host container instance to send or receive traffic.
         *  For task definitions that use the ``awsvpc`` network mode, you should only specify the ``containerPort``. The ``hostPort`` can be left blank or it must be the same value as the ``containerPort``.
         *  Port mappings on Windows use the ``NetNAT`` gateway address rather than ``localhost``. There is no loopback for port mappings on Windows, so you cannot access a container's mapped port from the host itself.
         *  This parameter maps to ``PortBindings`` in the [Create a container](https://docs.aws.amazon.com/https://docs.docker.com/engine/api/v1.35/#operation/ContainerCreate) section of the [Docker Remote API](https://docs.aws.amazon.com/https://docs.docker.com/engine/api/v1.35/) and the ``--publish`` option to [docker run](https://docs.aws.amazon.com/https://docs.docker.com/engine/reference/run/). If the network mode of a task definition is set to ``none``, then you can't specify port mappings. If the network mode of a task definition is set to ``host``, then host ports must either be undefined or they must match the container port in the port mapping.
         *   After a task reaches the ``RUNNING`` status, manual and automatic host and container port assignments are visible in the *Network Bindings* section of a container description for a selected task in the Amazon ECS console. The assignments are also visible in the ``networkBindings`` section [DescribeTasks](https://docs.aws.amazon.com/AmazonECS/latest/APIReference/API_DescribeTasks.html) responses.
         */
        portMappings?: pulumi.Input<pulumi.Input<inputs.ecs.TaskDefinitionPortMappingArgs>[]>;
        /**
         * When this parameter is true, the container is given elevated privileges on the host container instance (similar to the ``root`` user). This parameter maps to ``Privileged`` in the docker container create command and the ``--privileged`` option to docker run
         *   This parameter is not supported for Windows containers or tasks run on FARGATElong.
         */
        privileged?: pulumi.Input<boolean>;
        /**
         * When this parameter is ``true``, a TTY is allocated. This parameter maps to ``Tty`` in the docker container create command and the ``--tty`` option to docker run.
         */
        pseudoTerminal?: pulumi.Input<boolean>;
        /**
         * When this parameter is true, the container is given read-only access to its root file system. This parameter maps to ``ReadonlyRootfs`` in the docker container create command and the ``--read-only`` option to docker run.
         *   This parameter is not supported for Windows containers.
         */
        readonlyRootFilesystem?: pulumi.Input<boolean>;
        /**
         * The private repository authentication credentials to use.
         */
        repositoryCredentials?: pulumi.Input<inputs.ecs.TaskDefinitionRepositoryCredentialsArgs>;
        /**
         * The type and amount of a resource to assign to a container. The only supported resource is a GPU.
         */
        resourceRequirements?: pulumi.Input<pulumi.Input<inputs.ecs.TaskDefinitionResourceRequirementArgs>[]>;
        /**
         * The restart policy for a container. When you set up a restart policy, Amazon ECS can restart the container without needing to replace the task. For more information, see [Restart individual containers in Amazon ECS tasks with container restart policies](https://docs.aws.amazon.com/AmazonECS/latest/developerguide/container-restart-policy.html) in the *Amazon Elastic Container Service Developer Guide*.
         */
        restartPolicy?: pulumi.Input<inputs.ecs.TaskDefinitionRestartPolicyArgs>;
        /**
         * The secrets to pass to the container. For more information, see [Specifying Sensitive Data](https://docs.aws.amazon.com/AmazonECS/latest/developerguide/specifying-sensitive-data.html) in the *Amazon Elastic Container Service Developer Guide*.
         */
        secrets?: pulumi.Input<pulumi.Input<inputs.ecs.TaskDefinitionSecretArgs>[]>;
        /**
         * Time duration (in seconds) to wait before giving up on resolving dependencies for a container. For example, you specify two containers in a task definition with containerA having a dependency on containerB reaching a ``COMPLETE``, ``SUCCESS``, or ``HEALTHY`` status. If a ``startTimeout`` value is specified for containerB and it doesn't reach the desired status within that time then containerA gives up and not start. This results in the task transitioning to a ``STOPPED`` state.
         *   When the ``ECS_CONTAINER_START_TIMEOUT`` container agent configuration variable is used, it's enforced independently from this start timeout value.
         *   For tasks using the Fargate launch type, the task or service requires the following platforms:
         *   +  Linux platform version ``1.3.0`` or later.
         *   +  Windows platform version ``1.0.0`` or later.
         *
         *  For tasks using the EC2 launch type, your container instances require at least version ``1.26.0`` of the container agent to use a container start timeout value. However, we recommend using the latest container agent version. For information about checking your agent version and updating to the latest version, see [Updating the Amazon ECS Container Agent](https://docs.aws.amazon.com/AmazonECS/latest/developerguide/ecs-agent-update.html) in the *Amazon Elastic Container Service Developer Guide*. If you're using an Amazon ECS-optimized Linux AMI, your instance needs at least version ``1.26.0-1`` of the ``ecs-init`` package. If your container instances are launched from version ``20190301`` or later, then they contain the required versions of the container agent and ``ecs-init``. For more information, see [Amazon ECS-optimized Linux AMI](https://docs.aws.amazon.com/AmazonECS/latest/developerguide/ecs-optimized_AMI.html) in the *Amazon Elastic Container Service Developer Guide*.
         *  The valid values for Fargate are 2-120 seconds.
         */
        startTimeout?: pulumi.Input<number>;
        /**
         * Time duration (in seconds) to wait before the container is forcefully killed if it doesn't exit normally on its own.
         *  For tasks using the Fargate launch type, the task or service requires the following platforms:
         *   +  Linux platform version ``1.3.0`` or later.
         *   +  Windows platform version ``1.0.0`` or later.
         *
         *  For tasks that use the Fargate launch type, the max stop timeout value is 120 seconds and if the parameter is not specified, the default value of 30 seconds is used.
         *  For tasks that use the EC2 launch type, if the ``stopTimeout`` parameter isn't specified, the value set for the Amazon ECS container agent configuration variable ``ECS_CONTAINER_STOP_TIMEOUT`` is used. If neither the ``stopTimeout`` parameter or the ``ECS_CONTAINER_STOP_TIMEOUT`` agent configuration variable are set, then the default values of 30 seconds for Linux containers and 30 seconds on Windows containers are used. Your container instances require at least version 1.26.0 of the container agent to use a container stop timeout value. However, we recommend using the latest container agent version. For information about checking your agent version and updating to the latest version, see [Updating the Amazon ECS Container Agent](https://docs.aws.amazon.com/AmazonECS/latest/developerguide/ecs-agent-update.html) in the *Amazon Elastic Container Service Developer Guide*. If you're using an Amazon ECS-optimized Linux AMI, your instance needs at least version 1.26.0-1 of the ``ecs-init`` package. If your container instances are launched from version ``20190301`` or later, then they contain the required versions of the container agent and ``ecs-init``. For more information, see [Amazon ECS-optimized Linux AMI](https://docs.aws.amazon.com/AmazonECS/latest/developerguide/ecs-optimized_AMI.html) in the *Amazon Elastic Container Service Developer Guide*.
         *  The valid values for Fargate are 2-120 seconds.
         */
        stopTimeout?: pulumi.Input<number>;
        /**
         * A list of namespaced kernel parameters to set in the container. This parameter maps to ``Sysctls`` in the docker container create command and the ``--sysctl`` option to docker run. For example, you can configure ``net.ipv4.tcp_keepalive_time`` setting to maintain longer lived connections.
         */
        systemControls?: pulumi.Input<pulumi.Input<inputs.ecs.TaskDefinitionSystemControlArgs>[]>;
        /**
         * A list of ``ulimits`` to set in the container. This parameter maps to ``Ulimits`` in the [Create a container](https://docs.aws.amazon.com/https://docs.docker.com/engine/api/v1.35/#operation/ContainerCreate) section of the [Docker Remote API](https://docs.aws.amazon.com/https://docs.docker.com/engine/api/v1.35/) and the ``--ulimit`` option to [docker run](https://docs.aws.amazon.com/https://docs.docker.com/engine/reference/run/). Valid naming values are displayed in the [Ulimit](https://docs.aws.amazon.com/AmazonECS/latest/APIReference/API_Ulimit.html) data type. This parameter requires version 1.18 of the Docker Remote API or greater on your container instance. To check the Docker Remote API version on your container instance, log in to your container instance and run the following command: ``sudo docker version --format '{{.Server.APIVersion}}'``
         *   This parameter is not supported for Windows containers.
         */
        ulimits?: pulumi.Input<pulumi.Input<inputs.ecs.TaskDefinitionUlimitArgs>[]>;
        /**
         * The user to use inside the container. This parameter maps to ``User`` in the docker container create command and the ``--user`` option to docker run.
         *   When running tasks using the ``host`` network mode, don't run containers using the root user (UID 0). We recommend using a non-root user for better security.
         *   You can specify the ``user`` using the following formats. If specifying a UID or GID, you must specify it as a positive integer.
         *   +   ``user``
         *   +   ``user:group``
         *   +   ``uid``
         *   +   ``uid:gid``
         *   +   ``user:gid``
         *   +   ``uid:group``
         *
         *   This parameter is not supported for Windows containers.
         */
        user?: pulumi.Input<string>;
        /**
         * Specifies whether Amazon ECS will resolve the container image tag provided in the container definition to an image digest. By default, the value is ``enabled``. If you set the value for a container as ``disabled``, Amazon ECS will not resolve the provided container image tag to a digest and will use the original image URI specified in the container definition for deployment. For more information about container image resolution, see [Container image resolution](https://docs.aws.amazon.com/AmazonECS/latest/developerguide/deployment-type-ecs.html#deployment-container-image-stability) in the *Amazon ECS Developer Guide*.
         */
        versionConsistency?: pulumi.Input<enums.ecs.TaskDefinitionContainerDefinitionVersionConsistency>;
        /**
         * Data volumes to mount from another container. This parameter maps to ``VolumesFrom`` in the docker container create command and the ``--volumes-from`` option to docker run.
         */
        volumesFrom?: pulumi.Input<pulumi.Input<inputs.ecs.TaskDefinitionVolumeFromArgs>[]>;
        /**
         * The working directory to run commands inside the container in. This parameter maps to ``WorkingDir`` in the docker container create command and the ``--workdir`` option to docker run.
         */
        workingDirectory?: pulumi.Input<string>;
    }
    /**
     * The ``ContainerDependency`` property specifies the dependencies defined for container startup and shutdown. A container can contain multiple dependencies. When a dependency is defined for container startup, for container shutdown it is reversed.
     *  Your Amazon ECS container instances require at least version 1.26.0 of the container agent to enable container dependencies. However, we recommend using the latest container agent version. For information about checking your agent version and updating to the latest version, see [Updating the Amazon ECS Container Agent](https://docs.aws.amazon.com/AmazonECS/latest/developerguide/ecs-agent-update.html) in the *Amazon Elastic Container Service Developer Guide*. If you are using an Amazon ECS-optimized Linux AMI, your instance needs at least version 1.26.0-1 of the ``ecs-init`` package. If your container instances are launched from version ``20190301`` or later, then they contain the required versions of the container agent and ``ecs-init``. For more information, see [Amazon ECS-optimized Linux AMI](https://docs.aws.amazon.com/AmazonECS/latest/developerguide/ecs-optimized_AMI.html) in the *Amazon Elastic Container Service Developer Guide*.
     *   For tasks using the Fargate launch type, this parameter requires that the task or service uses platform version 1.3.0 or later.
     */
    interface TaskDefinitionContainerDependencyArgs {
        /**
         * The dependency condition of the container. The following are the available conditions and their behavior:
         *   +   ``START`` - This condition emulates the behavior of links and volumes today. It validates that a dependent container is started before permitting other containers to start.
         *   +   ``COMPLETE`` - This condition validates that a dependent container runs to completion (exits) before permitting other containers to start. This can be useful for nonessential containers that run a script and then exit. This condition can't be set on an essential container.
         *   +   ``SUCCESS`` - This condition is the same as ``COMPLETE``, but it also requires that the container exits with a ``zero`` status. This condition can't be set on an essential container.
         *   +   ``HEALTHY`` - This condition validates that the dependent container passes its Docker health check before permitting other containers to start. This requires that the dependent container has health checks configured. This condition is confirmed only at task startup.
         */
        condition?: pulumi.Input<string>;
        /**
         * The name of a container.
         */
        containerName?: pulumi.Input<string>;
    }
    /**
     * The ``Device`` property specifies an object representing a container instance host device.
     */
    interface TaskDefinitionDeviceArgs {
        /**
         * The path inside the container at which to expose the host device.
         */
        containerPath?: pulumi.Input<string>;
        /**
         * The path for the device on the host container instance.
         */
        hostPath?: pulumi.Input<string>;
        /**
         * The explicit permissions to provide to the container for the device. By default, the container has permissions for ``read``, ``write``, and ``mknod`` for the device.
         */
        permissions?: pulumi.Input<pulumi.Input<string>[]>;
    }
    /**
     * The ``DockerVolumeConfiguration`` property specifies a Docker volume configuration and is used when you use Docker volumes. Docker volumes are only supported when you are using the EC2 launch type. Windows containers only support the use of the ``local`` driver. To use bind mounts, specify a ``host`` instead.
     */
    interface TaskDefinitionDockerVolumeConfigurationArgs {
        /**
         * If this value is ``true``, the Docker volume is created if it doesn't already exist.
         *   This field is only used if the ``scope`` is ``shared``.
         */
        autoprovision?: pulumi.Input<boolean>;
        /**
         * The Docker volume driver to use. The driver value must match the driver name provided by Docker because it is used for task placement. If the driver was installed using the Docker plugin CLI, use ``docker plugin ls`` to retrieve the driver name from your container instance. If the driver was installed using another method, use Docker plugin discovery to retrieve the driver name. This parameter maps to ``Driver`` in the docker container create command and the ``xxdriver`` option to docker volume create.
         */
        driver?: pulumi.Input<string>;
        /**
         * A map of Docker driver-specific options passed through. This parameter maps to ``DriverOpts`` in the docker create-volume command and the ``xxopt`` option to docker volume create.
         */
        driverOpts?: pulumi.Input<{
            [key: string]: pulumi.Input<string>;
        }>;
        /**
         * Custom metadata to add to your Docker volume. This parameter maps to ``Labels`` in the docker container create command and the ``xxlabel`` option to docker volume create.
         */
        labels?: pulumi.Input<{
            [key: string]: pulumi.Input<string>;
        }>;
        /**
         * The scope for the Docker volume that determines its lifecycle. Docker volumes that are scoped to a ``task`` are automatically provisioned when the task starts and destroyed when the task stops. Docker volumes that are scoped as ``shared`` persist after the task stops.
         */
        scope?: pulumi.Input<string>;
    }
    /**
     * This parameter is specified when you're using an Amazon Elastic File System file system for task storage. For more information, see [Amazon EFS volumes](https://docs.aws.amazon.com/AmazonECS/latest/developerguide/efs-volumes.html) in the *Amazon Elastic Container Service Developer Guide*.
     */
    interface TaskDefinitionEfsVolumeConfigurationArgs {
        /**
         * The authorization configuration details for the Amazon EFS file system.
         */
        authorizationConfig?: pulumi.Input<inputs.ecs.TaskDefinitionAuthorizationConfigArgs>;
        /**
         * The Amazon EFS file system ID to use.
         */
        filesystemId: pulumi.Input<string>;
        /**
         * The directory within the Amazon EFS file system to mount as the root directory inside the host. If this parameter is omitted, the root of the Amazon EFS volume will be used. Specifying ``/`` will have the same effect as omitting this parameter.
         *   If an EFS access point is specified in the ``authorizationConfig``, the root directory parameter must either be omitted or set to ``/`` which will enforce the path set on the EFS access point.
         */
        rootDirectory?: pulumi.Input<string>;
        /**
         * Determines whether to use encryption for Amazon EFS data in transit between the Amazon ECS host and the Amazon EFS server. Transit encryption must be turned on if Amazon EFS IAM authorization is used. If this parameter is omitted, the default value of ``DISABLED`` is used. For more information, see [Encrypting data in transit](https://docs.aws.amazon.com/efs/latest/ug/encryption-in-transit.html) in the *Amazon Elastic File System User Guide*.
         */
        transitEncryption?: pulumi.Input<enums.ecs.TaskDefinitionEfsVolumeConfigurationTransitEncryption>;
        /**
         * The port to use when sending encrypted data between the Amazon ECS host and the Amazon EFS server. If you do not specify a transit encryption port, it will use the port selection strategy that the Amazon EFS mount helper uses. For more information, see [EFS mount helper](https://docs.aws.amazon.com/efs/latest/ug/efs-mount-helper.html) in the *Amazon Elastic File System User Guide*.
         */
        transitEncryptionPort?: pulumi.Input<number>;
    }
    /**
     * A list of files containing the environment variables to pass to a container. You can specify up to ten environment files. The file must have a ``.env`` file extension. Each line in an environment file should contain an environment variable in ``VARIABLE=VALUE`` format. Lines beginning with ``#`` are treated as comments and are ignored.
     *  If there are environment variables specified using the ``environment`` parameter in a container definition, they take precedence over the variables contained within an environment file. If multiple environment files are specified that contain the same variable, they're processed from the top down. We recommend that you use unique variable names. For more information, see [Use a file to pass environment variables to a container](https://docs.aws.amazon.com/AmazonECS/latest/developerguide/use-environment-file.html) in the *Amazon Elastic Container Service Developer Guide*.
     *  Environment variable files are objects in Amazon S3 and all Amazon S3 security considerations apply.
     *  You must use the following platforms for the Fargate launch type:
     *   +  Linux platform version ``1.4.0`` or later.
     *   +  Windows platform version ``1.0.0`` or later.
     *
     *  Consider the following when using the Fargate launch type:
     *   +  The file is handled like a native Docker env-file.
     *   +  There is no support for shell escape handling.
     *   +  The container entry point interperts the ``VARIABLE`` values.
     */
    interface TaskDefinitionEnvironmentFileArgs {
        /**
         * The file type to use. Environment files are objects in Amazon S3. The only supported value is ``s3``.
         */
        type?: pulumi.Input<string>;
        /**
         * The Amazon Resource Name (ARN) of the Amazon S3 object containing the environment variable file.
         */
        value?: pulumi.Input<string>;
    }
    /**
     * The amount of ephemeral storage to allocate for the task. This parameter is used to expand the total amount of ephemeral storage available, beyond the default amount, for tasks hosted on FARGATElong. For more information, see [Using data volumes in tasks](https://docs.aws.amazon.com/AmazonECS/latest/developerguide/using_data_volumes.html) in the *Amazon ECS Developer Guide;*.
     *   For tasks using the Fargate launch type, the task requires the following platforms:
     *   +  Linux platform version ``1.4.0`` or later.
     *   +  Windows platform version ``1.0.0`` or later.
     */
    interface TaskDefinitionEphemeralStorageArgs {
        /**
         * The total amount, in GiB, of ephemeral storage to set for the task. The minimum supported value is ``21`` GiB and the maximum supported value is ``200`` GiB.
         */
        sizeInGiB?: pulumi.Input<number>;
    }
    /**
     * The authorization configuration details for Amazon FSx for Windows File Server file system. See [FSxWindowsFileServerVolumeConfiguration](https://docs.aws.amazon.com/AmazonECS/latest/APIReference/API_FSxWindowsFileServerVolumeConfiguration.html) in the *Amazon ECS API Reference*.
     *  For more information and the input format, see [Amazon FSx for Windows File Server Volumes](https://docs.aws.amazon.com/AmazonECS/latest/developerguide/wfsx-volumes.html) in the *Amazon Elastic Container Service Developer Guide*.
     */
    interface TaskDefinitionFSxAuthorizationConfigArgs {
        /**
         * The authorization credential option to use. The authorization credential options can be provided using either the Amazon Resource Name (ARN) of an ASMlong secret or SSM Parameter Store parameter. The ARN refers to the stored credentials.
         */
        credentialsParameter: pulumi.Input<string>;
        /**
         * A fully qualified domain name hosted by an [](https://docs.aws.amazon.com/directoryservice/latest/admin-guide/directory_microsoft_ad.html) Managed Microsoft AD (Active Directory) or self-hosted AD on Amazon EC2.
         */
        domain: pulumi.Input<string>;
    }
    /**
     * This parameter is specified when you're using [Amazon FSx for Windows File Server](https://docs.aws.amazon.com/fsx/latest/WindowsGuide/what-is.html) file system for task storage.
     *  For more information and the input format, see [Amazon FSx for Windows File Server volumes](https://docs.aws.amazon.com/AmazonECS/latest/developerguide/wfsx-volumes.html) in the *Amazon Elastic Container Service Developer Guide*.
     */
    interface TaskDefinitionFSxWindowsFileServerVolumeConfigurationArgs {
        /**
         * The authorization configuration details for the Amazon FSx for Windows File Server file system.
         */
        authorizationConfig?: pulumi.Input<inputs.ecs.TaskDefinitionFSxAuthorizationConfigArgs>;
        /**
         * The Amazon FSx for Windows File Server file system ID to use.
         */
        fileSystemId: pulumi.Input<string>;
        /**
         * The directory within the Amazon FSx for Windows File Server file system to mount as the root directory inside the host.
         */
        rootDirectory: pulumi.Input<string>;
    }
    /**
     * The FireLens configuration for the container. This is used to specify and configure a log router for container logs. For more information, see [Custom log routing](https://docs.aws.amazon.com/AmazonECS/latest/developerguide/using_firelens.html) in the *Amazon Elastic Container Service Developer Guide*.
     */
    interface TaskDefinitionFirelensConfigurationArgs {
        /**
         * The options to use when configuring the log router. This field is optional and can be used to add additional metadata, such as the task, task definition, cluster, and container instance details to the log event.
         *   If specified, valid option keys are:
         *   +   ``enable-ecs-log-metadata``, which can be ``true`` or ``false``
         *   +   ``config-file-type``, which can be ``s3`` or ``file``
         *   +   ``config-file-value``, which is either an S3 ARN or a file path
         */
        options?: pulumi.Input<{
            [key: string]: pulumi.Input<string>;
        }>;
        /**
         * The log router to use. The valid values are ``fluentd`` or ``fluentbit``.
         */
        type?: pulumi.Input<string>;
    }
    /**
     * The ``HealthCheck`` property specifies an object representing a container health check. Health check parameters that are specified in a container definition override any Docker health checks that exist in the container image (such as those specified in a parent image or from the image's Dockerfile). This configuration maps to the ``HEALTHCHECK`` parameter of docker run.
     *   The Amazon ECS container agent only monitors and reports on the health checks specified in the task definition. Amazon ECS does not monitor Docker health checks that are embedded in a container image and not specified in the container definition. Health check parameters that are specified in a container definition override any Docker health checks that exist in the container image.
     *   If a task is run manually, and not as part of a service, the task will continue its lifecycle regardless of its health status. For tasks that are part of a service, if the task reports as unhealthy then the task will be stopped and the service scheduler will replace it.
     *  The following are notes about container health check support:
     *   +  Container health checks require version 1.17.0 or greater of the Amazon ECS container agent. For more information, see [Updating the Amazon ECS Container Agent](https://docs.aws.amazon.com/AmazonECS/latest/developerguide/ecs-agent-update.html).
     *   +  Container health checks are supported for Fargate tasks if you are using platform version 1.1.0 or greater. For more information, see [Platform Versions](https://docs.aws.amazon.com/AmazonECS/latest/developerguide/platform_versions.html).
     *   +  Container health checks are not supported for tasks that are part of a service that is configured to use a Classic Load Balancer.
     */
    interface TaskDefinitionHealthCheckArgs {
        /**
         * A string array representing the command that the container runs to determine if it is healthy. The string array must start with ``CMD`` to run the command arguments directly, or ``CMD-SHELL`` to run the command with the container's default shell.
         *   When you use the AWS Management Console JSON panel, the CLIlong, or the APIs, enclose the list of commands in double quotes and brackets.
         *   ``[ "CMD-SHELL", "curl -f http://localhost/ || exit 1" ]``
         *  You don't include the double quotes and brackets when you use the AWS Management Console.
         *   ``CMD-SHELL, curl -f http://localhost/ || exit 1``
         *  An exit code of 0 indicates success, and non-zero exit code indicates failure. For more information, see ``HealthCheck`` in the docker container create command.
         */
        command?: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * The time period in seconds between each health check execution. You may specify between 5 and 300 seconds. The default value is 30 seconds. This value applies only when you specify a ``command``.
         */
        interval?: pulumi.Input<number>;
        /**
         * The number of times to retry a failed health check before the container is considered unhealthy. You may specify between 1 and 10 retries. The default value is 3. This value applies only when you specify a ``command``.
         */
        retries?: pulumi.Input<number>;
        /**
         * The optional grace period to provide containers time to bootstrap before failed health checks count towards the maximum number of retries. You can specify between 0 and 300 seconds. By default, the ``startPeriod`` is off. This value applies only when you specify a ``command``.
         *   If a health check succeeds within the ``startPeriod``, then the container is considered healthy and any subsequent failures count toward the maximum number of retries.
         */
        startPeriod?: pulumi.Input<number>;
        /**
         * The time period in seconds to wait for a health check to succeed before it is considered a failure. You may specify between 2 and 60 seconds. The default value is 5. This value applies only when you specify a ``command``.
         */
        timeout?: pulumi.Input<number>;
    }
    /**
     * The ``HostEntry`` property specifies a hostname and an IP address that are added to the ``/etc/hosts`` file of a container through the ``extraHosts`` parameter of its ``ContainerDefinition`` resource.
     */
    interface TaskDefinitionHostEntryArgs {
        /**
         * The hostname to use in the ``/etc/hosts`` entry.
         */
        hostname?: pulumi.Input<string>;
        /**
         * The IP address to use in the ``/etc/hosts`` entry.
         */
        ipAddress?: pulumi.Input<string>;
    }
    /**
     * The ``HostVolumeProperties`` property specifies details on a container instance bind mount host volume.
     */
    interface TaskDefinitionHostVolumePropertiesArgs {
        /**
         * When the ``host`` parameter is used, specify a ``sourcePath`` to declare the path on the host container instance that's presented to the container. If this parameter is empty, then the Docker daemon has assigned a host path for you. If the ``host`` parameter contains a ``sourcePath`` file location, then the data volume persists at the specified location on the host container instance until you delete it manually. If the ``sourcePath`` value doesn't exist on the host container instance, the Docker daemon creates it. If the location does exist, the contents of the source path folder are exported.
         *  If you're using the Fargate launch type, the ``sourcePath`` parameter is not supported.
         */
        sourcePath?: pulumi.Input<string>;
    }
    /**
     * Details on an Elastic Inference accelerator. For more information, see [Working with Amazon Elastic Inference on Amazon ECS](https://docs.aws.amazon.com/AmazonECS/latest/developerguide/ecs-inference.html) in the *Amazon Elastic Container Service Developer Guide*.
     */
    interface TaskDefinitionInferenceAcceleratorArgs {
        /**
         * The Elastic Inference accelerator device name. The ``deviceName`` must also be referenced in a container definition as a [ResourceRequirement](https://docs.aws.amazon.com/AmazonECS/latest/APIReference/API_ResourceRequirement.html).
         */
        deviceName?: pulumi.Input<string>;
        /**
         * The Elastic Inference accelerator type to use.
         */
        deviceType?: pulumi.Input<string>;
    }
    /**
     * The Linux capabilities to add or remove from the default Docker configuration for a container defined in the task definition. For more detailed information about these Linux capabilities, see the [capabilities(7)](https://docs.aws.amazon.com/http://man7.org/linux/man-pages/man7/capabilities.7.html) Linux manual page.
     *  The following describes how Docker processes the Linux capabilities specified in the ``add`` and ``drop`` request parameters. For information about the latest behavior, see [Docker Compose: order of cap_drop and cap_add](https://docs.aws.amazon.com/https://forums.docker.com/t/docker-compose-order-of-cap-drop-and-cap-add/97136/1) in the Docker Community Forum.
     *   +  When the container is a privleged container, the container capabilities are all of the default Docker capabilities. The capabilities specified in the ``add`` request parameter, and the ``drop`` request parameter are ignored.
     *   +  When the ``add`` request parameter is set to ALL, the container capabilities are all of the default Docker capabilities, excluding those specified in the ``drop`` request parameter.
     *   +  When the ``drop`` request parameter is set to ALL, the container capabilities are the capabilities specified in the ``add`` request parameter.
     *   +  When the ``add`` request parameter and the ``drop`` request parameter are both empty, the capabilities the container capabilities are all of the default Docker capabilities.
     *   +  The default is to first drop the capabilities specified in the ``drop`` request parameter, and then add the capabilities specified in the ``add`` request parameter.
     */
    interface TaskDefinitionKernelCapabilitiesArgs {
        /**
         * The Linux capabilities for the container that have been added to the default configuration provided by Docker. This parameter maps to ``CapAdd`` in the docker container create command and the ``--cap-add`` option to docker run.
         *   Tasks launched on FARGATElong only support adding the ``SYS_PTRACE`` kernel capability.
         *   Valid values: ``"ALL" | "AUDIT_CONTROL" | "AUDIT_WRITE" | "BLOCK_SUSPEND" | "CHOWN" | "DAC_OVERRIDE" | "DAC_READ_SEARCH" | "FOWNER" | "FSETID" | "IPC_LOCK" | "IPC_OWNER" | "KILL" | "LEASE" | "LINUX_IMMUTABLE" | "MAC_ADMIN" | "MAC_OVERRIDE" | "MKNOD" | "NET_ADMIN" | "NET_BIND_SERVICE" | "NET_BROADCAST" | "NET_RAW" | "SETFCAP" | "SETGID" | "SETPCAP" | "SETUID" | "SYS_ADMIN" | "SYS_BOOT" | "SYS_CHROOT" | "SYS_MODULE" | "SYS_NICE" | "SYS_PACCT" | "SYS_PTRACE" | "SYS_RAWIO" | "SYS_RESOURCE" | "SYS_TIME" | "SYS_TTY_CONFIG" | "SYSLOG" | "WAKE_ALARM"``
         */
        add?: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * The Linux capabilities for the container that have been removed from the default configuration provided by Docker. This parameter maps to ``CapDrop`` in the docker container create command and the ``--cap-drop`` option to docker run.
         *  Valid values: ``"ALL" | "AUDIT_CONTROL" | "AUDIT_WRITE" | "BLOCK_SUSPEND" | "CHOWN" | "DAC_OVERRIDE" | "DAC_READ_SEARCH" | "FOWNER" | "FSETID" | "IPC_LOCK" | "IPC_OWNER" | "KILL" | "LEASE" | "LINUX_IMMUTABLE" | "MAC_ADMIN" | "MAC_OVERRIDE" | "MKNOD" | "NET_ADMIN" | "NET_BIND_SERVICE" | "NET_BROADCAST" | "NET_RAW" | "SETFCAP" | "SETGID" | "SETPCAP" | "SETUID" | "SYS_ADMIN" | "SYS_BOOT" | "SYS_CHROOT" | "SYS_MODULE" | "SYS_NICE" | "SYS_PACCT" | "SYS_PTRACE" | "SYS_RAWIO" | "SYS_RESOURCE" | "SYS_TIME" | "SYS_TTY_CONFIG" | "SYSLOG" | "WAKE_ALARM"``
         */
        drop?: pulumi.Input<pulumi.Input<string>[]>;
    }
    /**
     * A key-value pair object.
     */
    interface TaskDefinitionKeyValuePairArgs {
        /**
         * The name of the key-value pair. For environment variables, this is the name of the environment variable.
         */
        name?: pulumi.Input<string>;
        /**
         * The value of the key-value pair. For environment variables, this is the value of the environment variable.
         */
        value?: pulumi.Input<string>;
    }
    /**
     * The Linux-specific options that are applied to the container, such as Linux [KernelCapabilities](https://docs.aws.amazon.com/AmazonECS/latest/APIReference/API_KernelCapabilities.html).
     */
    interface TaskDefinitionLinuxParametersArgs {
        /**
         * The Linux capabilities for the container that are added to or dropped from the default configuration provided by Docker.
         *   For tasks that use the Fargate launch type, ``capabilities`` is supported for all platform versions but the ``add`` parameter is only supported if using platform version 1.4.0 or later.
         */
        capabilities?: pulumi.Input<inputs.ecs.TaskDefinitionKernelCapabilitiesArgs>;
        /**
         * Any host devices to expose to the container. This parameter maps to ``Devices`` in the docker container create command and the ``--device`` option to docker run.
         *   If you're using tasks that use the Fargate launch type, the ``devices`` parameter isn't supported.
         */
        devices?: pulumi.Input<pulumi.Input<inputs.ecs.TaskDefinitionDeviceArgs>[]>;
        /**
         * Run an ``init`` process inside the container that forwards signals and reaps processes. This parameter maps to the ``--init`` option to docker run. This parameter requires version 1.25 of the Docker Remote API or greater on your container instance. To check the Docker Remote API version on your container instance, log in to your container instance and run the following command: ``sudo docker version --format '{{.Server.APIVersion}}'``
         */
        initProcessEnabled?: pulumi.Input<boolean>;
        /**
         * The total amount of swap memory (in MiB) a container can use. This parameter will be translated to the ``--memory-swap`` option to docker run where the value would be the sum of the container memory plus the ``maxSwap`` value.
         *  If a ``maxSwap`` value of ``0`` is specified, the container will not use swap. Accepted values are ``0`` or any positive integer. If the ``maxSwap`` parameter is omitted, the container will use the swap configuration for the container instance it is running on. A ``maxSwap`` value must be set for the ``swappiness`` parameter to be used.
         *   If you're using tasks that use the Fargate launch type, the ``maxSwap`` parameter isn't supported.
         *  If you're using tasks on Amazon Linux 2023 the ``swappiness`` parameter isn't supported.
         */
        maxSwap?: pulumi.Input<number>;
        /**
         * The value for the size (in MiB) of the ``/dev/shm`` volume. This parameter maps to the ``--shm-size`` option to docker run.
         *   If you are using tasks that use the Fargate launch type, the ``sharedMemorySize`` parameter is not supported.
         */
        sharedMemorySize?: pulumi.Input<number>;
        /**
         * This allows you to tune a container's memory swappiness behavior. A ``swappiness`` value of ``0`` will cause swapping to not happen unless absolutely necessary. A ``swappiness`` value of ``100`` will cause pages to be swapped very aggressively. Accepted values are whole numbers between ``0`` and ``100``. If the ``swappiness`` parameter is not specified, a default value of ``60`` is used. If a value is not specified for ``maxSwap`` then this parameter is ignored. This parameter maps to the ``--memory-swappiness`` option to docker run.
         *   If you're using tasks that use the Fargate launch type, the ``swappiness`` parameter isn't supported.
         *  If you're using tasks on Amazon Linux 2023 the ``swappiness`` parameter isn't supported.
         */
        swappiness?: pulumi.Input<number>;
        /**
         * The container path, mount options, and size (in MiB) of the tmpfs mount. This parameter maps to the ``--tmpfs`` option to docker run.
         *   If you're using tasks that use the Fargate launch type, the ``tmpfs`` parameter isn't supported.
         */
        tmpfs?: pulumi.Input<pulumi.Input<inputs.ecs.TaskDefinitionTmpfsArgs>[]>;
    }
    /**
     * The ``LogConfiguration`` property specifies log configuration options to send to a custom log driver for the container.
     */
    interface TaskDefinitionLogConfigurationArgs {
        /**
         * The log driver to use for the container.
         *  For tasks on FARGATElong, the supported log drivers are ``awslogs``, ``splunk``, and ``awsfirelens``.
         *  For tasks hosted on Amazon EC2 instances, the supported log drivers are ``awslogs``, ``fluentd``, ``gelf``, ``json-file``, ``journald``, ``syslog``, ``splunk``, and ``awsfirelens``.
         *  For more information about using the ``awslogs`` log driver, see [Send Amazon ECS logs to CloudWatch](https://docs.aws.amazon.com/AmazonECS/latest/developerguide/using_awslogs.html) in the *Amazon Elastic Container Service Developer Guide*.
         *  For more information about using the ``awsfirelens`` log driver, see [Send Amazon ECS logs to an service or Partner](https://docs.aws.amazon.com/AmazonECS/latest/developerguide/using_firelens.html).
         *   If you have a custom driver that isn't listed, you can fork the Amazon ECS container agent project that's [available on GitHub](https://docs.aws.amazon.com/https://github.com/aws/amazon-ecs-agent) and customize it to work with that driver. We encourage you to submit pull requests for changes that you would like to have included. However, we don't currently provide support for running modified copies of this software.
         */
        logDriver: pulumi.Input<string>;
        /**
         * The configuration options to send to the log driver.
         *  The options you can specify depend on the log driver. Some of the options you can specify when you use the ``awslogs`` log driver to route logs to Amazon CloudWatch include the following:
         *   + awslogs-create-group Required: No Specify whether you want the log group to be created automatically. If this option isn't specified, it defaults to false. Your IAM policy must include the logs:CreateLogGroup permission before you attempt to use awslogs-create-group. + awslogs-region Required: Yes Specify the Region that the awslogs log driver is to send your Docker logs to. You can choose to send all of your logs from clusters in different Regions to a single region in CloudWatch Logs. This is so that they're all visible in one location. Otherwise, you can separate them by Region for more granularity. Make sure that the specified log group exists in the Region that you specify with this option. + awslogs-group Required: Yes Make sure to specify a log group that the awslogs log driver sends its log streams to. + awslogs-stream-prefix Required: Yes, when using the Fargate launch type.Optional for the EC2 launch type, required for the Fargate launch type. Use the awslogs-stream-prefix option to associate a log stream with the specified prefix, the container name, and the ID of the Amazon ECS task that the container belongs to. If you specify a prefix with this option, then the log stream takes the format prefix-name/container-name/ecs-task-id. If you don't specify a prefix with this option, then the log stream is named after the container ID that's assigned by the Docker daemon on the container instance. Because it's difficult to trace logs back to the container that sent them with just the Docker container ID (which is only available on the container instance), we recommend that you specify a prefix with this option. For Amazon ECS services, you can use the service name as the prefix. Doing so, you can trace log streams to the service that the container belongs to, the name of the container that sent them, and the ID of the task that the container belongs to. You must specify a stream-prefix for your logs to have your logs appear in the Log pane when using the Amazon ECS console. + awslogs-datetime-format Required: No This option defines a multiline start pattern in Python strftime format. A log message consists of a line that matches the pattern and any following lines that don’t match the pattern. The matched line is the delimiter between log messages. One example of a use case for using this format is for parsing output such as a stack dump, which might otherwise be logged in multiple entries. The correct pattern allows it to be captured in a single entry. For more information, see awslogs-datetime-format. You cannot configure both the awslogs-datetime-format and awslogs-multiline-pattern options. Multiline logging performs regular expression parsing and matching of all log messages. This might have a negative impact on logging performance. + awslogs-multiline-pattern Required: No This option defines a multiline start pattern that uses a regular expression. A log message consists of a line that matches the pattern and any following lines that don’t match the pattern. The matched line is the delimiter between log messages. For more information, see awslogs-multiline-pattern. This option is ignored if awslogs-datetime-format is also configured. You cannot configure both the awslogs-datetime-format and awslogs-multiline-pattern options. Multiline logging performs regular expression parsing and matching of all log messages. This might have a negative impact on logging performance. + mode Required: No Valid values: non-blocking | blocking This option defines the delivery mode of log messages from the container to CloudWatch Logs. The delivery mode you choose affects application availability when the flow of logs from container to CloudWatch is interrupted. If you use the blocking mode and the flow of logs to CloudWatch is interrupted, calls from container code to write to the stdout and stderr streams will block. The logging thread of the application will block as a result. This may cause the application to become unresponsive and lead to container healthcheck failure. If you use the non-blocking mode, the container's logs are instead stored in an in-memory intermediate buffer configured with the max-buffer-size option. This prevents the application from becoming unresponsive when logs cannot be sent to CloudWatch. We recommend using this mode if you want to ensure service availability and are okay with some log loss. For more information, see Preventing log loss with non-blocking mode in the awslogs container log driver. + max-buffer-size Required: No Default value: 1m When non-blocking mode is used, the max-buffer-size log option controls the size of the buffer that's used for intermediate message storage. Make sure to specify an adequate buffer size based on your application. When the buffer fills up, further logs cannot be stored. Logs that cannot be stored are lost.
         *  To route logs using the ``splunk`` log router, you need to specify a ``splunk-token`` and a ``splunk-url``.
         *  When you use the ``awsfirelens`` log router to route logs to an AWS Service or AWS Partner Network destination for log storage and analytics, you can set the ``log-driver-buffer-limit`` option to limit the number of events that are buffered in memory, before being sent to the log router container. It can help to resolve potential log loss issue because high throughput might result in memory running out for the buffer inside of Docker.
         *  Other options you can specify when using ``awsfirelens`` to route logs depend on the destination. When you export logs to Amazon Data Firehose, you can specify the AWS Region with ``region`` and a name for the log stream with ``delivery_stream``.
         *  When you export logs to Amazon Kinesis Data Streams, you can specify an AWS Region with ``region`` and a data stream name with ``stream``.
         *   When you export logs to Amazon OpenSearch Service, you can specify options like ``Name``, ``Host`` (OpenSearch Service endpoint without protocol), ``Port``, ``Index``, ``Type``, ``Aws_auth``, ``Aws_region``, ``Suppress_Type_Name``, and ``tls``. For more information, see [Under the hood: FireLens for Amazon ECS Tasks](https://docs.aws.amazon.com/containers/under-the-hood-firelens-for-amazon-ecs-tasks/).
         *  When you export logs to Amazon S3, you can specify the bucket using the ``bucket`` option. You can also specify ``region``, ``total_file_size``, ``upload_timeout``, and ``use_put_object`` as options.
         *  This parameter requires version 1.19 of the Docker Remote API or greater on your container instance. To check the Docker Remote API version on your container instance, log in to your container instance and run the following command: ``sudo docker version --format '{{.Server.APIVersion}}'``
         */
        options?: pulumi.Input<{
            [key: string]: pulumi.Input<string>;
        }>;
        /**
         * The secrets to pass to the log configuration. For more information, see [Specifying sensitive data](https://docs.aws.amazon.com/AmazonECS/latest/developerguide/specifying-sensitive-data.html) in the *Amazon Elastic Container Service Developer Guide*.
         */
        secretOptions?: pulumi.Input<pulumi.Input<inputs.ecs.TaskDefinitionSecretArgs>[]>;
    }
    /**
     * The details for a volume mount point that's used in a container definition.
     */
    interface TaskDefinitionMountPointArgs {
        /**
         * The path on the container to mount the host volume at.
         */
        containerPath?: pulumi.Input<string>;
        /**
         * If this value is ``true``, the container has read-only access to the volume. If this value is ``false``, then the container can write to the volume. The default value is ``false``.
         */
        readOnly?: pulumi.Input<boolean>;
        /**
         * The name of the volume to mount. Must be a volume name referenced in the ``name`` parameter of task definition ``volume``.
         */
        sourceVolume?: pulumi.Input<string>;
    }
    /**
     * The constraint on task placement in the task definition. For more information, see [Task placement constraints](https://docs.aws.amazon.com/AmazonECS/latest/developerguide/task-placement-constraints.html) in the *Amazon Elastic Container Service Developer Guide*.
     *   Task placement constraints aren't supported for tasks run on FARGATElong.
     */
    interface TaskDefinitionPlacementConstraintArgs {
        /**
         * A cluster query language expression to apply to the constraint. For more information, see [Cluster query language](https://docs.aws.amazon.com/AmazonECS/latest/developerguide/cluster-query-language.html) in the *Amazon Elastic Container Service Developer Guide*.
         */
        expression?: pulumi.Input<string>;
        /**
         * The type of constraint. The ``MemberOf`` constraint restricts selection to be from a group of valid candidates.
         */
        type: pulumi.Input<string>;
    }
    /**
     * The ``PortMapping`` property specifies a port mapping. Port mappings allow containers to access ports on the host container instance to send or receive traffic. Port mappings are specified as part of the container definition.
     *  If you are using containers in a task with the ``awsvpc`` or ``host`` network mode, exposed ports should be specified using ``containerPort``. The ``hostPort`` can be left blank or it must be the same value as the ``containerPort``.
     *  After a task reaches the ``RUNNING`` status, manual and automatic host and container port assignments are visible in the ``networkBindings`` section of [DescribeTasks](https://docs.aws.amazon.com/AmazonECS/latest/APIReference/API_DescribeTasks.html) API responses.
     */
    interface TaskDefinitionPortMappingArgs {
        /**
         * The application protocol that's used for the port mapping. This parameter only applies to Service Connect. We recommend that you set this parameter to be consistent with the protocol that your application uses. If you set this parameter, Amazon ECS adds protocol-specific connection handling to the Service Connect proxy. If you set this parameter, Amazon ECS adds protocol-specific telemetry in the Amazon ECS console and CloudWatch.
         *  If you don't set a value for this parameter, then TCP is used. However, Amazon ECS doesn't add protocol-specific telemetry for TCP.
         *   ``appProtocol`` is immutable in a Service Connect service. Updating this field requires a service deletion and redeployment.
         *  Tasks that run in a namespace can use short names to connect to services in the namespace. Tasks can connect to services across all of the clusters in the namespace. Tasks connect through a managed proxy container that collects logs and metrics for increased visibility. Only the tasks that Amazon ECS services create are supported with Service Connect. For more information, see [Service Connect](https://docs.aws.amazon.com/AmazonECS/latest/developerguide/service-connect.html) in the *Amazon Elastic Container Service Developer Guide*.
         */
        appProtocol?: pulumi.Input<enums.ecs.TaskDefinitionPortMappingAppProtocol>;
        /**
         * The port number on the container that's bound to the user-specified or automatically assigned host port.
         *  If you use containers in a task with the ``awsvpc`` or ``host`` network mode, specify the exposed ports using ``containerPort``.
         *  If you use containers in a task with the ``bridge`` network mode and you specify a container port and not a host port, your container automatically receives a host port in the ephemeral port range. For more information, see ``hostPort``. Port mappings that are automatically assigned in this way do not count toward the 100 reserved ports limit of a container instance.
         */
        containerPort?: pulumi.Input<number>;
        /**
         * The port number range on the container that's bound to the dynamically mapped host port range.
         *  The following rules apply when you specify a ``containerPortRange``:
         *   +  You must use either the ``bridge`` network mode or the ``awsvpc`` network mode.
         *   +  This parameter is available for both the EC2 and FARGATElong launch types.
         *   +  This parameter is available for both the Linux and Windows operating systems.
         *   +  The container instance must have at least version 1.67.0 of the container agent and at least version 1.67.0-1 of the ``ecs-init`` package
         *   +  You can specify a maximum of 100 port ranges per container.
         *   +  You do not specify a ``hostPortRange``. The value of the ``hostPortRange`` is set as follows:
         *   +  For containers in a task with the ``awsvpc`` network mode, the ``hostPortRange`` is set to the same value as the ``containerPortRange``. This is a static mapping strategy.
         *   +  For containers in a task with the ``bridge`` network mode, the Amazon ECS agent finds open host ports from the default ephemeral range and passes it to docker to bind them to the container ports.
         *
         *   +  The ``containerPortRange`` valid values are between 1 and 65535.
         *   +  A port can only be included in one port mapping per container.
         *   +  You cannot specify overlapping port ranges.
         *   +  The first port in the range must be less than last port in the range.
         *   +  Docker recommends that you turn off the docker-proxy in the Docker daemon config file when you have a large number of ports.
         *  For more information, see [Issue #11185](https://docs.aws.amazon.com/https://github.com/moby/moby/issues/11185) on the Github website.
         *  For information about how to turn off the docker-proxy in the Docker daemon config file, see [Docker daemon](https://docs.aws.amazon.com/AmazonECS/latest/developerguide/bootstrap_container_instance.html#bootstrap_docker_daemon) in the *Amazon ECS Developer Guide*.
         *
         *  You can call [DescribeTasks](https://docs.aws.amazon.com/AmazonECS/latest/APIReference/API_DescribeTasks.html) to view the ``hostPortRange`` which are the host ports that are bound to the container ports.
         */
        containerPortRange?: pulumi.Input<string>;
        /**
         * The port number on the container instance to reserve for your container.
         *  If you specify a ``containerPortRange``, leave this field empty and the value of the ``hostPort`` is set as follows:
         *   +  For containers in a task with the ``awsvpc`` network mode, the ``hostPort`` is set to the same value as the ``containerPort``. This is a static mapping strategy.
         *   +  For containers in a task with the ``bridge`` network mode, the Amazon ECS agent finds open ports on the host and automatically binds them to the container ports. This is a dynamic mapping strategy.
         *
         *  If you use containers in a task with the ``awsvpc`` or ``host`` network mode, the ``hostPort`` can either be left blank or set to the same value as the ``containerPort``.
         *  If you use containers in a task with the ``bridge`` network mode, you can specify a non-reserved host port for your container port mapping, or you can omit the ``hostPort`` (or set it to ``0``) while specifying a ``containerPort`` and your container automatically receives a port in the ephemeral port range for your container instance operating system and Docker version.
         *  The default ephemeral port range for Docker version 1.6.0 and later is listed on the instance under ``/proc/sys/net/ipv4/ip_local_port_range``. If this kernel parameter is unavailable, the default ephemeral port range from 49153 through 65535 (Linux) or 49152 through 65535 (Windows) is used. Do not attempt to specify a host port in the ephemeral port range as these are reserved for automatic assignment. In general, ports below 32768 are outside of the ephemeral port range.
         *  The default reserved ports are 22 for SSH, the Docker ports 2375 and 2376, and the Amazon ECS container agent ports 51678-51680. Any host port that was previously specified in a running task is also reserved while the task is running. That is, after a task stops, the host port is released. The current reserved ports are displayed in the ``remainingResources`` of [DescribeContainerInstances](https://docs.aws.amazon.com/AmazonECS/latest/APIReference/API_DescribeContainerInstances.html) output. A container instance can have up to 100 reserved ports at a time. This number includes the default reserved ports. Automatically assigned ports aren't included in the 100 reserved ports quota.
         */
        hostPort?: pulumi.Input<number>;
        /**
         * The name that's used for the port mapping. This parameter is the name that you use in the ``serviceConnectConfiguration`` and the ``vpcLatticeConfigurations`` of a service. The name can include up to 64 characters. The characters can include lowercase letters, numbers, underscores (_), and hyphens (-). The name can't start with a hyphen.
         */
        name?: pulumi.Input<string>;
        /**
         * The protocol used for the port mapping. Valid values are ``tcp`` and ``udp``. The default is ``tcp``. ``protocol`` is immutable in a Service Connect service. Updating this field requires a service deletion and redeployment.
         */
        protocol?: pulumi.Input<string>;
    }
    /**
     * The configuration details for the App Mesh proxy.
     *  For tasks that use the EC2 launch type, the container instances require at least version 1.26.0 of the container agent and at least version 1.26.0-1 of the ``ecs-init`` package to use a proxy configuration. If your container instances are launched from the Amazon ECS optimized AMI version ``20190301`` or later, then they contain the required versions of the container agent and ``ecs-init``. For more information, see [Amazon ECS-optimized Linux AMI](https://docs.aws.amazon.com/AmazonECS/latest/developerguide/ecs-optimized_AMI.html)
     */
    interface TaskDefinitionProxyConfigurationArgs {
        /**
         * The name of the container that will serve as the App Mesh proxy.
         */
        containerName: pulumi.Input<string>;
        /**
         * The set of network configuration parameters to provide the Container Network Interface (CNI) plugin, specified as key-value pairs.
         *   +   ``IgnoredUID`` - (Required) The user ID (UID) of the proxy container as defined by the ``user`` parameter in a container definition. This is used to ensure the proxy ignores its own traffic. If ``IgnoredGID`` is specified, this field can be empty.
         *   +   ``IgnoredGID`` - (Required) The group ID (GID) of the proxy container as defined by the ``user`` parameter in a container definition. This is used to ensure the proxy ignores its own traffic. If ``IgnoredUID`` is specified, this field can be empty.
         *   +   ``AppPorts`` - (Required) The list of ports that the application uses. Network traffic to these ports is forwarded to the ``ProxyIngressPort`` and ``ProxyEgressPort``.
         *   +   ``ProxyIngressPort`` - (Required) Specifies the port that incoming traffic to the ``AppPorts`` is directed to.
         *   +   ``ProxyEgressPort`` - (Required) Specifies the port that outgoing traffic from the ``AppPorts`` is directed to.
         *   +   ``EgressIgnoredPorts`` - (Required) The egress traffic going to the specified ports is ignored and not redirected to the ``ProxyEgressPort``. It can be an empty list.
         *   +   ``EgressIgnoredIPs`` - (Required) The egress traffic going to the specified IP addresses is ignored and not redirected to the ``ProxyEgressPort``. It can be an empty list.
         */
        proxyConfigurationProperties?: pulumi.Input<pulumi.Input<inputs.ecs.TaskDefinitionKeyValuePairArgs>[]>;
        /**
         * The proxy type. The only supported value is ``APPMESH``.
         */
        type?: pulumi.Input<string>;
    }
    /**
     * The repository credentials for private registry authentication.
     */
    interface TaskDefinitionRepositoryCredentialsArgs {
        /**
         * The Amazon Resource Name (ARN) of the secret containing the private repository credentials.
         *   When you use the Amazon ECS API, CLI, or AWS SDK, if the secret exists in the same Region as the task that you're launching then you can use either the full ARN or the name of the secret. When you use the AWS Management Console, you must specify the full ARN of the secret.
         */
        credentialsParameter?: pulumi.Input<string>;
    }
    /**
     * The type and amount of a resource to assign to a container. The supported resource types are GPUs and Elastic Inference accelerators. For more information, see [Working with GPUs on Amazon ECS](https://docs.aws.amazon.com/AmazonECS/latest/developerguide/ecs-gpu.html) or [Working with Amazon Elastic Inference on Amazon ECS](https://docs.aws.amazon.com/AmazonECS/latest/developerguide/ecs-inference.html) in the *Amazon Elastic Container Service Developer Guide*
     */
    interface TaskDefinitionResourceRequirementArgs {
        /**
         * The type of resource to assign to a container.
         */
        type: pulumi.Input<string>;
        /**
         * The value for the specified resource type.
         *  When the type is ``GPU``, the value is the number of physical ``GPUs`` the Amazon ECS container agent reserves for the container. The number of GPUs that's reserved for all containers in a task can't exceed the number of available GPUs on the container instance that the task is launched on.
         *  When the type is ``InferenceAccelerator``, the ``value`` matches the ``deviceName`` for an [InferenceAccelerator](https://docs.aws.amazon.com/AmazonECS/latest/APIReference/API_InferenceAccelerator.html) specified in a task definition.
         */
        value: pulumi.Input<string>;
    }
    /**
     * You can enable a restart policy for each container defined in your task definition, to overcome transient failures faster and maintain task availability. When you enable a restart policy for a container, Amazon ECS can restart the container if it exits, without needing to replace the task. For more information, see [Restart individual containers in Amazon ECS tasks with container restart policies](https://docs.aws.amazon.com/AmazonECS/latest/developerguide/container-restart-policy.html) in the *Amazon Elastic Container Service Developer Guide*.
     */
    interface TaskDefinitionRestartPolicyArgs {
        /**
         * Specifies whether a restart policy is enabled for the container.
         */
        enabled?: pulumi.Input<boolean>;
        /**
         * A list of exit codes that Amazon ECS will ignore and not attempt a restart on. You can specify a maximum of 50 container exit codes. By default, Amazon ECS does not ignore any exit codes.
         */
        ignoredExitCodes?: pulumi.Input<pulumi.Input<number>[]>;
        /**
         * A period of time (in seconds) that the container must run for before a restart can be attempted. A container can be restarted only once every ``restartAttemptPeriod`` seconds. If a container isn't able to run for this time period and exits early, it will not be restarted. You can set a minimum ``restartAttemptPeriod`` of 60 seconds and a maximum ``restartAttemptPeriod`` of 1800 seconds. By default, a container must run for 300 seconds before it can be restarted.
         */
        restartAttemptPeriod?: pulumi.Input<number>;
    }
    /**
     * Information about the platform for the Amazon ECS service or task.
     *  For more information about ``RuntimePlatform``, see [RuntimePlatform](https://docs.aws.amazon.com/AmazonECS/latest/developerguide/task_definition_parameters.html#runtime-platform) in the *Amazon Elastic Container Service Developer Guide*.
     */
    interface TaskDefinitionRuntimePlatformArgs {
        /**
         * The CPU architecture.
         *  You can run your Linux tasks on an ARM-based platform by setting the value to ``ARM64``. This option is available for tasks that run on Linux Amazon EC2 instance or Linux containers on Fargate.
         */
        cpuArchitecture?: pulumi.Input<string>;
        /**
         * The operating system.
         */
        operatingSystemFamily?: pulumi.Input<string>;
    }
    /**
     * An object representing the secret to expose to your container. Secrets can be exposed to a container in the following ways:
     *   +  To inject sensitive data into your containers as environment variables, use the ``secrets`` container definition parameter.
     *   +  To reference sensitive information in the log configuration of a container, use the ``secretOptions`` container definition parameter.
     *
     *  For more information, see [Specifying sensitive data](https://docs.aws.amazon.com/AmazonECS/latest/developerguide/specifying-sensitive-data.html) in the *Amazon Elastic Container Service Developer Guide*.
     */
    interface TaskDefinitionSecretArgs {
        /**
         * The name of the secret.
         */
        name: pulumi.Input<string>;
        /**
         * The secret to expose to the container. The supported values are either the full ARN of the ASMlong secret or the full ARN of the parameter in the SSM Parameter Store.
         *  For information about the require IAMlong permissions, see [Required IAM permissions for Amazon ECS secrets](https://docs.aws.amazon.com/AmazonECS/latest/developerguide/specifying-sensitive-data-secrets.html#secrets-iam) (for Secrets Manager) or [Required IAM permissions for Amazon ECS secrets](https://docs.aws.amazon.com/AmazonECS/latest/developerguide/specifying-sensitive-data-parameters.html) (for Systems Manager Parameter store) in the *Amazon Elastic Container Service Developer Guide*.
         *   If the SSM Parameter Store parameter exists in the same Region as the task you're launching, then you can use either the full ARN or name of the parameter. If the parameter exists in a different Region, then the full ARN must be specified.
         */
        valueFrom: pulumi.Input<string>;
    }
    /**
     * A list of namespaced kernel parameters to set in the container. This parameter maps to ``Sysctls`` in the docker container create command and the ``--sysctl`` option to docker run. For example, you can configure ``net.ipv4.tcp_keepalive_time`` setting to maintain longer lived connections.
     *  We don't recommend that you specify network-related ``systemControls`` parameters for multiple containers in a single task that also uses either the ``awsvpc`` or ``host`` network mode. Doing this has the following disadvantages:
     *   +  For tasks that use the ``awsvpc`` network mode including Fargate, if you set ``systemControls`` for any container, it applies to all containers in the task. If you set different ``systemControls`` for multiple containers in a single task, the container that's started last determines which ``systemControls`` take effect.
     *   +  For tasks that use the ``host`` network mode, the network namespace ``systemControls`` aren't supported.
     *
     *  If you're setting an IPC resource namespace to use for the containers in the task, the following conditions apply to your system controls. For more information, see [IPC mode](https://docs.aws.amazon.com/AmazonECS/latest/developerguide/task_definition_parameters.html#task_definition_ipcmode).
     *   +  For tasks that use the ``host`` IPC mode, IPC namespace ``systemControls`` aren't supported.
     *   +  For tasks that use the ``task`` IPC mode, IPC namespace ``systemControls`` values apply to all containers within a task.
     *
     *   This parameter is not supported for Windows containers.
     *    This parameter is only supported for tasks that are hosted on FARGATElong if the tasks are using platform version ``1.4.0`` or later (Linux). This isn't supported for Windows containers on Fargate.
     */
    interface TaskDefinitionSystemControlArgs {
        /**
         * The namespaced kernel parameter to set a ``value`` for.
         */
        namespace?: pulumi.Input<string>;
        /**
         * The namespaced kernel parameter to set a ``value`` for.
         *  Valid IPC namespace values: ``"kernel.msgmax" | "kernel.msgmnb" | "kernel.msgmni" | "kernel.sem" | "kernel.shmall" | "kernel.shmmax" | "kernel.shmmni" | "kernel.shm_rmid_forced"``, and ``Sysctls`` that start with ``"fs.mqueue.*"``
         *  Valid network namespace values: ``Sysctls`` that start with ``"net.*"``
         *  All of these values are supported by Fargate.
         */
        value?: pulumi.Input<string>;
    }
    /**
     * The container path, mount options, and size of the tmpfs mount.
     */
    interface TaskDefinitionTmpfsArgs {
        /**
         * The absolute file path where the tmpfs volume is to be mounted.
         */
        containerPath?: pulumi.Input<string>;
        /**
         * The list of tmpfs volume mount options.
         *  Valid values: ``"defaults" | "ro" | "rw" | "suid" | "nosuid" | "dev" | "nodev" | "exec" | "noexec" | "sync" | "async" | "dirsync" | "remount" | "mand" | "nomand" | "atime" | "noatime" | "diratime" | "nodiratime" | "bind" | "rbind" | "unbindable" | "runbindable" | "private" | "rprivate" | "shared" | "rshared" | "slave" | "rslave" | "relatime" | "norelatime" | "strictatime" | "nostrictatime" | "mode" | "uid" | "gid" | "nr_inodes" | "nr_blocks" | "mpol"``
         */
        mountOptions?: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * The maximum size (in MiB) of the tmpfs volume.
         */
        size: pulumi.Input<number>;
    }
    /**
     * The ``ulimit`` settings to pass to the container.
     *  Amazon ECS tasks hosted on FARGATElong use the default resource limit values set by the operating system with the exception of the ``nofile`` resource limit parameter which FARGATElong overrides. The ``nofile`` resource limit sets a restriction on the number of open files that a container can use. The default ``nofile`` soft limit is ``65535`` and the default hard limit is ``65535``.
     *  You can specify the ``ulimit`` settings for a container in a task definition.
     */
    interface TaskDefinitionUlimitArgs {
        /**
         * The hard limit for the ``ulimit`` type. The value can be specified in bytes, seconds, or as a count, depending on the ``type`` of the ``ulimit``.
         */
        hardLimit: pulumi.Input<number>;
        /**
         * The ``type`` of the ``ulimit``.
         */
        name: pulumi.Input<string>;
        /**
         * The soft limit for the ``ulimit`` type. The value can be specified in bytes, seconds, or as a count, depending on the ``type`` of the ``ulimit``.
         */
        softLimit: pulumi.Input<number>;
    }
    /**
     * The data volume configuration for tasks launched using this task definition. Specifying a volume configuration in a task definition is optional. The volume configuration may contain multiple volumes but only one volume configured at launch is supported. Each volume defined in the volume configuration may only specify a ``name`` and one of either ``configuredAtLaunch``, ``dockerVolumeConfiguration``, ``efsVolumeConfiguration``, ``fsxWindowsFileServerVolumeConfiguration``, or ``host``. If an empty volume configuration is specified, by default Amazon ECS uses a host volume. For more information, see [Using data volumes in tasks](https://docs.aws.amazon.com/AmazonECS/latest/developerguide/using_data_volumes.html).
     */
    interface TaskDefinitionVolumeArgs {
        /**
         * Indicates whether the volume should be configured at launch time. This is used to create Amazon EBS volumes for standalone tasks or tasks created as part of a service. Each task definition revision may only have one volume configured at launch in the volume configuration.
         *  To configure a volume at launch time, use this task definition revision and specify a ``volumeConfigurations`` object when calling the ``CreateService``, ``UpdateService``, ``RunTask`` or ``StartTask`` APIs.
         */
        configuredAtLaunch?: pulumi.Input<boolean>;
        /**
         * This parameter is specified when you use Docker volumes.
         *  Windows containers only support the use of the ``local`` driver. To use bind mounts, specify the ``host`` parameter instead.
         *   Docker volumes aren't supported by tasks run on FARGATElong.
         */
        dockerVolumeConfiguration?: pulumi.Input<inputs.ecs.TaskDefinitionDockerVolumeConfigurationArgs>;
        /**
         * This parameter is specified when you use an Amazon Elastic File System file system for task storage.
         */
        efsVolumeConfiguration?: pulumi.Input<inputs.ecs.TaskDefinitionEfsVolumeConfigurationArgs>;
        /**
         * This parameter is specified when you use Amazon FSx for Windows File Server file system for task storage.
         */
        fSxWindowsFileServerVolumeConfiguration?: pulumi.Input<inputs.ecs.TaskDefinitionFSxWindowsFileServerVolumeConfigurationArgs>;
        /**
         * This parameter is specified when you use bind mount host volumes. The contents of the ``host`` parameter determine whether your bind mount host volume persists on the host container instance and where it's stored. If the ``host`` parameter is empty, then the Docker daemon assigns a host path for your data volume. However, the data isn't guaranteed to persist after the containers that are associated with it stop running.
         *  Windows containers can mount whole directories on the same drive as ``$env:ProgramData``. Windows containers can't mount directories on a different drive, and mount point can't be across drives. For example, you can mount ``C:\my\path:C:\my\path`` and ``D:\:D:\``, but not ``D:\my\path:C:\my\path`` or ``D:\:C:\my\path``.
         */
        host?: pulumi.Input<inputs.ecs.TaskDefinitionHostVolumePropertiesArgs>;
        /**
         * The name of the volume. Up to 255 letters (uppercase and lowercase), numbers, underscores, and hyphens are allowed.
         *  When using a volume configured at launch, the ``name`` is required and must also be specified as the volume name in the ``ServiceVolumeConfiguration`` or ``TaskVolumeConfiguration`` parameter when creating your service or standalone task.
         *  For all other types of volumes, this name is referenced in the ``sourceVolume`` parameter of the ``mountPoints`` object in the container definition.
         *  When a volume is using the ``efsVolumeConfiguration``, the name is required.
         */
        name?: pulumi.Input<string>;
    }
    /**
     * Details on a data volume from another container in the same task definition.
     */
    interface TaskDefinitionVolumeFromArgs {
        /**
         * If this value is ``true``, the container has read-only access to the volume. If this value is ``false``, then the container can write to the volume. The default value is ``false``.
         */
        readOnly?: pulumi.Input<boolean>;
        /**
         * The name of another container within the same task definition to mount volumes from.
         */
        sourceContainer?: pulumi.Input<string>;
    }
    /**
     * The VPC subnets and security groups associated with a task. All specified subnets and security groups must be from the same VPC.
     */
    interface TaskSetAwsVpcConfigurationArgs {
        /**
         * Whether the task's elastic network interface receives a public IP address. The default value is DISABLED.
         */
        assignPublicIp?: pulumi.Input<enums.ecs.TaskSetAwsVpcConfigurationAssignPublicIp>;
        /**
         * The security groups associated with the task or service. If you do not specify a security group, the default security group for the VPC is used. There is a limit of 5 security groups that can be specified per AwsVpcConfiguration.
         */
        securityGroups?: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * The subnets associated with the task or service. There is a limit of 16 subnets that can be specified per AwsVpcConfiguration.
         */
        subnets: pulumi.Input<pulumi.Input<string>[]>;
    }
    interface TaskSetCapacityProviderStrategyItemArgs {
        /**
         * The *base* value designates how many tasks, at a minimum, to run on the specified capacity provider. Only one capacity provider in a capacity provider strategy can have a *base* defined. If no value is specified, the default value of `0` is used.
         */
        base?: pulumi.Input<number>;
        /**
         * The short name of the capacity provider.
         */
        capacityProvider?: pulumi.Input<string>;
        /**
         * The *weight* value designates the relative percentage of the total number of tasks launched that should use the specified capacity provider. The `weight` value is taken into consideration after the `base` value, if defined, is satisfied.
         *
         * If no `weight` value is specified, the default value of `0` is used. When multiple capacity providers are specified within a capacity provider strategy, at least one of the capacity providers must have a weight value greater than zero and any capacity providers with a weight of `0` can't be used to place tasks. If you specify multiple capacity providers in a strategy that all have a weight of `0` , any `RunTask` or `CreateService` actions using the capacity provider strategy will fail.
         *
         * An example scenario for using weights is defining a strategy that contains two capacity providers and both have a weight of `1` , then when the `base` is satisfied, the tasks will be split evenly across the two capacity providers. Using that same logic, if you specify a weight of `1` for *capacityProviderA* and a weight of `4` for *capacityProviderB* , then for every one task that's run using *capacityProviderA* , four tasks would use *capacityProviderB* .
         */
        weight?: pulumi.Input<number>;
    }
    /**
     * A load balancer object representing the load balancer to use with the task set. The supported load balancer types are either an Application Load Balancer or a Network Load Balancer.
     */
    interface TaskSetLoadBalancerArgs {
        /**
         * The name of the container (as it appears in a container definition) to associate with the load balancer.
         */
        containerName?: pulumi.Input<string>;
        /**
         * The port on the container to associate with the load balancer. This port must correspond to a containerPort in the task definition the tasks in the service are using. For tasks that use the EC2 launch type, the container instance they are launched on must allow ingress traffic on the hostPort of the port mapping.
         */
        containerPort?: pulumi.Input<number>;
        /**
         * The full Amazon Resource Name (ARN) of the Elastic Load Balancing target group or groups associated with a service or task set. A target group ARN is only specified when using an Application Load Balancer or Network Load Balancer. If you are using a Classic Load Balancer this should be omitted. For services using the ECS deployment controller, you can specify one or multiple target groups. For more information, see https://docs.aws.amazon.com/AmazonECS/latest/developerguide/register-multiple-targetgroups.html in the Amazon Elastic Container Service Developer Guide. For services using the CODE_DEPLOY deployment controller, you are required to define two target groups for the load balancer. For more information, see https://docs.aws.amazon.com/AmazonECS/latest/developerguide/deployment-type-bluegreen.html in the Amazon Elastic Container Service Developer Guide. If your service's task definition uses the awsvpc network mode (which is required for the Fargate launch type), you must choose ip as the target type, not instance, when creating your target groups because tasks that use the awsvpc network mode are associated with an elastic network interface, not an Amazon EC2 instance.
         */
        targetGroupArn?: pulumi.Input<string>;
    }
    /**
     * An object representing the network configuration for a task or service.
     */
    interface TaskSetNetworkConfigurationArgs {
        /**
         * The VPC subnets and security groups that are associated with a task.
         *
         * > All specified subnets and security groups must be from the same VPC.
         */
        awsVpcConfiguration?: pulumi.Input<inputs.ecs.TaskSetAwsVpcConfigurationArgs>;
    }
    interface TaskSetScaleArgs {
        /**
         * The unit of measure for the scale value.
         */
        unit?: pulumi.Input<enums.ecs.TaskSetScaleUnit>;
        /**
         * The value, specified as a percent total of a service's desiredCount, to scale the task set. Accepted values are numbers between 0 and 100.
         */
        value?: pulumi.Input<number>;
    }
    interface TaskSetServiceRegistryArgs {
        /**
         * The container name value, already specified in the task definition, to be used for your service discovery service. If the task definition that your service task specifies uses the bridge or host network mode, you must specify a containerName and containerPort combination from the task definition. If the task definition that your service task specifies uses the awsvpc network mode and a type SRV DNS record is used, you must specify either a containerName and containerPort combination or a port value, but not both.
         */
        containerName?: pulumi.Input<string>;
        /**
         * The port value, already specified in the task definition, to be used for your service discovery service. If the task definition your service task specifies uses the bridge or host network mode, you must specify a containerName and containerPort combination from the task definition. If the task definition your service task specifies uses the awsvpc network mode and a type SRV DNS record is used, you must specify either a containerName and containerPort combination or a port value, but not both.
         */
        containerPort?: pulumi.Input<number>;
        /**
         * The port value used if your service discovery service specified an SRV record. This field may be used if both the awsvpc network mode and SRV records are used.
         */
        port?: pulumi.Input<number>;
        /**
         * The Amazon Resource Name (ARN) of the service registry. The currently supported service registry is AWS Cloud Map. For more information, see https://docs.aws.amazon.com/cloud-map/latest/api/API_CreateService.html
         */
        registryArn?: pulumi.Input<string>;
    }
}
export declare namespace efs {
    /**
     * Required if the ``RootDirectory`` > ``Path`` specified does not exist. Specifies the POSIX IDs and permissions to apply to the access point's ``RootDirectory`` > ``Path``. If the access point root directory does not exist, EFS creates it with these settings when a client connects to the access point. When specifying ``CreationInfo``, you must include values for all properties.
     *  Amazon EFS creates a root directory only if you have provided the CreationInfo: OwnUid, OwnGID, and permissions for the directory. If you do not provide this information, Amazon EFS does not create the root directory. If the root directory does not exist, attempts to mount using the access point will fail.
     *   If you do not provide ``CreationInfo`` and the specified ``RootDirectory`` does not exist, attempts to mount the file system using the access point will fail.
     */
    interface AccessPointCreationInfoArgs {
        /**
         * Specifies the POSIX group ID to apply to the ``RootDirectory``. Accepts values from 0 to 2^32 (4294967295).
         */
        ownerGid: pulumi.Input<string>;
        /**
         * Specifies the POSIX user ID to apply to the ``RootDirectory``. Accepts values from 0 to 2^32 (4294967295).
         */
        ownerUid: pulumi.Input<string>;
        /**
         * Specifies the POSIX permissions to apply to the ``RootDirectory``, in the format of an octal number representing the file's mode bits.
         */
        permissions: pulumi.Input<string>;
    }
    /**
     * The full POSIX identity, including the user ID, group ID, and any secondary group IDs, on the access point that is used for all file system operations performed by NFS clients using the access point.
     */
    interface AccessPointPosixUserArgs {
        /**
         * The POSIX group ID used for all file system operations using this access point.
         */
        gid: pulumi.Input<string>;
        /**
         * Secondary POSIX group IDs used for all file system operations using this access point.
         */
        secondaryGids?: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * The POSIX user ID used for all file system operations using this access point.
         */
        uid: pulumi.Input<string>;
    }
    /**
     * Specifies the directory on the Amazon EFS file system that the access point provides access to. The access point exposes the specified file system path as the root directory of your file system to applications using the access point. NFS clients using the access point can only access data in the access point's ``RootDirectory`` and its subdirectories.
     */
    interface AccessPointRootDirectoryArgs {
        /**
         * (Optional) Specifies the POSIX IDs and permissions to apply to the access point's ``RootDirectory``. If the ``RootDirectory`` > ``Path`` specified does not exist, EFS creates the root directory using the ``CreationInfo`` settings when a client connects to an access point. When specifying the ``CreationInfo``, you must provide values for all properties.
         *   If you do not provide ``CreationInfo`` and the specified ``RootDirectory`` > ``Path`` does not exist, attempts to mount the file system using the access point will fail.
         */
        creationInfo?: pulumi.Input<inputs.efs.AccessPointCreationInfoArgs>;
        /**
         * Specifies the path on the EFS file system to expose as the root directory to NFS clients using the access point to access the EFS file system. A path can have up to four subdirectories. If the specified path does not exist, you are required to provide the ``CreationInfo``.
         */
        path?: pulumi.Input<string>;
    }
    /**
     * The backup policy turns automatic backups for the file system on or off.
     */
    interface FileSystemBackupPolicyArgs {
        /**
         * Set the backup policy status for the file system.
         *   +   *ENABLED* - Turns automatic backups on for the file system.
         *   +   *DISABLED* - Turns automatic backups off for the file system.
         */
        status: pulumi.Input<enums.efs.FileSystemBackupPolicyStatus>;
    }
    /**
     * Describes a policy used by Lifecycle management that specifies when to transition files into and out of the EFS storage classes. For more information, see [Managing file system storage](https://docs.aws.amazon.com/efs/latest/ug/lifecycle-management-efs.html).
     *    +  Each ``LifecyclePolicy`` object can have only a single transition. This means that in a request body, ``LifecyclePolicies`` must be structured as an array of ``LifecyclePolicy`` objects, one object for each transition, ``TransitionToIA``, ``TransitionToArchive``, ``TransitionToPrimaryStorageClass``.
     *   +  See the AWS::EFS::FileSystem examples for the correct ``LifecyclePolicy`` structure. Do not use the syntax shown on this page.
     */
    interface FileSystemLifecyclePolicyArgs {
        /**
         * The number of days after files were last accessed in primary storage (the Standard storage class) at which to move them to Archive storage. Metadata operations such as listing the contents of a directory don't count as file access events.
         */
        transitionToArchive?: pulumi.Input<string>;
        /**
         * The number of days after files were last accessed in primary storage (the Standard storage class) at which to move them to Infrequent Access (IA) storage. Metadata operations such as listing the contents of a directory don't count as file access events.
         */
        transitionToIa?: pulumi.Input<string>;
        /**
         * Whether to move files back to primary (Standard) storage after they are accessed in IA or Archive storage. Metadata operations such as listing the contents of a directory don't count as file access events.
         */
        transitionToPrimaryStorageClass?: pulumi.Input<string>;
    }
    /**
     * Describes the protection on the file system.
     */
    interface FileSystemProtectionArgs {
        /**
         * The status of the file system's replication overwrite protection.
         *   +   ``ENABLED`` – The file system cannot be used as the destination file system in a replication configuration. The file system is writeable. Replication overwrite protection is ``ENABLED`` by default.
         *   +   ``DISABLED`` – The file system can be used as the destination file system in a replication configuration. The file system is read-only and can only be modified by EFS replication.
         *   +   ``REPLICATING`` – The file system is being used as the destination file system in a replication configuration. The file system is read-only and is modified only by EFS replication.
         *
         *  If the replication configuration is deleted, the file system's replication overwrite protection is re-enabled, the file system becomes writeable.
         */
        replicationOverwriteProtection?: pulumi.Input<enums.efs.FileSystemProtectionReplicationOverwriteProtection>;
    }
    /**
     * Describes the replication configuration for a specific file system.
     */
    interface FileSystemReplicationConfigurationArgs {
        /**
         * An array of destination objects. Only one destination object is supported.
         */
        destinations?: pulumi.Input<pulumi.Input<inputs.efs.FileSystemReplicationDestinationArgs>[]>;
    }
    /**
     * Describes the destination file system in the replication configuration.
     */
    interface FileSystemReplicationDestinationArgs {
        /**
         * For One Zone file systems, the replication configuration must specify the Availability Zone in which the destination file system is located.
         *  Use the format ``us-east-1a`` to specify the Availability Zone. For more information about One Zone file systems, see [EFS file system types](https://docs.aws.amazon.com/efs/latest/ug/storage-classes.html) in the *Amazon EFS User Guide*.
         *   One Zone file system type is not available in all Availability Zones in AWS-Regions where Amazon EFS is available.
         */
        availabilityZoneName?: pulumi.Input<string>;
        /**
         * The ID of the destination Amazon EFS file system.
         */
        fileSystemId?: pulumi.Input<string>;
        /**
         * The ID of an kms-key-long used to protect the encrypted file system.
         */
        kmsKeyId?: pulumi.Input<string>;
        /**
         * The AWS-Region in which the destination file system is located.
         *   For One Zone file systems, the replication configuration must specify the AWS-Region in which the destination file system is located.
         */
        region?: pulumi.Input<string>;
        /**
         * The Amazon Resource Name (ARN) of the current source file system in the replication configuration.
         */
        roleArn?: pulumi.Input<string>;
        /**
         * Describes the status of the replication configuration. For more information about replication status, see [Viewing replication details](https://docs.aws.amazon.com//efs/latest/ug/awsbackup.html#restoring-backup-efsmonitoring-replication-status.html) in the *Amazon EFS User Guide*.
         */
        status?: pulumi.Input<string>;
        /**
         * Message that provides details about the ``PAUSED`` or ``ERRROR`` state of the replication destination configuration. For more information about replication status messages, see [Viewing replication details](https://docs.aws.amazon.com//efs/latest/ug/awsbackup.html#restoring-backup-efsmonitoring-replication-status.html) in the *Amazon EFS User Guide*.
         */
        statusMessage?: pulumi.Input<string>;
    }
}
export declare namespace eks {
    /**
     * An access policy to associate with the current access entry.
     */
    interface AccessEntryAccessPolicyArgs {
        /**
         * The scope of an `AccessPolicy` that's associated to an `AccessEntry` .
         */
        accessScope: pulumi.Input<inputs.eks.AccessEntryAccessScopeArgs>;
        /**
         * The ARN of the access policy to add to the access entry.
         */
        policyArn: pulumi.Input<string>;
    }
    /**
     * The access scope of the access policy.
     */
    interface AccessEntryAccessScopeArgs {
        /**
         * The namespaces to associate with the access scope. Only specify if Type is set to 'namespace'.
         */
        namespaces?: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * The type of the access scope.
         */
        type: pulumi.Input<enums.eks.AccessEntryAccessScopeType>;
    }
    /**
     * A pod identity to associate with an add-on.
     */
    interface AddonPodIdentityAssociationArgs {
        /**
         * The IAM role ARN that the pod identity association is created for.
         */
        roleArn: pulumi.Input<string>;
        /**
         * The Kubernetes service account that the pod identity association is created for.
         */
        serviceAccount: pulumi.Input<string>;
    }
    /**
     * An object representing the Access Config to use for the cluster.
     */
    interface ClusterAccessConfigArgs {
        /**
         * Specify the authentication mode that should be used to create your cluster.
         */
        authenticationMode?: pulumi.Input<enums.eks.ClusterAccessConfigAuthenticationMode>;
        /**
         * Set this value to false to avoid creating a default cluster admin Access Entry using the IAM principal used to create the cluster.
         */
        bootstrapClusterCreatorAdminPermissions?: pulumi.Input<boolean>;
    }
    /**
     * Todo: add description
     */
    interface ClusterBlockStorageArgs {
        /**
         * Todo: add description
         */
        enabled?: pulumi.Input<boolean>;
    }
    /**
     * Todo: add description
     */
    interface ClusterComputeConfigArgs {
        /**
         * Todo: add description
         */
        enabled?: pulumi.Input<boolean>;
        /**
         * Todo: add description
         */
        nodePools?: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * Todo: add description
         */
        nodeRoleArn?: pulumi.Input<string>;
    }
    /**
     * Specify the placement group of the control plane machines for your cluster.
     */
    interface ClusterControlPlanePlacementArgs {
        /**
         * Specify the placement group name of the control place machines for your cluster.
         */
        groupName?: pulumi.Input<string>;
    }
    /**
     * Todo: add description
     */
    interface ClusterElasticLoadBalancingArgs {
        /**
         * Todo: add description
         */
        enabled?: pulumi.Input<boolean>;
    }
    /**
     * The encryption configuration for the cluster
     */
    interface ClusterEncryptionConfigArgs {
        /**
         * The encryption provider for the cluster.
         */
        provider?: pulumi.Input<inputs.eks.ClusterProviderArgs>;
        /**
         * Specifies the resources to be encrypted. The only supported value is "secrets".
         */
        resources?: pulumi.Input<pulumi.Input<string>[]>;
    }
    /**
     * The Kubernetes network configuration for the cluster.
     */
    interface ClusterKubernetesNetworkConfigArgs {
        /**
         * Todo: add description
         */
        elasticLoadBalancing?: pulumi.Input<inputs.eks.ClusterElasticLoadBalancingArgs>;
        /**
         * Ipv4 or Ipv6. You can only specify ipv6 for 1.21 and later clusters that use version 1.10.1 or later of the Amazon VPC CNI add-on
         */
        ipFamily?: pulumi.Input<enums.eks.ClusterKubernetesNetworkConfigIpFamily>;
        /**
         * The CIDR block to assign Kubernetes service IP addresses from. If you don't specify a block, Kubernetes assigns addresses from either the 10.100.0.0/16 or 172.20.0.0/16 CIDR blocks. We recommend that you specify a block that does not overlap with resources in other networks that are peered or connected to your VPC.
         */
        serviceIpv4Cidr?: pulumi.Input<string>;
        /**
         * The CIDR block to assign Kubernetes service IP addresses from.
         */
        serviceIpv6Cidr?: pulumi.Input<string>;
    }
    /**
     * The cluster control plane logging configuration for your cluster.
     */
    interface ClusterLoggingEnabledTypesArgs {
        /**
         * The enabled control plane logs for your cluster. All log types are disabled if the array is empty.
         *
         * > When updating a resource, you must include this `EnabledTypes` property if the previous CloudFormation template of the resource had it.
         */
        enabledTypes?: pulumi.Input<pulumi.Input<inputs.eks.ClusterLoggingTypeConfigArgs>[]>;
    }
    /**
     * Enabled Logging Type
     */
    interface ClusterLoggingTypeConfigArgs {
        /**
         * name of the log type
         */
        type?: pulumi.Input<enums.eks.ClusterLoggingTypeConfigType>;
    }
    /**
     * An object representing the Outpost configuration to use for AWS EKS outpost cluster.
     */
    interface ClusterOutpostConfigArgs {
        /**
         * Specify the Instance type of the machines that should be used to create your cluster.
         */
        controlPlaneInstanceType: pulumi.Input<string>;
        /**
         * Specify the placement group of the control plane machines for your cluster.
         */
        controlPlanePlacement?: pulumi.Input<inputs.eks.ClusterControlPlanePlacementArgs>;
        /**
         * Specify one or more Arn(s) of Outpost(s) on which you would like to create your cluster.
         */
        outpostArns: pulumi.Input<pulumi.Input<string>[]>;
    }
    interface ClusterProviderArgs {
        /**
         * Amazon Resource Name (ARN) or alias of the KMS key. The KMS key must be symmetric, created in the same region as the cluster, and if the KMS key was created in a different account, the user must have access to the KMS key.
         */
        keyArn?: pulumi.Input<string>;
    }
    /**
     * Configuration fields for specifying on-premises node and pod CIDRs that are external to the VPC passed during cluster creation.
     */
    interface ClusterRemoteNetworkConfigArgs {
        /**
         * Network configuration of nodes run on-premises with EKS Hybrid Nodes.
         */
        remoteNodeNetworks: pulumi.Input<pulumi.Input<inputs.eks.ClusterRemoteNodeNetworkArgs>[]>;
        /**
         * Network configuration of pods run on-premises with EKS Hybrid Nodes.
         */
        remotePodNetworks?: pulumi.Input<pulumi.Input<inputs.eks.ClusterRemotePodNetworkArgs>[]>;
    }
    /**
     * Network configuration of nodes run on-premises with EKS Hybrid Nodes.
     */
    interface ClusterRemoteNodeNetworkArgs {
        /**
         * Specifies the list of remote node CIDRs.
         */
        cidrs: pulumi.Input<pulumi.Input<string>[]>;
    }
    /**
     * Network configuration of pods run on-premises with EKS Hybrid Nodes.
     */
    interface ClusterRemotePodNetworkArgs {
        /**
         * Specifies the list of remote pod CIDRs.
         */
        cidrs: pulumi.Input<pulumi.Input<string>[]>;
    }
    /**
     * An object representing the VPC configuration to use for an Amazon EKS cluster.
     */
    interface ClusterResourcesVpcConfigArgs {
        /**
         * Set this value to true to enable private access for your cluster's Kubernetes API server endpoint. If you enable private access, Kubernetes API requests from within your cluster's VPC use the private VPC endpoint. The default value for this parameter is false, which disables private access for your Kubernetes API server. If you disable private access and you have nodes or AWS Fargate pods in the cluster, then ensure that publicAccessCidrs includes the necessary CIDR blocks for communication with the nodes or Fargate pods.
         */
        endpointPrivateAccess?: pulumi.Input<boolean>;
        /**
         * Set this value to false to disable public access to your cluster's Kubernetes API server endpoint. If you disable public access, your cluster's Kubernetes API server can only receive requests from within the cluster VPC. The default value for this parameter is true, which enables public access for your Kubernetes API server.
         */
        endpointPublicAccess?: pulumi.Input<boolean>;
        /**
         * The CIDR blocks that are allowed access to your cluster's public Kubernetes API server endpoint. Communication to the endpoint from addresses outside of the CIDR blocks that you specify is denied. The default value is 0.0.0.0/0. If you've disabled private endpoint access and you have nodes or AWS Fargate pods in the cluster, then ensure that you specify the necessary CIDR blocks.
         */
        publicAccessCidrs?: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * Specify one or more security groups for the cross-account elastic network interfaces that Amazon EKS creates to use to allow communication between your worker nodes and the Kubernetes control plane. If you don't specify a security group, the default security group for your VPC is used.
         */
        securityGroupIds?: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * Specify subnets for your Amazon EKS nodes. Amazon EKS creates cross-account elastic network interfaces in these subnets to allow communication between your nodes and the Kubernetes control plane.
         */
        subnetIds: pulumi.Input<pulumi.Input<string>[]>;
    }
    /**
     * Todo: add description
     */
    interface ClusterStorageConfigArgs {
        /**
         * Todo: add description
         */
        blockStorage?: pulumi.Input<inputs.eks.ClusterBlockStorageArgs>;
    }
    /**
     * An object representing the Upgrade Policy to use for the cluster.
     */
    interface ClusterUpgradePolicyArgs {
        /**
         * Specify the support type for your cluster.
         */
        supportType?: pulumi.Input<enums.eks.ClusterUpgradePolicySupportType>;
    }
    /**
     * The current zonal shift configuration to use for the cluster.
     */
    interface ClusterZonalShiftConfigArgs {
        /**
         * Set this value to true to enable zonal shift for the cluster.
         */
        enabled?: pulumi.Input<boolean>;
    }
    /**
     * A key-value pair to associate with a pod.
     */
    interface FargateProfileLabelArgs {
        /**
         * The key name of the label.
         */
        key: pulumi.Input<string>;
        /**
         * The value for the label.
         */
        value: pulumi.Input<string>;
    }
    interface FargateProfileSelectorArgs {
        /**
         * The Kubernetes labels that the selector should match. A pod must contain all of the labels that are specified in the selector for it to be considered a match.
         */
        labels?: pulumi.Input<pulumi.Input<inputs.eks.FargateProfileLabelArgs>[]>;
        /**
         * The Kubernetes `namespace` that the selector should match.
         */
        namespace: pulumi.Input<string>;
    }
    /**
     * An object representing an OpenID Connect (OIDC) configuration.
     */
    interface IdentityProviderConfigOidcIdentityProviderConfigArgs {
        /**
         * This is also known as audience. The ID for the client application that makes authentication requests to the OpenID identity provider.
         */
        clientId: pulumi.Input<string>;
        /**
         * The JWT claim that the provider uses to return your groups.
         */
        groupsClaim?: pulumi.Input<string>;
        /**
         * The prefix that is prepended to group claims to prevent clashes with existing names (such as system: groups).
         */
        groupsPrefix?: pulumi.Input<string>;
        /**
         * The URL of the OpenID identity provider that allows the API server to discover public signing keys for verifying tokens.
         */
        issuerUrl: pulumi.Input<string>;
        /**
         * The key-value pairs that describe required claims in the identity token. If set, each claim is verified to be present in the token with a matching value.
         */
        requiredClaims?: pulumi.Input<pulumi.Input<inputs.eks.IdentityProviderConfigRequiredClaimArgs>[]>;
        /**
         * The JSON Web Token (JWT) claim to use as the username. The default is sub, which is expected to be a unique identifier of the end user. You can choose other claims, such as email or name, depending on the OpenID identity provider. Claims other than email are prefixed with the issuer URL to prevent naming clashes with other plug-ins.
         */
        usernameClaim?: pulumi.Input<string>;
        /**
         * The prefix that is prepended to username claims to prevent clashes with existing names. If you do not provide this field, and username is a value other than email, the prefix defaults to issuerurl#. You can use the value - to disable all prefixing.
         */
        usernamePrefix?: pulumi.Input<string>;
    }
    /**
     * The key value pairs that describe required claims in the identity token. If set, each claim is verified to be present in the token with a matching value.
     */
    interface IdentityProviderConfigRequiredClaimArgs {
        /**
         * The key of the requiredClaims.
         */
        key: pulumi.Input<string>;
        /**
         * The value for the requiredClaims.
         */
        value: pulumi.Input<string>;
    }
    /**
     * Enable exporting the Kubernetes control plane logs for your cluster to CloudWatch Logs based on log types. By default, cluster control plane logs aren't exported to CloudWatch Logs.
     */
    interface LoggingArgs {
        /**
         * The cluster control plane logging configuration for your cluster.
         */
        clusterLogging?: pulumi.Input<inputs.eks.ClusterLoggingEnabledTypesArgs>;
    }
    /**
     * An object representing a launch template specification for AWS EKS Nodegroup.
     */
    interface NodegroupLaunchTemplateSpecificationArgs {
        /**
         * The ID of the launch template.
         *
         * You must specify either the launch template ID or the launch template name in the request, but not both. After node group creation, you cannot use a different ID.
         */
        id?: pulumi.Input<string>;
        /**
         * The name of the launch template.
         *
         * You must specify either the launch template name or the launch template ID in the request, but not both. After node group creation, you cannot use a different name.
         */
        name?: pulumi.Input<string>;
        /**
         * The version number of the launch template to use. If no version is specified, then the template's default version is used. You can use a different version for node group updates.
         */
        version?: pulumi.Input<string>;
    }
    /**
     * The node auto repair configuration for node group.
     */
    interface NodegroupNodeRepairConfigArgs {
        /**
         * Set this value to true to enable node auto repair for the node group.
         */
        enabled?: pulumi.Input<boolean>;
    }
    /**
     * An object representing a remote access configuration specification for AWS EKS Nodegroup.
     */
    interface NodegroupRemoteAccessArgs {
        /**
         * The Amazon EC2 SSH key name that provides access for SSH communication with the nodes in the managed node group. For more information, see [Amazon EC2 key pairs and Linux instances](https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/ec2-key-pairs.html) in the *Amazon Elastic Compute Cloud User Guide for Linux Instances* . For Windows, an Amazon EC2 SSH key is used to obtain the RDP password. For more information, see [Amazon EC2 key pairs and Windows instances](https://docs.aws.amazon.com/AWSEC2/latest/WindowsGuide/ec2-key-pairs.html) in the *Amazon Elastic Compute Cloud User Guide for Windows Instances* .
         */
        ec2SshKey: pulumi.Input<string>;
        /**
         * The security group IDs that are allowed SSH access (port 22) to the nodes. For Windows, the port is 3389. If you specify an Amazon EC2 SSH key but don't specify a source security group when you create a managed node group, then the port on the nodes is opened to the internet ( `0.0.0.0/0` ). For more information, see [Security Groups for Your VPC](https://docs.aws.amazon.com/vpc/latest/userguide/VPC_SecurityGroups.html) in the *Amazon Virtual Private Cloud User Guide* .
         */
        sourceSecurityGroups?: pulumi.Input<pulumi.Input<string>[]>;
    }
    /**
     * An object representing a auto scaling group specification for AWS EKS Nodegroup.
     */
    interface NodegroupScalingConfigArgs {
        /**
         * The current number of nodes that the managed node group should maintain.
         *
         * > If you use the Kubernetes [Cluster Autoscaler](https://docs.aws.amazon.com/https://github.com/kubernetes/autoscaler#kubernetes-autoscaler) , you shouldn't change the `desiredSize` value directly, as this can cause the Cluster Autoscaler to suddenly scale up or scale down.
         *
         * Whenever this parameter changes, the number of worker nodes in the node group is updated to the specified size. If this parameter is given a value that is smaller than the current number of running worker nodes, the necessary number of worker nodes are terminated to match the given value. When using CloudFormation, no action occurs if you remove this parameter from your CFN template.
         *
         * This parameter can be different from `minSize` in some cases, such as when starting with extra hosts for testing. This parameter can also be different when you want to start with an estimated number of needed hosts, but let the Cluster Autoscaler reduce the number if there are too many. When the Cluster Autoscaler is used, the `desiredSize` parameter is altered by the Cluster Autoscaler (but can be out-of-date for short periods of time). the Cluster Autoscaler doesn't scale a managed node group lower than `minSize` or higher than `maxSize` .
         */
        desiredSize?: pulumi.Input<number>;
        /**
         * The maximum number of nodes that the managed node group can scale out to. For information about the maximum number that you can specify, see [Amazon EKS service quotas](https://docs.aws.amazon.com/eks/latest/userguide/service-quotas.html) in the *Amazon EKS User Guide* .
         */
        maxSize?: pulumi.Input<number>;
        /**
         * The minimum number of nodes that the managed node group can scale in to.
         */
        minSize?: pulumi.Input<number>;
    }
    /**
     * An object representing a Taint specification for AWS EKS Nodegroup.
     */
    interface NodegroupTaintArgs {
        /**
         * The effect of the taint.
         */
        effect?: pulumi.Input<string>;
        /**
         * The key of the taint.
         */
        key?: pulumi.Input<string>;
        /**
         * The value of the taint.
         */
        value?: pulumi.Input<string>;
    }
    /**
     * The node group update configuration.
     */
    interface NodegroupUpdateConfigArgs {
        /**
         * The maximum number of nodes unavailable at once during a version update. Nodes will be updated in parallel. This value or maxUnavailablePercentage is required to have a value.The maximum number is 100.
         */
        maxUnavailable?: pulumi.Input<number>;
        /**
         * The maximum percentage of nodes unavailable during a version update. This percentage of nodes will be updated in parallel, up to 100 nodes at once. This value or maxUnavailable is required to have a value.
         */
        maxUnavailablePercentage?: pulumi.Input<number>;
        /**
         * The configuration for the behavior to follow during an node group version update of this managed node group. You choose between two possible strategies for replacing nodes during an UpdateNodegroupVersion action.
         */
        updateStrategy?: pulumi.Input<string>;
    }
}
export declare namespace elasticache {
    /**
     * Specifies the authentication mode to use. Below is an example of the possible JSON values:
     *
     * ```
     * { Passwords: ["*****", "******"] // If Type is password.
     * }
     * ```
     */
    interface AuthenticationModePropertiesArgs {
        /**
         * Passwords used for this user account. You can create up to two passwords for each user.
         */
        passwords?: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * Authentication Type
         */
        type: pulumi.Input<enums.elasticache.UserAuthenticationModePropertiesType>;
    }
    interface GlobalReplicationGroupMemberArgs {
        /**
         * Regionally unique identifier for the member i.e. ReplicationGroupId.
         */
        replicationGroupId?: pulumi.Input<string>;
        /**
         * The AWS region of the Global Datastore member.
         */
        replicationGroupRegion?: pulumi.Input<string>;
        /**
         * Indicates the role of the member, primary or secondary.
         */
        role?: pulumi.Input<enums.elasticache.GlobalReplicationGroupMemberRole>;
    }
    interface GlobalReplicationGroupRegionalConfigurationArgs {
        /**
         * The replication group id of the Global Datastore member.
         */
        replicationGroupId?: pulumi.Input<string>;
        /**
         * The AWS region of the Global Datastore member.
         */
        replicationGroupRegion?: pulumi.Input<string>;
        /**
         * A list of PreferredAvailabilityZones objects that specifies the configuration of a node group in the resharded cluster.
         */
        reshardingConfigurations?: pulumi.Input<pulumi.Input<inputs.elasticache.GlobalReplicationGroupReshardingConfigurationArgs>[]>;
    }
    interface GlobalReplicationGroupReshardingConfigurationArgs {
        /**
         * Unique identifier for the Node Group. This is either auto-generated by ElastiCache (4-digit id) or a user supplied id.
         */
        nodeGroupId?: pulumi.Input<string>;
        /**
         * A list of preferred availability zones for the nodes of new node groups.
         */
        preferredAvailabilityZones?: pulumi.Input<pulumi.Input<string>[]>;
    }
    /**
     * The cache capacity limit of the Serverless Cache.
     */
    interface ServerlessCacheCacheUsageLimitsArgs {
        /**
         * The maximum data storage limit in the cache, expressed in Gigabytes.
         */
        dataStorage?: pulumi.Input<inputs.elasticache.ServerlessCacheDataStorageArgs>;
        /**
         * The number of ElastiCache Processing Units (ECPU) the cache can consume per second.
         */
        ecpuPerSecond?: pulumi.Input<inputs.elasticache.ServerlessCacheEcpuPerSecondArgs>;
    }
    /**
     * The cached data capacity of the Serverless Cache.
     */
    interface ServerlessCacheDataStorageArgs {
        /**
         * The maximum cached data capacity of the Serverless Cache.
         */
        maximum?: pulumi.Input<number>;
        /**
         * The minimum cached data capacity of the Serverless Cache.
         */
        minimum?: pulumi.Input<number>;
        /**
         * The unit of cached data capacity of the Serverless Cache.
         */
        unit: pulumi.Input<enums.elasticache.ServerlessCacheDataStorageUnit>;
    }
    /**
     * The ECPU per second of the Serverless Cache.
     */
    interface ServerlessCacheEcpuPerSecondArgs {
        /**
         * The maximum ECPU per second of the Serverless Cache.
         */
        maximum?: pulumi.Input<number>;
        /**
         * The minimum ECPU per second of the Serverless Cache.
         */
        minimum?: pulumi.Input<number>;
    }
    /**
     * The address and the port.
     */
    interface ServerlessCacheEndpointArgs {
        /**
         * Endpoint address.
         */
        address?: pulumi.Input<string>;
        /**
         * Endpoint port.
         */
        port?: pulumi.Input<string>;
    }
}
export declare namespace elasticbeanstalk {
    interface ApplicationMaxAgeRuleArgs {
        /**
         * Set to true to delete a version's source bundle from Amazon S3 when Elastic Beanstalk deletes the application version.
         */
        deleteSourceFromS3?: pulumi.Input<boolean>;
        /**
         * Specify true to apply the rule, or false to disable it.
         */
        enabled?: pulumi.Input<boolean>;
        /**
         * Specify the number of days to retain an application versions.
         */
        maxAgeInDays?: pulumi.Input<number>;
    }
    interface ApplicationMaxCountRuleArgs {
        /**
         * Set to true to delete a version's source bundle from Amazon S3 when Elastic Beanstalk deletes the application version.
         */
        deleteSourceFromS3?: pulumi.Input<boolean>;
        /**
         * Specify true to apply the rule, or false to disable it.
         */
        enabled?: pulumi.Input<boolean>;
        /**
         * Specify the maximum number of application versions to retain.
         */
        maxCount?: pulumi.Input<number>;
    }
    interface ApplicationResourceLifecycleConfigArgs {
        /**
         * The ARN of an IAM service role that Elastic Beanstalk has permission to assume. The ServiceRole property is required the first time that you provide a ResourceLifecycleConfig for the application. After you provide it once, Elastic Beanstalk persists the Service Role with the application, and you don't need to specify it again. You can, however, specify it in subsequent updates to change the Service Role to another value.
         */
        serviceRole?: pulumi.Input<string>;
        /**
         * Defines lifecycle settings for application versions.
         */
        versionLifecycleConfig?: pulumi.Input<inputs.elasticbeanstalk.ApplicationVersionLifecycleConfigArgs>;
    }
    interface ApplicationVersionLifecycleConfigArgs {
        /**
         * Specify a max age rule to restrict the length of time that application versions are retained for an application.
         */
        maxAgeRule?: pulumi.Input<inputs.elasticbeanstalk.ApplicationMaxAgeRuleArgs>;
        /**
         * Specify a max count rule to restrict the number of application versions that are retained for an application.
         */
        maxCountRule?: pulumi.Input<inputs.elasticbeanstalk.ApplicationMaxCountRuleArgs>;
    }
    interface ApplicationVersionSourceBundleArgs {
        /**
         * The Amazon S3 bucket where the data is located.
         */
        s3Bucket: pulumi.Input<string>;
        /**
         * The Amazon S3 key where the data is located.
         */
        s3Key: pulumi.Input<string>;
    }
    interface ConfigurationTemplateConfigurationOptionSettingArgs {
        /**
         * A unique namespace that identifies the option's associated AWS resource.
         */
        namespace: pulumi.Input<string>;
        /**
         * The name of the configuration option.
         */
        optionName: pulumi.Input<string>;
        /**
         * A unique resource name for the option setting. Use it for a time–based scaling configuration option.
         */
        resourceName?: pulumi.Input<string>;
        /**
         * The current value for the configuration option.
         */
        value?: pulumi.Input<string>;
    }
    interface ConfigurationTemplateSourceConfigurationArgs {
        /**
         * The name of the application associated with the configuration.
         */
        applicationName: pulumi.Input<string>;
        /**
         * The name of the configuration template.
         */
        templateName: pulumi.Input<string>;
    }
    interface EnvironmentOptionSettingArgs {
        /**
         * A unique namespace that identifies the option's associated AWS resource.
         */
        namespace: pulumi.Input<string>;
        /**
         * The name of the configuration option.
         */
        optionName: pulumi.Input<string>;
        /**
         * A unique resource name for the option setting. Use it for a time–based scaling configuration option.
         */
        resourceName?: pulumi.Input<string>;
        /**
         * The current value for the configuration option.
         */
        value?: pulumi.Input<string>;
    }
    interface EnvironmentTierArgs {
        /**
         * The name of this environment tier.
         */
        name?: pulumi.Input<string>;
        /**
         * The type of this environment tier.
         */
        type?: pulumi.Input<string>;
        /**
         * The version of this environment tier. When you don't set a value to it, Elastic Beanstalk uses the latest compatible worker tier version.
         */
        version?: pulumi.Input<string>;
    }
}
export declare namespace elasticloadbalancingv2 {
    /**
     * Specifies an action for a listener rule.
     */
    interface ListenerActionArgs {
        /**
         * [HTTPS listeners] Information for using Amazon Cognito to authenticate users. Specify only when ``Type`` is ``authenticate-cognito``.
         */
        authenticateCognitoConfig?: pulumi.Input<inputs.elasticloadbalancingv2.ListenerAuthenticateCognitoConfigArgs>;
        /**
         * [HTTPS listeners] Information about an identity provider that is compliant with OpenID Connect (OIDC). Specify only when ``Type`` is ``authenticate-oidc``.
         */
        authenticateOidcConfig?: pulumi.Input<inputs.elasticloadbalancingv2.ListenerAuthenticateOidcConfigArgs>;
        /**
         * [Application Load Balancer] Information for creating an action that returns a custom HTTP response. Specify only when ``Type`` is ``fixed-response``.
         */
        fixedResponseConfig?: pulumi.Input<inputs.elasticloadbalancingv2.ListenerFixedResponseConfigArgs>;
        /**
         * Information for creating an action that distributes requests among one or more target groups. For Network Load Balancers, you can specify a single target group. Specify only when ``Type`` is ``forward``. If you specify both ``ForwardConfig`` and ``TargetGroupArn``, you can specify only one target group using ``ForwardConfig`` and it must be the same target group specified in ``TargetGroupArn``.
         */
        forwardConfig?: pulumi.Input<inputs.elasticloadbalancingv2.ListenerForwardConfigArgs>;
        /**
         * The order for the action. This value is required for rules with multiple actions. The action with the lowest value for order is performed first.
         */
        order?: pulumi.Input<number>;
        /**
         * [Application Load Balancer] Information for creating a redirect action. Specify only when ``Type`` is ``redirect``.
         */
        redirectConfig?: pulumi.Input<inputs.elasticloadbalancingv2.ListenerRedirectConfigArgs>;
        /**
         * The Amazon Resource Name (ARN) of the target group. Specify only when ``Type`` is ``forward`` and you want to route to a single target group. To route to one or more target groups, use ``ForwardConfig`` instead.
         */
        targetGroupArn?: pulumi.Input<string>;
        /**
         * The type of action.
         */
        type: pulumi.Input<string>;
    }
    /**
     * Information about a listener attribute.
     */
    interface ListenerAttributeArgs {
        /**
         * The name of the attribute.
         *  The following attribute is supported by Network Load Balancers, and Gateway Load Balancers.
         *   +   ``tcp.idle_timeout.seconds`` - The tcp idle timeout value, in seconds. The valid range is 60-6000 seconds. The default is 350 seconds.
         *
         *  The following attributes are only supported by Application Load Balancers.
         *   +   ``routing.http.request.x_amzn_mtls_clientcert_serial_number.header_name`` - Enables you to modify the header name of the *X-Amzn-Mtls-Clientcert-Serial-Number* HTTP request header.
         *   +   ``routing.http.request.x_amzn_mtls_clientcert_issuer.header_name`` - Enables you to modify the header name of the *X-Amzn-Mtls-Clientcert-Issuer* HTTP request header.
         *   +   ``routing.http.request.x_amzn_mtls_clientcert_subject.header_name`` - Enables you to modify the header name of the *X-Amzn-Mtls-Clientcert-Subject* HTTP request header.
         *   +   ``routing.http.request.x_amzn_mtls_clientcert_validity.header_name`` - Enables you to modify the header name of the *X-Amzn-Mtls-Clientcert-Validity* HTTP request header.
         *   +   ``routing.http.request.x_amzn_mtls_clientcert_leaf.header_name`` - Enables you to modify the header name of the *X-Amzn-Mtls-Clientcert-Leaf* HTTP request header.
         *   +   ``routing.http.request.x_amzn_mtls_clientcert.header_name`` - Enables you to modify the header name of the *X-Amzn-Mtls-Clientcert* HTTP request header.
         *   +   ``routing.http.request.x_amzn_tls_version.header_name`` - Enables you to modify the header name of the *X-Amzn-Tls-Version* HTTP request header.
         *   +   ``routing.http.request.x_amzn_tls_cipher_suite.header_name`` - Enables you to modify the header name of the *X-Amzn-Tls-Cipher-Suite* HTTP request header.
         *   +   ``routing.http.response.server.enabled`` - Enables you to allow or remove the HTTP response server header.
         *   +   ``routing.http.response.strict_transport_security.header_value`` - Informs browsers that the site should only be accessed using HTTPS, and that any future attempts to access it using HTTP should automatically be converted to HTTPS.
         *   +   ``routing.http.response.access_control_allow_origin.header_value`` - Specifies which origins are allowed to access the server.
         *   +   ``routing.http.response.access_control_allow_methods.header_value`` - Returns which HTTP methods are allowed when accessing the server from a different origin.
         *   +   ``routing.http.response.access_control_allow_headers.header_value`` - Specifies which headers can be used during the request.
         *   +   ``routing.http.response.access_control_allow_credentials.header_value`` - Indicates whether the browser should include credentials such as cookies or authentication when making requests.
         *   +   ``routing.http.response.access_control_expose_headers.header_value`` - Returns which headers the browser can expose to the requesting client.
         *   +   ``routing.http.response.access_control_max_age.header_value`` - Specifies how long the results of a preflight request can be cached, in seconds.
         *   +   ``routing.http.response.content_security_policy.header_value`` - Specifies restrictions enforced by the browser to help minimize the risk of certain types of security threats.
         *   +   ``routing.http.response.x_content_type_options.header_value`` - Indicates whether the MIME types advertised in the *Content-Type* headers should be followed and not be changed.
         *   +   ``routing.http.response.x_frame_options.header_value`` - Indicates whether the browser is allowed to render a page in a *frame*, *iframe*, *embed* or *object*.
         */
        key?: pulumi.Input<string>;
        /**
         * The value of the attribute.
         */
        value?: pulumi.Input<string>;
    }
    /**
     * Specifies information required when integrating with Amazon Cognito to authenticate users.
     */
    interface ListenerAuthenticateCognitoConfigArgs {
        /**
         * The query parameters (up to 10) to include in the redirect request to the authorization endpoint.
         */
        authenticationRequestExtraParams?: pulumi.Input<{
            [key: string]: pulumi.Input<string>;
        }>;
        /**
         * The behavior if the user is not authenticated. The following are possible values:
         *   +  deny```` - Return an HTTP 401 Unauthorized error.
         *   +  allow```` - Allow the request to be forwarded to the target.
         *   +  authenticate```` - Redirect the request to the IdP authorization endpoint. This is the default value.
         */
        onUnauthenticatedRequest?: pulumi.Input<string>;
        /**
         * The set of user claims to be requested from the IdP. The default is ``openid``.
         *  To verify which scope values your IdP supports and how to separate multiple values, see the documentation for your IdP.
         */
        scope?: pulumi.Input<string>;
        /**
         * The name of the cookie used to maintain session information. The default is AWSELBAuthSessionCookie.
         */
        sessionCookieName?: pulumi.Input<string>;
        /**
         * The maximum duration of the authentication session, in seconds. The default is 604800 seconds (7 days).
         */
        sessionTimeout?: pulumi.Input<string>;
        /**
         * The Amazon Resource Name (ARN) of the Amazon Cognito user pool.
         */
        userPoolArn: pulumi.Input<string>;
        /**
         * The ID of the Amazon Cognito user pool client.
         */
        userPoolClientId: pulumi.Input<string>;
        /**
         * The domain prefix or fully-qualified domain name of the Amazon Cognito user pool.
         */
        userPoolDomain: pulumi.Input<string>;
    }
    /**
     * Specifies information required using an identity provide (IdP) that is compliant with OpenID Connect (OIDC) to authenticate users.
     */
    interface ListenerAuthenticateOidcConfigArgs {
        /**
         * The query parameters (up to 10) to include in the redirect request to the authorization endpoint.
         */
        authenticationRequestExtraParams?: pulumi.Input<{
            [key: string]: pulumi.Input<string>;
        }>;
        /**
         * The authorization endpoint of the IdP. This must be a full URL, including the HTTPS protocol, the domain, and the path.
         */
        authorizationEndpoint: pulumi.Input<string>;
        /**
         * The OAuth 2.0 client identifier.
         */
        clientId: pulumi.Input<string>;
        /**
         * The OAuth 2.0 client secret. This parameter is required if you are creating a rule. If you are modifying a rule, you can omit this parameter if you set ``UseExistingClientSecret`` to true.
         */
        clientSecret?: pulumi.Input<string>;
        /**
         * The OIDC issuer identifier of the IdP. This must be a full URL, including the HTTPS protocol, the domain, and the path.
         */
        issuer: pulumi.Input<string>;
        /**
         * The behavior if the user is not authenticated. The following are possible values:
         *   +  deny```` - Return an HTTP 401 Unauthorized error.
         *   +  allow```` - Allow the request to be forwarded to the target.
         *   +  authenticate```` - Redirect the request to the IdP authorization endpoint. This is the default value.
         */
        onUnauthenticatedRequest?: pulumi.Input<string>;
        /**
         * The set of user claims to be requested from the IdP. The default is ``openid``.
         *  To verify which scope values your IdP supports and how to separate multiple values, see the documentation for your IdP.
         */
        scope?: pulumi.Input<string>;
        /**
         * The name of the cookie used to maintain session information. The default is AWSELBAuthSessionCookie.
         */
        sessionCookieName?: pulumi.Input<string>;
        /**
         * The maximum duration of the authentication session, in seconds. The default is 604800 seconds (7 days).
         */
        sessionTimeout?: pulumi.Input<string>;
        /**
         * The token endpoint of the IdP. This must be a full URL, including the HTTPS protocol, the domain, and the path.
         */
        tokenEndpoint: pulumi.Input<string>;
        /**
         * Indicates whether to use the existing client secret when modifying a rule. If you are creating a rule, you can omit this parameter or set it to false.
         */
        useExistingClientSecret?: pulumi.Input<boolean>;
        /**
         * The user info endpoint of the IdP. This must be a full URL, including the HTTPS protocol, the domain, and the path.
         */
        userInfoEndpoint: pulumi.Input<string>;
    }
    /**
     * Specifies an SSL server certificate to use as the default certificate for a secure listener.
     */
    interface ListenerCertificateArgs {
        /**
         * The Amazon Resource Name (ARN) of the certificate.
         */
        certificateArn?: pulumi.Input<string>;
    }
    /**
     * Specifies information required when returning a custom HTTP response.
     */
    interface ListenerFixedResponseConfigArgs {
        /**
         * The content type.
         *  Valid Values: text/plain | text/css | text/html | application/javascript | application/json
         */
        contentType?: pulumi.Input<string>;
        /**
         * The message.
         */
        messageBody?: pulumi.Input<string>;
        /**
         * The HTTP response code (2XX, 4XX, or 5XX).
         */
        statusCode: pulumi.Input<string>;
    }
    /**
     * Information for creating an action that distributes requests among one or more target groups. For Network Load Balancers, you can specify a single target group. Specify only when ``Type`` is ``forward``. If you specify both ``ForwardConfig`` and ``TargetGroupArn``, you can specify only one target group using ``ForwardConfig`` and it must be the same target group specified in ``TargetGroupArn``.
     */
    interface ListenerForwardConfigArgs {
        /**
         * Information about the target group stickiness for a rule.
         */
        targetGroupStickinessConfig?: pulumi.Input<inputs.elasticloadbalancingv2.ListenerTargetGroupStickinessConfigArgs>;
        /**
         * Information about how traffic will be distributed between multiple target groups in a forward rule.
         */
        targetGroups?: pulumi.Input<pulumi.Input<inputs.elasticloadbalancingv2.ListenerTargetGroupTupleArgs>[]>;
    }
    /**
     * The mutual authentication configuration information.
     */
    interface ListenerMutualAuthenticationArgs {
        /**
         * Indicates whether trust store CA certificate names are advertised.
         */
        advertiseTrustStoreCaNames?: pulumi.Input<string>;
        /**
         * Indicates whether expired client certificates are ignored.
         */
        ignoreClientCertificateExpiry?: pulumi.Input<boolean>;
        /**
         * The client certificate handling method. Options are ``off``, ``passthrough`` or ``verify``. The default value is ``off``.
         */
        mode?: pulumi.Input<string>;
        /**
         * The Amazon Resource Name (ARN) of the trust store.
         */
        trustStoreArn?: pulumi.Input<string>;
    }
    /**
     * Information about a redirect action.
     *  A URI consists of the following components: protocol://hostname:port/path?query. You must modify at least one of the following components to avoid a redirect loop: protocol, hostname, port, or path. Any components that you do not modify retain their original values.
     *  You can reuse URI components using the following reserved keywords:
     *   +  #{protocol}
     *   +  #{host}
     *   +  #{port}
     *   +  #{path} (the leading "/" is removed)
     *   +  #{query}
     *
     *  For example, you can change the path to "/new/#{path}", the hostname to "example.#{host}", or the query to "#{query}&value=xyz".
     */
    interface ListenerRedirectConfigArgs {
        /**
         * The hostname. This component is not percent-encoded. The hostname can contain #{host}.
         */
        host?: pulumi.Input<string>;
        /**
         * The absolute path, starting with the leading "/". This component is not percent-encoded. The path can contain #{host}, #{path}, and #{port}.
         */
        path?: pulumi.Input<string>;
        /**
         * The port. You can specify a value from 1 to 65535 or #{port}.
         */
        port?: pulumi.Input<string>;
        /**
         * The protocol. You can specify HTTP, HTTPS, or #{protocol}. You can redirect HTTP to HTTP, HTTP to HTTPS, and HTTPS to HTTPS. You can't redirect HTTPS to HTTP.
         */
        protocol?: pulumi.Input<string>;
        /**
         * The query parameters, URL-encoded when necessary, but not percent-encoded. Do not include the leading "?", as it is automatically added. You can specify any of the reserved keywords.
         */
        query?: pulumi.Input<string>;
        /**
         * The HTTP redirect code. The redirect is either permanent (HTTP 301) or temporary (HTTP 302).
         */
        statusCode: pulumi.Input<string>;
    }
    /**
     * Specifies an action for a listener rule.
     */
    interface ListenerRuleActionArgs {
        /**
         * [HTTPS listeners] Information for using Amazon Cognito to authenticate users. Specify only when ``Type`` is ``authenticate-cognito``.
         */
        authenticateCognitoConfig?: pulumi.Input<inputs.elasticloadbalancingv2.ListenerRuleAuthenticateCognitoConfigArgs>;
        /**
         * [HTTPS listeners] Information about an identity provider that is compliant with OpenID Connect (OIDC). Specify only when ``Type`` is ``authenticate-oidc``.
         */
        authenticateOidcConfig?: pulumi.Input<inputs.elasticloadbalancingv2.ListenerRuleAuthenticateOidcConfigArgs>;
        /**
         * [Application Load Balancer] Information for creating an action that returns a custom HTTP response. Specify only when ``Type`` is ``fixed-response``.
         */
        fixedResponseConfig?: pulumi.Input<inputs.elasticloadbalancingv2.ListenerRuleFixedResponseConfigArgs>;
        /**
         * Information for creating an action that distributes requests among one or more target groups. For Network Load Balancers, you can specify a single target group. Specify only when ``Type`` is ``forward``. If you specify both ``ForwardConfig`` and ``TargetGroupArn``, you can specify only one target group using ``ForwardConfig`` and it must be the same target group specified in ``TargetGroupArn``.
         */
        forwardConfig?: pulumi.Input<inputs.elasticloadbalancingv2.ListenerRuleForwardConfigArgs>;
        /**
         * The order for the action. This value is required for rules with multiple actions. The action with the lowest value for order is performed first.
         */
        order?: pulumi.Input<number>;
        /**
         * [Application Load Balancer] Information for creating a redirect action. Specify only when ``Type`` is ``redirect``.
         */
        redirectConfig?: pulumi.Input<inputs.elasticloadbalancingv2.ListenerRuleRedirectConfigArgs>;
        /**
         * The Amazon Resource Name (ARN) of the target group. Specify only when ``Type`` is ``forward`` and you want to route to a single target group. To route to one or more target groups, use ``ForwardConfig`` instead.
         */
        targetGroupArn?: pulumi.Input<string>;
        /**
         * The type of action.
         */
        type: pulumi.Input<string>;
    }
    /**
     * Specifies information required when integrating with Amazon Cognito to authenticate users.
     */
    interface ListenerRuleAuthenticateCognitoConfigArgs {
        /**
         * The query parameters (up to 10) to include in the redirect request to the authorization endpoint.
         */
        authenticationRequestExtraParams?: pulumi.Input<{
            [key: string]: pulumi.Input<string>;
        }>;
        /**
         * The behavior if the user is not authenticated. The following are possible values:
         *   +  deny```` - Return an HTTP 401 Unauthorized error.
         *   +  allow```` - Allow the request to be forwarded to the target.
         *   +  authenticate```` - Redirect the request to the IdP authorization endpoint. This is the default value.
         */
        onUnauthenticatedRequest?: pulumi.Input<string>;
        /**
         * The set of user claims to be requested from the IdP. The default is ``openid``.
         *  To verify which scope values your IdP supports and how to separate multiple values, see the documentation for your IdP.
         */
        scope?: pulumi.Input<string>;
        /**
         * The name of the cookie used to maintain session information. The default is AWSELBAuthSessionCookie.
         */
        sessionCookieName?: pulumi.Input<string>;
        /**
         * The maximum duration of the authentication session, in seconds. The default is 604800 seconds (7 days).
         */
        sessionTimeout?: pulumi.Input<number>;
        /**
         * The Amazon Resource Name (ARN) of the Amazon Cognito user pool.
         */
        userPoolArn: pulumi.Input<string>;
        /**
         * The ID of the Amazon Cognito user pool client.
         */
        userPoolClientId: pulumi.Input<string>;
        /**
         * The domain prefix or fully-qualified domain name of the Amazon Cognito user pool.
         */
        userPoolDomain: pulumi.Input<string>;
    }
    /**
     * Specifies information required using an identity provide (IdP) that is compliant with OpenID Connect (OIDC) to authenticate users.
     */
    interface ListenerRuleAuthenticateOidcConfigArgs {
        /**
         * The query parameters (up to 10) to include in the redirect request to the authorization endpoint.
         */
        authenticationRequestExtraParams?: pulumi.Input<{
            [key: string]: pulumi.Input<string>;
        }>;
        /**
         * The authorization endpoint of the IdP. This must be a full URL, including the HTTPS protocol, the domain, and the path.
         */
        authorizationEndpoint: pulumi.Input<string>;
        /**
         * The OAuth 2.0 client identifier.
         */
        clientId: pulumi.Input<string>;
        /**
         * The OAuth 2.0 client secret. This parameter is required if you are creating a rule. If you are modifying a rule, you can omit this parameter if you set ``UseExistingClientSecret`` to true.
         */
        clientSecret?: pulumi.Input<string>;
        /**
         * The OIDC issuer identifier of the IdP. This must be a full URL, including the HTTPS protocol, the domain, and the path.
         */
        issuer: pulumi.Input<string>;
        /**
         * The behavior if the user is not authenticated. The following are possible values:
         *   +  deny```` - Return an HTTP 401 Unauthorized error.
         *   +  allow```` - Allow the request to be forwarded to the target.
         *   +  authenticate```` - Redirect the request to the IdP authorization endpoint. This is the default value.
         */
        onUnauthenticatedRequest?: pulumi.Input<string>;
        /**
         * The set of user claims to be requested from the IdP. The default is ``openid``.
         *  To verify which scope values your IdP supports and how to separate multiple values, see the documentation for your IdP.
         */
        scope?: pulumi.Input<string>;
        /**
         * The name of the cookie used to maintain session information. The default is AWSELBAuthSessionCookie.
         */
        sessionCookieName?: pulumi.Input<string>;
        /**
         * The maximum duration of the authentication session, in seconds. The default is 604800 seconds (7 days).
         */
        sessionTimeout?: pulumi.Input<number>;
        /**
         * The token endpoint of the IdP. This must be a full URL, including the HTTPS protocol, the domain, and the path.
         */
        tokenEndpoint: pulumi.Input<string>;
        /**
         * Indicates whether to use the existing client secret when modifying a rule. If you are creating a rule, you can omit this parameter or set it to false.
         */
        useExistingClientSecret?: pulumi.Input<boolean>;
        /**
         * The user info endpoint of the IdP. This must be a full URL, including the HTTPS protocol, the domain, and the path.
         */
        userInfoEndpoint: pulumi.Input<string>;
    }
    /**
     * Specifies information required when returning a custom HTTP response.
     */
    interface ListenerRuleFixedResponseConfigArgs {
        /**
         * The content type.
         *  Valid Values: text/plain | text/css | text/html | application/javascript | application/json
         */
        contentType?: pulumi.Input<string>;
        /**
         * The message.
         */
        messageBody?: pulumi.Input<string>;
        /**
         * The HTTP response code (2XX, 4XX, or 5XX).
         */
        statusCode: pulumi.Input<string>;
    }
    /**
     * Information for creating an action that distributes requests among one or more target groups. For Network Load Balancers, you can specify a single target group. Specify only when ``Type`` is ``forward``. If you specify both ``ForwardConfig`` and ``TargetGroupArn``, you can specify only one target group using ``ForwardConfig`` and it must be the same target group specified in ``TargetGroupArn``.
     */
    interface ListenerRuleForwardConfigArgs {
        /**
         * Information about the target group stickiness for a rule.
         */
        targetGroupStickinessConfig?: pulumi.Input<inputs.elasticloadbalancingv2.ListenerRuleTargetGroupStickinessConfigArgs>;
        /**
         * Information about how traffic will be distributed between multiple target groups in a forward rule.
         */
        targetGroups?: pulumi.Input<pulumi.Input<inputs.elasticloadbalancingv2.ListenerRuleTargetGroupTupleArgs>[]>;
    }
    /**
     * Information about a host header condition.
     */
    interface ListenerRuleHostHeaderConfigArgs {
        /**
         * The host names. The maximum size of each name is 128 characters. The comparison is case insensitive. The following wildcard characters are supported: * (matches 0 or more characters) and ? (matches exactly 1 character).
         *  If you specify multiple strings, the condition is satisfied if one of the strings matches the host name.
         */
        values?: pulumi.Input<pulumi.Input<string>[]>;
    }
    /**
     * Information about an HTTP header condition.
     *  There is a set of standard HTTP header fields. You can also define custom HTTP header fields.
     */
    interface ListenerRuleHttpHeaderConfigArgs {
        /**
         * The name of the HTTP header field. The maximum size is 40 characters. The header name is case insensitive. The allowed characters are specified by RFC 7230. Wildcards are not supported.
         */
        httpHeaderName?: pulumi.Input<string>;
        /**
         * The strings to compare against the value of the HTTP header. The maximum size of each string is 128 characters. The comparison strings are case insensitive. The following wildcard characters are supported: * (matches 0 or more characters) and ? (matches exactly 1 character).
         *  If the same header appears multiple times in the request, we search them in order until a match is found.
         *  If you specify multiple strings, the condition is satisfied if one of the strings matches the value of the HTTP header. To require that all of the strings are a match, create one condition per string.
         */
        values?: pulumi.Input<pulumi.Input<string>[]>;
    }
    /**
     * Information about an HTTP method condition.
     *  HTTP defines a set of request methods, also referred to as HTTP verbs. For more information, see the [HTTP Method Registry](https://docs.aws.amazon.com/https://www.iana.org/assignments/http-methods/http-methods.xhtml). You can also define custom HTTP methods.
     */
    interface ListenerRuleHttpRequestMethodConfigArgs {
        /**
         * The name of the request method. The maximum size is 40 characters. The allowed characters are A-Z, hyphen (-), and underscore (_). The comparison is case sensitive. Wildcards are not supported; therefore, the method name must be an exact match.
         *  If you specify multiple strings, the condition is satisfied if one of the strings matches the HTTP request method. We recommend that you route GET and HEAD requests in the same way, because the response to a HEAD request may be cached.
         */
        values?: pulumi.Input<pulumi.Input<string>[]>;
    }
    /**
     * Information about a path pattern condition.
     */
    interface ListenerRulePathPatternConfigArgs {
        /**
         * The path patterns to compare against the request URL. The maximum size of each string is 128 characters. The comparison is case sensitive. The following wildcard characters are supported: * (matches 0 or more characters) and ? (matches exactly 1 character).
         *  If you specify multiple strings, the condition is satisfied if one of them matches the request URL. The path pattern is compared only to the path of the URL, not to its query string.
         */
        values?: pulumi.Input<pulumi.Input<string>[]>;
    }
    /**
     * Information about a query string condition.
     *  The query string component of a URI starts after the first '?' character and is terminated by either a '#' character or the end of the URI. A typical query string contains key/value pairs separated by '&' characters. The allowed characters are specified by RFC 3986. Any character can be percentage encoded.
     */
    interface ListenerRuleQueryStringConfigArgs {
        /**
         * The key/value pairs or values to find in the query string. The maximum size of each string is 128 characters. The comparison is case insensitive. The following wildcard characters are supported: * (matches 0 or more characters) and ? (matches exactly 1 character). To search for a literal '*' or '?' character in a query string, you must escape these characters in ``Values`` using a '\' character.
         *  If you specify multiple key/value pairs or values, the condition is satisfied if one of them is found in the query string.
         */
        values?: pulumi.Input<pulumi.Input<inputs.elasticloadbalancingv2.ListenerRuleQueryStringKeyValueArgs>[]>;
    }
    /**
     * Information about a key/value pair.
     */
    interface ListenerRuleQueryStringKeyValueArgs {
        /**
         * The key. You can omit the key.
         */
        key?: pulumi.Input<string>;
        /**
         * The value.
         */
        value?: pulumi.Input<string>;
    }
    /**
     * Information about a redirect action.
     *  A URI consists of the following components: protocol://hostname:port/path?query. You must modify at least one of the following components to avoid a redirect loop: protocol, hostname, port, or path. Any components that you do not modify retain their original values.
     *  You can reuse URI components using the following reserved keywords:
     *   +  #{protocol}
     *   +  #{host}
     *   +  #{port}
     *   +  #{path} (the leading "/" is removed)
     *   +  #{query}
     *
     *  For example, you can change the path to "/new/#{path}", the hostname to "example.#{host}", or the query to "#{query}&value=xyz".
     */
    interface ListenerRuleRedirectConfigArgs {
        /**
         * The hostname. This component is not percent-encoded. The hostname can contain #{host}.
         */
        host?: pulumi.Input<string>;
        /**
         * The absolute path, starting with the leading "/". This component is not percent-encoded. The path can contain #{host}, #{path}, and #{port}.
         */
        path?: pulumi.Input<string>;
        /**
         * The port. You can specify a value from 1 to 65535 or #{port}.
         */
        port?: pulumi.Input<string>;
        /**
         * The protocol. You can specify HTTP, HTTPS, or #{protocol}. You can redirect HTTP to HTTP, HTTP to HTTPS, and HTTPS to HTTPS. You can't redirect HTTPS to HTTP.
         */
        protocol?: pulumi.Input<string>;
        /**
         * The query parameters, URL-encoded when necessary, but not percent-encoded. Do not include the leading "?", as it is automatically added. You can specify any of the reserved keywords.
         */
        query?: pulumi.Input<string>;
        /**
         * The HTTP redirect code. The redirect is either permanent (HTTP 301) or temporary (HTTP 302).
         */
        statusCode: pulumi.Input<string>;
    }
    /**
     * Specifies a condition for a listener rule.
     */
    interface ListenerRuleRuleConditionArgs {
        /**
         * The field in the HTTP request. The following are the possible values:
         *   +   ``http-header``
         *   +   ``http-request-method``
         *   +   ``host-header``
         *   +   ``path-pattern``
         *   +   ``query-string``
         *   +   ``source-ip``
         */
        field?: pulumi.Input<string>;
        /**
         * Information for a host header condition. Specify only when ``Field`` is ``host-header``.
         */
        hostHeaderConfig?: pulumi.Input<inputs.elasticloadbalancingv2.ListenerRuleHostHeaderConfigArgs>;
        /**
         * Information for an HTTP header condition. Specify only when ``Field`` is ``http-header``.
         */
        httpHeaderConfig?: pulumi.Input<inputs.elasticloadbalancingv2.ListenerRuleHttpHeaderConfigArgs>;
        /**
         * Information for an HTTP method condition. Specify only when ``Field`` is ``http-request-method``.
         */
        httpRequestMethodConfig?: pulumi.Input<inputs.elasticloadbalancingv2.ListenerRuleHttpRequestMethodConfigArgs>;
        /**
         * Information for a path pattern condition. Specify only when ``Field`` is ``path-pattern``.
         */
        pathPatternConfig?: pulumi.Input<inputs.elasticloadbalancingv2.ListenerRulePathPatternConfigArgs>;
        /**
         * Information for a query string condition. Specify only when ``Field`` is ``query-string``.
         */
        queryStringConfig?: pulumi.Input<inputs.elasticloadbalancingv2.ListenerRuleQueryStringConfigArgs>;
        /**
         * Information for a source IP condition. Specify only when ``Field`` is ``source-ip``.
         */
        sourceIpConfig?: pulumi.Input<inputs.elasticloadbalancingv2.ListenerRuleSourceIpConfigArgs>;
        /**
         * The condition value. Specify only when ``Field`` is ``host-header`` or ``path-pattern``. Alternatively, to specify multiple host names or multiple path patterns, use ``HostHeaderConfig`` or ``PathPatternConfig``.
         *  If ``Field`` is ``host-header`` and you're not using ``HostHeaderConfig``, you can specify a single host name (for example, my.example.com). A host name is case insensitive, can be up to 128 characters in length, and can contain any of the following characters.
         *   +  A-Z, a-z, 0-9
         *   +  - .
         *   +  * (matches 0 or more characters)
         *   +  ? (matches exactly 1 character)
         *
         *  If ``Field`` is ``path-pattern`` and you're not using ``PathPatternConfig``, you can specify a single path pattern (for example, /img/*). A path pattern is case-sensitive, can be up to 128 characters in length, and can contain any of the following characters.
         *   +  A-Z, a-z, 0-9
         *   +  _ - . $ / ~ " ' @ : +
         *   +  & (using &amp;)
         *   +  * (matches 0 or more characters)
         *   +  ? (matches exactly 1 character)
         */
        values?: pulumi.Input<pulumi.Input<string>[]>;
    }
    /**
     * Information about a source IP condition.
     *  You can use this condition to route based on the IP address of the source that connects to the load balancer. If a client is behind a proxy, this is the IP address of the proxy not the IP address of the client.
     */
    interface ListenerRuleSourceIpConfigArgs {
        /**
         * The source IP addresses, in CIDR format. You can use both IPv4 and IPv6 addresses. Wildcards are not supported.
         *  If you specify multiple addresses, the condition is satisfied if the source IP address of the request matches one of the CIDR blocks. This condition is not satisfied by the addresses in the X-Forwarded-For header.
         */
        values?: pulumi.Input<pulumi.Input<string>[]>;
    }
    /**
     * Information about the target group stickiness for a rule.
     */
    interface ListenerRuleTargetGroupStickinessConfigArgs {
        /**
         * The time period, in seconds, during which requests from a client should be routed to the same target group. The range is 1-604800 seconds (7 days).
         */
        durationSeconds?: pulumi.Input<number>;
        /**
         * Indicates whether target group stickiness is enabled.
         */
        enabled?: pulumi.Input<boolean>;
    }
    /**
     * Information about how traffic will be distributed between multiple target groups in a forward rule.
     */
    interface ListenerRuleTargetGroupTupleArgs {
        /**
         * The Amazon Resource Name (ARN) of the target group.
         */
        targetGroupArn?: pulumi.Input<string>;
        /**
         * The weight. The range is 0 to 999.
         */
        weight?: pulumi.Input<number>;
    }
    /**
     * Information about the target group stickiness for a rule.
     */
    interface ListenerTargetGroupStickinessConfigArgs {
        /**
         * The time period, in seconds, during which requests from a client should be routed to the same target group. The range is 1-604800 seconds (7 days).
         */
        durationSeconds?: pulumi.Input<number>;
        /**
         * Indicates whether target group stickiness is enabled.
         */
        enabled?: pulumi.Input<boolean>;
    }
    /**
     * Information about how traffic will be distributed between multiple target groups in a forward rule.
     */
    interface ListenerTargetGroupTupleArgs {
        /**
         * The Amazon Resource Name (ARN) of the target group.
         */
        targetGroupArn?: pulumi.Input<string>;
        /**
         * The weight. The range is 0 to 999.
         */
        weight?: pulumi.Input<number>;
    }
    /**
     * Specifies an attribute for an Application Load Balancer, a Network Load Balancer, or a Gateway Load Balancer.
     */
    interface LoadBalancerAttributeArgs {
        /**
         * The name of the attribute.
         *  The following attributes are supported by all load balancers:
         *   +   ``deletion_protection.enabled`` - Indicates whether deletion protection is enabled. The value is ``true`` or ``false``. The default is ``false``.
         *   +   ``load_balancing.cross_zone.enabled`` - Indicates whether cross-zone load balancing is enabled. The possible values are ``true`` and ``false``. The default for Network Load Balancers and Gateway Load Balancers is ``false``. The default for Application Load Balancers is ``true``, and can't be changed.
         *
         *  The following attributes are supported by both Application Load Balancers and Network Load Balancers:
         *   +   ``access_logs.s3.enabled`` - Indicates whether access logs are enabled. The value is ``true`` or ``false``. The default is ``false``.
         *   +   ``access_logs.s3.bucket`` - The name of the S3 bucket for the access logs. This attribute is required if access logs are enabled. The bucket must exist in the same region as the load balancer and have a bucket policy that grants Elastic Load Balancing permissions to write to the bucket.
         *   +   ``access_logs.s3.prefix`` - The prefix for the location in the S3 bucket for the access logs.
         *   +   ``ipv6.deny_all_igw_traffic`` - Blocks internet gateway (IGW) access to the load balancer. It is set to ``false`` for internet-facing load balancers and ``true`` for internal load balancers, preventing unintended access to your internal load balancer through an internet gateway.
         *   +   ``zonal_shift.config.enabled`` - Indicates whether zonal shift is enabled. The possible values are ``true`` and ``false``. The default is ``false``.
         *
         *  The following attributes are supported by only Application Load Balancers:
         *   +   ``idle_timeout.timeout_seconds`` - The idle timeout value, in seconds. The valid range is 1-4000 seconds. The default is 60 seconds.
         *   +   ``client_keep_alive.seconds`` - The client keep alive value, in seconds. The valid range is 60-604800 seconds. The default is 3600 seconds.
         *   +   ``connection_logs.s3.enabled`` - Indicates whether connection logs are enabled. The value is ``true`` or ``false``. The default is ``false``.
         *   +   ``connection_logs.s3.bucket`` - The name of the S3 bucket for the connection logs. This attribute is required if connection logs are enabled. The bucket must exist in the same region as the load balancer and have a bucket policy that grants Elastic Load Balancing permissions to write to the bucket.
         *   +   ``connection_logs.s3.prefix`` - The prefix for the location in the S3 bucket for the connection logs.
         *   +   ``routing.http.desync_mitigation_mode`` - Determines how the load balancer handles requests that might pose a security risk to your application. The possible values are ``monitor``, ``defensive``, and ``strictest``. The default is ``defensive``.
         *   +   ``routing.http.drop_invalid_header_fields.enabled`` - Indicates whether HTTP headers with invalid header fields are removed by the load balancer (``true``) or routed to targets (``false``). The default is ``false``.
         *   +   ``routing.http.preserve_host_header.enabled`` - Indicates whether the Application Load Balancer should preserve the ``Host`` header in the HTTP request and send it to the target without any change. The possible values are ``true`` and ``false``. The default is ``false``.
         *   +   ``routing.http.x_amzn_tls_version_and_cipher_suite.enabled`` - Indicates whether the two headers (``x-amzn-tls-version`` and ``x-amzn-tls-cipher-suite``), which contain information about the negotiated TLS version and cipher suite, are added to the client request before sending it to the target. The ``x-amzn-tls-version`` header has information about the TLS protocol version negotiated with the client, and the ``x-amzn-tls-cipher-suite`` header has information about the cipher suite negotiated with the client. Both headers are in OpenSSL format. The possible values for the attribute are ``true`` and ``false``. The default is ``false``.
         *   +   ``routing.http.xff_client_port.enabled`` - Indicates whether the ``X-Forwarded-For`` header should preserve the source port that the client used to connect to the load balancer. The possible values are ``true`` and ``false``. The default is ``false``.
         *   +   ``routing.http.xff_header_processing.mode`` - Enables you to modify, preserve, or remove the ``X-Forwarded-For`` header in the HTTP request before the Application Load Balancer sends the request to the target. The possible values are ``append``, ``preserve``, and ``remove``. The default is ``append``.
         *   +  If the value is ``append``, the Application Load Balancer adds the client IP address (of the last hop) to the ``X-Forwarded-For`` header in the HTTP request before it sends it to targets.
         *   +  If the value is ``preserve`` the Application Load Balancer preserves the ``X-Forwarded-For`` header in the HTTP request, and sends it to targets without any change.
         *   +  If the value is ``remove``, the Application Load Balancer removes the ``X-Forwarded-For`` header in the HTTP request before it sends it to targets.
         *
         *   +   ``routing.http2.enabled`` - Indicates whether HTTP/2 is enabled. The possible values are ``true`` and ``false``. The default is ``true``. Elastic Load Balancing requires that message header names contain only alphanumeric characters and hyphens.
         *   +   ``waf.fail_open.enabled`` - Indicates whether to allow a WAF-enabled load balancer to route requests to targets if it is unable to forward the request to AWS WAF. The possible values are ``true`` and ``false``. The default is ``false``.
         *
         *  The following attributes are supported by only Network Load Balancers:
         *   +   ``dns_record.client_routing_policy`` - Indicates how traffic is distributed among the load balancer Availability Zones. The possible values are ``availability_zone_affinity`` with 100 percent zonal affinity, ``partial_availability_zone_affinity`` with 85 percent zonal affinity, and ``any_availability_zone`` with 0 percent zonal affinity.
         */
        key?: pulumi.Input<string>;
        /**
         * The value of the attribute.
         */
        value?: pulumi.Input<string>;
    }
    /**
     * The minimum capacity for a load balancer.
     */
    interface LoadBalancerMinimumLoadBalancerCapacityArgs {
        /**
         * The number of capacity units.
         */
        capacityUnits: pulumi.Input<number>;
    }
    /**
     * Specifies a subnet for a load balancer.
     */
    interface LoadBalancerSubnetMappingArgs {
        /**
         * [Network Load Balancers] The allocation ID of the Elastic IP address for an internet-facing load balancer.
         */
        allocationId?: pulumi.Input<string>;
        /**
         * [Network Load Balancers] The IPv6 address.
         */
        iPv6Address?: pulumi.Input<string>;
        /**
         * [Network Load Balancers] The private IPv4 address for an internal load balancer.
         */
        privateIPv4Address?: pulumi.Input<string>;
        /**
         * [Network Load Balancers with UDP listeners] The IPv6 prefix to use for source NAT. Specify an IPv6 prefix (/80 netmask) from the subnet CIDR block or ``auto_assigned`` to use an IPv6 prefix selected at random from the subnet CIDR block.
         */
        sourceNatIpv6Prefix?: pulumi.Input<string>;
        /**
         * The ID of the subnet.
         */
        subnetId: pulumi.Input<string>;
    }
    interface TargetGroupAttributeArgs {
        /**
         * The value of the attribute.
         */
        key?: pulumi.Input<string>;
        /**
         * The name of the attribute.
         */
        value?: pulumi.Input<string>;
    }
    interface TargetGroupMatcherArgs {
        /**
         * You can specify values between 0 and 99. You can specify multiple values, or a range of values. The default value is 12.
         */
        grpcCode?: pulumi.Input<string>;
        /**
         * For Application Load Balancers, you can specify values between 200 and 499, and the default value is 200. You can specify multiple values or a range of values.
         */
        httpCode?: pulumi.Input<string>;
    }
    interface TargetGroupTargetDescriptionArgs {
        /**
         * An Availability Zone or all. This determines whether the target receives traffic from the load balancer nodes in the specified Availability Zone or from all enabled Availability Zones for the load balancer.
         */
        availabilityZone?: pulumi.Input<string>;
        /**
         * The ID of the target. If the target type of the target group is instance, specify an instance ID. If the target type is ip, specify an IP address. If the target type is lambda, specify the ARN of the Lambda function. If the target type is alb, specify the ARN of the Application Load Balancer target.
         */
        id: pulumi.Input<string>;
        /**
         * The port on which the target is listening. If the target group protocol is GENEVE, the supported port is 6081. If the target type is alb, the targeted Application Load Balancer must have at least one listener whose port matches the target group port. Not used if the target is a Lambda function.
         */
        port?: pulumi.Input<number>;
    }
    interface TrustStoreRevocationRevocationContentArgs {
        /**
         * The type of revocation file.
         */
        revocationType?: pulumi.Input<string>;
        /**
         * The Amazon S3 bucket for the revocation file.
         */
        s3Bucket?: pulumi.Input<string>;
        /**
         * The Amazon S3 path for the revocation file.
         */
        s3Key?: pulumi.Input<string>;
        /**
         * The Amazon S3 object version of the revocation file.
         */
        s3ObjectVersion?: pulumi.Input<string>;
    }
}
export declare namespace emr {
    interface StepHadoopJarStepConfigArgs {
        /**
         * A list of command line arguments passed to the JAR file's main function when executed.
         */
        args?: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * A path to a JAR file run during the step.
         */
        jar: pulumi.Input<string>;
        /**
         * The name of the main class in the specified Java file. If not specified, the JAR file should specify a Main-Class in its manifest file.
         */
        mainClass?: pulumi.Input<string>;
        /**
         * A list of Java properties that are set when the step runs. You can use these properties to pass key value pairs to your main function.
         */
        stepProperties?: pulumi.Input<pulumi.Input<inputs.emr.StepKeyValueArgs>[]>;
    }
    interface StepKeyValueArgs {
        /**
         * The unique identifier of a key-value pair.
         */
        key?: pulumi.Input<string>;
        /**
         * The value part of the identified key.
         */
        value?: pulumi.Input<string>;
    }
}
export declare namespace emrcontainers {
    interface VirtualClusterContainerInfoArgs {
        /**
         * The information about the Amazon EKS cluster.
         */
        eksInfo: pulumi.Input<inputs.emrcontainers.VirtualClusterEksInfoArgs>;
    }
    interface VirtualClusterContainerProviderArgs {
        /**
         * The ID of the container cluster
         */
        id: pulumi.Input<string>;
        /**
         * The information about the container cluster.
         */
        info: pulumi.Input<inputs.emrcontainers.VirtualClusterContainerInfoArgs>;
        /**
         * The type of the container provider
         */
        type: pulumi.Input<string>;
    }
    interface VirtualClusterEksInfoArgs {
        /**
         * The namespaces of the EKS cluster.
         *
         * *Minimum* : 1
         *
         * *Maximum* : 63
         *
         * *Pattern* : `[a-z0-9]([-a-z0-9]*[a-z0-9])?`
         */
        namespace: pulumi.Input<string>;
    }
}
export declare namespace emrserverless {
    /**
     * Configuration for Auto Start of Application
     */
    interface ApplicationAutoStartConfigurationArgs {
        /**
         * If set to true, the Application will automatically start. Defaults to true.
         */
        enabled?: pulumi.Input<boolean>;
    }
    /**
     * Configuration for Auto Stop of Application
     */
    interface ApplicationAutoStopConfigurationArgs {
        /**
         * If set to true, the Application will automatically stop after being idle. Defaults to true.
         */
        enabled?: pulumi.Input<boolean>;
        /**
         * The amount of time [in minutes] to wait before auto stopping the Application when idle. Defaults to 15 minutes.
         */
        idleTimeoutMinutes?: pulumi.Input<number>;
    }
    interface ApplicationCloudWatchLoggingConfigurationArgs {
        /**
         * If set to false, CloudWatch logging will be turned off. Defaults to false.
         */
        enabled?: pulumi.Input<boolean>;
        /**
         * KMS key ARN to encrypt the logs stored in given CloudWatch log-group.
         */
        encryptionKeyArn?: pulumi.Input<string>;
        /**
         * Log-group name to produce log-streams on CloudWatch. If undefined, logs will be produced in a default log-group /aws/emr-serverless
         */
        logGroupName?: pulumi.Input<string>;
        /**
         * Log-stream name prefix by which log-stream names will start in the CloudWatch Log-group.
         */
        logStreamNamePrefix?: pulumi.Input<string>;
        /**
         * The specific log-streams which need to be uploaded to CloudWatch.
         */
        logTypeMap?: pulumi.Input<pulumi.Input<inputs.emrserverless.ApplicationLogTypeMapKeyValuePairArgs>[]>;
    }
    /**
     * Configuration for a JobRun.
     */
    interface ApplicationConfigurationObjectArgs {
        /**
         * String with a maximum length of 1024.
         */
        classification: pulumi.Input<string>;
        configurations?: pulumi.Input<pulumi.Input<inputs.emrserverless.ApplicationConfigurationObjectArgs>[]>;
        properties?: pulumi.Input<{
            [key: string]: pulumi.Input<string>;
        }>;
    }
    /**
     * The image configuration.
     */
    interface ApplicationImageConfigurationInputArgs {
        /**
         * The URI of an image in the Amazon ECR registry. This field is required when you create a new application. If you leave this field blank in an update, Amazon EMR will remove the image configuration.
         */
        imageUri?: pulumi.Input<string>;
    }
    interface ApplicationInitialCapacityConfigArgs {
        workerConfiguration: pulumi.Input<inputs.emrserverless.ApplicationWorkerConfigurationArgs>;
        /**
         * Initial count of workers to be initialized when an Application is started. This count will be continued to be maintained until the Application is stopped
         */
        workerCount: pulumi.Input<number>;
    }
    interface ApplicationInitialCapacityConfigKeyValuePairArgs {
        /**
         * Worker type for an analytics framework.
         */
        key: pulumi.Input<string>;
        value: pulumi.Input<inputs.emrserverless.ApplicationInitialCapacityConfigArgs>;
    }
    interface ApplicationInteractiveConfigurationArgs {
        /**
         * Enables an Apache Livy endpoint that you can connect to and run interactive jobs
         */
        livyEndpointEnabled?: pulumi.Input<boolean>;
        /**
         * Enabled you to connect an Application to Amazon EMR Studio to run interactive workloads in a notebook
         */
        studioEnabled?: pulumi.Input<boolean>;
    }
    interface ApplicationLogTypeMapKeyValuePairArgs {
        key: pulumi.Input<string>;
        value: pulumi.Input<pulumi.Input<string>[]>;
    }
    interface ApplicationManagedPersistenceMonitoringConfigurationArgs {
        /**
         * If set to false, managed logging will be turned off. Defaults to true.
         */
        enabled?: pulumi.Input<boolean>;
        /**
         * KMS key ARN to encrypt the logs stored in managed persistence
         */
        encryptionKeyArn?: pulumi.Input<string>;
    }
    interface ApplicationMaximumAllowedResourcesArgs {
        /**
         * Per worker CPU resource. vCPU is the only supported unit and specifying vCPU is optional.
         */
        cpu: pulumi.Input<string>;
        /**
         * Per worker Disk resource. GB is the only supported unit and specifying GB is optional
         */
        disk?: pulumi.Input<string>;
        /**
         * Per worker memory resource. GB is the only supported unit and specifying GB is optional.
         */
        memory: pulumi.Input<string>;
    }
    /**
     * Monitoring configuration for batch and interactive JobRun.
     */
    interface ApplicationMonitoringConfigurationArgs {
        /**
         * CloudWatch logging configurations for a JobRun.
         */
        cloudWatchLoggingConfiguration?: pulumi.Input<inputs.emrserverless.ApplicationCloudWatchLoggingConfigurationArgs>;
        /**
         * Managed log persistence configurations for a JobRun.
         */
        managedPersistenceMonitoringConfiguration?: pulumi.Input<inputs.emrserverless.ApplicationManagedPersistenceMonitoringConfigurationArgs>;
        /**
         * Prometheus monitoring configurations for a JobRun.
         */
        prometheusMonitoringConfiguration?: pulumi.Input<inputs.emrserverless.ApplicationPrometheusMonitoringConfigurationArgs>;
        /**
         * S3 monitoring configurations for a JobRun.
         */
        s3MonitoringConfiguration?: pulumi.Input<inputs.emrserverless.ApplicationS3MonitoringConfigurationArgs>;
    }
    interface ApplicationNetworkConfigurationArgs {
        /**
         * The ID of the security groups in the VPC to which you want to connect your job or application.
         */
        securityGroupIds?: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * The ID of the subnets in the VPC to which you want to connect your job or application.
         */
        subnetIds?: pulumi.Input<pulumi.Input<string>[]>;
    }
    interface ApplicationPrometheusMonitoringConfigurationArgs {
        /**
         * The remote write URL in the Amazon Managed Service for Prometheus workspace to send metrics to.
         */
        remoteWriteUrl?: pulumi.Input<string>;
    }
    interface ApplicationS3MonitoringConfigurationArgs {
        /**
         * KMS key ARN to encrypt the logs stored in given s3
         */
        encryptionKeyArn?: pulumi.Input<string>;
        logUri?: pulumi.Input<string>;
    }
    /**
     * The scheduler configuration for batch and streaming jobs running on this application. Supported with release labels emr-7.0.0 and above.
     */
    interface ApplicationSchedulerConfigurationArgs {
        /**
         * The maximum concurrent job runs on this application. If scheduler configuration is enabled on your application, the default value is 15. The valid range is 1 to 1000.
         */
        maxConcurrentRuns?: pulumi.Input<number>;
        /**
         * The maximum duration in minutes for the job in QUEUED state. If scheduler configuration is enabled on your application, the default value is 360 minutes (6 hours). The valid range is from 15 to 720.
         */
        queueTimeoutMinutes?: pulumi.Input<number>;
    }
    interface ApplicationWorkerConfigurationArgs {
        /**
         * Per worker CPU resource. vCPU is the only supported unit and specifying vCPU is optional.
         */
        cpu: pulumi.Input<string>;
        /**
         * Per worker Disk resource. GB is the only supported unit and specifying GB is optional
         */
        disk?: pulumi.Input<string>;
        /**
         * Per worker DiskType resource. Shuffle optimized and Standard are only supported types and specifying diskType is optional
         */
        diskType?: pulumi.Input<string>;
        /**
         * Per worker memory resource. GB is the only supported unit and specifying GB is optional.
         */
        memory: pulumi.Input<string>;
    }
    /**
     * The specifications for a worker type.
     */
    interface ApplicationWorkerTypeSpecificationInputArgs {
        /**
         * The image configuration for a worker type.
         */
        imageConfiguration?: pulumi.Input<inputs.emrserverless.ApplicationImageConfigurationInputArgs>;
    }
}
export declare namespace entityresolution {
    interface IdMappingWorkflowIdMappingRuleBasedPropertiesArgs {
        /**
         * The comparison type. You can either choose `ONE_TO_ONE` or `MANY_TO_MANY` as the `attributeMatchingModel` .
         *
         * If you choose `MANY_TO_MANY` , the system can match attributes across the sub-types of an attribute type. For example, if the value of the `Email` field of Profile A matches the value of the `BusinessEmail` field of Profile B, the two profiles are matched on the `Email` attribute type.
         *
         * If you choose `ONE_TO_ONE` , the system can only match attributes if the sub-types are an exact match. For example, for the `Email` attribute type, the system will only consider it a match if the value of the `Email` field of Profile A matches the value of the `Email` field of Profile B.
         */
        attributeMatchingModel: pulumi.Input<enums.entityresolution.IdMappingWorkflowIdMappingRuleBasedPropertiesAttributeMatchingModel>;
        /**
         * The type of matching record that is allowed to be used in an ID mapping workflow.
         *
         * If the value is set to `ONE_SOURCE_TO_ONE_TARGET` , only one record in the source can be matched to the same record in the target.
         *
         * If the value is set to `MANY_SOURCE_TO_ONE_TARGET` , multiple records in the source can be matched to one record in the target.
         */
        recordMatchingModel: pulumi.Input<enums.entityresolution.IdMappingWorkflowIdMappingRuleBasedPropertiesRecordMatchingModel>;
        /**
         * The set of rules you can use in an ID mapping workflow. The limitations specified for the source or target to define the match rules must be compatible.
         */
        ruleDefinitionType?: pulumi.Input<enums.entityresolution.IdMappingWorkflowIdMappingRuleBasedPropertiesRuleDefinitionType>;
        /**
         * The rules that can be used for ID mapping.
         */
        rules?: pulumi.Input<pulumi.Input<inputs.entityresolution.IdMappingWorkflowRuleArgs>[]>;
    }
    interface IdMappingWorkflowIdMappingTechniquesArgs {
        /**
         * The type of ID mapping.
         */
        idMappingType?: pulumi.Input<enums.entityresolution.IdMappingWorkflowIdMappingTechniquesIdMappingType>;
        /**
         * An object which defines any additional configurations required by the provider service.
         */
        providerProperties?: pulumi.Input<inputs.entityresolution.IdMappingWorkflowProviderPropertiesArgs>;
        /**
         * An object which defines any additional configurations required by rule-based matching.
         */
        ruleBasedProperties?: pulumi.Input<inputs.entityresolution.IdMappingWorkflowIdMappingRuleBasedPropertiesArgs>;
    }
    interface IdMappingWorkflowInputSourceArgs {
        /**
         * An Glue table ARN for the input source table, MatchingWorkflow arn or IdNamespace ARN
         */
        inputSourceArn: pulumi.Input<string>;
        /**
         * The ARN (Amazon Resource Name) that AWS Entity Resolution generated for the `SchemaMapping` .
         */
        schemaArn?: pulumi.Input<string>;
        /**
         * The type of ID namespace. There are two types: `SOURCE` and `TARGET` .
         *
         * The `SOURCE` contains configurations for `sourceId` data that will be processed in an ID mapping workflow.
         *
         * The `TARGET` contains a configuration of `targetId` which all `sourceIds` will resolve to.
         */
        type?: pulumi.Input<enums.entityresolution.IdMappingWorkflowInputSourceType>;
    }
    interface IdMappingWorkflowIntermediateSourceConfigurationArgs {
        /**
         * The s3 path that would be used to stage the intermediate data being generated during workflow execution.
         */
        intermediateS3Path: pulumi.Input<string>;
    }
    interface IdMappingWorkflowOutputSourceArgs {
        /**
         * Customer AWS KMS ARN for encryption at rest. If not provided, system will use an AWS Entity Resolution managed KMS key.
         */
        kmsArn?: pulumi.Input<string>;
        /**
         * The S3 path to which Entity Resolution will write the output table
         */
        outputS3Path: pulumi.Input<string>;
    }
    interface IdMappingWorkflowProviderPropertiesArgs {
        /**
         * The Amazon S3 location that temporarily stores your data while it processes. Your information won't be saved permanently.
         */
        intermediateSourceConfiguration?: pulumi.Input<inputs.entityresolution.IdMappingWorkflowIntermediateSourceConfigurationArgs>;
        /**
         * Additional Provider configuration that would be required for the provider service. The Configuration must be in JSON string format
         */
        providerConfiguration?: pulumi.Input<{
            [key: string]: pulumi.Input<string>;
        }>;
        /**
         * Arn of the Provider Service being used.
         */
        providerServiceArn: pulumi.Input<string>;
    }
    interface IdMappingWorkflowRuleArgs {
        /**
         * A list of `MatchingKeys` . The `MatchingKeys` must have been defined in the `SchemaMapping` . Two records are considered to match according to this rule if all of the `MatchingKeys` match.
         */
        matchingKeys: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * A name for the matching rule.
         */
        ruleName: pulumi.Input<string>;
    }
    interface IdNamespaceIdMappingWorkflowPropertiesArgs {
        /**
         * The type of ID mapping.
         */
        idMappingType: pulumi.Input<enums.entityresolution.IdNamespaceIdMappingWorkflowPropertiesIdMappingType>;
        /**
         * An object which defines any additional configurations required by the provider service.
         */
        providerProperties?: pulumi.Input<inputs.entityresolution.IdNamespaceNamespaceProviderPropertiesArgs>;
        /**
         * An object which defines any additional configurations required by rule-based matching.
         */
        ruleBasedProperties?: pulumi.Input<inputs.entityresolution.IdNamespaceNamespaceRuleBasedPropertiesArgs>;
    }
    interface IdNamespaceInputSourceArgs {
        /**
         * An AWS Glue table Amazon Resource Name (ARN) or a matching workflow ARN for the input source table.
         */
        inputSourceArn: pulumi.Input<string>;
        /**
         * The name of the schema.
         */
        schemaName?: pulumi.Input<string>;
    }
    interface IdNamespaceNamespaceProviderPropertiesArgs {
        /**
         * Additional Provider configuration that would be required for the provider service. The Configuration must be in JSON string format.
         */
        providerConfiguration?: pulumi.Input<{
            [key: string]: pulumi.Input<string>;
        }>;
        /**
         * The Amazon Resource Name (ARN) of the provider service.
         */
        providerServiceArn: pulumi.Input<string>;
    }
    interface IdNamespaceNamespaceRuleBasedPropertiesArgs {
        /**
         * The comparison type. You can either choose `ONE_TO_ONE` or `MANY_TO_MANY` as the `attributeMatchingModel` .
         *
         * If you choose `MANY_TO_MANY` , the system can match attributes across the sub-types of an attribute type. For example, if the value of the `Email` field of Profile A matches the value of `BusinessEmail` field of Profile B, the two profiles are matched on the `Email` attribute type.
         *
         * If you choose `ONE_TO_ONE` , the system can only match attributes if the sub-types are an exact match. For example, for the `Email` attribute type, the system will only consider it a match if the value of the `Email` field of Profile A matches the value of the `Email` field of Profile B.
         */
        attributeMatchingModel?: pulumi.Input<enums.entityresolution.IdNamespaceNamespaceRuleBasedPropertiesAttributeMatchingModel>;
        /**
         * The type of matching record that is allowed to be used in an ID mapping workflow.
         *
         * If the value is set to `ONE_SOURCE_TO_ONE_TARGET` , only one record in the source is matched to one record in the target.
         *
         * If the value is set to `MANY_SOURCE_TO_ONE_TARGET` , all matching records in the source are matched to one record in the target.
         */
        recordMatchingModels?: pulumi.Input<pulumi.Input<enums.entityresolution.IdNamespaceRecordMatchingModel>[]>;
        /**
         * The sets of rules you can use in an ID mapping workflow. The limitations specified for the source and target must be compatible.
         */
        ruleDefinitionTypes?: pulumi.Input<pulumi.Input<enums.entityresolution.IdNamespaceRuleDefinitionType>[]>;
        /**
         * The rules for the ID namespace.
         */
        rules?: pulumi.Input<pulumi.Input<inputs.entityresolution.IdNamespaceRuleArgs>[]>;
    }
    interface IdNamespaceRuleArgs {
        /**
         * A list of `MatchingKeys` . The `MatchingKeys` must have been defined in the `SchemaMapping` . Two records are considered to match according to this rule if all of the `MatchingKeys` match.
         */
        matchingKeys: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * A name for the matching rule.
         */
        ruleName: pulumi.Input<string>;
    }
    interface MatchingWorkflowIncrementalRunConfigArgs {
        /**
         * The type of incremental run. It takes only one value: `IMMEDIATE` .
         */
        incrementalRunType: pulumi.Input<enums.entityresolution.MatchingWorkflowIncrementalRunConfigIncrementalRunType>;
    }
    interface MatchingWorkflowInputSourceArgs {
        /**
         * Normalizes the attributes defined in the schema in the input data. For example, if an attribute has an `AttributeType` of `PHONE_NUMBER` , and the data in the input table is in a format of 1234567890, AWS Entity Resolution will normalize this field in the output to (123)-456-7890.
         */
        applyNormalization?: pulumi.Input<boolean>;
        /**
         * An Glue table ARN for the input source table
         */
        inputSourceArn: pulumi.Input<string>;
        /**
         * The name of the schema.
         */
        schemaArn: pulumi.Input<string>;
    }
    interface MatchingWorkflowIntermediateSourceConfigurationArgs {
        /**
         * The s3 path that would be used to stage the intermediate data being generated during workflow execution.
         */
        intermediateS3Path: pulumi.Input<string>;
    }
    interface MatchingWorkflowOutputAttributeArgs {
        /**
         * Enables the ability to hash the column values in the output.
         */
        hashed?: pulumi.Input<boolean>;
        /**
         * A name of a column to be written to the output. This must be an `InputField` name in the schema mapping.
         */
        name: pulumi.Input<string>;
    }
    interface MatchingWorkflowOutputSourceArgs {
        /**
         * Normalizes the attributes defined in the schema in the input data. For example, if an attribute has an `AttributeType` of `PHONE_NUMBER` , and the data in the input table is in a format of 1234567890, AWS Entity Resolution will normalize this field in the output to (123)-456-7890.
         */
        applyNormalization?: pulumi.Input<boolean>;
        /**
         * Customer KMS ARN for encryption at rest. If not provided, system will use an AWS Entity Resolution managed KMS key.
         */
        kmsArn?: pulumi.Input<string>;
        /**
         * A list of `OutputAttribute` objects, each of which have the fields `Name` and `Hashed` . Each of these objects selects a column to be included in the output table, and whether the values of the column should be hashed.
         */
        output: pulumi.Input<pulumi.Input<inputs.entityresolution.MatchingWorkflowOutputAttributeArgs>[]>;
        /**
         * The S3 path to which Entity Resolution will write the output table
         */
        outputS3Path: pulumi.Input<string>;
    }
    interface MatchingWorkflowProviderPropertiesArgs {
        /**
         * The Amazon S3 location that temporarily stores your data while it processes. Your information won't be saved permanently.
         */
        intermediateSourceConfiguration?: pulumi.Input<inputs.entityresolution.MatchingWorkflowIntermediateSourceConfigurationArgs>;
        /**
         * Additional Provider configuration that would be required for the provider service. The Configuration must be in JSON string format
         */
        providerConfiguration?: pulumi.Input<{
            [key: string]: pulumi.Input<string>;
        }>;
        /**
         * Arn of the Provider service being used.
         */
        providerServiceArn: pulumi.Input<string>;
    }
    interface MatchingWorkflowResolutionTechniquesArgs {
        /**
         * The properties of the provider service.
         */
        providerProperties?: pulumi.Input<inputs.entityresolution.MatchingWorkflowProviderPropertiesArgs>;
        /**
         * The type of matching. There are three types of matching: `RULE_MATCHING` , `ML_MATCHING` , and `PROVIDER` .
         */
        resolutionType?: pulumi.Input<enums.entityresolution.MatchingWorkflowResolutionType>;
        /**
         * An object which defines the list of matching rules to run and has a field `Rules` , which is a list of rule objects.
         */
        ruleBasedProperties?: pulumi.Input<inputs.entityresolution.MatchingWorkflowRuleBasedPropertiesArgs>;
    }
    interface MatchingWorkflowRuleArgs {
        /**
         * A list of `MatchingKeys` . The `MatchingKeys` must have been defined in the `SchemaMapping` . Two records are considered to match according to this rule if all of the `MatchingKeys` match.
         */
        matchingKeys: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * A name for the matching rule.
         */
        ruleName: pulumi.Input<string>;
    }
    interface MatchingWorkflowRuleBasedPropertiesArgs {
        /**
         * The comparison type. You can either choose `ONE_TO_ONE` or `MANY_TO_MANY` as the `attributeMatchingModel` .
         *
         * If you choose `MANY_TO_MANY` , the system can match attributes across the sub-types of an attribute type. For example, if the value of the `Email` field of Profile A and the value of `BusinessEmail` field of Profile B matches, the two profiles are matched on the `Email` attribute type.
         *
         * If you choose `ONE_TO_ONE` , the system can only match attributes if the sub-types are an exact match. For example, for the `Email` attribute type, the system will only consider it a match if the value of the `Email` field of Profile A matches the value of the `Email` field of Profile B.
         */
        attributeMatchingModel: pulumi.Input<enums.entityresolution.MatchingWorkflowRuleBasedPropertiesAttributeMatchingModel>;
        /**
         * An indicator of whether to generate IDs and index the data or not.
         *
         * If you choose `IDENTIFIER_GENERATION` , the process generates IDs and indexes the data.
         *
         * If you choose `INDEXING` , the process indexes the data without generating IDs.
         */
        matchPurpose?: pulumi.Input<enums.entityresolution.MatchingWorkflowRuleBasedPropertiesMatchPurpose>;
        /**
         * A list of `Rule` objects, each of which have fields `RuleName` and `MatchingKeys` .
         */
        rules: pulumi.Input<pulumi.Input<inputs.entityresolution.MatchingWorkflowRuleArgs>[]>;
    }
    interface SchemaMappingSchemaInputAttributeArgs {
        fieldName: pulumi.Input<string>;
        groupName?: pulumi.Input<string>;
        hashed?: pulumi.Input<boolean>;
        matchKey?: pulumi.Input<string>;
        /**
         * The subtype of the Attribute. Would be required only when type is PROVIDER_ID
         */
        subType?: pulumi.Input<string>;
        type: pulumi.Input<enums.entityresolution.SchemaMappingSchemaAttributeType>;
    }
}
export declare namespace events {
    interface ConnectionApiKeyAuthParametersArgs {
        /**
         * The name of the API key to use for authorization.
         */
        apiKeyName: pulumi.Input<string>;
        /**
         * The value for the API key to use for authorization.
         */
        apiKeyValue: pulumi.Input<string>;
    }
    interface ConnectionAuthParametersArgs {
        /**
         * The API Key parameters to use for authorization.
         */
        apiKeyAuthParameters?: pulumi.Input<inputs.events.ConnectionApiKeyAuthParametersArgs>;
        /**
         * The authorization parameters for Basic authorization.
         */
        basicAuthParameters?: pulumi.Input<inputs.events.ConnectionBasicAuthParametersArgs>;
        /**
         * For private OAuth authentication endpoints. The parameters EventBridge uses to authenticate against the endpoint.
         *
         * For more information, see [Authorization methods for connections](https://docs.aws.amazon.com/eventbridge/latest/userguide/eb-target-connection-auth.html) in the **Amazon EventBridge User Guide** .
         */
        connectivityParameters?: pulumi.Input<inputs.events.ConnectionConnectivityParametersArgs>;
        /**
         * Additional parameters for the connection that are passed through with every invocation to the HTTP endpoint.
         */
        invocationHttpParameters?: pulumi.Input<inputs.events.ConnectionHttpParametersArgs>;
        /**
         * The OAuth parameters to use for authorization.
         */
        oAuthParameters?: pulumi.Input<inputs.events.ConnectionOAuthParametersArgs>;
    }
    interface ConnectionBasicAuthParametersArgs {
        /**
         * The password associated with the user name to use for Basic authorization.
         */
        password: pulumi.Input<string>;
        /**
         * The user name to use for Basic authorization.
         */
        username: pulumi.Input<string>;
    }
    interface ConnectionClientParametersArgs {
        /**
         * The client ID to use for OAuth authorization.
         */
        clientId: pulumi.Input<string>;
        /**
         * The client secret assciated with the client ID to use for OAuth authorization.
         */
        clientSecret: pulumi.Input<string>;
    }
    interface ConnectionConnectivityParametersArgs {
        /**
         * The parameters for EventBridge to use when invoking the resource endpoint.
         */
        resourceParameters: pulumi.Input<inputs.events.ConnectionResourceParametersArgs>;
    }
    interface ConnectionHttpParametersArgs {
        /**
         * Any additional body string parameters for the connection.
         */
        bodyParameters?: pulumi.Input<pulumi.Input<inputs.events.ConnectionParameterArgs>[]>;
        /**
         * Any additional header parameters for the connection.
         */
        headerParameters?: pulumi.Input<pulumi.Input<inputs.events.ConnectionParameterArgs>[]>;
        /**
         * Any additional query string parameters for the connection.
         */
        queryStringParameters?: pulumi.Input<pulumi.Input<inputs.events.ConnectionParameterArgs>[]>;
    }
    interface ConnectionOAuthParametersArgs {
        /**
         * The URL to the authorization endpoint when OAuth is specified as the authorization type.
         */
        authorizationEndpoint: pulumi.Input<string>;
        /**
         * The client parameters for OAuth authorization.
         */
        clientParameters: pulumi.Input<inputs.events.ConnectionClientParametersArgs>;
        /**
         * The method to use for the authorization request.
         */
        httpMethod: pulumi.Input<enums.events.ConnectionOAuthParametersHttpMethod>;
        /**
         * Details about the additional parameters to use for the connection.
         */
        oAuthHttpParameters?: pulumi.Input<inputs.events.ConnectionHttpParametersArgs>;
    }
    interface ConnectionParameterArgs {
        /**
         * Specifies whether the value is secret.
         */
        isValueSecret?: pulumi.Input<boolean>;
        /**
         * The key for a query string parameter.
         */
        key: pulumi.Input<string>;
        /**
         * The value associated with the key for the query string parameter.
         */
        value: pulumi.Input<string>;
    }
    interface ConnectionResourceParametersArgs {
        /**
         * For connections to private APIs, the Amazon Resource Name (ARN) of the resource association EventBridge created between the connection and the private API's resource configuration.
         *
         * > The value of this property is set by EventBridge . Any value you specify in your template is ignored.
         */
        resourceAssociationArn?: pulumi.Input<string>;
        /**
         * The Amazon Resource Name (ARN) of the Amazon VPC Lattice resource configuration for the resource endpoint.
         */
        resourceConfigurationArn: pulumi.Input<string>;
    }
    /**
     * Dead Letter Queue for the event bus.
     */
    interface DeadLetterConfigPropertiesArgs {
        /**
         * The ARN of the SQS queue specified as the target for the dead-letter queue.
         */
        arn?: pulumi.Input<string>;
    }
    interface EndpointEventBusArgs {
        eventBusArn: pulumi.Input<string>;
    }
    interface EndpointFailoverConfigArgs {
        /**
         * The main Region of the endpoint.
         */
        primary: pulumi.Input<inputs.events.EndpointPrimaryArgs>;
        /**
         * The Region that events are routed to when failover is triggered or event replication is enabled.
         */
        secondary: pulumi.Input<inputs.events.EndpointSecondaryArgs>;
    }
    interface EndpointPrimaryArgs {
        /**
         * The ARN of the health check used by the endpoint to determine whether failover is triggered.
         */
        healthCheck: pulumi.Input<string>;
    }
    interface EndpointReplicationConfigArgs {
        /**
         * The state of event replication.
         */
        state: pulumi.Input<enums.events.EndpointReplicationState>;
    }
    interface EndpointRoutingConfigArgs {
        /**
         * The failover configuration for an endpoint. This includes what triggers failover and what happens when it's triggered.
         */
        failoverConfig: pulumi.Input<inputs.events.EndpointFailoverConfigArgs>;
    }
    interface EndpointSecondaryArgs {
        /**
         * Defines the secondary Region.
         */
        route: pulumi.Input<string>;
    }
    /**
     * The private resource the HTTP request will be sent to.
     */
    interface InvocationConnectivityParametersPropertiesArgs {
        /**
         * The parameters for EventBridge to use when invoking the resource endpoint.
         */
        resourceParameters: pulumi.Input<inputs.events.ConnectionResourceParametersArgs>;
    }
    interface RuleAppSyncParametersArgs {
        /**
         * The GraphQL operation; that is, the query, mutation, or subscription to be parsed and executed by the GraphQL service.
         *
         * For more information, see [Operations](https://docs.aws.amazon.com/appsync/latest/devguide/graphql-architecture.html#graphql-operations) in the *AWS AppSync User Guide* .
         */
        graphQlOperation: pulumi.Input<string>;
    }
    interface RuleAwsVpcConfigurationArgs {
        /**
         * Specifies whether the task's elastic network interface receives a public IP address. You can specify `ENABLED` only when `LaunchType` in `EcsParameters` is set to `FARGATE` .
         */
        assignPublicIp?: pulumi.Input<string>;
        /**
         * Specifies the security groups associated with the task. These security groups must all be in the same VPC. You can specify as many as five security groups. If you do not specify a security group, the default security group for the VPC is used.
         */
        securityGroups?: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * Specifies the subnets associated with the task. These subnets must all be in the same VPC. You can specify as many as 16 subnets.
         */
        subnets: pulumi.Input<pulumi.Input<string>[]>;
    }
    interface RuleBatchArrayPropertiesArgs {
        /**
         * The size of the array, if this is an array batch job. Valid values are integers between 2 and 10,000.
         */
        size?: pulumi.Input<number>;
    }
    interface RuleBatchParametersArgs {
        /**
         * The array properties for the submitted job, such as the size of the array. The array size can be between 2 and 10,000. If you specify array properties for a job, it becomes an array job. This parameter is used only if the target is an AWS Batch job.
         */
        arrayProperties?: pulumi.Input<inputs.events.RuleBatchArrayPropertiesArgs>;
        /**
         * The ARN or name of the job definition to use if the event target is an AWS Batch job. This job definition must already exist.
         */
        jobDefinition: pulumi.Input<string>;
        /**
         * The name to use for this execution of the job, if the target is an AWS Batch job.
         */
        jobName: pulumi.Input<string>;
        /**
         * The retry strategy to use for failed jobs, if the target is an AWS Batch job. The retry strategy is the number of times to retry the failed job execution. Valid values are 1–10. When you specify a retry strategy here, it overrides the retry strategy defined in the job definition.
         */
        retryStrategy?: pulumi.Input<inputs.events.RuleBatchRetryStrategyArgs>;
    }
    interface RuleBatchRetryStrategyArgs {
        /**
         * The number of times to attempt to retry, if the job fails. Valid values are 1–10.
         */
        attempts?: pulumi.Input<number>;
    }
    interface RuleCapacityProviderStrategyItemArgs {
        /**
         * The base value designates how many tasks, at a minimum, to run on the specified capacity provider. Only one capacity provider in a capacity provider strategy can have a base defined. If no value is specified, the default value of 0 is used.
         */
        base?: pulumi.Input<number>;
        /**
         * The short name of the capacity provider.
         */
        capacityProvider: pulumi.Input<string>;
        /**
         * The weight value designates the relative percentage of the total number of tasks launched that should use the specified capacity provider. The weight value is taken into consideration after the base value, if defined, is satisfied.
         */
        weight?: pulumi.Input<number>;
    }
    interface RuleDeadLetterConfigArgs {
        /**
         * The ARN of the SQS queue specified as the target for the dead-letter queue.
         */
        arn?: pulumi.Input<string>;
    }
    interface RuleEcsParametersArgs {
        /**
         * The capacity provider strategy to use for the task.
         *
         * If a `capacityProviderStrategy` is specified, the `launchType` parameter must be omitted. If no `capacityProviderStrategy` or launchType is specified, the `defaultCapacityProviderStrategy` for the cluster is used.
         */
        capacityProviderStrategy?: pulumi.Input<pulumi.Input<inputs.events.RuleCapacityProviderStrategyItemArgs>[]>;
        /**
         * Specifies whether to enable Amazon ECS managed tags for the task. For more information, see [Tagging Your Amazon ECS Resources](https://docs.aws.amazon.com/AmazonECS/latest/developerguide/ecs-using-tags.html) in the Amazon Elastic Container Service Developer Guide.
         */
        enableEcsManagedTags?: pulumi.Input<boolean>;
        /**
         * Whether or not to enable the execute command functionality for the containers in this task. If true, this enables execute command functionality on all containers in the task.
         */
        enableExecuteCommand?: pulumi.Input<boolean>;
        /**
         * Specifies an ECS task group for the task. The maximum length is 255 characters.
         */
        group?: pulumi.Input<string>;
        /**
         * Specifies the launch type on which your task is running. The launch type that you specify here must match one of the launch type (compatibilities) of the target task. The `FARGATE` value is supported only in the Regions where AWS Fargate with Amazon ECS is supported. For more information, see [AWS Fargate on Amazon ECS](https://docs.aws.amazon.com/AmazonECS/latest/developerguide/AWS-Fargate.html) in the *Amazon Elastic Container Service Developer Guide* .
         */
        launchType?: pulumi.Input<string>;
        /**
         * Use this structure if the Amazon ECS task uses the `awsvpc` network mode. This structure specifies the VPC subnets and security groups associated with the task, and whether a public IP address is to be used. This structure is required if `LaunchType` is `FARGATE` because the `awsvpc` mode is required for Fargate tasks.
         *
         * If you specify `NetworkConfiguration` when the target ECS task does not use the `awsvpc` network mode, the task fails.
         */
        networkConfiguration?: pulumi.Input<inputs.events.RuleNetworkConfigurationArgs>;
        /**
         * An array of placement constraint objects to use for the task. You can specify up to 10 constraints per task (including constraints in the task definition and those specified at runtime).
         */
        placementConstraints?: pulumi.Input<pulumi.Input<inputs.events.RulePlacementConstraintArgs>[]>;
        /**
         * The placement strategy objects to use for the task. You can specify a maximum of five strategy rules per task.
         */
        placementStrategies?: pulumi.Input<pulumi.Input<inputs.events.RulePlacementStrategyArgs>[]>;
        /**
         * Specifies the platform version for the task. Specify only the numeric portion of the platform version, such as `1.1.0` .
         *
         * This structure is used only if `LaunchType` is `FARGATE` . For more information about valid platform versions, see [AWS Fargate Platform Versions](https://docs.aws.amazon.com/AmazonECS/latest/developerguide/platform_versions.html) in the *Amazon Elastic Container Service Developer Guide* .
         */
        platformVersion?: pulumi.Input<string>;
        /**
         * Specifies whether to propagate the tags from the task definition to the task. If no value is specified, the tags are not propagated. Tags can only be propagated to the task during task creation. To add tags to a task after task creation, use the TagResource API action.
         */
        propagateTags?: pulumi.Input<string>;
        /**
         * The reference ID to use for the task.
         */
        referenceId?: pulumi.Input<string>;
        /**
         * The metadata that you apply to the task to help you categorize and organize them. Each tag consists of a key and an optional value, both of which you define. To learn more, see [RunTask](https://docs.aws.amazon.com/AmazonECS/latest/APIReference/API_RunTask.html#ECS-RunTask-request-tags) in the Amazon ECS API Reference.
         */
        tagList?: pulumi.Input<pulumi.Input<inputs.events.RuleTagArgs>[]>;
        /**
         * The number of tasks to create based on `TaskDefinition` . The default is 1.
         */
        taskCount?: pulumi.Input<number>;
        /**
         * The ARN of the task definition to use if the event target is an Amazon ECS task.
         */
        taskDefinitionArn: pulumi.Input<string>;
    }
    interface RuleHttpParametersArgs {
        /**
         * The headers that need to be sent as part of request invoking the API Gateway API or EventBridge ApiDestination.
         */
        headerParameters?: pulumi.Input<{
            [key: string]: pulumi.Input<string>;
        }>;
        /**
         * The path parameter values to be used to populate API Gateway API or EventBridge ApiDestination path wildcards ("*").
         */
        pathParameterValues?: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * The query string keys/values that need to be sent as part of request invoking the API Gateway API or EventBridge ApiDestination.
         */
        queryStringParameters?: pulumi.Input<{
            [key: string]: pulumi.Input<string>;
        }>;
    }
    interface RuleInputTransformerArgs {
        /**
         * Map of JSON paths to be extracted from the event. You can then insert these in the template in `InputTemplate` to produce the output you want to be sent to the target.
         *
         * `InputPathsMap` is an array key-value pairs, where each value is a valid JSON path. You can have as many as 100 key-value pairs. You must use JSON dot notation, not bracket notation.
         *
         * The keys cannot start with " AWS ."
         */
        inputPathsMap?: pulumi.Input<{
            [key: string]: pulumi.Input<string>;
        }>;
        /**
         * Input template where you specify placeholders that will be filled with the values of the keys from `InputPathsMap` to customize the data sent to the target. Enclose each `InputPathsMaps` value in brackets: < *value* >
         *
         * If `InputTemplate` is a JSON object (surrounded by curly braces), the following restrictions apply:
         *
         * - The placeholder cannot be used as an object key.
         *
         * The following example shows the syntax for using `InputPathsMap` and `InputTemplate` .
         *
         * `"InputTransformer":`
         *
         * `{`
         *
         * `"InputPathsMap": {"instance": "$.detail.instance","status": "$.detail.status"},`
         *
         * `"InputTemplate": "<instance> is in state <status>"`
         *
         * `}`
         *
         * To have the `InputTemplate` include quote marks within a JSON string, escape each quote marks with a slash, as in the following example:
         *
         * `"InputTransformer":`
         *
         * `{`
         *
         * `"InputPathsMap": {"instance": "$.detail.instance","status": "$.detail.status"},`
         *
         * `"InputTemplate": "<instance> is in state \"<status>\""`
         *
         * `}`
         *
         * The `InputTemplate` can also be valid JSON with varibles in quotes or out, as in the following example:
         *
         * `"InputTransformer":`
         *
         * `{`
         *
         * `"InputPathsMap": {"instance": "$.detail.instance","status": "$.detail.status"},`
         *
         * `"InputTemplate": '{"myInstance": <instance>,"myStatus": "<instance> is in state \"<status>\""}'`
         *
         * `}`
         */
        inputTemplate: pulumi.Input<string>;
    }
    interface RuleKinesisParametersArgs {
        /**
         * The JSON path to be extracted from the event and used as the partition key. For more information, see [Amazon Kinesis Streams Key Concepts](https://docs.aws.amazon.com/streams/latest/dev/key-concepts.html#partition-key) in the *Amazon Kinesis Streams Developer Guide* .
         */
        partitionKeyPath: pulumi.Input<string>;
    }
    interface RuleNetworkConfigurationArgs {
        /**
         * Use this structure to specify the VPC subnets and security groups for the task, and whether a public IP address is to be used. This structure is relevant only for ECS tasks that use the `awsvpc` network mode.
         */
        awsVpcConfiguration?: pulumi.Input<inputs.events.RuleAwsVpcConfigurationArgs>;
    }
    interface RulePlacementConstraintArgs {
        /**
         * A cluster query language expression to apply to the constraint. You cannot specify an expression if the constraint type is `distinctInstance` . To learn more, see [Cluster Query Language](https://docs.aws.amazon.com/AmazonECS/latest/developerguide/cluster-query-language.html) in the Amazon Elastic Container Service Developer Guide.
         */
        expression?: pulumi.Input<string>;
        /**
         * The type of constraint. Use distinctInstance to ensure that each task in a particular group is running on a different container instance. Use memberOf to restrict the selection to a group of valid candidates.
         */
        type?: pulumi.Input<string>;
    }
    interface RulePlacementStrategyArgs {
        /**
         * The field to apply the placement strategy against. For the spread placement strategy, valid values are instanceId (or host, which has the same effect), or any platform or custom attribute that is applied to a container instance, such as attribute:ecs.availability-zone. For the binpack placement strategy, valid values are cpu and memory. For the random placement strategy, this field is not used.
         */
        field?: pulumi.Input<string>;
        /**
         * The type of placement strategy. The random placement strategy randomly places tasks on available candidates. The spread placement strategy spreads placement across available candidates evenly based on the field parameter. The binpack strategy places tasks on available candidates that have the least available amount of the resource that is specified with the field parameter. For example, if you binpack on memory, a task is placed on the instance with the least amount of remaining memory (but still enough to run the task).
         */
        type?: pulumi.Input<string>;
    }
    interface RuleRedshiftDataParametersArgs {
        /**
         * The name of the database. Required when authenticating using temporary credentials.
         */
        database: pulumi.Input<string>;
        /**
         * The database user name. Required when authenticating using temporary credentials.
         */
        dbUser?: pulumi.Input<string>;
        /**
         * The name or ARN of the secret that enables access to the database. Required when authenticating using AWS Secrets Manager.
         */
        secretManagerArn?: pulumi.Input<string>;
        /**
         * The SQL statement text to run.
         */
        sql?: pulumi.Input<string>;
        /**
         * One or more SQL statements to run. The SQL statements are run as a single transaction. They run serially in the order of the array. Subsequent SQL statements don't start until the previous statement in the array completes. If any SQL statement fails, then because they are run as one transaction, all work is rolled back.
         */
        sqls?: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * The name of the SQL statement. You can name the SQL statement when you create it to identify the query.
         */
        statementName?: pulumi.Input<string>;
        /**
         * Indicates whether to send an event back to EventBridge after the SQL statement runs.
         */
        withEvent?: pulumi.Input<boolean>;
    }
    interface RuleRetryPolicyArgs {
        /**
         * The maximum amount of time, in seconds, to continue to make retry attempts.
         */
        maximumEventAgeInSeconds?: pulumi.Input<number>;
        /**
         * The maximum number of retry attempts to make before the request fails. Retry attempts continue until either the maximum number of attempts is made or until the duration of the `MaximumEventAgeInSeconds` is met.
         */
        maximumRetryAttempts?: pulumi.Input<number>;
    }
    interface RuleRunCommandParametersArgs {
        /**
         * Currently, we support including only one RunCommandTarget block, which specifies either an array of InstanceIds or a tag.
         */
        runCommandTargets: pulumi.Input<pulumi.Input<inputs.events.RuleRunCommandTargetArgs>[]>;
    }
    interface RuleRunCommandTargetArgs {
        /**
         * Can be either `tag:` *tag-key* or `InstanceIds` .
         */
        key: pulumi.Input<string>;
        /**
         * If `Key` is `tag:` *tag-key* , `Values` is a list of tag values. If `Key` is `InstanceIds` , `Values` is a list of Amazon EC2 instance IDs.
         */
        values: pulumi.Input<pulumi.Input<string>[]>;
    }
    interface RuleSageMakerPipelineParameterArgs {
        /**
         * Name of parameter to start execution of a SageMaker AI Model Building Pipeline.
         */
        name: pulumi.Input<string>;
        /**
         * Value of parameter to start execution of a SageMaker AI Model Building Pipeline.
         */
        value: pulumi.Input<string>;
    }
    interface RuleSageMakerPipelineParametersArgs {
        /**
         * List of Parameter names and values for SageMaker AI Model Building Pipeline execution.
         */
        pipelineParameterList?: pulumi.Input<pulumi.Input<inputs.events.RuleSageMakerPipelineParameterArgs>[]>;
    }
    interface RuleSqsParametersArgs {
        /**
         * The FIFO message group ID to use as the target.
         */
        messageGroupId: pulumi.Input<string>;
    }
    interface RuleTagArgs {
        /**
         * A string you can use to assign a value. The combination of tag keys and values can help you organize and categorize your resources.
         */
        key?: pulumi.Input<string>;
        /**
         * The value for the specified tag key.
         */
        value?: pulumi.Input<string>;
    }
    interface RuleTargetArgs {
        /**
         * Contains the GraphQL operation to be parsed and executed, if the event target is an AWS AppSync API.
         */
        appSyncParameters?: pulumi.Input<inputs.events.RuleAppSyncParametersArgs>;
        /**
         * The Amazon Resource Name (ARN) of the target.
         */
        arn: pulumi.Input<string>;
        /**
         * If the event target is an AWS Batch job, this contains the job definition, job name, and other parameters. For more information, see [Jobs](https://docs.aws.amazon.com/batch/latest/userguide/jobs.html) in the *AWS Batch User Guide* .
         */
        batchParameters?: pulumi.Input<inputs.events.RuleBatchParametersArgs>;
        /**
         * The `DeadLetterConfig` that defines the target queue to send dead-letter queue events to.
         */
        deadLetterConfig?: pulumi.Input<inputs.events.RuleDeadLetterConfigArgs>;
        /**
         * Contains the Amazon ECS task definition and task count to be used, if the event target is an Amazon ECS task. For more information about Amazon ECS tasks, see [Task Definitions](https://docs.aws.amazon.com/AmazonECS/latest/developerguide/task_defintions.html) in the *Amazon EC2 Container Service Developer Guide* .
         */
        ecsParameters?: pulumi.Input<inputs.events.RuleEcsParametersArgs>;
        /**
         * Contains the HTTP parameters to use when the target is a API Gateway endpoint or EventBridge ApiDestination.
         *
         * If you specify an API Gateway API or EventBridge ApiDestination as a target, you can use this parameter to specify headers, path parameters, and query string keys/values as part of your target invoking request. If you're using ApiDestinations, the corresponding Connection can also have these values configured. In case of any conflicting keys, values from the Connection take precedence.
         */
        httpParameters?: pulumi.Input<inputs.events.RuleHttpParametersArgs>;
        /**
         * The ID of the target within the specified rule. Use this ID to reference the target when updating the rule. We recommend using a memorable and unique string.
         */
        id: pulumi.Input<string>;
        /**
         * Valid JSON text passed to the target. In this case, nothing from the event itself is passed to the target. For more information, see [The JavaScript Object Notation (JSON) Data Interchange Format](https://docs.aws.amazon.com/http://www.rfc-editor.org/rfc/rfc7159.txt) .
         */
        input?: pulumi.Input<string>;
        /**
         * The value of the JSONPath that is used for extracting part of the matched event when passing it to the target. You may use JSON dot notation or bracket notation. For more information about JSON paths, see [JSONPath](https://docs.aws.amazon.com/http://goessner.net/articles/JsonPath/) .
         */
        inputPath?: pulumi.Input<string>;
        /**
         * Settings to enable you to provide custom input to a target based on certain event data. You can extract one or more key-value pairs from the event and then use that data to send customized input to the target.
         */
        inputTransformer?: pulumi.Input<inputs.events.RuleInputTransformerArgs>;
        /**
         * The custom parameter you can use to control the shard assignment, when the target is a Kinesis data stream. If you do not include this parameter, the default is to use the `eventId` as the partition key.
         */
        kinesisParameters?: pulumi.Input<inputs.events.RuleKinesisParametersArgs>;
        /**
         * Contains the Amazon Redshift Data API parameters to use when the target is a Amazon Redshift cluster.
         *
         * If you specify a Amazon Redshift Cluster as a Target, you can use this to specify parameters to invoke the Amazon Redshift Data API ExecuteStatement based on EventBridge events.
         */
        redshiftDataParameters?: pulumi.Input<inputs.events.RuleRedshiftDataParametersArgs>;
        /**
         * The retry policy configuration to use for the dead-letter queue.
         */
        retryPolicy?: pulumi.Input<inputs.events.RuleRetryPolicyArgs>;
        /**
         * The Amazon Resource Name (ARN) of the IAM role to be used for this target when the rule is triggered. If one rule triggers multiple targets, you can use a different IAM role for each target.
         */
        roleArn?: pulumi.Input<string>;
        /**
         * Parameters used when you are using the rule to invoke Amazon EC2 Run Command.
         */
        runCommandParameters?: pulumi.Input<inputs.events.RuleRunCommandParametersArgs>;
        /**
         * Contains the SageMaker AI Model Building Pipeline parameters to start execution of a SageMaker AI Model Building Pipeline.
         *
         * If you specify a SageMaker AI Model Building Pipeline as a target, you can use this to specify parameters to start a pipeline execution based on EventBridge events.
         */
        sageMakerPipelineParameters?: pulumi.Input<inputs.events.RuleSageMakerPipelineParametersArgs>;
        /**
         * Contains the message group ID to use when the target is a FIFO queue.
         *
         * If you specify an SQS FIFO queue as a target, the queue must have content-based deduplication enabled.
         */
        sqsParameters?: pulumi.Input<inputs.events.RuleSqsParametersArgs>;
    }
}
export declare namespace eventschemas {
}
export declare namespace evidently {
    interface ExperimentMetricGoalObjectArgs {
        /**
         * `INCREASE` means that a variation with a higher number for this metric is performing better.
         *
         * `DECREASE` means that a variation with a lower number for this metric is performing better.
         */
        desiredChange: pulumi.Input<enums.evidently.ExperimentMetricGoalObjectDesiredChange>;
        /**
         * The JSON path to reference the entity id in the event.
         */
        entityIdKey: pulumi.Input<string>;
        /**
         * Event patterns have the same structure as the events they match. Rules use event patterns to select events. An event pattern either matches an event or it doesn't.
         */
        eventPattern?: pulumi.Input<string>;
        /**
         * A name for the metric. It can include up to 255 characters.
         */
        metricName: pulumi.Input<string>;
        /**
         * A label for the units that the metric is measuring.
         */
        unitLabel?: pulumi.Input<string>;
        /**
         * The JSON path to reference the numerical metric value in the event.
         */
        valueKey: pulumi.Input<string>;
    }
    interface ExperimentOnlineAbConfigObjectArgs {
        /**
         * The name of the variation that is to be the default variation that the other variations are compared to.
         */
        controlTreatmentName?: pulumi.Input<string>;
        /**
         * A set of key-value pairs. The keys are treatment names, and the values are the portion of experiment traffic to be assigned to that treatment. Specify the traffic portion in thousandths of a percent, so 20,000 for a variation would allocate 20% of the experiment traffic to that variation.
         */
        treatmentWeights?: pulumi.Input<pulumi.Input<inputs.evidently.ExperimentTreatmentToWeightArgs>[]>;
    }
    interface ExperimentRunningStatusObjectArgs {
        /**
         * Provide the analysis Completion time for an experiment
         */
        analysisCompleteTime?: pulumi.Input<string>;
        /**
         * Provide CANCELLED or COMPLETED desired state when stopping an experiment
         */
        desiredState?: pulumi.Input<string>;
        /**
         * Reason is a required input for stopping the experiment
         */
        reason?: pulumi.Input<string>;
        /**
         * Provide START or STOP action to apply on an experiment
         */
        status?: pulumi.Input<string>;
    }
    interface ExperimentTreatmentObjectArgs {
        /**
         * The description of the treatment.
         */
        description?: pulumi.Input<string>;
        /**
         * The name of the feature for this experiment.
         */
        feature: pulumi.Input<string>;
        /**
         * A name for this treatment. It can include up to 127 characters.
         */
        treatmentName: pulumi.Input<string>;
        /**
         * The name of the variation to use for this treatment.
         */
        variation: pulumi.Input<string>;
    }
    interface ExperimentTreatmentToWeightArgs {
        /**
         * The portion of experiment traffic to allocate to this treatment. Specify the traffic portion in thousandths of a percent, so 20,000 allocated to a treatment would allocate 20% of the experiment traffic to that treatment.
         */
        splitWeight: pulumi.Input<number>;
        /**
         * The name of the treatment.
         */
        treatment: pulumi.Input<string>;
    }
    interface FeatureEntityOverrideArgs {
        /**
         * The entity ID to be served the variation specified in `Variation` .
         */
        entityId?: pulumi.Input<string>;
        /**
         * The name of the variation to serve to the user session that matches the `EntityId` .
         */
        variation?: pulumi.Input<string>;
    }
    interface FeatureVariationObjectArgs {
        /**
         * The value assigned to this variation, if the variation type is boolean.
         */
        booleanValue?: pulumi.Input<boolean>;
        /**
         * The value assigned to this variation, if the variation type is a double.
         */
        doubleValue?: pulumi.Input<number>;
        /**
         * The value assigned to this variation, if the variation type is a long.
         */
        longValue?: pulumi.Input<number>;
        /**
         * The value assigned to this variation, if the variation type is a string.
         */
        stringValue?: pulumi.Input<string>;
        /**
         * A name for the variation. It can include up to 127 characters.
         */
        variationName?: pulumi.Input<string>;
    }
    interface LaunchExecutionStatusObjectArgs {
        /**
         * Provide CANCELLED or COMPLETED as the launch desired state. Defaults to Completed if not provided.
         */
        desiredState?: pulumi.Input<string>;
        /**
         * Provide a reason for stopping the launch. Defaults to empty if not provided.
         */
        reason?: pulumi.Input<string>;
        /**
         * Provide START or STOP action to apply on a launch
         */
        status: pulumi.Input<string>;
    }
    interface LaunchGroupObjectArgs {
        /**
         * A description of the launch group.
         */
        description?: pulumi.Input<string>;
        /**
         * The feature that this launch is using.
         */
        feature: pulumi.Input<string>;
        /**
         * A name for this launch group. It can include up to 127 characters.
         */
        groupName: pulumi.Input<string>;
        /**
         * The feature variation to use for this launch group.
         */
        variation: pulumi.Input<string>;
    }
    interface LaunchGroupToWeightArgs {
        /**
         * The name of the launch group. It can include up to 127 characters.
         */
        groupName: pulumi.Input<string>;
        /**
         * The portion of launch traffic to allocate to this launch group.
         *
         * This is represented in thousandths of a percent. For example, specify 20,000 to allocate 20% of the launch audience to this launch group.
         */
        splitWeight: pulumi.Input<number>;
    }
    interface LaunchMetricDefinitionObjectArgs {
        /**
         * The JSON path to reference the entity id in the event.
         */
        entityIdKey: pulumi.Input<string>;
        /**
         * Event patterns have the same structure as the events they match. Rules use event patterns to select events. An event pattern either matches an event or it doesn't.
         */
        eventPattern?: pulumi.Input<string>;
        /**
         * A name for the metric. It can include up to 255 characters.
         */
        metricName: pulumi.Input<string>;
        /**
         * A label for the units that the metric is measuring.
         */
        unitLabel?: pulumi.Input<string>;
        /**
         * The JSON path to reference the numerical metric value in the event.
         */
        valueKey: pulumi.Input<string>;
    }
    interface LaunchSegmentOverrideArgs {
        /**
         * A number indicating the order to use to evaluate segment overrides, if there are more than one. Segment overrides with lower numbers are evaluated first.
         */
        evaluationOrder: pulumi.Input<number>;
        /**
         * The ARN of the segment to use for this override.
         */
        segment: pulumi.Input<string>;
        /**
         * The traffic allocation percentages among the feature variations to assign to this segment. This is a set of key-value pairs. The keys are variation names. The values represent the amount of traffic to allocate to that variation for this segment. This is expressed in thousandths of a percent, so a weight of 50000 represents 50% of traffic.
         */
        weights: pulumi.Input<pulumi.Input<inputs.evidently.LaunchGroupToWeightArgs>[]>;
    }
    interface LaunchStepConfigArgs {
        /**
         * An array of structures that define how much launch traffic to allocate to each launch group during this step of the launch.
         */
        groupWeights: pulumi.Input<pulumi.Input<inputs.evidently.LaunchGroupToWeightArgs>[]>;
        /**
         * An array of structures that you can use to specify different traffic splits for one or more audience *segments* . A segment is a portion of your audience that share one or more characteristics. Examples could be Chrome browser users, users in Europe, or Firefox browser users in Europe who also fit other criteria that your application collects, such as age.
         *
         * For more information, see [Use segments to focus your audience](https://docs.aws.amazon.com/AmazonCloudWatch/latest/monitoring/CloudWatch-Evidently-segments.html) .
         */
        segmentOverrides?: pulumi.Input<pulumi.Input<inputs.evidently.LaunchSegmentOverrideArgs>[]>;
        /**
         * The date and time to start this step of the launch. Use UTC format, `yyyy-MM-ddTHH:mm:ssZ` . For example, `2025-11-25T23:59:59Z`
         */
        startTime: pulumi.Input<string>;
    }
    interface ProjectAppConfigResourceObjectArgs {
        /**
         * The ID of the AWS AppConfig application to use for client-side evaluation.
         */
        applicationId: pulumi.Input<string>;
        /**
         * The ID of the AWS AppConfig environment to use for client-side evaluation.
         */
        environmentId: pulumi.Input<string>;
    }
    /**
     * Destinations for data.
     */
    interface ProjectDataDeliveryObjectArgs {
        /**
         * If the project stores evaluation events in CloudWatch Logs , this structure stores the log group name.
         */
        logGroup?: pulumi.Input<string>;
        /**
         * If the project stores evaluation events in an Amazon S3 bucket, this structure stores the bucket name and bucket prefix.
         */
        s3?: pulumi.Input<inputs.evidently.ProjectS3DestinationArgs>;
    }
    interface ProjectS3DestinationArgs {
        /**
         * The name of the bucket in which Evidently stores evaluation events.
         */
        bucketName: pulumi.Input<string>;
        /**
         * The bucket prefix in which Evidently stores evaluation events.
         */
        prefix?: pulumi.Input<string>;
    }
}
export declare namespace finspace {
    /**
     * Additional parameters to identify Federation mode
     */
    interface EnvironmentFederationParametersArgs {
        /**
         * SAML metadata URL to link with the Environment
         */
        applicationCallBackUrl?: pulumi.Input<string>;
        /**
         * Attribute map for SAML configuration
         */
        attributeMap?: pulumi.Input<pulumi.Input<inputs.finspace.EnvironmentFederationParametersAttributeMapItemPropertiesArgs>[]>;
        /**
         * Federation provider name to link with the Environment
         */
        federationProviderName?: pulumi.Input<string>;
        /**
         * SAML metadata URL to link with the Environment
         */
        federationUrn?: pulumi.Input<string>;
        /**
         * SAML metadata document to link the federation provider to the Environment
         */
        samlMetadataDocument?: pulumi.Input<string>;
        /**
         * SAML metadata URL to link with the Environment
         */
        samlMetadataUrl?: pulumi.Input<string>;
    }
    interface EnvironmentFederationParametersAttributeMapItemPropertiesArgs {
        /**
         * The key name of the tag. You can specify a value that is 1 to 128 Unicode characters in length and cannot be prefixed with aws:. You can use any of the following characters: the set of Unicode letters, digits, whitespace, _, ., /, =, +, and -.
         */
        key?: pulumi.Input<string>;
        /**
         * The value for the tag. You can specify a value that is 0 to 256 Unicode characters in length and cannot be prefixed with aws:. You can use any of the following characters: the set of Unicode letters, digits, whitespace, _, ., /, =, +, and -.
         */
        value?: pulumi.Input<string>;
    }
    /**
     * Parameters of the first Superuser for the FinSpace Environment
     */
    interface EnvironmentSuperuserParametersArgs {
        /**
         * Email address
         */
        emailAddress?: pulumi.Input<string>;
        /**
         * First name
         */
        firstName?: pulumi.Input<string>;
        /**
         * Last name
         */
        lastName?: pulumi.Input<string>;
    }
}
export declare namespace fis {
    /**
     * Specifies an action for the experiment template.
     */
    interface ExperimentTemplateActionArgs {
        /**
         * The ID of the action.
         */
        actionId: pulumi.Input<string>;
        /**
         * A description for the action.
         */
        description?: pulumi.Input<string>;
        /**
         * The parameters for the action, if applicable.
         */
        parameters?: pulumi.Input<{
            [key: string]: pulumi.Input<string>;
        }>;
        /**
         * The name of the action that must be completed before the current action starts.
         */
        startAfter?: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * One or more targets for the action.
         */
        targets?: pulumi.Input<{
            [key: string]: pulumi.Input<string>;
        }>;
    }
    interface ExperimentTemplateCloudWatchDashboardArgs {
        /**
         * The Amazon Resource Name (ARN) of the CloudWatch dashboard to include in the experiment report.
         */
        dashboardIdentifier: pulumi.Input<string>;
    }
    interface ExperimentTemplateExperimentOptionsArgs {
        /**
         * The account targeting setting for the experiment template.
         */
        accountTargeting?: pulumi.Input<enums.fis.ExperimentTemplateExperimentOptionsAccountTargeting>;
        /**
         * The target resolution failure mode for the experiment template.
         */
        emptyTargetResolutionMode?: pulumi.Input<enums.fis.ExperimentTemplateExperimentOptionsEmptyTargetResolutionMode>;
    }
    interface ExperimentTemplateExperimentReportConfigurationArgs {
        /**
         * The data sources for the experiment report.
         */
        dataSources?: pulumi.Input<inputs.fis.ExperimentTemplateExperimentReportConfigurationDataSourcesPropertiesArgs>;
        /**
         * The output destinations of the experiment report.
         */
        outputs: pulumi.Input<inputs.fis.ExperimentTemplateExperimentReportConfigurationOutputsPropertiesArgs>;
        /**
         * The duration after the experiment end time for the data sources to include in the report.
         */
        postExperimentDuration?: pulumi.Input<string>;
        /**
         * The duration before the experiment start time for the data sources to include in the report.
         */
        preExperimentDuration?: pulumi.Input<string>;
    }
    /**
     * The data sources for the experiment report.
     */
    interface ExperimentTemplateExperimentReportConfigurationDataSourcesPropertiesArgs {
        cloudWatchDashboards?: pulumi.Input<pulumi.Input<inputs.fis.ExperimentTemplateCloudWatchDashboardArgs>[]>;
    }
    /**
     * The output destinations of the experiment report.
     */
    interface ExperimentTemplateExperimentReportConfigurationOutputsPropertiesArgs {
        experimentReportS3Configuration: pulumi.Input<inputs.fis.ExperimentTemplateExperimentReportConfigurationOutputsPropertiesExperimentReportS3ConfigurationPropertiesArgs>;
    }
    interface ExperimentTemplateExperimentReportConfigurationOutputsPropertiesExperimentReportS3ConfigurationPropertiesArgs {
        bucketName: pulumi.Input<string>;
        prefix?: pulumi.Input<string>;
    }
    interface ExperimentTemplateLogConfigurationArgs {
        /**
         * The configuration for experiment logging to CloudWatch Logs .
         */
        cloudWatchLogsConfiguration?: pulumi.Input<inputs.fis.ExperimentTemplateLogConfigurationCloudWatchLogsConfigurationPropertiesArgs>;
        /**
         * The schema version.
         */
        logSchemaVersion: pulumi.Input<number>;
        /**
         * The configuration for experiment logging to Amazon S3 .
         */
        s3Configuration?: pulumi.Input<inputs.fis.ExperimentTemplateLogConfigurationS3ConfigurationPropertiesArgs>;
    }
    /**
     * The configuration for experiment logging to CloudWatch Logs .
     */
    interface ExperimentTemplateLogConfigurationCloudWatchLogsConfigurationPropertiesArgs {
        logGroupArn: pulumi.Input<string>;
    }
    /**
     * The configuration for experiment logging to Amazon S3 .
     */
    interface ExperimentTemplateLogConfigurationS3ConfigurationPropertiesArgs {
        bucketName: pulumi.Input<string>;
        prefix?: pulumi.Input<string>;
    }
    interface ExperimentTemplateStopConditionArgs {
        source: pulumi.Input<string>;
        value?: pulumi.Input<string>;
    }
    /**
     * Specifies a target for an experiment.
     */
    interface ExperimentTemplateTargetArgs {
        /**
         * The filters to apply to identify target resources using specific attributes.
         */
        filters?: pulumi.Input<pulumi.Input<inputs.fis.ExperimentTemplateTargetFilterArgs>[]>;
        /**
         * The parameters for the resource type.
         */
        parameters?: pulumi.Input<{
            [key: string]: pulumi.Input<string>;
        }>;
        /**
         * The Amazon Resource Names (ARNs) of the targets.
         */
        resourceArns?: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * The tags for the target resources.
         */
        resourceTags?: pulumi.Input<{
            [key: string]: pulumi.Input<string>;
        }>;
        /**
         * The resource type.
         */
        resourceType: pulumi.Input<string>;
        /**
         * Scopes the identified resources to a specific count or percentage.
         */
        selectionMode: pulumi.Input<string>;
    }
    /**
     * Describes a filter used for the target resource input in an experiment template.
     */
    interface ExperimentTemplateTargetFilterArgs {
        path: pulumi.Input<string>;
        values: pulumi.Input<pulumi.Input<string>[]>;
    }
}
export declare namespace fms {
    /**
     * An FMS includeMap or excludeMap.
     */
    interface PolicyIeMapArgs {
        /**
         * The account list for the map.
         */
        account?: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * The organizational unit list for the map.
         */
        orgunit?: pulumi.Input<pulumi.Input<string>[]>;
    }
    /**
     * Network ACL common policy.
     */
    interface PolicyNetworkAclCommonPolicyArgs {
        /**
         * The definition of the first and last rules for the network ACL policy.
         */
        networkAclEntrySet: pulumi.Input<inputs.fms.PolicyNetworkAclEntrySetArgs>;
    }
    /**
     * Network ACL entry.
     */
    interface PolicyNetworkAclEntryArgs {
        /**
         * CIDR block.
         */
        cidrBlock?: pulumi.Input<string>;
        /**
         * Whether the entry is an egress entry.
         */
        egress: pulumi.Input<boolean>;
        /**
         * ICMP type and code.
         */
        icmpTypeCode?: pulumi.Input<inputs.fms.PolicyNetworkAclEntryIcmpTypeCodePropertiesArgs>;
        /**
         * IPv6 CIDR block.
         */
        ipv6CidrBlock?: pulumi.Input<string>;
        /**
         * Port range.
         */
        portRange?: pulumi.Input<inputs.fms.PolicyNetworkAclEntryPortRangePropertiesArgs>;
        /**
         * Protocol.
         */
        protocol: pulumi.Input<string>;
        /**
         * Rule Action.
         */
        ruleAction: pulumi.Input<enums.fms.PolicyNetworkAclEntryRuleAction>;
    }
    /**
     * ICMP type and code.
     */
    interface PolicyNetworkAclEntryIcmpTypeCodePropertiesArgs {
        /**
         * Code.
         */
        code: pulumi.Input<number>;
        /**
         * Type.
         */
        type: pulumi.Input<number>;
    }
    /**
     * Port range.
     */
    interface PolicyNetworkAclEntryPortRangePropertiesArgs {
        /**
         * From Port.
         */
        from: pulumi.Input<number>;
        /**
         * To Port.
         */
        to: pulumi.Input<number>;
    }
    /**
     * Network ACL entry set.
     */
    interface PolicyNetworkAclEntrySetArgs {
        /**
         * The rules that you want to run first in the Firewall Manager managed network ACLs.
         *
         * > Provide these in the order in which you want them to run. Firewall Manager will assign the specific rule numbers for you, in the network ACLs that it creates.
         *
         * You must specify at least one first entry or one last entry in any network ACL policy.
         */
        firstEntries?: pulumi.Input<pulumi.Input<inputs.fms.PolicyNetworkAclEntryArgs>[]>;
        /**
         * Applies only when remediation is enabled for the policy as a whole. Firewall Manager uses this setting when it finds policy violations that involve conflicts between the custom entries and the policy entries.
         *
         * If forced remediation is disabled, Firewall Manager marks the network ACL as noncompliant and does not try to remediate. For more information about the remediation behavior, see [Remediation for managed network ACLs](https://docs.aws.amazon.com/waf/latest/developerguide/network-acl-policies.html#network-acls-remediation) in the *AWS Firewall Manager Developer Guide* .
         */
        forceRemediateForFirstEntries: pulumi.Input<boolean>;
        /**
         * Applies only when remediation is enabled for the policy as a whole. Firewall Manager uses this setting when it finds policy violations that involve conflicts between the custom entries and the policy entries.
         *
         * If forced remediation is disabled, Firewall Manager marks the network ACL as noncompliant and does not try to remediate. For more information about the remediation behavior, see [Remediation for managed network ACLs](https://docs.aws.amazon.com/waf/latest/developerguide/network-acl-policies.html#network-acls-remediation) in the *AWS Firewall Manager Developer Guide* .
         */
        forceRemediateForLastEntries: pulumi.Input<boolean>;
        /**
         * The rules that you want to run last in the Firewall Manager managed network ACLs.
         *
         * > Provide these in the order in which you want them to run. Firewall Manager will assign the specific rule numbers for you, in the network ACLs that it creates.
         *
         * You must specify at least one first entry or one last entry in any network ACL policy.
         */
        lastEntries?: pulumi.Input<pulumi.Input<inputs.fms.PolicyNetworkAclEntryArgs>[]>;
    }
    /**
     * Network firewall policy.
     */
    interface PolicyNetworkFirewallPolicyArgs {
        /**
         * Defines the deployment model to use for the firewall policy. To use a distributed model, set [FirewallDeploymentModel](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-fms-policy-thirdpartyfirewallpolicy.html) to `DISTRIBUTED` .
         */
        firewallDeploymentModel: pulumi.Input<enums.fms.PolicyFirewallDeploymentModel>;
    }
    /**
     * Firewall policy option.
     */
    interface PolicyOptionArgs {
        /**
         * Defines a Firewall Manager network ACL policy.
         */
        networkAclCommonPolicy?: pulumi.Input<inputs.fms.PolicyNetworkAclCommonPolicyArgs>;
        /**
         * Defines the deployment model to use for the firewall policy.
         */
        networkFirewallPolicy?: pulumi.Input<inputs.fms.PolicyNetworkFirewallPolicyArgs>;
        /**
         * Defines the policy options for a third-party firewall policy.
         */
        thirdPartyFirewallPolicy?: pulumi.Input<inputs.fms.PolicyThirdPartyFirewallPolicyArgs>;
    }
    /**
     * A resource tag.
     */
    interface PolicyResourceTagArgs {
        /**
         * The resource tag key.
         */
        key: pulumi.Input<string>;
        /**
         * The resource tag value.
         */
        value?: pulumi.Input<string>;
    }
    /**
     * Firewall security service policy data.
     */
    interface PolicySecurityServicePolicyDataArgs {
        /**
         * Details about the service that are specific to the service type, in JSON format.
         *
         * - Example: `DNS_FIREWALL`
         *
         * `"{\"type\":\"DNS_FIREWALL\",\"preProcessRuleGroups\":[{\"ruleGroupId\":\"rslvr-frg-1\",\"priority\":10}],\"postProcessRuleGroups\":[{\"ruleGroupId\":\"rslvr-frg-2\",\"priority\":9911}]}"`
         *
         * > Valid values for `preProcessRuleGroups` are between 1 and 99. Valid values for `postProcessRuleGroups` are between 9901 and 10000.
         * - Example: `NETWORK_FIREWALL` - Centralized deployment model
         *
         * `"{\"type\":\"NETWORK_FIREWALL\",\"awsNetworkFirewallConfig\":{\"networkFirewallStatelessRuleGroupReferences\":[{\"resourceARN\":\"arn:aws:network-firewall:us-east-1:123456789011:stateless-rulegroup/test\",\"priority\":1}],\"networkFirewallStatelessDefaultActions\":[\"aws:forward_to_sfe\",\"customActionName\"],\"networkFirewallStatelessFragmentDefaultActions\":[\"aws:forward_to_sfe\",\"customActionName\"],\"networkFirewallStatelessCustomActions\":[{\"actionName\":\"customActionName\",\"actionDefinition\":{\"publishMetricAction\":{\"dimensions\":[{\"value\":\"metricdimensionvalue\"}]}}}],\"networkFirewallStatefulRuleGroupReferences\":[{\"resourceARN\":\"arn:aws:network-firewall:us-east-1:123456789011:stateful-rulegroup/test\"}],\"networkFirewallLoggingConfiguration\":{\"logDestinationConfigs\":[{\"logDestinationType\":\"S3\",\"logType\":\"ALERT\",\"logDestination\":{\"bucketName\":\"s3-bucket-name\"}},{\"logDestinationType\":\"S3\",\"logType\":\"FLOW\",\"logDestination\":{\"bucketName\":\"s3-bucket-name\"}}],\"overrideExistingConfig\":true}},\"firewallDeploymentModel\":{\"centralizedFirewallDeploymentModel\":{\"centralizedFirewallOrchestrationConfig\":{\"inspectionVpcIds\":[{\"resourceId\":\"vpc-1234\",\"accountId\":\"123456789011\"}],\"firewallCreationConfig\":{\"endpointLocation\":{\"availabilityZoneConfigList\":[{\"availabilityZoneId\":null,\"availabilityZoneName\":\"us-east-1a\",\"allowedIPV4CidrList\":[\"10.0.0.0/28\"]}]}},\"allowedIPV4CidrList\":[]}}}}"`
         *
         * To use the distributed deployment model, you must set [FirewallDeploymentModel](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-fms-policy-networkfirewallpolicy.html) to `DISTRIBUTED` .
         * - Example: `NETWORK_FIREWALL` - Distributed deployment model with automatic Availability Zone configuration
         *
         * `"{\"type\":\"NETWORK_FIREWALL\",\"networkFirewallStatelessRuleGroupReferences\":[{\"resourceARN\":\"arn:aws:network-firewall:us-east-1:123456789011:stateless-rulegroup/test\",\"priority\":1}],\"networkFirewallStatelessDefaultActions\":[\"aws:forward_to_sfe\",\"customActionName\"],\"networkFirewallStatelessFragmentDefaultActions\":[\"aws:forward_to_sfe\",\"customActionName\"],\"networkFirewallStatelessCustomActions\":[{\"actionName\":\"customActionName\",\"actionDefinition\":{\"publishMetricAction\":{\"dimensions\":[{\"value\":\"metricdimensionvalue\"}]}}}],\"networkFirewallStatefulRuleGroupReferences\":[{\"resourceARN\":\"arn:aws:network-firewall:us-east-1:123456789011:stateful-rulegroup/test\"}],\"networkFirewallOrchestrationConfig\":{\"singleFirewallEndpointPerVPC\":false,\"allowedIPV4CidrList\":[\"10.0.0.0/28\",\"192.168.0.0/28\"],\"routeManagementAction\":\"OFF\"},\"networkFirewallLoggingConfiguration\":{\"logDestinationConfigs\":[{\"logDestinationType\":\"S3\",\"logType\":\"ALERT\",\"logDestination\":{\"bucketName\":\"s3-bucket-name\"}},{\"logDestinationType\":\"S3\",\"logType\":\"FLOW\",\"logDestination\":{\"bucketName\":\"s3-bucket-name\"}}],\"overrideExistingConfig\":true}}"`
         *
         * With automatic Availbility Zone configuration, Firewall Manager chooses which Availability Zones to create the endpoints in. To use the distributed deployment model, you must set [FirewallDeploymentModel](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-fms-policy-networkfirewallpolicy.html) to `DISTRIBUTED` .
         * - Example: `NETWORK_FIREWALL` - Distributed deployment model with automatic Availability Zone configuration and route management
         *
         * `"{\"type\":\"NETWORK_FIREWALL\",\"networkFirewallStatelessRuleGroupReferences\":[{\"resourceARN\":\"arn:aws:network-firewall:us-east-1:123456789011:stateless-rulegroup/test\",\"priority\":1}],\"networkFirewallStatelessDefaultActions\":[\"aws:forward_to_sfe\",\"customActionName\"],\"networkFirewallStatelessFragmentDefaultActions\":[\"aws:forward_to_sfe\",\"customActionName\"],\"networkFirewallStatelessCustomActions\":[{\"actionName\":\"customActionName\",\"actionDefinition\":{\"publishMetricAction\":{\"dimensions\":[{\"value\":\"metricdimensionvalue\"}]}}}],\"networkFirewallStatefulRuleGroupReferences\":[{\"resourceARN\":\"arn:aws:network-firewall:us-east-1:123456789011:stateful-rulegroup/test\"}],\"networkFirewallOrchestrationConfig\":{\"singleFirewallEndpointPerVPC\":false,\"allowedIPV4CidrList\":[\"10.0.0.0/28\",\"192.168.0.0/28\"],\"routeManagementAction\":\"MONITOR\",\"routeManagementTargetTypes\":[\"InternetGateway\"]},\"networkFirewallLoggingConfiguration\":{\"logDestinationConfigs\":[{\"logDestinationType\":\"S3\",\"logType\":\"ALERT\",\"logDestination\":{\"bucketName\":\"s3-bucket-name\"}},{\"logDestinationType\":\"S3\",\"logType\": \"FLOW\",\"logDestination\":{\"bucketName\":\"s3-bucket-name\"}}],\"overrideExistingConfig\":true}}"`
         *
         * To use the distributed deployment model, you must set [FirewallDeploymentModel](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-fms-policy-networkfirewallpolicy.html) to `DISTRIBUTED` .
         * - Example: `NETWORK_FIREWALL` - Distributed deployment model with custom Availability Zone configuration
         *
         * `"{\"type\":\"NETWORK_FIREWALL\",\"networkFirewallStatelessRuleGroupReferences\":[{\"resourceARN\":\"arn:aws:network-firewall:us-east-1:123456789011:stateless-rulegroup/test\",\"priority\":1}],\"networkFirewallStatelessDefaultActions\":[\"aws:forward_to_sfe\",\"customActionName\"],\"networkFirewallStatelessFragmentDefaultActions\":[\"aws:forward_to_sfe\",\"fragmentcustomactionname\"],\"networkFirewallStatelessCustomActions\":[{\"actionName\":\"customActionName\", \"actionDefinition\":{\"publishMetricAction\":{\"dimensions\":[{\"value\":\"metricdimensionvalue\"}]}}},{\"actionName\":\"fragmentcustomactionname\",\"actionDefinition\":{\"publishMetricAction\":{\"dimensions\":[{\"value\":\"fragmentmetricdimensionvalue\"}]}}}],\"networkFirewallStatefulRuleGroupReferences\":[{\"resourceARN\":\"arn:aws:network-firewall:us-east-1:123456789011:stateful-rulegroup/test\"}],\"networkFirewallOrchestrationConfig\":{\"firewallCreationConfig\":{ \"endpointLocation\":{\"availabilityZoneConfigList\":[{\"availabilityZoneName\":\"us-east-1a\",\"allowedIPV4CidrList\":[\"10.0.0.0/28\"]},{\"availabilityZoneName\":\"us-east-1b\",\"allowedIPV4CidrList\":[ \"10.0.0.0/28\"]}]} },\"singleFirewallEndpointPerVPC\":false,\"allowedIPV4CidrList\":null,\"routeManagementAction\":\"OFF\",\"networkFirewallLoggingConfiguration\":{\"logDestinationConfigs\":[{\"logDestinationType\":\"S3\",\"logType\":\"ALERT\",\"logDestination\":{\"bucketName\":\"s3-bucket-name\"}},{\"logDestinationType\":\"S3\",\"logType\":\"FLOW\",\"logDestination\":{\"bucketName\":\"s3-bucket-name\"}}],\"overrideExistingConfig\":boolean}}"`
         *
         * With custom Availability Zone configuration, you define which specific Availability Zones to create endpoints in by configuring `firewallCreationConfig` . To configure the Availability Zones in `firewallCreationConfig` , specify either the `availabilityZoneName` or `availabilityZoneId` parameter, not both parameters.
         *
         * To use the distributed deployment model, you must set [FirewallDeploymentModel](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-fms-policy-networkfirewallpolicy.html) to `DISTRIBUTED` .
         * - Example: `NETWORK_FIREWALL` - Distributed deployment model with custom Availability Zone configuration and route management
         *
         * `"{\"type\":\"NETWORK_FIREWALL\",\"networkFirewallStatelessRuleGroupReferences\":[{\"resourceARN\":\"arn:aws:network-firewall:us-east-1:123456789011:stateless-rulegroup/test\",\"priority\":1}],\"networkFirewallStatelessDefaultActions\":[\"aws:forward_to_sfe\",\"customActionName\"],\"networkFirewallStatelessFragmentDefaultActions\":[\"aws:forward_to_sfe\",\"fragmentcustomactionname\"],\"networkFirewallStatelessCustomActions\":[{\"actionName\":\"customActionName\",\"actionDefinition\":{\"publishMetricAction\":{\"dimensions\":[{\"value\":\"metricdimensionvalue\"}]}}},{\"actionName\":\"fragmentcustomactionname\",\"actionDefinition\":{\"publishMetricAction\":{\"dimensions\":[{\"value\":\"fragmentmetricdimensionvalue\"}]}}}],\"networkFirewallStatefulRuleGroupReferences\":[{\"resourceARN\":\"arn:aws:network-firewall:us-east-1:123456789011:stateful-rulegroup/test\"}],\"networkFirewallOrchestrationConfig\":{\"firewallCreationConfig\":{\"endpointLocation\":{\"availabilityZoneConfigList\":[{\"availabilityZoneName\":\"us-east-1a\",\"allowedIPV4CidrList\":[\"10.0.0.0/28\"]},{\"availabilityZoneName\":\"us-east-1b\",\"allowedIPV4CidrList\":[\"10.0.0.0/28\"]}]}},\"singleFirewallEndpointPerVPC\":false,\"allowedIPV4CidrList\":null,\"routeManagementAction\":\"MONITOR\",\"routeManagementTargetTypes\":[\"InternetGateway\"],\"routeManagementConfig\":{\"allowCrossAZTrafficIfNoEndpoint\":true}},\"networkFirewallLoggingConfiguration\":{\"logDestinationConfigs\":[{\"logDestinationType\":\"S3\",\"logType\":\"ALERT\",\"logDestination\":{\"bucketName\":\"s3-bucket-name\"}},{\"logDestinationType\":\"S3\",\"logType\":\"FLOW\",\"logDestination\":{\"bucketName\":\"s3-bucket-name\"}}],\"overrideExistingConfig\":boolean}}"`
         *
         * To use the distributed deployment model, you must set [FirewallDeploymentModel](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-fms-policy-networkfirewallpolicy.html) to `DISTRIBUTED` .
         * - Example: `THIRD_PARTY_FIREWALL` - Palo Alto Networks Cloud Next-Generation Firewall centralized deployment model
         *
         * `"{ \"type\":\"THIRD_PARTY_FIREWALL\", \"thirdPartyFirewall\":\"PALO_ALTO_NETWORKS_CLOUD_NGFW\", \"thirdPartyFirewallConfig\":{ \"thirdPartyFirewallPolicyList\":[\"global-1\"] },\"firewallDeploymentModel\":{\"centralizedFirewallDeploymentModel\":{\"centralizedFirewallOrchestrationConfig\":{\"inspectionVpcIds\":[{\"resourceId\":\"vpc-1234\",\"accountId\":\"123456789011\"}],\"firewallCreationConfig\":{\"endpointLocation\":{\"availabilityZoneConfigList\":[{\"availabilityZoneId\":null,\"availabilityZoneName\":\"us-east-1a\",\"allowedIPV4CidrList\":[\"10.0.0.0/28\"]}]}},\"allowedIPV4CidrList\":[]}}}}"`
         *
         * To use the distributed deployment model, you must set [FirewallDeploymentModel](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-fms-policy-thirdpartyfirewallpolicy.html) to `CENTRALIZED` .
         * - Example: `THIRD_PARTY_FIREWALL` - Palo Alto Networks Cloud Next-Generation Firewall distributed deployment model
         *
         * `"{\"type\":\"THIRD_PARTY_FIREWALL\",\"thirdPartyFirewall\":\"PALO_ALTO_NETWORKS_CLOUD_NGFW\",\"thirdPartyFirewallConfig\":{\"thirdPartyFirewallPolicyList\":[\"global-1\"] },\"firewallDeploymentModel\":{ \"distributedFirewallDeploymentModel\":{ \"distributedFirewallOrchestrationConfig\":{\"firewallCreationConfig\":{\"endpointLocation\":{ \"availabilityZoneConfigList\":[ {\"availabilityZoneName\":\"${AvailabilityZone}\" } ] } }, \"allowedIPV4CidrList\":[ ] } } } }"`
         *
         * To use the distributed deployment model, you must set [FirewallDeploymentModel](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-fms-policy-thirdpartyfirewallpolicy.html) to `DISTRIBUTED` .
         * - Specification for `SHIELD_ADVANCED` for Amazon CloudFront distributions
         *
         * `"{\"type\":\"SHIELD_ADVANCED\",\"automaticResponseConfiguration\": {\"automaticResponseStatus\":\"ENABLED|IGNORED|DISABLED\", \"automaticResponseAction\":\"BLOCK|COUNT\"}, \"overrideCustomerWebaclClassic\":true|false}"`
         *
         * For example: `"{\"type\":\"SHIELD_ADVANCED\",\"automaticResponseConfiguration\": {\"automaticResponseStatus\":\"ENABLED\", \"automaticResponseAction\":\"COUNT\"}}"`
         *
         * The default value for `automaticResponseStatus` is `IGNORED` . The value for `automaticResponseAction` is only required when `automaticResponseStatus` is set to `ENABLED` . The default value for `overrideCustomerWebaclClassic` is `false` .
         *
         * For other resource types that you can protect with a Shield Advanced policy, this `ManagedServiceData` configuration is an empty string.
         * - Example: `WAFV2`
         *
         * `"{\"type\":\"WAFV2\",\"preProcessRuleGroups\":[{\"ruleGroupArn\":null,\"overrideAction\":{\"type\":\"NONE\"},\"managedRuleGroupIdentifier\":{\"version\":null,\"vendorName\":\"AWS\",\"managedRuleGroupName\":\"AWSManagedRulesAmazonIpReputationList\"},\"ruleGroupType\":\"ManagedRuleGroup\",\"excludeRules\":[{\"name\":\"NoUserAgent_HEADER\"}]}],\"postProcessRuleGroups\":[],\"defaultAction\":{\"type\":\"ALLOW\"},\"overrideCustomerWebACLAssociation\":false,\"loggingConfiguration\":{\"logDestinationConfigs\":[\"arn:aws:firehose:us-west-2:12345678912:deliverystream/aws-waf-logs-fms-admin-destination\"],\"redactedFields\":[{\"redactedFieldType\":\"SingleHeader\",\"redactedFieldValue\":\"Cookies\"},{\"redactedFieldType\":\"Method\"}]}}"`
         *
         * In the `loggingConfiguration` , you can specify one `logDestinationConfigs` , you can optionally provide up to 20 `redactedFields` , and the `RedactedFieldType` must be one of `URI` , `QUERY_STRING` , `HEADER` , or `METHOD` .
         * - Example: `AWS WAF Classic`
         *
         * `"{\"type\": \"WAF\", \"ruleGroups\": [{\"id\":\"12345678-1bcd-9012-efga-0987654321ab\", \"overrideAction\" : {\"type\": \"COUNT\"}}], \"defaultAction\": {\"type\": \"BLOCK\"}}"`
         * - Example: `WAFV2` - AWS Firewall Manager support for AWS WAF managed rule group versioning
         *
         * `"{\"type\":\"WAFV2\",\"preProcessRuleGroups\":[{\"ruleGroupArn\":null,\"overrideAction\":{\"type\":\"NONE\"},\"managedRuleGroupIdentifier\":{\"versionEnabled\":true,\"version\":\"Version_2.0\",\"vendorName\":\"AWS\",\"managedRuleGroupName\":\"AWSManagedRulesCommonRuleSet\"},\"ruleGroupType\":\"ManagedRuleGroup\",\"excludeRules\":[{\"name\":\"NoUserAgent_HEADER\"}]}],\"postProcessRuleGroups\":[],\"defaultAction\":{\"type\":\"ALLOW\"},\"overrideCustomerWebACLAssociation\":false,\"loggingConfiguration\":{\"logDestinationConfigs\":[\"arn:aws:firehose:us-west-2:12345678912:deliverystream/aws-waf-logs-fms-admin-destination\"],\"redactedFields\":[{\"redactedFieldType\":\"SingleHeader\",\"redactedFieldValue\":\"Cookies\"},{\"redactedFieldType\":\"Method\"}]}}"`
         *
         * To use a specific version of a AWS WAF managed rule group in your Firewall Manager policy, you must set `versionEnabled` to `true` , and set `version` to the version you'd like to use. If you don't set `versionEnabled` to `true` , or if you omit `versionEnabled` , then Firewall Manager uses the default version of the AWS WAF managed rule group.
         * - Example: `SECURITY_GROUPS_COMMON`
         *
         * `"{\"type\":\"SECURITY_GROUPS_COMMON\",\"revertManualSecurityGroupChanges\":false,\"exclusiveResourceSecurityGroupManagement\":false, \"applyToAllEC2InstanceENIs\":false,\"securityGroups\":[{\"id\":\" sg-000e55995d61a06bd\"}]}"`
         * - Example: Shared VPCs. Apply the preceding policy to resources in shared VPCs as well as to those in VPCs that the account owns
         *
         * `"{\"type\":\"SECURITY_GROUPS_COMMON\",\"revertManualSecurityGroupChanges\":false,\"exclusiveResourceSecurityGroupManagement\":false, \"applyToAllEC2InstanceENIs\":false,\"includeSharedVPC\":true,\"securityGroups\":[{\"id\":\" sg-000e55995d61a06bd\"}]}"`
         * - Example: `SECURITY_GROUPS_CONTENT_AUDIT`
         *
         * `"{\"type\":\"SECURITY_GROUPS_CONTENT_AUDIT\",\"securityGroups\":[{\"id\":\"sg-000e55995d61a06bd\"}],\"securityGroupAction\":{\"type\":\"ALLOW\"}}"`
         *
         * The security group action for content audit can be `ALLOW` or `DENY` . For `ALLOW` , all in-scope security group rules must be within the allowed range of the policy's security group rules. For `DENY` , all in-scope security group rules must not contain a value or a range that matches a rule value or range in the policy security group.
         * - Example: `SECURITY_GROUPS_USAGE_AUDIT`
         *
         * `"{\"type\":\"SECURITY_GROUPS_USAGE_AUDIT\",\"deleteUnusedSecurityGroups\":true,\"coalesceRedundantSecurityGroups\":true}"`
         */
        managedServiceData?: pulumi.Input<string>;
        /**
         * Contains the settings to configure a network ACL policy, a AWS Network Firewall firewall policy deployment model, or a third-party firewall policy.
         */
        policyOption?: pulumi.Input<inputs.fms.PolicyOptionArgs>;
        /**
         * The service that the policy is using to protect the resources. This specifies the type of policy that is created, either an AWS WAF policy, a Shield Advanced policy, or a security group policy. For security group policies, Firewall Manager supports one security group for each common policy and for each content audit policy. This is an adjustable limit that you can increase by contacting SUPlong .
         */
        type: pulumi.Input<enums.fms.PolicyType>;
    }
    /**
     * Third party firewall policy.
     */
    interface PolicyThirdPartyFirewallPolicyArgs {
        /**
         * Defines the deployment model to use for the third-party firewall policy.
         */
        firewallDeploymentModel: pulumi.Input<enums.fms.PolicyFirewallDeploymentModel>;
    }
}
export declare namespace forecast {
    interface DatasetAttributesItemPropertiesArgs {
        /**
         * Name of the dataset field
         */
        attributeName?: pulumi.Input<string>;
        /**
         * Data type of the field
         */
        attributeType?: pulumi.Input<enums.forecast.DatasetAttributesItemPropertiesAttributeType>;
    }
    /**
     * A Key Management Service (KMS) key and the Identity and Access Management (IAM) role that Amazon Forecast can assume to access the key.
     */
    interface EncryptionConfigPropertiesArgs {
        /**
         * The Amazon Resource Name (ARN) of the KMS key.
         */
        kmsKeyArn?: pulumi.Input<string>;
        /**
         * The ARN of the IAM role that Amazon Forecast can assume to access the AWS KMS key.
         *
         * Passing a role across AWS accounts is not allowed. If you pass a role that isn't in your account, you get an `InvalidInputException` error.
         */
        roleArn?: pulumi.Input<string>;
    }
    /**
     * The schema for the dataset. The schema attributes and their order must match the fields in your data. The dataset `Domain` and `DatasetType` that you choose determine the minimum required fields in your training data. For information about the required fields for a specific dataset domain and type, see [Dataset Domains and Dataset Types](https://docs.aws.amazon.com/forecast/latest/dg/howitworks-domains-ds-types.html) .
     */
    interface SchemaPropertiesArgs {
        /**
         * An array of attributes specifying the name and type of each field in a dataset.
         */
        attributes?: pulumi.Input<pulumi.Input<inputs.forecast.DatasetAttributesItemPropertiesArgs>[]>;
    }
}
export declare namespace frauddetector {
    interface DetectorEntityTypeArgs {
        /**
         * The entity type ARN.
         */
        arn?: pulumi.Input<string>;
        /**
         * The time when the entity type was created.
         */
        createdTime?: pulumi.Input<string>;
        /**
         * The description.
         */
        description?: pulumi.Input<string>;
        /**
         * Indicates whether the resource is defined within this CloudFormation template and impacts the create, update, and delete behavior of the stack. If the value is `true` , CloudFormation will create/update/delete the resource when creating/updating/deleting the stack. If the value is `false` , CloudFormation will validate that the object exists and then use it within the resource without making changes to the object.
         *
         * For example, when creating `AWS::FraudDetector::Detector` you must define at least two variables. You can set `Inline=true` for these Variables and CloudFormation will create/update/delete the variables as part of stack operations. However, if you set `Inline=false` , CloudFormation will associate the variables to your detector but not execute any changes to the variables.
         */
        inline?: pulumi.Input<boolean>;
        /**
         * The time when the entity type was last updated.
         */
        lastUpdatedTime?: pulumi.Input<string>;
        /**
         * The entity type name.
         */
        name?: pulumi.Input<string>;
        /**
         * Tags associated with this entity type.
         */
        tags?: pulumi.Input<pulumi.Input<inputs.frauddetector.DetectorTagArgs>[]>;
    }
    interface DetectorEventTypeArgs {
        /**
         * The ARN of the event type.
         */
        arn?: pulumi.Input<string>;
        /**
         * The time when the event type was created.
         */
        createdTime?: pulumi.Input<string>;
        /**
         * The description of the event type.
         */
        description?: pulumi.Input<string>;
        /**
         * The event type entity types.
         */
        entityTypes?: pulumi.Input<pulumi.Input<inputs.frauddetector.DetectorEntityTypeArgs>[]>;
        /**
         * The event type event variables.
         */
        eventVariables?: pulumi.Input<pulumi.Input<inputs.frauddetector.DetectorEventVariableArgs>[]>;
        /**
         * Indicates whether the resource is defined within this CloudFormation template and impacts the create, update, and delete behavior of the stack. If the value is `true` , CloudFormation will create/update/delete the resource when creating/updating/deleting the stack. If the value is `false` , CloudFormation will validate that the object exists and then use it within the resource without making changes to the object.
         *
         * For example, when creating `AWS::FraudDetector::Detector` you must define at least two variables. You can set `Inline=true` for these variables and CloudFormation will create/update/delete the Variables as part of stack operations. However, if you set `Inline=false` , CloudFormation will associate the variables to your detector but not execute any changes to the variables.
         */
        inline?: pulumi.Input<boolean>;
        /**
         * The event type labels.
         */
        labels?: pulumi.Input<pulumi.Input<inputs.frauddetector.DetectorLabelArgs>[]>;
        /**
         * The time when the event type was last updated.
         */
        lastUpdatedTime?: pulumi.Input<string>;
        /**
         * The name for the event type
         */
        name?: pulumi.Input<string>;
        /**
         * Tags associated with this event type.
         */
        tags?: pulumi.Input<pulumi.Input<inputs.frauddetector.DetectorTagArgs>[]>;
    }
    interface DetectorEventVariableArgs {
        /**
         * The event variable ARN.
         */
        arn?: pulumi.Input<string>;
        /**
         * The time when the event variable was created.
         */
        createdTime?: pulumi.Input<string>;
        /**
         * The data source of the event variable.
         *
         * Valid values: `EVENT | EXTERNAL_MODEL_SCORE`
         *
         * When defining a variable within a detector, you can only use the `EVENT` value for DataSource when the *Inline* property is set to true. If the *Inline* property is set false, you can use either `EVENT` or `MODEL_SCORE` for DataSource.
         */
        dataSource?: pulumi.Input<enums.frauddetector.DetectorEventVariableDataSource>;
        /**
         * The data type of the event variable.
         *
         * Valid values: `STRING | INTEGER | BOOLEAN | FLOAT`
         */
        dataType?: pulumi.Input<enums.frauddetector.DetectorEventVariableDataType>;
        /**
         * The default value of the event variable. This is required if you are providing the details of your variables instead of the ARN.
         */
        defaultValue?: pulumi.Input<string>;
        /**
         * The description.
         */
        description?: pulumi.Input<string>;
        /**
         * Indicates whether the resource is defined within this CloudFormation template and impacts the create, update, and delete behavior of the stack. If the value is `true` , CloudFormation will create/update/delete the resource when creating/updating/deleting the stack. If the value is `false` , CloudFormation will validate that the object exists and then use it within the resource without making changes to the object.
         *
         * For example, when creating `AWS::FraudDetector::Detector` you must define at least two variables. You can set `Inline=true` for these variables and CloudFormation will create/update/delete the variables as part of stack operations. However, if you set `Inline=false` , CloudFormation will associate the variables to your detector but not execute any changes to the variables.
         */
        inline?: pulumi.Input<boolean>;
        /**
         * The time when the event variable was last updated.
         */
        lastUpdatedTime?: pulumi.Input<string>;
        /**
         * The name of the event variable.
         */
        name?: pulumi.Input<string>;
        /**
         * Tags associated with this event variable.
         */
        tags?: pulumi.Input<pulumi.Input<inputs.frauddetector.DetectorTagArgs>[]>;
        /**
         * The type of event variable. For more information, see [Variable types](https://docs.aws.amazon.com/frauddetector/latest/ug/create-a-variable.html#variable-types) .
         */
        variableType?: pulumi.Input<enums.frauddetector.DetectorEventVariableVariableType>;
    }
    interface DetectorLabelArgs {
        /**
         * The label ARN.
         */
        arn?: pulumi.Input<string>;
        /**
         * The time when the label was created.
         */
        createdTime?: pulumi.Input<string>;
        /**
         * The description.
         */
        description?: pulumi.Input<string>;
        /**
         * Indicates whether the resource is defined within this CloudFormation template and impacts the create, update, and delete behavior of the stack. If the value is `true` , CloudFormation will create/update/delete the resource when creating/updating/deleting the stack. If the value is `false` , CloudFormation will validate that the object exists and then use it within the resource without making changes to the object.
         *
         * For example, when creating `AWS::FraudDetector::Detector` you must define at least two variables. You can set `Inline=true` for these variables and CloudFormation will create/update/delete the variables as part of stack operations. However, if you set `Inline=false` , CloudFormation will associate the variables to your detector but not execute any changes to the variables.
         */
        inline?: pulumi.Input<boolean>;
        /**
         * The time when the label was last updated.
         */
        lastUpdatedTime?: pulumi.Input<string>;
        /**
         * The label name.
         */
        name?: pulumi.Input<string>;
        /**
         * Tags associated with this label.
         */
        tags?: pulumi.Input<pulumi.Input<inputs.frauddetector.DetectorTagArgs>[]>;
    }
    /**
     * A model to associate with a detector.
     */
    interface DetectorModelArgs {
        /**
         * The ARN of the model.
         */
        arn?: pulumi.Input<string>;
    }
    interface DetectorOutcomeArgs {
        /**
         * The outcome ARN.
         */
        arn?: pulumi.Input<string>;
        /**
         * The time when the outcome was created.
         */
        createdTime?: pulumi.Input<string>;
        /**
         * The description.
         */
        description?: pulumi.Input<string>;
        /**
         * Indicates whether the resource is defined within this CloudFormation template and impacts the create, update, and delete behavior of the stack. If the value is `true` , CloudFormation will create/update/delete the resource when creating/updating/deleting the stack. If the value is `false` , CloudFormation will validate that the object exists and then use it within the resource without making changes to the object.
         *
         * For example, when creating `AWS::FraudDetector::Detector` you must define at least two variables. You can set `Inline=true` for these variables and CloudFormation will create/update/delete the variables as part of stack operations. However, if you set `Inline=false` , CloudFormation will associate the variables to your detector but not execute any changes to the variables.
         */
        inline?: pulumi.Input<boolean>;
        /**
         * The time when the outcome was last updated.
         */
        lastUpdatedTime?: pulumi.Input<string>;
        /**
         * The outcome name.
         */
        name?: pulumi.Input<string>;
        /**
         * Tags associated with this outcome.
         */
        tags?: pulumi.Input<pulumi.Input<inputs.frauddetector.DetectorTagArgs>[]>;
    }
    interface DetectorRuleArgs {
        /**
         * The rule ARN.
         */
        arn?: pulumi.Input<string>;
        /**
         * The time when the event type was created.
         */
        createdTime?: pulumi.Input<string>;
        /**
         * The description.
         */
        description?: pulumi.Input<string>;
        /**
         * The detector for which the rule is associated.
         */
        detectorId?: pulumi.Input<string>;
        /**
         * The rule expression. A rule expression captures the business logic. For more information, see [Rule language reference](https://docs.aws.amazon.com/frauddetector/latest/ug/rule-language-reference.html) .
         */
        expression?: pulumi.Input<string>;
        /**
         * The rule language.
         *
         * Valid Value: DETECTORPL
         */
        language?: pulumi.Input<enums.frauddetector.DetectorRuleLanguage>;
        /**
         * The time when the event type was last updated.
         */
        lastUpdatedTime?: pulumi.Input<string>;
        /**
         * The rule outcome.
         */
        outcomes?: pulumi.Input<pulumi.Input<inputs.frauddetector.DetectorOutcomeArgs>[]>;
        /**
         * The rule ID.
         */
        ruleId?: pulumi.Input<string>;
        /**
         * The rule version.
         */
        ruleVersion?: pulumi.Input<string>;
        /**
         * Tags associated with this event type.
         */
        tags?: pulumi.Input<pulumi.Input<inputs.frauddetector.DetectorTagArgs>[]>;
    }
    interface DetectorTagArgs {
        /**
         * A tag key.
         */
        key: pulumi.Input<string>;
        /**
         * A value assigned to a tag key.
         */
        value: pulumi.Input<string>;
    }
    interface EventTypeEntityTypeArgs {
        /**
         * The entity type ARN.
         */
        arn?: pulumi.Input<string>;
        /**
         * The time when the event type was created.
         */
        createdTime?: pulumi.Input<string>;
        /**
         * The description.
         */
        description?: pulumi.Input<string>;
        /**
         * Indicates whether the resource is defined within this CloudFormation template and impacts the create, update, and delete behavior of the stack. If the value is `true` , CloudFormation will create/update/delete the resource when creating/updating/deleting the stack. If the value is `false` , CloudFormation will validate that the object exists and then use it within the resource without making changes to the object.
         *
         * For example, when creating `AWS::FraudDetector::EventType` you must define at least two variables. You can set `Inline=true` for these variables and CloudFormation will create/update/delete the variables as part of stack operations. However, if you set `Inline=false` , CloudFormation will associate the variables to your event type but not execute any changes to the variables.
         */
        inline?: pulumi.Input<boolean>;
        /**
         * The time when the event type was last updated.
         */
        lastUpdatedTime?: pulumi.Input<string>;
        /**
         * The entity type name.
         *
         * `^[0-9a-z_-]+$`
         */
        name?: pulumi.Input<string>;
        /**
         * Tags associated with this event type.
         */
        tags?: pulumi.Input<pulumi.Input<inputs.frauddetector.EventTypeTagArgs>[]>;
    }
    interface EventTypeEventVariableArgs {
        /**
         * The event variable ARN.
         */
        arn?: pulumi.Input<string>;
        /**
         * The time when the event type was created.
         */
        createdTime?: pulumi.Input<string>;
        /**
         * The source of the event variable.
         *
         * Valid values: `EVENT | EXTERNAL_MODEL_SCORE`
         *
         * When defining a variable within a event type, you can only use the `EVENT` value for DataSource when the *Inline* property is set to true. If the *Inline* property is set false, you can use either `EVENT` or `MODEL_SCORE` for DataSource.
         */
        dataSource?: pulumi.Input<enums.frauddetector.EventTypeEventVariableDataSource>;
        /**
         * The data type of the event variable. For more information, see [Data types](https://docs.aws.amazon.com/frauddetector/latest/ug/variables.html#data-types) .
         */
        dataType?: pulumi.Input<enums.frauddetector.EventTypeEventVariableDataType>;
        /**
         * The default value of the event variable
         */
        defaultValue?: pulumi.Input<string>;
        /**
         * The description.
         */
        description?: pulumi.Input<string>;
        /**
         * Indicates whether the resource is defined within this CloudFormation template and impacts the create, update, and delete behavior of the stack. If the value is `true` , CloudFormation will create/update/delete the resource when creating/updating/deleting the stack. If the value is `false` , CloudFormation will validate that the object exists and then use it within the resource without making changes to the object.
         *
         * For example, when creating `AWS::FraudDetector::EventType` you must define at least two variables. You can set `Inline=true` for these variables and CloudFormation will create/update/delete the Variables as part of stack operations. However, if you set `Inline=false` , CloudFormation will associate the variables to your event type but not execute any changes to the variables.
         */
        inline?: pulumi.Input<boolean>;
        /**
         * The time when the event type was last updated.
         */
        lastUpdatedTime?: pulumi.Input<string>;
        /**
         * The name of the event variable.
         */
        name?: pulumi.Input<string>;
        /**
         * Tags associated with this event type.
         */
        tags?: pulumi.Input<pulumi.Input<inputs.frauddetector.EventTypeTagArgs>[]>;
        /**
         * The type of event variable. For more information, see [Variable types](https://docs.aws.amazon.com/frauddetector/latest/ug/variables.html#variable-types) .
         */
        variableType?: pulumi.Input<enums.frauddetector.EventTypeEventVariableVariableType>;
    }
    interface EventTypeLabelArgs {
        /**
         * The label ARN.
         */
        arn?: pulumi.Input<string>;
        /**
         * The time when the event type was created.
         */
        createdTime?: pulumi.Input<string>;
        /**
         * The description.
         */
        description?: pulumi.Input<string>;
        /**
         * Indicates whether the resource is defined within this CloudFormation template and impacts the create, update, and delete behavior of the stack. If the value is `true` , CloudFormation will create/update/delete the resource when creating/updating/deleting the stack. If the value is `false` , CloudFormation will validate that the object exists and then use it within the resource without making changes to the object.
         *
         * For example, when creating `AWS::FraudDetector::EventType` you must define at least two variables. You can set `Inline=true` for these variables and CloudFormation will create/update/delete the variables as part of stack operations. However, if you set `Inline=false` , CloudFormation will associate the variables to your EventType but not execute any changes to the variables.
         */
        inline?: pulumi.Input<boolean>;
        /**
         * The time when the event type was last updated.
         */
        lastUpdatedTime?: pulumi.Input<string>;
        /**
         * The label name.
         */
        name?: pulumi.Input<string>;
        /**
         * Tags associated with this event type.
         */
        tags?: pulumi.Input<pulumi.Input<inputs.frauddetector.EventTypeTagArgs>[]>;
    }
    interface EventTypeTagArgs {
        /**
         * A tag key.
         */
        key: pulumi.Input<string>;
        /**
         * A value assigned to a tag key.
         */
        value: pulumi.Input<string>;
    }
}
export declare namespace fsx {
    /**
     * Describes a data repository association's automatic export policy. The ``AutoExportPolicy`` defines the types of updated objects on the file system that will be automatically exported to the data repository. As you create, modify, or delete files, Amazon FSx for Lustre automatically exports the defined changes asynchronously once your application finishes modifying the file.
     *  The ``AutoExportPolicy`` is only supported on Amazon FSx for Lustre file systems with a data repository association.
     */
    interface DataRepositoryAssociationAutoExportPolicyArgs {
        /**
         * The ``AutoExportPolicy`` can have the following event values:
         *   +   ``NEW`` - New files and directories are automatically exported to the data repository as they are added to the file system.
         *   +   ``CHANGED`` - Changes to files and directories on the file system are automatically exported to the data repository.
         *   +   ``DELETED`` - Files and directories are automatically deleted on the data repository when they are deleted on the file system.
         *
         *  You can define any combination of event types for your ``AutoExportPolicy``.
         */
        events: pulumi.Input<pulumi.Input<enums.fsx.DataRepositoryAssociationEventType>[]>;
    }
    /**
     * Describes the data repository association's automatic import policy. The AutoImportPolicy defines how Amazon FSx keeps your file metadata and directory listings up to date by importing changes to your Amazon FSx for Lustre file system as you modify objects in a linked S3 bucket.
     *  The ``AutoImportPolicy`` is only supported on Amazon FSx for Lustre file systems with a data repository association.
     */
    interface DataRepositoryAssociationAutoImportPolicyArgs {
        /**
         * The ``AutoImportPolicy`` can have the following event values:
         *   +   ``NEW`` - Amazon FSx automatically imports metadata of files added to the linked S3 bucket that do not currently exist in the FSx file system.
         *   +   ``CHANGED`` - Amazon FSx automatically updates file metadata and invalidates existing file content on the file system as files change in the data repository.
         *   +   ``DELETED`` - Amazon FSx automatically deletes files on the file system as corresponding files are deleted in the data repository.
         *
         *  You can define any combination of event types for your ``AutoImportPolicy``.
         */
        events: pulumi.Input<pulumi.Input<enums.fsx.DataRepositoryAssociationEventType>[]>;
    }
    /**
     * The configuration for an Amazon S3 data repository linked to an Amazon FSx Lustre file system with a data repository association. The configuration defines which file events (new, changed, or deleted files or directories) are automatically imported from the linked data repository to the file system or automatically exported from the file system to the data repository.
     */
    interface DataRepositoryAssociationS3Args {
        /**
         * Describes a data repository association's automatic export policy. The ``AutoExportPolicy`` defines the types of updated objects on the file system that will be automatically exported to the data repository. As you create, modify, or delete files, Amazon FSx for Lustre automatically exports the defined changes asynchronously once your application finishes modifying the file.
         *  The ``AutoExportPolicy`` is only supported on Amazon FSx for Lustre file systems with a data repository association.
         */
        autoExportPolicy?: pulumi.Input<inputs.fsx.DataRepositoryAssociationAutoExportPolicyArgs>;
        /**
         * Describes the data repository association's automatic import policy. The AutoImportPolicy defines how Amazon FSx keeps your file metadata and directory listings up to date by importing changes to your Amazon FSx for Lustre file system as you modify objects in a linked S3 bucket.
         *  The ``AutoImportPolicy`` is only supported on Amazon FSx for Lustre file systems with a data repository association.
         */
        autoImportPolicy?: pulumi.Input<inputs.fsx.DataRepositoryAssociationAutoImportPolicyArgs>;
    }
}
export declare namespace gamelift {
    interface AliasRoutingStrategyArgs {
        /**
         * A unique identifier for a fleet that the alias points to. If you specify SIMPLE for the Type property, you must specify this property.
         */
        fleetId?: pulumi.Input<string>;
        /**
         * The message text to be used with a terminal routing strategy. If you specify TERMINAL for the Type property, you must specify this property.
         */
        message?: pulumi.Input<string>;
        /**
         * Simple routing strategy. The alias resolves to one specific fleet. Use this type when routing to active fleets.
         */
        type: pulumi.Input<enums.gamelift.AliasRoutingStrategyType>;
    }
    interface BuildStorageLocationArgs {
        /**
         * An Amazon S3 bucket identifier. This is the name of the S3 bucket.
         */
        bucket: pulumi.Input<string>;
        /**
         * The name of the zip file that contains the build files or script files.
         */
        key: pulumi.Input<string>;
        /**
         * The version of the file, if object versioning is turned on for the bucket. Amazon GameLift uses this information when retrieving files from your S3 bucket. To retrieve a specific version of the file, provide an object version. To retrieve the latest version of the file, do not set this parameter.
         */
        objectVersion?: pulumi.Input<string>;
        /**
         * The Amazon Resource Name (ARN) for an IAM role that allows Amazon GameLift to access the S3 bucket.
         */
        roleArn: pulumi.Input<string>;
    }
    /**
     * Defines the range of ports on the instance that allow inbound traffic to connect with containers in a fleet.
     */
    interface ContainerFleetConnectionPortRangeArgs {
        /**
         * A starting value for a range of allowed port numbers.
         */
        fromPort: pulumi.Input<number>;
        /**
         * An ending value for a range of allowed port numbers. Port numbers are end-inclusive. This value must be higher than FromPort.
         */
        toPort: pulumi.Input<number>;
    }
    /**
     * Provides details about how to drain old tasks and replace them with new updated tasks.
     */
    interface ContainerFleetDeploymentConfigurationArgs {
        /**
         * The strategy to apply in case of impairment; defaults to MAINTAIN.
         */
        impairmentStrategy?: pulumi.Input<enums.gamelift.ContainerFleetDeploymentConfigurationImpairmentStrategy>;
        /**
         * The minimum percentage of healthy required; defaults to 75.
         */
        minimumHealthyPercentage?: pulumi.Input<number>;
        /**
         * The protection strategy for deployment on the container fleet; defaults to WITH_PROTECTION.
         */
        protectionStrategy?: pulumi.Input<enums.gamelift.ContainerFleetDeploymentConfigurationProtectionStrategy>;
    }
    /**
     * A policy that limits the number of game sessions a player can create on the same fleet. This optional policy gives game owners control over how players can consume available game server resources. A resource creation policy makes the following statement: "An individual player can create a maximum number of new game sessions within a specified time period".
     *
     * The policy is evaluated when a player tries to create a new game session. For example, assume you have a policy of 10 new game sessions and a time period of 60 minutes. On receiving a CreateGameSession request, Amazon GameLift checks that the player (identified by CreatorId) has created fewer than 10 game sessions in the past 60 minutes.
     */
    interface ContainerFleetGameSessionCreationLimitPolicyArgs {
        /**
         * The maximum number of game sessions that an individual can create during the policy period.
         */
        newGameSessionsPerCreator?: pulumi.Input<number>;
        /**
         * The time span used in evaluating the resource creation limit policy.
         */
        policyPeriodInMinutes?: pulumi.Input<number>;
    }
    /**
     * A range of IP addresses and port settings that allow inbound traffic to connect to server processes on an Amazon GameLift hosting resource. New game sessions that are started on the fleet are assigned an IP address/port number combination, which must fall into the fleet's allowed ranges. For fleets created with a custom game server, the ranges reflect the server's game session assignments. For Realtime Servers fleets, Amazon GameLift automatically opens two port ranges, one for TCP messaging and one for UDP, for use by the Realtime servers.
     */
    interface ContainerFleetIpPermissionArgs {
        /**
         * A starting value for a range of allowed port numbers.
         */
        fromPort: pulumi.Input<number>;
        /**
         * A range of allowed IP addresses. This value must be expressed in CIDR notation. Example: "000.000.000.000/[subnet mask]" or optionally the shortened version "0.0.0.0/[subnet mask]".
         */
        ipRange: pulumi.Input<string>;
        /**
         * The network communication protocol used by the fleet.
         */
        protocol: pulumi.Input<enums.gamelift.ContainerFleetIpPermissionProtocol>;
        /**
         * An ending value for a range of allowed port numbers. Port numbers are end-inclusive. This value must be higher than FromPort.
         */
        toPort: pulumi.Input<number>;
    }
    /**
     * Current resource capacity settings in a specified fleet or location. The location value might refer to a fleet's remote location or its home Region.
     */
    interface ContainerFleetLocationCapacityArgs {
        /**
         * The number of EC2 instances you want to maintain in the specified fleet location. This value must fall between the minimum and maximum size limits.
         */
        desiredEc2Instances: pulumi.Input<number>;
        /**
         * The maximum value that is allowed for the fleet's instance count for a location.
         */
        maxSize: pulumi.Input<number>;
        /**
         * The minimum value allowed for the fleet's instance count for a location.
         */
        minSize: pulumi.Input<number>;
    }
    /**
     * A remote location where a multi-location fleet can deploy EC2 instances for game hosting.
     */
    interface ContainerFleetLocationConfigurationArgs {
        /**
         * An AWS Region code, such as `us-west-2` . For a list of supported Regions and Local Zones, see [Amazon GameLift Servers service locations](https://docs.aws.amazon.com/gamelift/latest/developerguide/gamelift-regions.html) for managed hosting.
         */
        location: pulumi.Input<string>;
        locationCapacity?: pulumi.Input<inputs.gamelift.ContainerFleetLocationCapacityArgs>;
        stoppedActions?: pulumi.Input<pulumi.Input<enums.gamelift.ContainerFleetStoppedActionsItem>[]>;
    }
    /**
     * A policy the location and provider of logs from the fleet.
     */
    interface ContainerFleetLogConfigurationArgs {
        /**
         * The type of log collection to use for a fleet.
         *
         * - `CLOUDWATCH` -- (default value) Send logs to an Amazon CloudWatch log group that you define. Each container emits a log stream, which is organized in the log group.
         * - `S3` -- Store logs in an Amazon S3 bucket that you define. This bucket must reside in the fleet's home AWS Region.
         * - `NONE` -- Don't collect container logs.
         */
        logDestination?: pulumi.Input<enums.gamelift.ContainerFleetLogDestination>;
        /**
         * The name of the S3 bucket to pull logs from if S3 is the LogDestination
         */
        s3BucketName?: pulumi.Input<string>;
    }
    /**
     * Rule that controls how a fleet is scaled. Scaling policies are uniquely identified by the combination of name and fleet ID.
     */
    interface ContainerFleetScalingPolicyArgs {
        /**
         * Comparison operator to use when measuring a metric against the threshold value.
         */
        comparisonOperator?: pulumi.Input<enums.gamelift.ContainerFleetScalingPolicyComparisonOperator>;
        /**
         * Length of time (in minutes) the metric must be at or beyond the threshold before a scaling event is triggered.
         */
        evaluationPeriods?: pulumi.Input<number>;
        /**
         * Name of the Amazon GameLift-defined metric that is used to trigger a scaling adjustment.
         */
        metricName: pulumi.Input<enums.gamelift.ContainerFleetScalingPolicyMetricName>;
        /**
         * A descriptive label that is associated with a fleet's scaling policy. Policy names do not need to be unique.
         */
        name: pulumi.Input<string>;
        /**
         * The type of scaling policy to create. For a target-based policy, set the parameter MetricName to 'PercentAvailableGameSessions' and specify a TargetConfiguration. For a rule-based policy set the following parameters: MetricName, ComparisonOperator, Threshold, EvaluationPeriods, ScalingAdjustmentType, and ScalingAdjustment.
         */
        policyType?: pulumi.Input<enums.gamelift.ContainerFleetScalingPolicyPolicyType>;
        /**
         * Amount of adjustment to make, based on the scaling adjustment type.
         */
        scalingAdjustment?: pulumi.Input<number>;
        /**
         * The type of adjustment to make to a fleet's instance count.
         */
        scalingAdjustmentType?: pulumi.Input<enums.gamelift.ContainerFleetScalingPolicyScalingAdjustmentType>;
        /**
         * An object that contains settings for a target-based scaling policy.
         */
        targetConfiguration?: pulumi.Input<inputs.gamelift.ContainerFleetTargetConfigurationArgs>;
        /**
         * Metric value used to trigger a scaling event.
         */
        threshold?: pulumi.Input<number>;
    }
    /**
     * Settings for a target-based scaling policy. A target-based policy tracks a particular fleet metric specifies a target value for the metric. As player usage changes, the policy triggers Amazon GameLift to adjust capacity so that the metric returns to the target value. The target configuration specifies settings as needed for the target based policy, including the target value.
     */
    interface ContainerFleetTargetConfigurationArgs {
        /**
         * Desired value to use with a target-based scaling policy. The value must be relevant for whatever metric the scaling policy is using. For example, in a policy using the metric PercentAvailableGameSessions, the target value should be the preferred size of the fleet's buffer (the percent of capacity that should be idle and ready for new game sessions).
         */
        targetValue: pulumi.Input<number>;
    }
    /**
     * A dependency that impacts a container's startup and shutdown.
     */
    interface ContainerGroupDefinitionContainerDependencyArgs {
        /**
         * The type of dependency.
         */
        condition: pulumi.Input<enums.gamelift.ContainerGroupDefinitionContainerDependencyCondition>;
        /**
         * A descriptive label for the container definition. The container being defined depends on this container's condition.
         */
        containerName: pulumi.Input<string>;
    }
    /**
     * An environment variable to set inside a container, in the form of a key-value pair.
     */
    interface ContainerGroupDefinitionContainerEnvironmentArgs {
        /**
         * The environment variable name.
         */
        name: pulumi.Input<string>;
        /**
         * The environment variable value.
         */
        value: pulumi.Input<string>;
    }
    /**
     * Specifies how the process manager checks the health of containers.
     */
    interface ContainerGroupDefinitionContainerHealthCheckArgs {
        /**
         * A string array representing the command that the container runs to determine if it is healthy.
         */
        command: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * How often (in seconds) the health is checked.
         */
        interval?: pulumi.Input<number>;
        /**
         * How many times the process manager will retry the command after a timeout. (The first run of the command does not count as a retry.)
         */
        retries?: pulumi.Input<number>;
        /**
         * The optional grace period (in seconds) to give a container time to boostrap before teh health check is declared failed.
         */
        startPeriod?: pulumi.Input<number>;
        /**
         * How many seconds the process manager allows the command to run before canceling it.
         */
        timeout?: pulumi.Input<number>;
    }
    /**
     * Defines the mount point configuration within a container.
     */
    interface ContainerGroupDefinitionContainerMountPointArgs {
        /**
         * The access permissions for the mounted path.
         */
        accessLevel?: pulumi.Input<enums.gamelift.ContainerGroupDefinitionContainerMountPointAccessLevel>;
        /**
         * The path inside the container where the mount is accessible.
         */
        containerPath?: pulumi.Input<string>;
        /**
         * The path on the host that will be mounted in the container.
         */
        instancePath: pulumi.Input<string>;
    }
    /**
     * A set of one or more port numbers that can be opened on the container.
     */
    interface ContainerGroupDefinitionContainerPortRangeArgs {
        /**
         * A starting value for the range of allowed port numbers.
         */
        fromPort: pulumi.Input<number>;
        /**
         * Defines the protocol of these ports.
         */
        protocol: pulumi.Input<enums.gamelift.ContainerGroupDefinitionContainerPortRangeProtocol>;
        /**
         * An ending value for the range of allowed port numbers. Port numbers are end-inclusive. This value must be equal to or greater than FromPort.
         */
        toPort: pulumi.Input<number>;
    }
    /**
     * Specifies the information required to run game servers with this container group
     */
    interface ContainerGroupDefinitionGameServerContainerDefinitionArgs {
        /**
         * A descriptive label for the container definition. Container definition names must be unique with a container group definition.
         */
        containerName: pulumi.Input<string>;
        /**
         * A list of container dependencies that determines when this container starts up and shuts down. For container groups with multiple containers, dependencies let you define a startup/shutdown sequence across the containers.
         */
        dependsOn?: pulumi.Input<pulumi.Input<inputs.gamelift.ContainerGroupDefinitionContainerDependencyArgs>[]>;
        /**
         * The environment variables to pass to a container.
         */
        environmentOverride?: pulumi.Input<pulumi.Input<inputs.gamelift.ContainerGroupDefinitionContainerEnvironmentArgs>[]>;
        /**
         * Specifies the image URI of this container.
         */
        imageUri: pulumi.Input<string>;
        /**
         * A list of mount point configurations to be used in a container.
         */
        mountPoints?: pulumi.Input<pulumi.Input<inputs.gamelift.ContainerGroupDefinitionContainerMountPointArgs>[]>;
        /**
         * Defines the ports on the container.
         */
        portConfiguration?: pulumi.Input<inputs.gamelift.ContainerGroupDefinitionPortConfigurationArgs>;
        /**
         * The digest of the container image.
         */
        resolvedImageDigest?: pulumi.Input<string>;
        /**
         * The version of the server SDK used in this container group
         */
        serverSdkVersion: pulumi.Input<string>;
    }
    /**
     * Defines the ports on a container.
     */
    interface ContainerGroupDefinitionPortConfigurationArgs {
        /**
         * Specifies one or more ranges of ports on a container.
         */
        containerPortRanges: pulumi.Input<pulumi.Input<inputs.gamelift.ContainerGroupDefinitionContainerPortRangeArgs>[]>;
    }
    /**
     * Supports the function of the main container group
     */
    interface ContainerGroupDefinitionSupportContainerDefinitionArgs {
        /**
         * A descriptive label for the container definition.
         */
        containerName: pulumi.Input<string>;
        /**
         * A list of container dependencies that determines when this container starts up and shuts down. For container groups with multiple containers, dependencies let you define a startup/shutdown sequence across the containers.
         */
        dependsOn?: pulumi.Input<pulumi.Input<inputs.gamelift.ContainerGroupDefinitionContainerDependencyArgs>[]>;
        /**
         * The environment variables to pass to a container.
         */
        environmentOverride?: pulumi.Input<pulumi.Input<inputs.gamelift.ContainerGroupDefinitionContainerEnvironmentArgs>[]>;
        /**
         * Specifies if the container is essential. If an essential container fails a health check, then all containers in the container group will be restarted. You must specify exactly 1 essential container in a container group.
         */
        essential?: pulumi.Input<boolean>;
        /**
         * Specifies how the health of the containers will be checked.
         */
        healthCheck?: pulumi.Input<inputs.gamelift.ContainerGroupDefinitionContainerHealthCheckArgs>;
        /**
         * Specifies the image URI of this container.
         */
        imageUri: pulumi.Input<string>;
        /**
         * The total memory limit of container groups following this definition in MiB
         */
        memoryHardLimitMebibytes?: pulumi.Input<number>;
        /**
         * A list of mount point configurations to be used in a container.
         */
        mountPoints?: pulumi.Input<pulumi.Input<inputs.gamelift.ContainerGroupDefinitionContainerMountPointArgs>[]>;
        /**
         * Defines the ports on the container.
         */
        portConfiguration?: pulumi.Input<inputs.gamelift.ContainerGroupDefinitionPortConfigurationArgs>;
        /**
         * The digest of the container image.
         */
        resolvedImageDigest?: pulumi.Input<string>;
        /**
         * The number of virtual CPUs to give to the support group
         */
        vcpu?: pulumi.Input<number>;
    }
    /**
     * Configuration for Anywhere fleet.
     */
    interface FleetAnywhereConfigurationArgs {
        /**
         * Cost of compute can be specified on Anywhere Fleets to prioritize placement across Queue destinations based on Cost.
         */
        cost: pulumi.Input<string>;
    }
    /**
     * Information about the use of a TLS/SSL certificate for a fleet. TLS certificate generation is enabled at the fleet level, with one certificate generated for the fleet. When this feature is enabled, the certificate can be retrieved using the GameLift Server SDK call GetInstanceCertificate. All instances in a fleet share the same certificate.
     */
    interface FleetCertificateConfigurationArgs {
        /**
         * Indicates whether a TLS/SSL certificate is generated for a fleet.
         *
         * Valid values include:
         *
         * - *GENERATED* - Generate a TLS/SSL certificate for this fleet.
         * - *DISABLED* - (default) Do not generate a TLS/SSL certificate for this fleet.
         */
        certificateType: pulumi.Input<enums.gamelift.FleetCertificateConfigurationCertificateType>;
    }
    /**
     * A range of IP addresses and port settings that allow inbound traffic to connect to server processes on an Amazon GameLift hosting resource. New game sessions that are started on the fleet are assigned an IP address/port number combination, which must fall into the fleet's allowed ranges. For fleets created with a custom game server, the ranges reflect the server's game session assignments. For Realtime Servers fleets, Amazon GameLift automatically opens two port ranges, one for TCP messaging and one for UDP, for use by the Realtime servers.
     */
    interface FleetIpPermissionArgs {
        /**
         * A starting value for a range of allowed port numbers.
         */
        fromPort: pulumi.Input<number>;
        /**
         * A range of allowed IP addresses. This value must be expressed in CIDR notation. Example: "000.000.000.000/[subnet mask]" or optionally the shortened version "0.0.0.0/[subnet mask]".
         */
        ipRange: pulumi.Input<string>;
        /**
         * The network communication protocol used by the fleet.
         */
        protocol: pulumi.Input<enums.gamelift.FleetIpPermissionProtocol>;
        /**
         * An ending value for a range of allowed port numbers. Port numbers are end-inclusive. This value must be higher than FromPort.
         */
        toPort: pulumi.Input<number>;
    }
    /**
     * Current resource capacity settings in a specified fleet or location. The location value might refer to a fleet's remote location or its home Region.
     */
    interface FleetLocationCapacityArgs {
        /**
         * The number of EC2 instances you want to maintain in the specified fleet location. This value must fall between the minimum and maximum size limits.
         */
        desiredEc2Instances: pulumi.Input<number>;
        /**
         * The maximum value that is allowed for the fleet's instance count for a location. When creating a new fleet, GameLift automatically sets this value to "1". Once the fleet is active, you can change this value.
         */
        maxSize: pulumi.Input<number>;
        /**
         * The minimum value allowed for the fleet's instance count for a location. When creating a new fleet, GameLift automatically sets this value to "0". After the fleet is active, you can change this value.
         */
        minSize: pulumi.Input<number>;
    }
    /**
     * A remote location where a multi-location fleet can deploy EC2 instances for game hosting.
     */
    interface FleetLocationConfigurationArgs {
        /**
         * An AWS Region code, such as `us-west-2` . For a list of supported Regions and Local Zones, see [Amazon GameLift Servers service locations](https://docs.aws.amazon.com/gamelift/latest/developerguide/gamelift-regions.html) for managed hosting.
         */
        location: pulumi.Input<string>;
        /**
         * Current resource capacity settings for managed EC2 fleets and managed container fleets. For multi-location fleets, location values might refer to a fleet's remote location or its home Region.
         *
         * *Returned by:* [DescribeFleetCapacity](https://docs.aws.amazon.com/gamelift/latest/apireference/API_DescribeFleetCapacity.html) , [DescribeFleetLocationCapacity](https://docs.aws.amazon.com/gamelift/latest/apireference/API_DescribeFleetLocationCapacity.html) , [UpdateFleetCapacity](https://docs.aws.amazon.com/gamelift/latest/apireference/API_UpdateFleetCapacity.html)
         */
        locationCapacity?: pulumi.Input<inputs.gamelift.FleetLocationCapacityArgs>;
    }
    /**
     * A policy that limits the number of game sessions a player can create on the same fleet. This optional policy gives game owners control over how players can consume available game server resources. A resource creation policy makes the following statement: "An individual player can create a maximum number of new game sessions within a specified time period".
     *
     * The policy is evaluated when a player tries to create a new game session. For example, assume you have a policy of 10 new game sessions and a time period of 60 minutes. On receiving a CreateGameSession request, Amazon GameLift checks that the player (identified by CreatorId) has created fewer than 10 game sessions in the past 60 minutes.
     */
    interface FleetResourceCreationLimitPolicyArgs {
        /**
         * The maximum number of game sessions that an individual can create during the policy period.
         */
        newGameSessionsPerCreator?: pulumi.Input<number>;
        /**
         * The time span used in evaluating the resource creation limit policy.
         */
        policyPeriodInMinutes?: pulumi.Input<number>;
    }
    /**
     * A collection of server process configurations that describe the processes to run on each instance in a fleet. All fleets must have a runtime configuration. Each instance in the fleet maintains server processes as specified in the runtime configuration, launching new ones as existing processes end. Each instance regularly checks for an updated runtime configuration makes adjustments as called for.
     *
     * The runtime configuration enables the instances in a fleet to run multiple processes simultaneously. Potential scenarios are as follows: (1) Run multiple processes of a single game server executable to maximize usage of your hosting resources. (2) Run one or more processes of different executables, such as your game server and a metrics tracking program. (3) Run multiple processes of a single game server but with different launch parameters, for example to run one process on each instance in debug mode.
     *
     * An Amazon GameLift instance is limited to 50 processes running simultaneously. A runtime configuration must specify fewer than this limit. To calculate the total number of processes specified in a runtime configuration, add the values of the ConcurrentExecutions parameter for each ServerProcess object in the runtime configuration.
     */
    interface FleetRuntimeConfigurationArgs {
        /**
         * The maximum amount of time (in seconds) that a game session can remain in status ACTIVATING. If the game session is not active before the timeout, activation is terminated and the game session status is changed to TERMINATED.
         */
        gameSessionActivationTimeoutSeconds?: pulumi.Input<number>;
        /**
         * The maximum number of game sessions with status ACTIVATING to allow on an instance simultaneously. This setting limits the amount of instance resources that can be used for new game activations at any one time.
         */
        maxConcurrentGameSessionActivations?: pulumi.Input<number>;
        /**
         * A collection of server process configurations that describe which server processes to run on each instance in a fleet.
         */
        serverProcesses?: pulumi.Input<pulumi.Input<inputs.gamelift.FleetServerProcessArgs>[]>;
    }
    /**
     * Rule that controls how a fleet is scaled. Scaling policies are uniquely identified by the combination of name and fleet ID.
     */
    interface FleetScalingPolicyArgs {
        /**
         * Comparison operator to use when measuring a metric against the threshold value.
         */
        comparisonOperator?: pulumi.Input<enums.gamelift.FleetScalingPolicyComparisonOperator>;
        /**
         * Length of time (in minutes) the metric must be at or beyond the threshold before a scaling event is triggered.
         */
        evaluationPeriods?: pulumi.Input<number>;
        /**
         * The fleet location.
         */
        location?: pulumi.Input<string>;
        /**
         * Name of the Amazon GameLift-defined metric that is used to trigger a scaling adjustment.
         */
        metricName: pulumi.Input<enums.gamelift.FleetScalingPolicyMetricName>;
        /**
         * A descriptive label that is associated with a fleet's scaling policy. Policy names do not need to be unique.
         */
        name: pulumi.Input<string>;
        /**
         * The type of scaling policy to create. For a target-based policy, set the parameter MetricName to 'PercentAvailableGameSessions' and specify a TargetConfiguration. For a rule-based policy set the following parameters: MetricName, ComparisonOperator, Threshold, EvaluationPeriods, ScalingAdjustmentType, and ScalingAdjustment.
         */
        policyType?: pulumi.Input<enums.gamelift.FleetScalingPolicyPolicyType>;
        /**
         * Amount of adjustment to make, based on the scaling adjustment type.
         */
        scalingAdjustment?: pulumi.Input<number>;
        /**
         * The type of adjustment to make to a fleet's instance count.
         */
        scalingAdjustmentType?: pulumi.Input<enums.gamelift.FleetScalingPolicyScalingAdjustmentType>;
        /**
         * Current status of the scaling policy. The scaling policy can be in force only when in an ACTIVE status. Scaling policies can be suspended for individual fleets. If the policy is suspended for a fleet, the policy status does not change.
         */
        status?: pulumi.Input<enums.gamelift.FleetScalingPolicyStatus>;
        /**
         * An object that contains settings for a target-based scaling policy.
         */
        targetConfiguration?: pulumi.Input<inputs.gamelift.FleetTargetConfigurationArgs>;
        /**
         * Metric value used to trigger a scaling event.
         */
        threshold?: pulumi.Input<number>;
        /**
         * The current status of the fleet's scaling policies in a requested fleet location. The status PENDING_UPDATE indicates that an update was requested for the fleet but has not yet been completed for the location.
         */
        updateStatus?: pulumi.Input<enums.gamelift.FleetScalingPolicyUpdateStatus>;
    }
    /**
     * A set of instructions for launching server processes on each instance in a fleet. Each instruction set identifies the location of the server executable, optional launch parameters, and the number of server processes with this configuration to maintain concurrently on the instance. Server process configurations make up a fleet's RuntimeConfiguration.
     */
    interface FleetServerProcessArgs {
        /**
         * The number of server processes that use this configuration to run concurrently on an instance.
         */
        concurrentExecutions: pulumi.Input<number>;
        /**
         * The location of the server executable in a custom game build or the name of the Realtime script file that contains the Init() function. Game builds and Realtime scripts are installed on instances at the root:
         *
         * Windows (for custom game builds only): C:\game. Example: "C:\game\MyGame\server.exe"
         *
         * Linux: /local/game. Examples: "/local/game/MyGame/server.exe" or "/local/game/MyRealtimeScript.js"
         */
        launchPath: pulumi.Input<string>;
        /**
         * An optional list of parameters to pass to the server executable or Realtime script on launch.
         */
        parameters?: pulumi.Input<string>;
    }
    /**
     * Settings for a target-based scaling policy. A target-based policy tracks a particular fleet metric specifies a target value for the metric. As player usage changes, the policy triggers Amazon GameLift to adjust capacity so that the metric returns to the target value. The target configuration specifies settings as needed for the target based policy, including the target value.
     */
    interface FleetTargetConfigurationArgs {
        /**
         * Desired value to use with a target-based scaling policy. The value must be relevant for whatever metric the scaling policy is using. For example, in a policy using the metric PercentAvailableGameSessions, the target value should be the preferred size of the fleet's buffer (the percent of capacity that should be idle and ready for new game sessions).
         */
        targetValue: pulumi.Input<number>;
    }
    /**
     * Configuration settings to define a scaling policy for the Auto Scaling group that is optimized for game hosting. Updating this game server group property will not take effect for the created EC2 Auto Scaling group, please update the EC2 Auto Scaling group directly after creating the resource.
     */
    interface GameServerGroupAutoScalingPolicyArgs {
        /**
         * Length of time, in seconds, it takes for a new instance to start new game server processes and register with Amazon GameLift Servers FleetIQ. Specifying a warm-up time can be useful, particularly with game servers that take a long time to start up, because it avoids prematurely starting new instances.
         */
        estimatedInstanceWarmup?: pulumi.Input<number>;
        /**
         * Settings for a target-based scaling policy applied to Auto Scaling group. These settings are used to create a target-based policy that tracks the GameLift FleetIQ metric `PercentUtilizedGameServers` and specifies a target value for the metric. As player usage changes, the policy triggers to adjust the game server group capacity so that the metric returns to the target value.
         */
        targetTrackingConfiguration: pulumi.Input<inputs.gamelift.GameServerGroupTargetTrackingConfigurationArgs>;
    }
    /**
     * An allowed instance type for your game server group.
     */
    interface GameServerGroupInstanceDefinitionArgs {
        instanceType: pulumi.Input<string>;
        weightedCapacity?: pulumi.Input<string>;
    }
    /**
     * The EC2 launch template that contains configuration settings and game server code to be deployed to all instances in the game server group. Updating this game server group property will not take effect for the created EC2 Auto Scaling group, please update the EC2 Auto Scaling group directly after creating the resource.
     */
    interface GameServerGroupLaunchTemplateArgs {
        /**
         * A unique identifier for an existing Amazon EC2 launch template.
         */
        launchTemplateId?: pulumi.Input<string>;
        /**
         * A readable identifier for an existing Amazon EC2 launch template.
         */
        launchTemplateName?: pulumi.Input<string>;
        /**
         * The version of the Amazon EC2 launch template to use. If no version is specified, the default version will be used. With Amazon EC2, you can specify a default version for a launch template. If none is set, the default is the first version created.
         */
        version?: pulumi.Input<string>;
    }
    /**
     * Settings for a target-based scaling policy applied to Auto Scaling group.
     */
    interface GameServerGroupTargetTrackingConfigurationArgs {
        /**
         * Desired value to use with a game server group target-based scaling policy.
         */
        targetValue: pulumi.Input<number>;
    }
    /**
     * A fleet or alias designated in a game session queue.
     */
    interface GameSessionQueueDestinationArgs {
        /**
         * The Amazon Resource Name (ARN) that is assigned to fleet or fleet alias. ARNs, which include a fleet ID or alias ID and a Region name, provide a unique identifier across all Regions.
         */
        destinationArn?: pulumi.Input<string>;
    }
    interface GameSessionQueueFilterConfigurationArgs {
        /**
         * A list of locations to allow game session placement in, in the form of AWS Region codes such as `us-west-2` .
         */
        allowedLocations?: pulumi.Input<pulumi.Input<string>[]>;
    }
    /**
     * Sets a latency cap for individual players when placing a game session.
     */
    interface GameSessionQueuePlayerLatencyPolicyArgs {
        /**
         * The maximum latency value that is allowed for any player, in milliseconds. All policies must have a value set for this property.
         */
        maximumIndividualPlayerLatencyMilliseconds?: pulumi.Input<number>;
        /**
         * The length of time, in seconds, that the policy is enforced while placing a new game session.
         */
        policyDurationSeconds?: pulumi.Input<number>;
    }
    interface GameSessionQueuePriorityConfigurationArgs {
        /**
         * The prioritization order to use for fleet locations, when the `PriorityOrder` property includes `LOCATION` . Locations can include AWS Region codes (such as `us-west-2` ), local zones, and custom locations (for Anywhere fleets). Each location must be listed only once. For details, see [Amazon GameLift Servers service locations.](https://docs.aws.amazon.com/gamelift/latest/developerguide/gamelift-regions.html)
         */
        locationOrder?: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * A custom sequence to use when prioritizing where to place new game sessions. Each priority type is listed once.
         *
         * - `LATENCY` -- Amazon GameLift Servers prioritizes locations where the average player latency is lowest. Player latency data is provided in each game session placement request.
         * - `COST` -- Amazon GameLift Servers prioritizes queue destinations with the lowest current hosting costs. Cost is evaluated based on the destination's location, instance type, and fleet type (Spot or On-Demand).
         * - `DESTINATION` -- Amazon GameLift Servers prioritizes based on the list order of destinations in the queue configuration.
         * - `LOCATION` -- Amazon GameLift Servers prioritizes based on the provided order of locations, as defined in `LocationOrder` .
         */
        priorityOrder?: pulumi.Input<pulumi.Input<enums.gamelift.GameSessionQueuePriorityOrderItem>[]>;
    }
    /**
     * A key-value pair that contains information about a game session.
     */
    interface MatchmakingConfigurationGamePropertyArgs {
        /**
         * The game property identifier.
         */
        key: pulumi.Input<string>;
        /**
         * The game property value.
         */
        value: pulumi.Input<string>;
    }
    interface ScriptS3LocationArgs {
        /**
         * An Amazon S3 bucket identifier. This is the name of the S3 bucket.
         */
        bucket: pulumi.Input<string>;
        /**
         * The name of the zip file that contains the script files.
         */
        key: pulumi.Input<string>;
        /**
         * The version of the file, if object versioning is turned on for the bucket. Amazon GameLift uses this information when retrieving files from your S3 bucket. To retrieve a specific version of the file, provide an object version. To retrieve the latest version of the file, do not set this parameter.
         */
        objectVersion?: pulumi.Input<string>;
        /**
         * The Amazon Resource Name (ARN) for an IAM role that allows Amazon GameLift to access the S3 bucket.
         */
        roleArn: pulumi.Input<string>;
    }
}
export declare namespace gameliftstreams {
    interface ApplicationRuntimeEnvironmentArgs {
        /**
         * The operating system and other drivers. For Proton, this also includes the Proton compatibility layer.
         */
        type: pulumi.Input<string>;
        /**
         * Versioned container environment for the application operating system.
         */
        version: pulumi.Input<string>;
    }
    interface StreamGroupDefaultApplicationArgs {
        /**
         * An [Amazon Resource Name (ARN)](https://docs.aws.amazon.com/IAM/latest/UserGuide/reference-arns.html) that uniquely identifies the application resource. Format example: `arn:aws:gameliftstreams:us-west-2:123456789012:application/a-9ZY8X7Wv6` .
         */
        arn?: pulumi.Input<string>;
        /**
         * An ID that uniquely identifies the application resource. For example: `a-9ZY8X7Wv6` .
         */
        id?: pulumi.Input<string>;
    }
    interface StreamGroupLocationConfigurationArgs {
        /**
         * The streaming capacity that is allocated and ready to handle stream requests without delay. You pay for this capacity whether it's in use or not. Best for quickest time from streaming request to streaming session.
         */
        alwaysOnCapacity?: pulumi.Input<number>;
        /**
         * A location's name. For example, `us-east-1` . For a complete list of locations that Amazon GameLift Streams supports, refer to [Regions and quotas](https://docs.aws.amazon.com/gameliftstreams/latest/developerguide/regions-quotas.html) in the *Amazon GameLift Streams Developer Guide* .
         */
        locationName: pulumi.Input<string>;
        /**
         * The streaming capacity that Amazon GameLift Streams can allocate in response to stream requests, and then de-allocate when the session has terminated. This offers a cost control measure at the expense of a greater startup time (typically under 5 minutes).
         */
        onDemandCapacity?: pulumi.Input<number>;
    }
}
export declare namespace globalaccelerator {
    /**
     * ARN of resource to share.
     */
    interface CrossAccountAttachmentResourceArgs {
        /**
         * An IP address range, in CIDR format, that is specified as resource. The address must be provisioned and advertised in AWS Global Accelerator by following the bring your own IP address (BYOIP) process for Global Accelerator
         *
         * For more information, see [Bring your own IP addresses (BYOIP)](https://docs.aws.amazon.com/global-accelerator/latest/dg/using-byoip.html) in the AWS Global Accelerator Developer Guide.
         */
        cidr?: pulumi.Input<string>;
        /**
         * The endpoint ID for the endpoint that is specified as a AWS resource.
         *
         * An endpoint ID for the cross-account feature is the ARN of an AWS resource, such as a Network Load Balancer, that Global Accelerator supports as an endpoint for an accelerator.
         */
        endpointId?: pulumi.Input<string>;
        /**
         * The AWS Region where a shared endpoint resource is located.
         */
        region?: pulumi.Input<string>;
    }
    /**
     * The configuration for a given endpoint
     */
    interface EndpointGroupEndpointConfigurationArgs {
        /**
         * Attachment ARN that provides access control to the cross account endpoint. Not required for resources hosted in the same account as the endpoint group.
         */
        attachmentArn?: pulumi.Input<string>;
        /**
         * true if client ip should be preserved
         */
        clientIpPreservationEnabled?: pulumi.Input<boolean>;
        /**
         * Id of the endpoint. For Network/Application Load Balancer this value is the ARN.  For EIP, this value is the allocation ID.  For EC2 instances, this is the EC2 instance ID
         */
        endpointId: pulumi.Input<string>;
        /**
         * The weight for the endpoint.
         */
        weight?: pulumi.Input<number>;
    }
    /**
     * listener to endpoint port mapping.
     */
    interface EndpointGroupPortOverrideArgs {
        /**
         * The endpoint port that you want a listener port to be mapped to. This is the port on the endpoint, such as the Application Load Balancer or Amazon EC2 instance.
         */
        endpointPort: pulumi.Input<number>;
        /**
         * The listener port that you want to map to a specific endpoint port. This is the port that user traffic arrives to the Global Accelerator on.
         */
        listenerPort: pulumi.Input<number>;
    }
    /**
     * A port range to support for connections from  clients to your accelerator.
     */
    interface ListenerPortRangeArgs {
        /**
         * The first port in the range of ports, inclusive.
         */
        fromPort: pulumi.Input<number>;
        /**
         * The last port in the range of ports, inclusive.
         */
        toPort: pulumi.Input<number>;
    }
}
export declare namespace glue {
    /**
     * Specifies an AWS Glue Data Catalog target.
     */
    interface CrawlerCatalogTargetArgs {
        /**
         * The name of the connection for an Amazon S3-backed Data Catalog table to be a target of the crawl when using a Catalog connection type paired with a NETWORK Connection type.
         */
        connectionName?: pulumi.Input<string>;
        /**
         * The name of the database to be synchronized.
         */
        databaseName?: pulumi.Input<string>;
        /**
         * A valid Amazon dead-letter SQS ARN. For example, arn:aws:sqs:region:account:deadLetterQueue.
         */
        dlqEventQueueArn?: pulumi.Input<string>;
        /**
         * A valid Amazon SQS ARN. For example, arn:aws:sqs:region:account:sqs.
         */
        eventQueueArn?: pulumi.Input<string>;
        /**
         * A list of the tables to be synchronized.
         */
        tables?: pulumi.Input<pulumi.Input<string>[]>;
    }
    /**
     * Specifies a Delta data store to crawl one or more Delta tables.
     */
    interface CrawlerDeltaTargetArgs {
        /**
         * The name of the connection to use to connect to the Delta table target.
         */
        connectionName?: pulumi.Input<string>;
        /**
         * Specifies whether the crawler will create native tables, to allow integration with query engines that support querying of the Delta transaction log directly.
         */
        createNativeDeltaTable?: pulumi.Input<boolean>;
        /**
         * A list of the Amazon S3 paths to the Delta tables.
         */
        deltaTables?: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * Specifies whether to write the manifest files to the Delta table path.
         */
        writeManifest?: pulumi.Input<boolean>;
    }
    /**
     * Specifies an Amazon DynamoDB table to crawl.
     */
    interface CrawlerDynamoDbTargetArgs {
        /**
         * The name of the DynamoDB table to crawl.
         */
        path?: pulumi.Input<string>;
    }
    /**
     * Specifies Apache Hudi data store targets.
     */
    interface CrawlerHudiTargetArgs {
        /**
         * The name of the connection to use to connect to the Hudi target.
         */
        connectionName?: pulumi.Input<string>;
        /**
         * A list of global patterns used to exclude from the crawl.
         */
        exclusions?: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * The maximum depth of Amazon S3 paths that the crawler can traverse to discover the Hudi metadata folder in your Amazon S3 path. Used to limit the crawler run time.
         */
        maximumTraversalDepth?: pulumi.Input<number>;
        /**
         * One or more Amazon S3 paths that contains Hudi metadata folders as s3://bucket/prefix .
         */
        paths?: pulumi.Input<pulumi.Input<string>[]>;
    }
    /**
     * Specifies Apache Iceberg data store targets.
     */
    interface CrawlerIcebergTargetArgs {
        /**
         * The name of the connection to use to connect to the Iceberg target.
         */
        connectionName?: pulumi.Input<string>;
        /**
         * A list of global patterns used to exclude from the crawl.
         */
        exclusions?: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * The maximum depth of Amazon S3 paths that the crawler can traverse to discover the Iceberg metadata folder in your Amazon S3 path. Used to limit the crawler run time.
         */
        maximumTraversalDepth?: pulumi.Input<number>;
        /**
         * One or more Amazon S3 paths that contains Iceberg metadata folders as s3://bucket/prefix .
         */
        paths?: pulumi.Input<pulumi.Input<string>[]>;
    }
    /**
     * Specifies a JDBC data store to crawl.
     */
    interface CrawlerJdbcTargetArgs {
        /**
         * The name of the connection to use to connect to the JDBC target.
         */
        connectionName?: pulumi.Input<string>;
        /**
         * Specify a value of RAWTYPES or COMMENTS to enable additional metadata in table responses. RAWTYPES provides the native-level datatype. COMMENTS provides comments associated with a column or table in the database.
         *
         * If you do not need additional metadata, keep the field empty.
         */
        enableAdditionalMetadata?: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * A list of glob patterns used to exclude from the crawl. For more information, see Catalog Tables with a Crawler.
         */
        exclusions?: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * The path of the JDBC target.
         */
        path?: pulumi.Input<string>;
    }
    /**
     * Specifies AWS Lake Formation configuration settings for the crawler
     */
    interface CrawlerLakeFormationConfigurationArgs {
        /**
         * Required for cross account crawls. For same account crawls as the target data, this can be left as null.
         */
        accountId?: pulumi.Input<string>;
        /**
         * Specifies whether to use AWS Lake Formation credentials for the crawler instead of the IAM role credentials.
         */
        useLakeFormationCredentials?: pulumi.Input<boolean>;
    }
    /**
     * Specifies an Amazon DocumentDB or MongoDB data store to crawl.
     */
    interface CrawlerMongoDbTargetArgs {
        /**
         * The name of the connection to use to connect to the Amazon DocumentDB or MongoDB target.
         */
        connectionName?: pulumi.Input<string>;
        /**
         * The path of the Amazon DocumentDB or MongoDB target (database/collection).
         */
        path?: pulumi.Input<string>;
    }
    /**
     * When crawling an Amazon S3 data source after the first crawl is complete, specifies whether to crawl the entire dataset again or to crawl only folders that were added since the last crawler run. For more information, see Incremental Crawls in AWS Glue in the developer guide.
     */
    interface CrawlerRecrawlPolicyArgs {
        /**
         * Specifies whether to crawl the entire dataset again or to crawl only folders that were added since the last crawler run. A value of CRAWL_EVERYTHING specifies crawling the entire dataset again. A value of CRAWL_NEW_FOLDERS_ONLY specifies crawling only folders that were added since the last crawler run. A value of CRAWL_EVENT_MODE specifies crawling only the changes identified by Amazon S3 events.
         */
        recrawlBehavior?: pulumi.Input<string>;
    }
    /**
     * Specifies a data store in Amazon Simple Storage Service (Amazon S3).
     */
    interface CrawlerS3TargetArgs {
        /**
         * The name of a connection which allows a job or crawler to access data in Amazon S3 within an Amazon Virtual Private Cloud environment (Amazon VPC).
         */
        connectionName?: pulumi.Input<string>;
        /**
         * A valid Amazon dead-letter SQS ARN. For example, arn:aws:sqs:region:account:deadLetterQueue.
         */
        dlqEventQueueArn?: pulumi.Input<string>;
        /**
         * A valid Amazon SQS ARN. For example, arn:aws:sqs:region:account:sqs.
         */
        eventQueueArn?: pulumi.Input<string>;
        /**
         * A list of glob patterns used to exclude from the crawl.
         */
        exclusions?: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * The path to the Amazon S3 target.
         */
        path?: pulumi.Input<string>;
        /**
         * Sets the number of files in each leaf folder to be crawled when crawling sample files in a dataset. If not set, all the files are crawled. A valid value is an integer between 1 and 249.
         */
        sampleSize?: pulumi.Input<number>;
    }
    /**
     * A scheduling object using a cron statement to schedule an event.
     */
    interface CrawlerScheduleArgs {
        /**
         * A cron expression used to specify the schedule. For more information, see Time-Based Schedules for Jobs and Crawlers. For example, to run something every day at 12:15 UTC, specify cron(15 12 * * ? *).
         */
        scheduleExpression?: pulumi.Input<string>;
    }
    /**
     * The policy that specifies update and delete behaviors for the crawler. The policy tells the crawler what to do in the event that it detects a change in a table that already exists in the customer's database at the time of the crawl. The SchemaChangePolicy does not affect whether or how new tables and partitions are added. New tables and partitions are always created regardless of the SchemaChangePolicy on a crawler. The SchemaChangePolicy consists of two components, UpdateBehavior and DeleteBehavior.
     */
    interface CrawlerSchemaChangePolicyArgs {
        /**
         * The deletion behavior when the crawler finds a deleted object. A value of LOG specifies that if a table or partition is found to no longer exist, do not delete it, only log that it was found to no longer exist. A value of DELETE_FROM_DATABASE specifies that if a table or partition is found to have been removed, delete it from the database. A value of DEPRECATE_IN_DATABASE specifies that if a table has been found to no longer exist, to add a property to the table that says 'DEPRECATED' and includes a timestamp with the time of deprecation.
         */
        deleteBehavior?: pulumi.Input<string>;
        /**
         * The update behavior when the crawler finds a changed schema. A value of LOG specifies that if a table or a partition already exists, and a change is detected, do not update it, only log that a change was detected. Add new tables and new partitions (including on existing tables). A value of UPDATE_IN_DATABASE specifies that if a table or partition already exists, and a change is detected, update it. Add new tables and partitions.
         */
        updateBehavior?: pulumi.Input<string>;
    }
    /**
     * Specifies data stores to crawl.
     */
    interface CrawlerTargetsArgs {
        /**
         * Specifies AWS Glue Data Catalog targets.
         */
        catalogTargets?: pulumi.Input<pulumi.Input<inputs.glue.CrawlerCatalogTargetArgs>[]>;
        /**
         * Specifies an array of Delta data store targets.
         */
        deltaTargets?: pulumi.Input<pulumi.Input<inputs.glue.CrawlerDeltaTargetArgs>[]>;
        /**
         * Specifies Amazon DynamoDB targets.
         */
        dynamoDbTargets?: pulumi.Input<pulumi.Input<inputs.glue.CrawlerDynamoDbTargetArgs>[]>;
        /**
         * Specifies Apache Hudi data store targets.
         */
        hudiTargets?: pulumi.Input<pulumi.Input<inputs.glue.CrawlerHudiTargetArgs>[]>;
        /**
         * Specifies Apache Iceberg data store targets.
         */
        icebergTargets?: pulumi.Input<pulumi.Input<inputs.glue.CrawlerIcebergTargetArgs>[]>;
        /**
         * Specifies JDBC targets.
         */
        jdbcTargets?: pulumi.Input<pulumi.Input<inputs.glue.CrawlerJdbcTargetArgs>[]>;
        /**
         * A list of Mongo DB targets.
         */
        mongoDbTargets?: pulumi.Input<pulumi.Input<inputs.glue.CrawlerMongoDbTargetArgs>[]>;
        /**
         * Specifies Amazon Simple Storage Service (Amazon S3) targets.
         */
        s3Targets?: pulumi.Input<pulumi.Input<inputs.glue.CrawlerS3TargetArgs>[]>;
    }
    /**
     * The AWS Lake Formation principal.
     */
    interface DatabaseDataLakePrincipalArgs {
        /**
         * An identifier for the AWS Lake Formation principal.
         */
        dataLakePrincipalIdentifier?: pulumi.Input<string>;
    }
    /**
     * A FederatedDatabase structure that references an entity outside the AWS Glue Data Catalog.
     */
    interface DatabaseFederatedDatabaseArgs {
        /**
         * The name of the connection to the external metastore.
         */
        connectionName?: pulumi.Input<string>;
        /**
         * A unique identifier for the federated database.
         */
        identifier?: pulumi.Input<string>;
    }
    /**
     * A structure that describes a target database for resource linking.
     */
    interface DatabaseIdentifierArgs {
        /**
         * The ID of the Data Catalog in which the database resides.
         */
        catalogId?: pulumi.Input<string>;
        /**
         * The name of the catalog database.
         */
        databaseName?: pulumi.Input<string>;
        /**
         * Region of the target database.
         */
        region?: pulumi.Input<string>;
    }
    /**
     * The structure used to create or update a database.
     */
    interface DatabaseInputArgs {
        /**
         * Creates a set of default permissions on the table for principals. Used by AWS Lake Formation. Not used in the normal course of AWS Glue operations.
         */
        createTableDefaultPermissions?: pulumi.Input<pulumi.Input<inputs.glue.DatabasePrincipalPrivilegesArgs>[]>;
        /**
         * A description of the database.
         */
        description?: pulumi.Input<string>;
        /**
         * A FederatedDatabase structure that references an entity outside the AWS Glue Data Catalog.
         */
        federatedDatabase?: pulumi.Input<inputs.glue.DatabaseFederatedDatabaseArgs>;
        /**
         * The location of the database (for example, an HDFS path).
         */
        locationUri?: pulumi.Input<string>;
        /**
         * The name of the database. For hive compatibility, this is folded to lowercase when it is stored.
         */
        name?: pulumi.Input<string>;
        /**
         * These key-value pairs define parameters and properties of the database.
         */
        parameters?: any;
        /**
         * A DatabaseIdentifier structure that describes a target database for resource linking.
         */
        targetDatabase?: pulumi.Input<inputs.glue.DatabaseIdentifierArgs>;
    }
    /**
     * The permissions granted to a principal.
     */
    interface DatabasePrincipalPrivilegesArgs {
        /**
         * The permissions that are granted to the principal.
         */
        permissions?: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * The principal who is granted permissions.
         */
        principal?: pulumi.Input<inputs.glue.DatabaseDataLakePrincipalArgs>;
    }
    interface JobCommandArgs {
        /**
         * The name of the job command
         */
        name?: pulumi.Input<string>;
        /**
         * The Python version being used to execute a Python shell job.
         */
        pythonVersion?: pulumi.Input<string>;
        /**
         * Runtime is used to specify the versions of Ray, Python and additional libraries available in your environment
         */
        runtime?: pulumi.Input<string>;
        /**
         * Specifies the Amazon Simple Storage Service (Amazon S3) path to a script that executes a job
         */
        scriptLocation?: pulumi.Input<string>;
    }
    interface JobConnectionsListArgs {
        /**
         * A list of connections used by the job.
         */
        connections?: pulumi.Input<pulumi.Input<string>[]>;
    }
    interface JobExecutionPropertyArgs {
        /**
         * The maximum number of concurrent runs allowed for the job.
         */
        maxConcurrentRuns?: pulumi.Input<number>;
    }
    interface JobNotificationPropertyArgs {
        /**
         * It is the number of minutes to wait before sending a job run delay notification after a job run starts
         */
        notifyDelayAfter?: pulumi.Input<number>;
    }
    /**
     * Identifier for the registry which the schema is part of.
     */
    interface SchemaRegistryArgs {
        /**
         * Amazon Resource Name for the Registry.
         */
        arn?: pulumi.Input<string>;
        /**
         * Name of the registry in which the schema will be created.
         */
        name?: pulumi.Input<string>;
    }
    /**
     * Specify checkpoint version for update. This is only required to update the Compatibility.
     */
    interface SchemaVersionArgs {
        /**
         * Indicates if the latest version needs to be updated.
         */
        isLatest?: pulumi.Input<boolean>;
        /**
         * Indicates the version number in the schema to update.
         */
        versionNumber?: pulumi.Input<number>;
    }
    /**
     * Identifier for the schema where the schema version will be created.
     */
    interface SchemaVersionSchemaArgs {
        /**
         * Name of the registry to identify where the Schema is located.
         */
        registryName?: pulumi.Input<string>;
        /**
         * Amazon Resource Name for the Schema. This attribute can be used to uniquely represent the Schema.
         */
        schemaArn?: pulumi.Input<string>;
        /**
         * Name of the schema. This parameter requires RegistryName to be provided.
         */
        schemaName?: pulumi.Input<string>;
    }
    /**
     * The actions initiated by this trigger.
     */
    interface TriggerActionArgs {
        /**
         * The job arguments used when this trigger fires. For this job run, they replace the default arguments set in the job definition itself.
         */
        arguments?: any;
        /**
         * The name of the crawler to be used with this action.
         */
        crawlerName?: pulumi.Input<string>;
        /**
         * The name of a job to be executed.
         */
        jobName?: pulumi.Input<string>;
        /**
         * Specifies configuration properties of a job run notification.
         */
        notificationProperty?: pulumi.Input<inputs.glue.TriggerNotificationPropertyArgs>;
        /**
         * The name of the SecurityConfiguration structure to be used with this action.
         */
        securityConfiguration?: pulumi.Input<string>;
        /**
         * The JobRun timeout in minutes. This is the maximum time that a job run can consume resources before it is terminated and enters TIMEOUT status. The default is 2,880 minutes (48 hours). This overrides the timeout value set in the parent job.
         */
        timeout?: pulumi.Input<number>;
    }
    /**
     * Defines a condition under which a trigger fires.
     */
    interface TriggerConditionArgs {
        /**
         * The state of the crawler to which this condition applies.
         */
        crawlState?: pulumi.Input<string>;
        /**
         * The name of the crawler to which this condition applies.
         */
        crawlerName?: pulumi.Input<string>;
        /**
         * The name of the job whose JobRuns this condition applies to, and on which this trigger waits.
         */
        jobName?: pulumi.Input<string>;
        /**
         * A logical operator.
         */
        logicalOperator?: pulumi.Input<string>;
        /**
         * The condition state. Currently, the values supported are SUCCEEDED, STOPPED, TIMEOUT, and FAILED.
         */
        state?: pulumi.Input<string>;
    }
    /**
     * Batch condition that must be met (specified number of events received or batch time window expired) before EventBridge event trigger fires.
     */
    interface TriggerEventBatchingConditionArgs {
        /**
         * Number of events that must be received from Amazon EventBridge before EventBridge event trigger fires.
         */
        batchSize: pulumi.Input<number>;
        /**
         * Window of time in seconds after which EventBridge event trigger fires. Window starts when first event is received.
         */
        batchWindow?: pulumi.Input<number>;
    }
    /**
     * Specifies configuration properties of a job run notification.
     */
    interface TriggerNotificationPropertyArgs {
        /**
         * After a job run starts, the number of minutes to wait before sending a job run delay notification
         */
        notifyDelayAfter?: pulumi.Input<number>;
    }
    /**
     * The predicate of this trigger, which defines when it will fire.
     */
    interface TriggerPredicateArgs {
        /**
         * A list of the conditions that determine when the trigger will fire.
         */
        conditions?: pulumi.Input<pulumi.Input<inputs.glue.TriggerConditionArgs>[]>;
        /**
         * An optional field if only one condition is listed. If multiple conditions are listed, then this field is required.
         */
        logical?: pulumi.Input<string>;
    }
    interface UsageProfileConfigurationObjectArgs {
        allowedValues?: pulumi.Input<pulumi.Input<string>[]>;
        defaultValue?: pulumi.Input<string>;
        maxValue?: pulumi.Input<string>;
        minValue?: pulumi.Input<string>;
    }
    interface UsageProfileProfileConfigurationArgs {
        jobConfiguration?: pulumi.Input<{
            [key: string]: pulumi.Input<inputs.glue.UsageProfileConfigurationObjectArgs>;
        }>;
        sessionConfiguration?: pulumi.Input<{
            [key: string]: pulumi.Input<inputs.glue.UsageProfileConfigurationObjectArgs>;
        }>;
    }
}
export declare namespace grafana {
    /**
     * Maps Grafana friendly names to the IdPs SAML attributes.
     */
    interface WorkspaceAssertionAttributesArgs {
        /**
         * Name of the attribute within the SAML assert to use as the users email in Grafana.
         */
        email?: pulumi.Input<string>;
        /**
         * Name of the attribute within the SAML assert to use as the users groups in Grafana.
         */
        groups?: pulumi.Input<string>;
        /**
         * Name of the attribute within the SAML assert to use as the users login handle in Grafana.
         */
        login?: pulumi.Input<string>;
        /**
         * Name of the attribute within the SAML assert to use as the users name in Grafana.
         */
        name?: pulumi.Input<string>;
        /**
         * Name of the attribute within the SAML assert to use as the users organizations in Grafana.
         */
        org?: pulumi.Input<string>;
        /**
         * Name of the attribute within the SAML assert to use as the users roles in Grafana.
         */
        role?: pulumi.Input<string>;
    }
    /**
     * IdP Metadata used to configure SAML authentication in Grafana.
     */
    interface WorkspaceIdpMetadataArgs {
        /**
         * URL that vends the IdPs metadata.
         */
        url?: pulumi.Input<string>;
        /**
         * XML blob of the IdPs metadata.
         */
        xml?: pulumi.Input<string>;
    }
    /**
     * The configuration settings for Network Access Control.
     */
    interface WorkspaceNetworkAccessControlArgs {
        /**
         * The list of prefix list IDs. A prefix list is a list of CIDR ranges of IP addresses. The IP addresses specified are allowed to access your workspace. If the list is not included in the configuration then no IP addresses will be allowed to access the workspace.
         */
        prefixListIds?: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * The list of Amazon VPC endpoint IDs for the workspace. If a NetworkAccessConfiguration is specified then only VPC endpoints specified here will be allowed to access the workspace.
         */
        vpceIds?: pulumi.Input<pulumi.Input<string>[]>;
    }
    /**
     * Maps SAML roles to the Grafana Editor and Admin roles.
     */
    interface WorkspaceRoleValuesArgs {
        /**
         * List of SAML roles which will be mapped into the Grafana Admin role.
         */
        admin?: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * List of SAML roles which will be mapped into the Grafana Editor role.
         */
        editor?: pulumi.Input<pulumi.Input<string>[]>;
    }
    /**
     * SAML configuration data associated with an AMG workspace.
     */
    interface WorkspaceSamlConfigurationArgs {
        /**
         * List of SAML organizations allowed to access Grafana.
         */
        allowedOrganizations?: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * A structure that defines which attributes in the SAML assertion are to be used to define information about the users authenticated by that IdP to use the workspace.
         */
        assertionAttributes?: pulumi.Input<inputs.grafana.WorkspaceAssertionAttributesArgs>;
        /**
         * A structure containing the identity provider (IdP) metadata used to integrate the identity provider with this workspace.
         */
        idpMetadata: pulumi.Input<inputs.grafana.WorkspaceIdpMetadataArgs>;
        /**
         * The maximum lifetime an authenticated user can be logged in (in minutes) before being required to re-authenticate.
         */
        loginValidityDuration?: pulumi.Input<number>;
        /**
         * A structure containing arrays that map group names in the SAML assertion to the Grafana `Admin` and `Editor` roles in the workspace.
         */
        roleValues?: pulumi.Input<inputs.grafana.WorkspaceRoleValuesArgs>;
    }
    /**
     * The configuration settings for an Amazon VPC that contains data sources for your Grafana workspace to connect to.
     */
    interface WorkspaceVpcConfigurationArgs {
        /**
         * The list of Amazon EC2 security group IDs attached to the Amazon VPC for your Grafana workspace to connect.
         */
        securityGroupIds: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * The list of Amazon EC2 subnet IDs created in the Amazon VPC for your Grafana workspace to connect.
         */
        subnetIds: pulumi.Input<pulumi.Input<string>[]>;
    }
}
export declare namespace greengrassv2 {
    interface ComponentVersionComponentDependencyRequirementArgs {
        dependencyType?: pulumi.Input<enums.greengrassv2.ComponentVersionComponentDependencyRequirementDependencyType>;
        versionRequirement?: pulumi.Input<string>;
    }
    interface ComponentVersionComponentPlatformArgs {
        /**
         * A dictionary of attributes for the platform. The AWS IoT Greengrass Core software defines the `os` and `platform` by default. You can specify additional platform attributes for a core device when you deploy the AWS IoT Greengrass nucleus component. For more information, see the [AWS IoT Greengrass nucleus component](https://docs.aws.amazon.com/greengrass/v2/developerguide/greengrass-nucleus-component.html) in the *AWS IoT Greengrass V2 Developer Guide* .
         */
        attributes?: pulumi.Input<{
            [key: string]: pulumi.Input<string>;
        }>;
        /**
         * The friendly name of the platform. This name helps you identify the platform.
         *
         * If you omit this parameter, AWS IoT Greengrass creates a friendly name from the `os` and `architecture` of the platform.
         */
        name?: pulumi.Input<string>;
    }
    interface ComponentVersionLambdaContainerParamsArgs {
        /**
         * The list of system devices that the container can access.
         */
        devices?: pulumi.Input<pulumi.Input<inputs.greengrassv2.ComponentVersionLambdaDeviceMountArgs>[]>;
        /**
         * The memory size of the container, expressed in kilobytes.
         *
         * Default: `16384` (16 MB)
         */
        memorySizeInKb?: pulumi.Input<number>;
        /**
         * Whether or not the container can read information from the device's `/sys` folder.
         *
         * Default: `false`
         */
        mountRoSysfs?: pulumi.Input<boolean>;
        /**
         * The list of volumes that the container can access.
         */
        volumes?: pulumi.Input<pulumi.Input<inputs.greengrassv2.ComponentVersionLambdaVolumeMountArgs>[]>;
    }
    interface ComponentVersionLambdaDeviceMountArgs {
        /**
         * Whether or not to add the component's system user as an owner of the device.
         *
         * Default: `false`
         */
        addGroupOwner?: pulumi.Input<boolean>;
        /**
         * The mount path for the device in the file system.
         */
        path?: pulumi.Input<string>;
        /**
         * The permission to access the device: read/only ( `ro` ) or read/write ( `rw` ).
         *
         * Default: `ro`
         */
        permission?: pulumi.Input<enums.greengrassv2.ComponentVersionLambdaFilesystemPermission>;
    }
    interface ComponentVersionLambdaEventSourceArgs {
        /**
         * The topic to which to subscribe to receive event messages.
         */
        topic?: pulumi.Input<string>;
        /**
         * The type of event source. Choose from the following options:
         *
         * - `PUB_SUB` – Subscribe to local publish/subscribe messages. This event source type doesn't support MQTT wildcards ( `+` and `#` ) in the event source topic.
         * - `IOT_CORE` – Subscribe to AWS IoT Core MQTT messages. This event source type supports MQTT wildcards ( `+` and `#` ) in the event source topic.
         */
        type?: pulumi.Input<enums.greengrassv2.ComponentVersionLambdaEventSourceType>;
    }
    interface ComponentVersionLambdaExecutionParametersArgs {
        /**
         * The map of environment variables that are available to the Lambda function when it runs.
         */
        environmentVariables?: pulumi.Input<{
            [key: string]: pulumi.Input<string>;
        }>;
        /**
         * The list of event sources to which to subscribe to receive work messages. The Lambda function runs when it receives a message from an event source. You can subscribe this function to local publish/subscribe messages and AWS IoT Core MQTT messages.
         */
        eventSources?: pulumi.Input<pulumi.Input<inputs.greengrassv2.ComponentVersionLambdaEventSourceArgs>[]>;
        /**
         * The list of arguments to pass to the Lambda function when it runs.
         */
        execArgs?: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * The encoding type that the Lambda function supports.
         *
         * Default: `json`
         */
        inputPayloadEncodingType?: pulumi.Input<enums.greengrassv2.ComponentVersionLambdaExecutionParametersInputPayloadEncodingType>;
        /**
         * The parameters for the Linux process that contains the Lambda function.
         */
        linuxProcessParams?: pulumi.Input<inputs.greengrassv2.ComponentVersionLambdaLinuxProcessParamsArgs>;
        /**
         * The maximum amount of time in seconds that a non-pinned Lambda function can idle before the AWS IoT Greengrass Core software stops its process.
         */
        maxIdleTimeInSeconds?: pulumi.Input<number>;
        /**
         * The maximum number of instances that a non-pinned Lambda function can run at the same time.
         */
        maxInstancesCount?: pulumi.Input<number>;
        /**
         * The maximum size of the message queue for the Lambda function component. The AWS IoT Greengrass core device stores messages in a FIFO (first-in-first-out) queue until it can run the Lambda function to consume each message.
         */
        maxQueueSize?: pulumi.Input<number>;
        /**
         * Whether or not the Lambda function is pinned, or long-lived.
         *
         * - A pinned Lambda function starts when the AWS IoT Greengrass Core starts and keeps running in its own container.
         * - A non-pinned Lambda function starts only when it receives a work item and exists after it idles for `maxIdleTimeInSeconds` . If the function has multiple work items, the AWS IoT Greengrass Core software creates multiple instances of the function.
         *
         * Default: `true`
         */
        pinned?: pulumi.Input<boolean>;
        /**
         * The interval in seconds at which a pinned (also known as long-lived) Lambda function component sends status updates to the Lambda manager component.
         */
        statusTimeoutInSeconds?: pulumi.Input<number>;
        /**
         * The maximum amount of time in seconds that the Lambda function can process a work item.
         */
        timeoutInSeconds?: pulumi.Input<number>;
    }
    interface ComponentVersionLambdaFunctionRecipeSourceArgs {
        /**
         * The component versions on which this Lambda function component depends.
         */
        componentDependencies?: pulumi.Input<{
            [key: string]: pulumi.Input<inputs.greengrassv2.ComponentVersionComponentDependencyRequirementArgs>;
        }>;
        /**
         * The system and runtime parameters for the Lambda function as it runs on the AWS IoT Greengrass core device.
         */
        componentLambdaParameters?: pulumi.Input<inputs.greengrassv2.ComponentVersionLambdaExecutionParametersArgs>;
        /**
         * The name of the component.
         *
         * Defaults to the name of the Lambda function.
         */
        componentName?: pulumi.Input<string>;
        /**
         * The platforms that the component version supports.
         */
        componentPlatforms?: pulumi.Input<pulumi.Input<inputs.greengrassv2.ComponentVersionComponentPlatformArgs>[]>;
        /**
         * The version of the component.
         *
         * Defaults to the version of the Lambda function as a semantic version. For example, if your function version is `3` , the component version becomes `3.0.0` .
         */
        componentVersion?: pulumi.Input<string>;
        /**
         * The ARN of the Lambda function. The ARN must include the version of the function to import. You can't use version aliases like `$LATEST` .
         */
        lambdaArn?: pulumi.Input<string>;
    }
    interface ComponentVersionLambdaLinuxProcessParamsArgs {
        /**
         * The parameters for the container in which the Lambda function runs.
         */
        containerParams?: pulumi.Input<inputs.greengrassv2.ComponentVersionLambdaContainerParamsArgs>;
        /**
         * The isolation mode for the process that contains the Lambda function. The process can run in an isolated runtime environment inside the AWS IoT Greengrass container, or as a regular process outside any container.
         *
         * Default: `GreengrassContainer`
         */
        isolationMode?: pulumi.Input<enums.greengrassv2.ComponentVersionLambdaLinuxProcessParamsIsolationMode>;
    }
    interface ComponentVersionLambdaVolumeMountArgs {
        /**
         * Whether or not to add the AWS IoT Greengrass user group as an owner of the volume.
         *
         * Default: `false`
         */
        addGroupOwner?: pulumi.Input<boolean>;
        /**
         * The path to the logical volume in the file system.
         */
        destinationPath?: pulumi.Input<string>;
        /**
         * The permission to access the volume: read/only ( `ro` ) or read/write ( `rw` ).
         *
         * Default: `ro`
         */
        permission?: pulumi.Input<enums.greengrassv2.ComponentVersionLambdaFilesystemPermission>;
        /**
         * The path to the physical volume in the file system.
         */
        sourcePath?: pulumi.Input<string>;
    }
    interface DeploymentComponentConfigurationUpdateArgs {
        merge?: pulumi.Input<string>;
        reset?: pulumi.Input<pulumi.Input<string>[]>;
    }
    interface DeploymentComponentDeploymentSpecificationArgs {
        componentVersion?: pulumi.Input<string>;
        configurationUpdate?: pulumi.Input<inputs.greengrassv2.DeploymentComponentConfigurationUpdateArgs>;
        runWith?: pulumi.Input<inputs.greengrassv2.DeploymentComponentRunWithArgs>;
    }
    interface DeploymentComponentRunWithArgs {
        posixUser?: pulumi.Input<string>;
        systemResourceLimits?: pulumi.Input<inputs.greengrassv2.DeploymentSystemResourceLimitsArgs>;
        windowsUser?: pulumi.Input<string>;
    }
    interface DeploymentComponentUpdatePolicyArgs {
        /**
         * Whether or not to notify components and wait for components to become safe to update. Choose from the following options:
         *
         * - `NOTIFY_COMPONENTS` – The deployment notifies each component before it stops and updates that component. Components can use the [SubscribeToComponentUpdates](https://docs.aws.amazon.com/greengrass/v2/developerguide/interprocess-communication.html#ipc-operation-subscribetocomponentupdates) IPC operation to receive these notifications. Then, components can respond with the [DeferComponentUpdate](https://docs.aws.amazon.com/greengrass/v2/developerguide/interprocess-communication.html#ipc-operation-defercomponentupdate) IPC operation. For more information, see the [Create deployments](https://docs.aws.amazon.com/greengrass/v2/developerguide/create-deployments.html) in the *AWS IoT Greengrass V2 Developer Guide* .
         * - `SKIP_NOTIFY_COMPONENTS` – The deployment doesn't notify components or wait for them to be safe to update.
         *
         * Default: `NOTIFY_COMPONENTS`
         */
        action?: pulumi.Input<enums.greengrassv2.DeploymentComponentUpdatePolicyAction>;
        /**
         * The amount of time in seconds that each component on a device has to report that it's safe to update. If the component waits for longer than this timeout, then the deployment proceeds on the device.
         *
         * Default: `60`
         */
        timeoutInSeconds?: pulumi.Input<number>;
    }
    interface DeploymentConfigurationValidationPolicyArgs {
        /**
         * The amount of time in seconds that a component can validate its configuration updates. If the validation time exceeds this timeout, then the deployment proceeds for the device.
         *
         * Default: `30`
         */
        timeoutInSeconds?: pulumi.Input<number>;
    }
    interface DeploymentIoTJobAbortConfigArgs {
        /**
         * The list of criteria that define when and how to cancel the configuration deployment.
         */
        criteriaList: pulumi.Input<pulumi.Input<inputs.greengrassv2.DeploymentIoTJobAbortCriteriaArgs>[]>;
    }
    interface DeploymentIoTJobAbortCriteriaArgs {
        /**
         * The action to perform when the criteria are met.
         */
        action: pulumi.Input<enums.greengrassv2.DeploymentIoTJobAbortCriteriaAction>;
        /**
         * The type of job deployment failure that can cancel a job.
         */
        failureType: pulumi.Input<enums.greengrassv2.DeploymentIoTJobAbortCriteriaFailureType>;
        /**
         * The minimum number of things that receive the configuration before the job can cancel.
         */
        minNumberOfExecutedThings: pulumi.Input<number>;
        /**
         * The minimum percentage of `failureType` failures that occur before the job can cancel.
         *
         * This parameter supports up to two digits after the decimal (for example, you can specify `10.9` or `10.99` , but not `10.999` ).
         */
        thresholdPercentage: pulumi.Input<number>;
    }
    interface DeploymentIoTJobConfigurationArgs {
        /**
         * The stop configuration for the job. This configuration defines when and how to stop a job rollout.
         */
        abortConfig?: pulumi.Input<inputs.greengrassv2.DeploymentIoTJobAbortConfigArgs>;
        /**
         * The rollout configuration for the job. This configuration defines the rate at which the job rolls out to the fleet of target devices.
         */
        jobExecutionsRolloutConfig?: pulumi.Input<inputs.greengrassv2.DeploymentIoTJobExecutionsRolloutConfigArgs>;
        /**
         * The timeout configuration for the job. This configuration defines the amount of time each device has to complete the job.
         */
        timeoutConfig?: pulumi.Input<inputs.greengrassv2.DeploymentIoTJobTimeoutConfigArgs>;
    }
    interface DeploymentIoTJobExecutionsRolloutConfigArgs {
        /**
         * The exponential rate to increase the job rollout rate.
         */
        exponentialRate?: pulumi.Input<inputs.greengrassv2.DeploymentIoTJobExponentialRolloutRateArgs>;
        /**
         * The maximum number of devices that receive a pending job notification, per minute.
         */
        maximumPerMinute?: pulumi.Input<number>;
    }
    interface DeploymentIoTJobExponentialRolloutRateArgs {
        /**
         * The minimum number of devices that receive a pending job notification, per minute, when the job starts. This parameter defines the initial rollout rate of the job.
         */
        baseRatePerMinute: pulumi.Input<number>;
        /**
         * The exponential factor to increase the rollout rate for the job.
         *
         * This parameter supports up to one digit after the decimal (for example, you can specify `1.5` , but not `1.55` ).
         */
        incrementFactor: pulumi.Input<number>;
        /**
         * The criteria to increase the rollout rate for the job.
         */
        rateIncreaseCriteria: pulumi.Input<inputs.greengrassv2.DeploymentIoTJobRateIncreaseCriteriaArgs>;
    }
    interface DeploymentIoTJobRateIncreaseCriteriaArgs {
    }
    interface DeploymentIoTJobTimeoutConfigArgs {
        /**
         * The amount of time, in minutes, that devices have to complete the job. The timer starts when the job status is set to `IN_PROGRESS` . If the job status doesn't change to a terminal state before the time expires, then the job status is set to `TIMED_OUT` .
         *
         * The timeout interval must be between 1 minute and 7 days (10080 minutes).
         */
        inProgressTimeoutInMinutes?: pulumi.Input<number>;
    }
    interface DeploymentPoliciesArgs {
        /**
         * The component update policy for the configuration deployment. This policy defines when it's safe to deploy the configuration to devices.
         */
        componentUpdatePolicy?: pulumi.Input<inputs.greengrassv2.DeploymentComponentUpdatePolicyArgs>;
        /**
         * The configuration validation policy for the configuration deployment. This policy defines how long each component has to validate its configure updates.
         */
        configurationValidationPolicy?: pulumi.Input<inputs.greengrassv2.DeploymentConfigurationValidationPolicyArgs>;
        /**
         * The failure handling policy for the configuration deployment. This policy defines what to do if the deployment fails.
         *
         * Default: `ROLLBACK`
         */
        failureHandlingPolicy?: pulumi.Input<enums.greengrassv2.DeploymentPoliciesFailureHandlingPolicy>;
    }
    interface DeploymentSystemResourceLimitsArgs {
        cpus?: pulumi.Input<number>;
        memory?: pulumi.Input<number>;
    }
}
export declare namespace groundstation {
    interface ConfigAntennaDownlinkConfigArgs {
        /**
         * Defines the spectrum configuration.
         */
        spectrumConfig?: pulumi.Input<inputs.groundstation.ConfigSpectrumConfigArgs>;
    }
    interface ConfigAntennaDownlinkDemodDecodeConfigArgs {
        /**
         * Defines how the RF signal will be decoded.
         */
        decodeConfig?: pulumi.Input<inputs.groundstation.ConfigDecodeConfigArgs>;
        /**
         * Defines how the RF signal will be demodulated.
         */
        demodulationConfig?: pulumi.Input<inputs.groundstation.ConfigDemodulationConfigArgs>;
        /**
         * Defines the spectrum configuration.
         */
        spectrumConfig?: pulumi.Input<inputs.groundstation.ConfigSpectrumConfigArgs>;
    }
    interface ConfigAntennaUplinkConfigArgs {
        /**
         * Defines the spectrum configuration.
         */
        spectrumConfig?: pulumi.Input<inputs.groundstation.ConfigUplinkSpectrumConfigArgs>;
        /**
         * The equivalent isotropically radiated power (EIRP) to use for uplink transmissions. Valid values are between 20.0 to 50.0 dBW.
         */
        targetEirp?: pulumi.Input<inputs.groundstation.ConfigEirpArgs>;
        /**
         * Whether or not uplink transmit is disabled.
         */
        transmitDisabled?: pulumi.Input<boolean>;
    }
    interface ConfigDataArgs {
        /**
         * Provides information for an antenna downlink config object. Antenna downlink config objects are used to provide parameters for downlinks where no demodulation or decoding is performed by Ground Station (RF over IP downlinks).
         */
        antennaDownlinkConfig?: pulumi.Input<inputs.groundstation.ConfigAntennaDownlinkConfigArgs>;
        /**
         * Provides information for a downlink demod decode config object. Downlink demod decode config objects are used to provide parameters for downlinks where the Ground Station service will demodulate and decode the downlinked data.
         */
        antennaDownlinkDemodDecodeConfig?: pulumi.Input<inputs.groundstation.ConfigAntennaDownlinkDemodDecodeConfigArgs>;
        /**
         * Provides information for an uplink config object. Uplink config objects are used to provide parameters for uplink contacts.
         */
        antennaUplinkConfig?: pulumi.Input<inputs.groundstation.ConfigAntennaUplinkConfigArgs>;
        /**
         * Provides information for a dataflow endpoint config object. Dataflow endpoint config objects are used to provide parameters about which IP endpoint(s) to use during a contact. Dataflow endpoints are where Ground Station sends data during a downlink contact and where Ground Station receives data to send to the satellite during an uplink contact.
         */
        dataflowEndpointConfig?: pulumi.Input<inputs.groundstation.ConfigDataflowEndpointConfigArgs>;
        /**
         * Provides information for an S3 recording config object. S3 recording config objects are used to provide parameters for S3 recording during downlink contacts.
         */
        s3RecordingConfig?: pulumi.Input<inputs.groundstation.ConfigS3RecordingConfigArgs>;
        /**
         * Provides information for a tracking config object. Tracking config objects are used to provide parameters about how to track the satellite through the sky during a contact.
         */
        trackingConfig?: pulumi.Input<inputs.groundstation.ConfigTrackingConfigArgs>;
        /**
         * Provides information for an uplink echo config object. Uplink echo config objects are used to provide parameters for uplink echo during uplink contacts.
         */
        uplinkEchoConfig?: pulumi.Input<inputs.groundstation.ConfigUplinkEchoConfigArgs>;
    }
    interface ConfigDataflowEndpointConfigArgs {
        /**
         * The name of the dataflow endpoint to use during contacts.
         */
        dataflowEndpointName?: pulumi.Input<string>;
        /**
         * The region of the dataflow endpoint to use during contacts. When omitted, Ground Station will use the region of the contact.
         */
        dataflowEndpointRegion?: pulumi.Input<string>;
    }
    interface ConfigDecodeConfigArgs {
        /**
         * The decoding settings are in JSON format and define a set of steps to perform to decode the data.
         */
        unvalidatedJson?: pulumi.Input<string>;
    }
    interface ConfigDemodulationConfigArgs {
        /**
         * The demodulation settings are in JSON format and define parameters for demodulation, for example which modulation scheme (e.g. PSK, QPSK, etc.) and matched filter to use.
         */
        unvalidatedJson?: pulumi.Input<string>;
    }
    interface ConfigEirpArgs {
        /**
         * The units of the EIRP.
         */
        units?: pulumi.Input<enums.groundstation.ConfigEirpUnits>;
        /**
         * The value of the EIRP. Valid values are between 20.0 to 50.0 dBW.
         */
        value?: pulumi.Input<number>;
    }
    interface ConfigFrequencyArgs {
        /**
         * The units of the frequency.
         */
        units?: pulumi.Input<enums.groundstation.ConfigFrequencyUnits>;
        /**
         * The value of the frequency. Valid values are between 2200 to 2300 MHz and 7750 to 8400 MHz for downlink and 2025 to 2120 MHz for uplink.
         */
        value?: pulumi.Input<number>;
    }
    interface ConfigFrequencyBandwidthArgs {
        /**
         * The units of the bandwidth.
         */
        units?: pulumi.Input<enums.groundstation.ConfigBandwidthUnits>;
        /**
         * The value of the bandwidth. AWS Ground Station currently has the following bandwidth limitations:
         *
         * - For `AntennaDownlinkDemodDecodeconfig` , valid values are between 125 kHz to 650 MHz.
         * - For `AntennaDownlinkconfig` , valid values are between 10 kHz to 54 MHz.
         * - For `AntennaUplinkConfig` , valid values are between 10 kHz to 54 MHz.
         */
        value?: pulumi.Input<number>;
    }
    interface ConfigS3RecordingConfigArgs {
        /**
         * S3 Bucket where the data is written. The name of the S3 Bucket provided must begin with `aws-groundstation` .
         */
        bucketArn?: pulumi.Input<string>;
        /**
         * The prefix of the S3 data object. If you choose to use any optional keys for substitution, these values will be replaced with the corresponding information from your contact details. For example, a prefix of `{satellite_id}/{year}/{month}/{day}/` will replaced with `fake_satellite_id/2021/01/10/`
         *
         * *Optional keys for substitution* : `{satellite_id}` | `{config-name}` | `{config-id}` | `{year}` | `{month}` | `{day}`
         */
        prefix?: pulumi.Input<string>;
        /**
         * Defines the ARN of the role assumed for putting archives to S3.
         */
        roleArn?: pulumi.Input<string>;
    }
    interface ConfigSpectrumConfigArgs {
        /**
         * The bandwidth of the spectrum. AWS Ground Station currently has the following bandwidth limitations:
         *
         * - For `AntennaDownlinkDemodDecodeconfig` , valid values are between 125 kHz to 650 MHz.
         * - For `AntennaDownlinkconfig` , valid values are between 10 kHz to 54 MHz.
         * - For `AntennaUplinkConfig` , valid values are between 10 kHz to 54 MHz.
         */
        bandwidth?: pulumi.Input<inputs.groundstation.ConfigFrequencyBandwidthArgs>;
        /**
         * The center frequency of the spectrum. Valid values are between 2200 to 2300 MHz and 7750 to 8400 MHz for downlink and 2025 to 2120 MHz for uplink.
         */
        centerFrequency?: pulumi.Input<inputs.groundstation.ConfigFrequencyArgs>;
        /**
         * The polarization of the spectrum. Valid values are `"RIGHT_HAND"` and `"LEFT_HAND"` . Capturing both `"RIGHT_HAND"` and `"LEFT_HAND"` polarization requires two separate configs.
         */
        polarization?: pulumi.Input<enums.groundstation.ConfigPolarization>;
    }
    interface ConfigTrackingConfigArgs {
        /**
         * Specifies whether or not to use autotrack. `REMOVED` specifies that program track should only be used during the contact. `PREFERRED` specifies that autotracking is preferred during the contact but fallback to program track if the signal is lost. `REQUIRED` specifies that autotracking is required during the contact and not to use program track if the signal is lost.
         */
        autotrack?: pulumi.Input<enums.groundstation.ConfigTrackingConfigAutotrack>;
    }
    interface ConfigUplinkEchoConfigArgs {
        /**
         * Defines the ARN of the uplink config to echo back to a dataflow endpoint.
         */
        antennaUplinkConfigArn?: pulumi.Input<string>;
        /**
         * Whether or not uplink echo is enabled.
         */
        enabled?: pulumi.Input<boolean>;
    }
    interface ConfigUplinkSpectrumConfigArgs {
        /**
         * The center frequency of the spectrum. Valid values are between 2200 to 2300 MHz and 7750 to 8400 MHz for downlink and 2025 to 2120 MHz for uplink.
         */
        centerFrequency?: pulumi.Input<inputs.groundstation.ConfigFrequencyArgs>;
        /**
         * The polarization of the spectrum. Valid values are `"RIGHT_HAND"` and `"LEFT_HAND"` .
         */
        polarization?: pulumi.Input<enums.groundstation.ConfigPolarization>;
    }
    /**
     * Information about AwsGroundStationAgentEndpoint.
     */
    interface DataflowEndpointGroupAwsGroundStationAgentEndpointArgs {
        /**
         * The status of AgentEndpoint.
         */
        agentStatus?: pulumi.Input<enums.groundstation.DataflowEndpointGroupAgentStatus>;
        /**
         * The results of the audit.
         */
        auditResults?: pulumi.Input<enums.groundstation.DataflowEndpointGroupAuditResults>;
        /**
         * The egress address of AgentEndpoint.
         */
        egressAddress?: pulumi.Input<inputs.groundstation.DataflowEndpointGroupConnectionDetailsArgs>;
        /**
         * The ingress address of AgentEndpoint.
         */
        ingressAddress?: pulumi.Input<inputs.groundstation.DataflowEndpointGroupRangedConnectionDetailsArgs>;
        /**
         * Name string associated with AgentEndpoint. Used as a human-readable identifier for AgentEndpoint.
         */
        name?: pulumi.Input<string>;
    }
    /**
     * Egress address of AgentEndpoint with an optional mtu.
     */
    interface DataflowEndpointGroupConnectionDetailsArgs {
        /**
         * Maximum transmission unit (MTU) size in bytes of a dataflow endpoint.
         */
        mtu?: pulumi.Input<number>;
        /**
         * A socket address.
         */
        socketAddress?: pulumi.Input<inputs.groundstation.DataflowEndpointGroupSocketAddressArgs>;
    }
    interface DataflowEndpointGroupDataflowEndpointArgs {
        /**
         * The address and port of an endpoint.
         */
        address?: pulumi.Input<inputs.groundstation.DataflowEndpointGroupSocketAddressArgs>;
        /**
         * Maximum transmission unit (MTU) size in bytes of a dataflow endpoint. Valid values are between 1400 and 1500. A default value of 1500 is used if not set.
         */
        mtu?: pulumi.Input<number>;
        /**
         * The endpoint name.
         *
         * When listing available contacts for a satellite, Ground Station searches for a dataflow endpoint whose name matches the value specified by the dataflow endpoint config of the selected mission profile. If no matching dataflow endpoints are found then Ground Station will not display any available contacts for the satellite.
         */
        name?: pulumi.Input<string>;
    }
    interface DataflowEndpointGroupEndpointDetailsArgs {
        /**
         * An agent endpoint.
         */
        awsGroundStationAgentEndpoint?: pulumi.Input<inputs.groundstation.DataflowEndpointGroupAwsGroundStationAgentEndpointArgs>;
        /**
         * Information about the endpoint such as name and the endpoint address.
         */
        endpoint?: pulumi.Input<inputs.groundstation.DataflowEndpointGroupDataflowEndpointArgs>;
        /**
         * The role ARN, and IDs for security groups and subnets.
         */
        securityDetails?: pulumi.Input<inputs.groundstation.DataflowEndpointGroupSecurityDetailsArgs>;
    }
    /**
     * An integer range that has a minimum and maximum value.
     */
    interface DataflowEndpointGroupIntegerRangeArgs {
        /**
         * A maximum value.
         */
        maximum?: pulumi.Input<number>;
        /**
         * A minimum value.
         */
        minimum?: pulumi.Input<number>;
    }
    /**
     * Ingress address of AgentEndpoint with a port range and an optional mtu.
     */
    interface DataflowEndpointGroupRangedConnectionDetailsArgs {
        /**
         * Maximum transmission unit (MTU) size in bytes of a dataflow endpoint.
         */
        mtu?: pulumi.Input<number>;
        /**
         * A ranged socket address.
         */
        socketAddress?: pulumi.Input<inputs.groundstation.DataflowEndpointGroupRangedSocketAddressArgs>;
    }
    /**
     * A socket address with a port range.
     */
    interface DataflowEndpointGroupRangedSocketAddressArgs {
        /**
         * IPv4 socket address.
         */
        name?: pulumi.Input<string>;
        /**
         * Port range of a socket address.
         */
        portRange?: pulumi.Input<inputs.groundstation.DataflowEndpointGroupIntegerRangeArgs>;
    }
    interface DataflowEndpointGroupSecurityDetailsArgs {
        /**
         * The ARN of a role which Ground Station has permission to assume, such as `arn:aws:iam::1234567890:role/DataDeliveryServiceRole` .
         *
         * Ground Station will assume this role and create an ENI in your VPC on the specified subnet upon creation of a dataflow endpoint group. This ENI is used as the ingress/egress point for data streamed during a satellite contact.
         */
        roleArn?: pulumi.Input<string>;
        /**
         * The security group Ids of the security role, such as `sg-1234567890abcdef0` .
         */
        securityGroupIds?: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * The subnet Ids of the security details, such as `subnet-12345678` .
         */
        subnetIds?: pulumi.Input<pulumi.Input<string>[]>;
    }
    interface DataflowEndpointGroupSocketAddressArgs {
        /**
         * The name of the endpoint, such as `Endpoint 1` .
         */
        name?: pulumi.Input<string>;
        /**
         * The port of the endpoint, such as `55888` .
         */
        port?: pulumi.Input<number>;
    }
    interface MissionProfileDataflowEdgeArgs {
        /**
         * The ARN of the destination for this dataflow edge. For example, specify the ARN of a dataflow endpoint config for a downlink edge or an antenna uplink config for an uplink edge.
         */
        destination?: pulumi.Input<string>;
        /**
         * The ARN of the source for this dataflow edge. For example, specify the ARN of an antenna downlink config for a downlink edge or a dataflow endpoint config for an uplink edge.
         */
        source?: pulumi.Input<string>;
    }
    interface MissionProfileStreamsKmsKeyArgs {
        /**
         * KMS Alias Arn.
         */
        kmsAliasArn?: pulumi.Input<string>;
        /**
         * KMS Alias Name.
         */
        kmsAliasName?: pulumi.Input<string>;
        /**
         * KMS Key Arn.
         */
        kmsKeyArn?: pulumi.Input<string>;
    }
}
export declare namespace guardduty {
    interface DetectorCfnDataSourceConfigurationsArgs {
        /**
         * Describes which Kubernetes data sources are enabled for a detector.
         */
        kubernetes?: pulumi.Input<inputs.guardduty.DetectorCfnKubernetesConfigurationArgs>;
        /**
         * Describes whether Malware Protection will be enabled as a data source.
         */
        malwareProtection?: pulumi.Input<inputs.guardduty.DetectorCfnMalwareProtectionConfigurationArgs>;
        /**
         * Describes whether S3 data event logs are enabled as a data source.
         */
        s3Logs?: pulumi.Input<inputs.guardduty.DetectorCfns3LogsConfigurationArgs>;
    }
    interface DetectorCfnFeatureAdditionalConfigurationArgs {
        /**
         * Name of the additional configuration.
         */
        name?: pulumi.Input<string>;
        /**
         * Status of the additional configuration.
         */
        status?: pulumi.Input<string>;
    }
    interface DetectorCfnFeatureConfigurationArgs {
        /**
         * Information about the additional configuration of a feature in your account.
         */
        additionalConfiguration?: pulumi.Input<pulumi.Input<inputs.guardduty.DetectorCfnFeatureAdditionalConfigurationArgs>[]>;
        /**
         * Name of the feature. For a list of allowed values, see [DetectorFeatureConfiguration](https://docs.aws.amazon.com/guardduty/latest/APIReference/API_DetectorFeatureConfiguration.html#guardduty-Type-DetectorFeatureConfiguration-name) in the *GuardDuty API Reference* .
         */
        name: pulumi.Input<string>;
        /**
         * Status of the feature configuration.
         */
        status: pulumi.Input<enums.guardduty.DetectorCfnFeatureConfigurationStatus>;
    }
    interface DetectorCfnKubernetesAuditLogsConfigurationArgs {
        /**
         * Describes whether Kubernetes audit logs are enabled as a data source for the detector.
         */
        enable: pulumi.Input<boolean>;
    }
    interface DetectorCfnKubernetesConfigurationArgs {
        /**
         * Describes whether Kubernetes audit logs are enabled as a data source for the detector.
         */
        auditLogs: pulumi.Input<inputs.guardduty.DetectorCfnKubernetesAuditLogsConfigurationArgs>;
    }
    interface DetectorCfnMalwareProtectionConfigurationArgs {
        /**
         * Describes the configuration of Malware Protection for EC2 instances with findings.
         */
        scanEc2InstanceWithFindings?: pulumi.Input<inputs.guardduty.DetectorCfnScanEc2InstanceWithFindingsConfigurationArgs>;
    }
    interface DetectorCfnScanEc2InstanceWithFindingsConfigurationArgs {
        /**
         * Describes the configuration for scanning EBS volumes as data source.
         */
        ebsVolumes?: pulumi.Input<boolean>;
    }
    interface DetectorCfns3LogsConfigurationArgs {
        /**
         * The status of S3 data event logs as a data source.
         */
        enable: pulumi.Input<boolean>;
    }
    interface FilterConditionArgs {
        eq?: pulumi.Input<pulumi.Input<string>[]>;
        equals?: pulumi.Input<pulumi.Input<string>[]>;
        greaterThan?: pulumi.Input<number>;
        greaterThanOrEqual?: pulumi.Input<number>;
        gt?: pulumi.Input<number>;
        gte?: pulumi.Input<number>;
        lessThan?: pulumi.Input<number>;
        lessThanOrEqual?: pulumi.Input<number>;
        lt?: pulumi.Input<number>;
        lte?: pulumi.Input<number>;
        neq?: pulumi.Input<pulumi.Input<string>[]>;
        notEquals?: pulumi.Input<pulumi.Input<string>[]>;
    }
    interface FilterFindingCriteriaArgs {
        /**
         * Represents a map of finding properties that match specified conditions and values when querying findings.
         *
         * For information about JSON criterion mapping to their console equivalent, see [Finding criteria](https://docs.aws.amazon.com/guardduty/latest/ug/guardduty_filter-findings.html#filter_criteria) . The following are the available criterion:
         *
         * - accountId
         * - id
         * - region
         * - severity
         *
         * To filter on the basis of severity, the API and AWS CLI use the following input list for the `FindingCriteria` condition:
         *
         * - *Low* : `["1", "2", "3"]`
         * - *Medium* : `["4", "5", "6"]`
         * - *High* : `["7", "8", "9"]`
         *
         * For more information, see [Severity levels for GuardDuty findings](https://docs.aws.amazon.com/guardduty/latest/ug/guardduty_findings.html#guardduty_findings-severity) in the *Amazon GuardDuty User Guide* .
         * - type
         * - updatedAt
         *
         * Type: ISO 8601 string format: `YYYY-MM-DDTHH:MM:SS.SSSZ` or `YYYY-MM-DDTHH:MM:SSZ` depending on whether the value contains milliseconds.
         * - resource.accessKeyDetails.accessKeyId
         * - resource.accessKeyDetails.principalId
         * - resource.accessKeyDetails.userName
         * - resource.accessKeyDetails.userType
         * - resource.instanceDetails.iamInstanceProfile.id
         * - resource.instanceDetails.imageId
         * - resource.instanceDetails.instanceId
         * - resource.instanceDetails.tags.key
         * - resource.instanceDetails.tags.value
         * - resource.instanceDetails.networkInterfaces.ipv6Addresses
         * - resource.instanceDetails.networkInterfaces.privateIpAddresses.privateIpAddress
         * - resource.instanceDetails.networkInterfaces.publicDnsName
         * - resource.instanceDetails.networkInterfaces.publicIp
         * - resource.instanceDetails.networkInterfaces.securityGroups.groupId
         * - resource.instanceDetails.networkInterfaces.securityGroups.groupName
         * - resource.instanceDetails.networkInterfaces.subnetId
         * - resource.instanceDetails.networkInterfaces.vpcId
         * - resource.instanceDetails.outpostArn
         * - resource.resourceType
         * - resource.s3BucketDetails.publicAccess.effectivePermissions
         * - resource.s3BucketDetails.name
         * - resource.s3BucketDetails.tags.key
         * - resource.s3BucketDetails.tags.value
         * - resource.s3BucketDetails.type
         * - service.action.actionType
         * - service.action.awsApiCallAction.api
         * - service.action.awsApiCallAction.callerType
         * - service.action.awsApiCallAction.errorCode
         * - service.action.awsApiCallAction.remoteIpDetails.city.cityName
         * - service.action.awsApiCallAction.remoteIpDetails.country.countryName
         * - service.action.awsApiCallAction.remoteIpDetails.ipAddressV4
         * - service.action.awsApiCallAction.remoteIpDetails.ipAddressV6
         * - service.action.awsApiCallAction.remoteIpDetails.organization.asn
         * - service.action.awsApiCallAction.remoteIpDetails.organization.asnOrg
         * - service.action.awsApiCallAction.serviceName
         * - service.action.dnsRequestAction.domain
         * - service.action.dnsRequestAction.domainWithSuffix
         * - service.action.networkConnectionAction.blocked
         * - service.action.networkConnectionAction.connectionDirection
         * - service.action.networkConnectionAction.localPortDetails.port
         * - service.action.networkConnectionAction.protocol
         * - service.action.networkConnectionAction.remoteIpDetails.city.cityName
         * - service.action.networkConnectionAction.remoteIpDetails.country.countryName
         * - service.action.networkConnectionAction.remoteIpDetails.ipAddressV4
         * - service.action.networkConnectionAction.remoteIpDetails.ipAddressV6
         * - service.action.networkConnectionAction.remoteIpDetails.organization.asn
         * - service.action.networkConnectionAction.remoteIpDetails.organization.asnOrg
         * - service.action.networkConnectionAction.remotePortDetails.port
         * - service.action.awsApiCallAction.remoteAccountDetails.affiliated
         * - service.action.kubernetesApiCallAction.remoteIpDetails.ipAddressV4
         * - service.action.kubernetesApiCallAction.remoteIpDetails.ipAddressV6
         * - service.action.kubernetesApiCallAction.namespace
         * - service.action.kubernetesApiCallAction.remoteIpDetails.organization.asn
         * - service.action.kubernetesApiCallAction.requestUri
         * - service.action.kubernetesApiCallAction.statusCode
         * - service.action.networkConnectionAction.localIpDetails.ipAddressV4
         * - service.action.networkConnectionAction.localIpDetails.ipAddressV6
         * - service.action.networkConnectionAction.protocol
         * - service.action.awsApiCallAction.serviceName
         * - service.action.awsApiCallAction.remoteAccountDetails.accountId
         * - service.additionalInfo.threatListName
         * - service.resourceRole
         * - resource.eksClusterDetails.name
         * - resource.kubernetesDetails.kubernetesWorkloadDetails.name
         * - resource.kubernetesDetails.kubernetesWorkloadDetails.namespace
         * - resource.kubernetesDetails.kubernetesUserDetails.username
         * - resource.kubernetesDetails.kubernetesWorkloadDetails.containers.image
         * - resource.kubernetesDetails.kubernetesWorkloadDetails.containers.imagePrefix
         * - service.ebsVolumeScanDetails.scanId
         * - service.ebsVolumeScanDetails.scanDetections.threatDetectedByName.threatNames.name
         * - service.ebsVolumeScanDetails.scanDetections.threatDetectedByName.threatNames.severity
         * - service.ebsVolumeScanDetails.scanDetections.threatDetectedByName.threatNames.filePaths.hash
         * - service.malwareScanDetails.threats.name
         * - resource.ecsClusterDetails.name
         * - resource.ecsClusterDetails.taskDetails.containers.image
         * - resource.ecsClusterDetails.taskDetails.definitionArn
         * - resource.containerDetails.image
         * - resource.rdsDbInstanceDetails.dbInstanceIdentifier
         * - resource.rdsDbInstanceDetails.dbClusterIdentifier
         * - resource.rdsDbInstanceDetails.engine
         * - resource.rdsDbUserDetails.user
         * - resource.rdsDbInstanceDetails.tags.key
         * - resource.rdsDbInstanceDetails.tags.value
         * - service.runtimeDetails.process.executableSha256
         * - service.runtimeDetails.process.name
         * - service.runtimeDetails.process.name
         * - resource.lambdaDetails.functionName
         * - resource.lambdaDetails.functionArn
         * - resource.lambdaDetails.tags.key
         * - resource.lambdaDetails.tags.value
         */
        criterion?: pulumi.Input<{
            [key: string]: pulumi.Input<inputs.guardduty.FilterConditionArgs>;
        }>;
    }
    interface MalwareProtectionPlanCfnActionsArgs {
        /**
         * Contains information about tagging status of the Malware Protection plan resource.
         */
        tagging?: pulumi.Input<inputs.guardduty.MalwareProtectionPlanCfnTaggingArgs>;
    }
    interface MalwareProtectionPlanCfnProtectedResourceArgs {
        /**
         * Information about the protected S3 bucket resource.
         */
        s3Bucket: pulumi.Input<inputs.guardduty.MalwareProtectionPlanCfnProtectedResourceS3BucketPropertiesArgs>;
    }
    /**
     * Information about the protected S3 bucket resource.
     */
    interface MalwareProtectionPlanCfnProtectedResourceS3BucketPropertiesArgs {
        /**
         * Name of the S3 bucket.
         */
        bucketName?: pulumi.Input<string>;
        /**
         * Information about the specified object prefixes. The S3 object will be scanned only if it belongs to any of the specified object prefixes.
         */
        objectPrefixes?: pulumi.Input<pulumi.Input<string>[]>;
    }
    interface MalwareProtectionPlanCfnTaggingArgs {
        /**
         * Indicates whether or not you chose GuardDuty to add a predefined tag to the scanned S3 object.
         */
        status?: pulumi.Input<string>;
    }
    interface PublishingDestinationCfnDestinationPropertiesArgs {
        /**
         * The ARN of the resource to publish to.
         */
        destinationArn?: pulumi.Input<string>;
        /**
         * The ARN of the KMS key to use for encryption.
         */
        kmsKeyArn?: pulumi.Input<string>;
    }
}
export declare namespace healthlake {
    /**
     * The identity provider configuration for the datastore
     */
    interface FhirDatastoreIdentityProviderConfigurationArgs {
        /**
         * Type of Authorization Strategy. The two types of supported Authorization strategies are SMART_ON_FHIR_V1 and AWS_AUTH.
         */
        authorizationStrategy: pulumi.Input<enums.healthlake.FhirDatastoreIdentityProviderConfigurationAuthorizationStrategy>;
        /**
         * Flag to indicate if fine-grained authorization will be enabled for the datastore
         */
        fineGrainedAuthorizationEnabled?: pulumi.Input<boolean>;
        /**
         * The Amazon Resource Name (ARN) of the Lambda function that will be used to decode the access token created by the authorization server.
         */
        idpLambdaArn?: pulumi.Input<string>;
        /**
         * The JSON metadata elements for identity provider configuration.
         */
        metadata?: pulumi.Input<string>;
    }
    /**
     * The customer-managed-key (CMK) used when creating a Data Store. If a customer owned key is not specified, an AWS owned key will be used for encryption.
     */
    interface FhirDatastoreKmsEncryptionConfigArgs {
        /**
         * The type of customer-managed-key (CMK) used for encryption. The two types of supported CMKs are customer owned CMKs and AWS owned CMKs.
         */
        cmkType: pulumi.Input<enums.healthlake.FhirDatastoreKmsEncryptionConfigCmkType>;
        /**
         * The KMS encryption key id/alias used to encrypt the Data Store contents at rest.
         */
        kmsKeyId?: pulumi.Input<string>;
    }
    /**
     * The preloaded data configuration for the Data Store. Only data preloaded from Synthea is supported.
     */
    interface FhirDatastorePreloadDataConfigArgs {
        /**
         * The type of preloaded data. Only Synthea preloaded data is supported.
         */
        preloadDataType: pulumi.Input<enums.healthlake.FhirDatastorePreloadDataConfigPreloadDataType>;
    }
    /**
     * The server-side encryption key configuration for a customer provided encryption key.
     */
    interface FhirDatastoreSseConfigurationArgs {
        /**
         * The server-side encryption key configuration for a customer provided encryption key.
         */
        kmsEncryptionConfig: pulumi.Input<inputs.healthlake.FhirDatastoreKmsEncryptionConfigArgs>;
    }
}
export declare namespace iam {
    /**
     * Contains information about an attached policy.
     *  An attached policy is a managed policy that has been attached to a user, group, or role.
     *  For more information about managed policies, see [Managed Policies and Inline Policies](https://docs.aws.amazon.com/IAM/latest/UserGuide/policies-managed-vs-inline.html) in the *User Guide*.
     */
    interface GroupPolicyArgs {
        /**
         * The policy document.
         */
        policyDocument: any;
        /**
         * The friendly name (not ARN) identifying the policy.
         */
        policyName: pulumi.Input<string>;
    }
    /**
     * Contains information about an attached policy.
     *  An attached policy is a managed policy that has been attached to a user, group, or role.
     *  For more information about managed policies, refer to [Managed Policies and Inline Policies](https://docs.aws.amazon.com/IAM/latest/UserGuide/policies-managed-vs-inline.html) in the *User Guide*.
     */
    interface RolePolicyArgs {
        /**
         * The entire contents of the policy that defines permissions. For more information, see [Overview of JSON policies](https://docs.aws.amazon.com/IAM/latest/UserGuide/access_policies.html#access_policies-json).
         */
        policyDocument: any;
        /**
         * The friendly name (not ARN) identifying the policy.
         */
        policyName: pulumi.Input<string>;
    }
    /**
     * The private key metadata for the SAML provider
     */
    interface SamlProviderSamlPrivateKeyArgs {
        /**
         * The unique identifier for the SAML private key.
         */
        keyId: pulumi.Input<string>;
        /**
         * The date and time, in <a href=\"http://www.iso.org/iso/iso8601\">ISO 8601 date-time </a> format, when the private key was uploaded.
         */
        timestamp: pulumi.Input<string>;
    }
    /**
     * Creates a password for the specified user, giving the user the ability to access AWS services through the console. For more information about managing passwords, see [Managing Passwords](https://docs.aws.amazon.com/IAM/latest/UserGuide/Using_ManagingLogins.html) in the *User Guide*.
     */
    interface UserLoginProfileArgs {
        /**
         * The user's password.
         */
        password: pulumi.Input<string>;
        /**
         * Specifies whether the user is required to set a new password on next sign-in.
         */
        passwordResetRequired?: pulumi.Input<boolean>;
    }
    /**
     * Contains information about an attached policy.
     *  An attached policy is a managed policy that has been attached to a user, group, or role.
     *  For more information about managed policies, refer to [Managed Policies and Inline Policies](https://docs.aws.amazon.com/IAM/latest/UserGuide/policies-managed-vs-inline.html) in the *User Guide*.
     */
    interface UserPolicyArgs {
        /**
         * The entire contents of the policy that defines permissions. For more information, see [Overview of JSON policies](https://docs.aws.amazon.com/IAM/latest/UserGuide/access_policies.html#access_policies-json).
         */
        policyDocument: any;
        /**
         * The friendly name (not ARN) identifying the policy.
         */
        policyName: pulumi.Input<string>;
    }
}
export declare namespace identitystore {
    /**
     * An object containing the identifier of a group member.
     */
    interface GroupMembershipMemberIdArgs {
        /**
         * The identifier for a user in the identity store.
         */
        userId: pulumi.Input<string>;
    }
}
export declare namespace imagebuilder {
    /**
     * Configuration details of the component.
     */
    interface ContainerRecipeComponentConfigurationArgs {
        /**
         * The Amazon Resource Name (ARN) of the component.
         */
        componentArn?: pulumi.Input<string>;
        /**
         * A group of parameter settings that are used to configure the component for a specific recipe.
         */
        parameters?: pulumi.Input<pulumi.Input<inputs.imagebuilder.ContainerRecipeComponentParameterArgs>[]>;
    }
    /**
     * Contains a key/value pair that sets the named component parameter.
     */
    interface ContainerRecipeComponentParameterArgs {
        /**
         * The name of the component parameter to set.
         */
        name: pulumi.Input<string>;
        /**
         * Sets the value for the named component parameter.
         */
        value: pulumi.Input<pulumi.Input<string>[]>;
    }
    /**
     * Amazon EBS-specific block device mapping specifications.
     */
    interface ContainerRecipeEbsInstanceBlockDeviceSpecificationArgs {
        /**
         * Use to configure delete on termination of the associated device.
         */
        deleteOnTermination?: pulumi.Input<boolean>;
        /**
         * Use to configure device encryption.
         */
        encrypted?: pulumi.Input<boolean>;
        /**
         * Use to configure device IOPS.
         */
        iops?: pulumi.Input<number>;
        /**
         * Use to configure the KMS key to use when encrypting the device.
         */
        kmsKeyId?: pulumi.Input<string>;
        /**
         * The snapshot that defines the device contents.
         */
        snapshotId?: pulumi.Input<string>;
        /**
         * For GP3 volumes only - The throughput in MiB/s that the volume supports.
         */
        throughput?: pulumi.Input<number>;
        /**
         * Use to override the device's volume size.
         */
        volumeSize?: pulumi.Input<number>;
        /**
         * Use to override the device's volume type.
         */
        volumeType?: pulumi.Input<enums.imagebuilder.ContainerRecipeEbsInstanceBlockDeviceSpecificationVolumeType>;
    }
    /**
     * Defines block device mappings for the instance used to configure your image.
     */
    interface ContainerRecipeInstanceBlockDeviceMappingArgs {
        /**
         * The device to which these mappings apply.
         */
        deviceName?: pulumi.Input<string>;
        /**
         * Use to manage Amazon EBS-specific configuration for this mapping.
         */
        ebs?: pulumi.Input<inputs.imagebuilder.ContainerRecipeEbsInstanceBlockDeviceSpecificationArgs>;
        /**
         * Use to remove a mapping from the parent image.
         */
        noDevice?: pulumi.Input<string>;
        /**
         * Use to manage instance ephemeral devices.
         */
        virtualName?: pulumi.Input<string>;
    }
    /**
     * A group of options that can be used to configure an instance for building and testing container images.
     */
    interface ContainerRecipeInstanceConfigurationArgs {
        /**
         * Defines the block devices to attach for building an instance from this Image Builder AMI.
         */
        blockDeviceMappings?: pulumi.Input<pulumi.Input<inputs.imagebuilder.ContainerRecipeInstanceBlockDeviceMappingArgs>[]>;
        /**
         * The AMI ID to use as the base image for a container build and test instance. If not specified, Image Builder will use the appropriate ECS-optimized AMI as a base image.
         */
        image?: pulumi.Input<string>;
    }
    /**
     * The container repository where the output container image is stored.
     */
    interface ContainerRecipeTargetContainerRepositoryArgs {
        /**
         * The name of the container repository where the output container image is stored. This name is prefixed by the repository location.
         */
        repositoryName?: pulumi.Input<string>;
        /**
         * Specifies the service in which this image was registered.
         */
        service?: pulumi.Input<enums.imagebuilder.ContainerRecipeTargetContainerRepositoryService>;
    }
    /**
     * The specific AMI settings (for example, launch permissions, AMI tags).
     */
    interface DistributionConfigurationAmiDistributionConfigurationArgs {
        /**
         * The tags to apply to AMIs distributed to this Region.
         */
        amiTags?: pulumi.Input<{
            [key: string]: pulumi.Input<string>;
        }>;
        /**
         * The description of the AMI distribution configuration.
         */
        description?: pulumi.Input<string>;
        /**
         * The KMS key identifier used to encrypt the distributed image.
         */
        kmsKeyId?: pulumi.Input<string>;
        /**
         * Launch permissions can be used to configure which AWS account s can use the AMI to launch instances.
         */
        launchPermissionConfiguration?: pulumi.Input<inputs.imagebuilder.DistributionConfigurationLaunchPermissionConfigurationArgs>;
        /**
         * The name of the AMI distribution configuration.
         */
        name?: pulumi.Input<string>;
        /**
         * The ID of accounts to which you want to distribute an image.
         */
        targetAccountIds?: pulumi.Input<pulumi.Input<string>[]>;
    }
    /**
     * Container distribution settings for encryption, licensing, and sharing in a specific Region.
     */
    interface DistributionConfigurationContainerDistributionConfigurationArgs {
        /**
         * Tags that are attached to the container distribution configuration.
         */
        containerTags?: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * The description of the container distribution configuration.
         */
        description?: pulumi.Input<string>;
        /**
         * The destination repository for the container distribution configuration.
         */
        targetRepository?: pulumi.Input<inputs.imagebuilder.DistributionConfigurationTargetContainerRepositoryArgs>;
    }
    /**
     * The distributions of the distribution configuration.
     */
    interface DistributionConfigurationDistributionArgs {
        /**
         * The specific AMI settings, such as launch permissions and AMI tags. For details, see example schema below.
         */
        amiDistributionConfiguration?: pulumi.Input<inputs.imagebuilder.DistributionConfigurationAmiDistributionConfigurationArgs>;
        /**
         * Container distribution settings for encryption, licensing, and sharing in a specific Region. For details, see example schema below.
         */
        containerDistributionConfiguration?: pulumi.Input<inputs.imagebuilder.DistributionConfigurationContainerDistributionConfigurationArgs>;
        /**
         * The Windows faster-launching configurations to use for AMI distribution.
         */
        fastLaunchConfigurations?: pulumi.Input<pulumi.Input<inputs.imagebuilder.DistributionConfigurationFastLaunchConfigurationArgs>[]>;
        /**
         * A group of launchTemplateConfiguration settings that apply to image distribution.
         */
        launchTemplateConfigurations?: pulumi.Input<pulumi.Input<inputs.imagebuilder.DistributionConfigurationLaunchTemplateConfigurationArgs>[]>;
        /**
         * The License Manager Configuration to associate with the AMI in the specified Region.
         */
        licenseConfigurationArns?: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * region
         */
        region: pulumi.Input<string>;
    }
    /**
     * The Windows faster-launching configuration to use for AMI distribution.
     */
    interface DistributionConfigurationFastLaunchConfigurationArgs {
        /**
         * The owner account ID for the fast-launch enabled Windows AMI.
         */
        accountId?: pulumi.Input<string>;
        /**
         * A Boolean that represents the current state of faster launching for the Windows AMI. Set to true to start using Windows faster launching, or false to stop using it.
         */
        enabled?: pulumi.Input<boolean>;
        /**
         * The launch template that the fast-launch enabled Windows AMI uses when it launches Windows instances to create pre-provisioned snapshots.
         */
        launchTemplate?: pulumi.Input<inputs.imagebuilder.DistributionConfigurationFastLaunchLaunchTemplateSpecificationArgs>;
        /**
         * The maximum number of parallel instances that are launched for creating resources.
         */
        maxParallelLaunches?: pulumi.Input<number>;
        /**
         * Configuration settings for managing the number of snapshots that are created from pre-provisioned instances for the Windows AMI when faster launching is enabled.
         */
        snapshotConfiguration?: pulumi.Input<inputs.imagebuilder.DistributionConfigurationFastLaunchSnapshotConfigurationArgs>;
    }
    /**
     * The launch template that the fast-launch enabled Windows AMI uses when it launches Windows instances to create pre-provisioned snapshots.
     */
    interface DistributionConfigurationFastLaunchLaunchTemplateSpecificationArgs {
        /**
         * The ID of the launch template to use for faster launching for a Windows AMI.
         */
        launchTemplateId?: pulumi.Input<string>;
        /**
         * The name of the launch template to use for faster launching for a Windows AMI.
         */
        launchTemplateName?: pulumi.Input<string>;
        /**
         * The version of the launch template to use for faster launching for a Windows AMI.
         */
        launchTemplateVersion?: pulumi.Input<string>;
    }
    /**
     * Configuration settings for managing the number of snapshots that are created from pre-provisioned instances for the Windows AMI when faster launching is enabled.
     */
    interface DistributionConfigurationFastLaunchSnapshotConfigurationArgs {
        /**
         * The number of pre-provisioned snapshots to keep on hand for a fast-launch enabled Windows AMI.
         */
        targetResourceCount?: pulumi.Input<number>;
    }
    /**
     * Launch permissions can be used to configure which AWS accounts can use the AMI to launch instances.
     */
    interface DistributionConfigurationLaunchPermissionConfigurationArgs {
        /**
         * The ARN for an Amazon Web Services Organization that you want to share your AMI with.
         */
        organizationArns?: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * The ARN for an Organizations organizational unit (OU) that you want to share your AMI with.
         */
        organizationalUnitArns?: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * The name of the group.
         */
        userGroups?: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * The AWS account ID.
         */
        userIds?: pulumi.Input<pulumi.Input<string>[]>;
    }
    /**
     * launchTemplateConfiguration settings that apply to image distribution.
     */
    interface DistributionConfigurationLaunchTemplateConfigurationArgs {
        /**
         * The account ID that this configuration applies to.
         */
        accountId?: pulumi.Input<string>;
        /**
         * Identifies the EC2 launch template to use.
         */
        launchTemplateId?: pulumi.Input<string>;
        /**
         * Set the specified EC2 launch template as the default launch template for the specified account.
         */
        setDefaultVersion?: pulumi.Input<boolean>;
    }
    /**
     * The destination repository for the container image.
     */
    interface DistributionConfigurationTargetContainerRepositoryArgs {
        /**
         * The repository name of target container repository.
         */
        repositoryName?: pulumi.Input<string>;
        /**
         * The service of target container repository.
         */
        service?: pulumi.Input<enums.imagebuilder.DistributionConfigurationTargetContainerRepositoryService>;
    }
    /**
     * Settings for Image Builder to configure the ECR repository and output container images that are scanned.
     */
    interface ImageEcrConfigurationArgs {
        /**
         * Tags for Image Builder to apply the output container image that is scanned. Tags can help you identify and manage your scanned images.
         */
        containerTags?: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * The name of the container repository that Amazon Inspector scans to identify findings for your container images. The name includes the path for the repository location. If you don’t provide this information, Image Builder creates a repository in your account named image-builder-image-scanning-repository to use for vulnerability scans for your output container images.
         */
        repositoryName?: pulumi.Input<string>;
    }
    /**
     * Settings for Image Builder to configure the ECR repository and output container images that are scanned.
     */
    interface ImagePipelineEcrConfigurationArgs {
        /**
         * Tags for Image Builder to apply the output container image that is scanned. Tags can help you identify and manage your scanned images.
         */
        containerTags?: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * The name of the container repository that Amazon Inspector scans to identify findings for your container images. The name includes the path for the repository location. If you don't provide this information, Image Builder creates a repository in your account named image-builder-image-scanning-repository to use for vulnerability scans for your output container images.
         */
        repositoryName?: pulumi.Input<string>;
    }
    /**
     * Determines if tests should run after building the image. Image Builder defaults to enable tests to run following the image build, before image distribution.
     */
    interface ImagePipelineImageScanningConfigurationArgs {
        /**
         * Contains ECR settings for vulnerability scans.
         */
        ecrConfiguration?: pulumi.Input<inputs.imagebuilder.ImagePipelineEcrConfigurationArgs>;
        /**
         * This sets whether Image Builder keeps a snapshot of the vulnerability scans that Amazon Inspector runs against the build instance when you create a new image.
         */
        imageScanningEnabled?: pulumi.Input<boolean>;
    }
    /**
     * Image tests configuration.
     */
    interface ImagePipelineImageTestsConfigurationArgs {
        /**
         * Defines if tests should be executed when building this image.
         */
        imageTestsEnabled?: pulumi.Input<boolean>;
        /**
         * The maximum time in minutes that tests are permitted to run.
         */
        timeoutMinutes?: pulumi.Input<number>;
    }
    /**
     * The schedule of the image pipeline.
     */
    interface ImagePipelineScheduleArgs {
        /**
         * The condition configures when the pipeline should trigger a new image build.
         */
        pipelineExecutionStartCondition?: pulumi.Input<enums.imagebuilder.ImagePipelineSchedulePipelineExecutionStartCondition>;
        /**
         * The expression determines how often EC2 Image Builder evaluates your pipelineExecutionStartCondition.
         */
        scheduleExpression?: pulumi.Input<string>;
    }
    /**
     * The workflow configuration of the image
     */
    interface ImagePipelineWorkflowConfigurationArgs {
        /**
         * Define execution decision in case of workflow failure
         */
        onFailure?: pulumi.Input<enums.imagebuilder.ImagePipelineWorkflowConfigurationOnFailure>;
        /**
         * The parallel group name
         */
        parallelGroup?: pulumi.Input<string>;
        /**
         * The parameters associated with the workflow
         */
        parameters?: pulumi.Input<pulumi.Input<inputs.imagebuilder.ImagePipelineWorkflowParameterArgs>[]>;
        /**
         * The Amazon Resource Name (ARN) of the workflow
         */
        workflowArn?: pulumi.Input<string>;
    }
    /**
     * A parameter associated with the workflow
     */
    interface ImagePipelineWorkflowParameterArgs {
        /**
         * The name of the workflow parameter to set.
         */
        name?: pulumi.Input<string>;
        /**
         * Sets the value for the named workflow parameter.
         */
        value?: pulumi.Input<pulumi.Input<string>[]>;
    }
    /**
     * Specify additional settings and launch scripts for your build instances.
     */
    interface ImageRecipeAdditionalInstanceConfigurationArgs {
        /**
         * Contains settings for the SSM agent on your build instance.
         */
        systemsManagerAgent?: pulumi.Input<inputs.imagebuilder.ImageRecipeSystemsManagerAgentArgs>;
        /**
         * Use this property to provide commands or a command script to run when you launch your build instance.
         */
        userDataOverride?: pulumi.Input<string>;
    }
    /**
     * Configuration details of the component.
     */
    interface ImageRecipeComponentConfigurationArgs {
        /**
         * The Amazon Resource Name (ARN) of the component.
         */
        componentArn?: pulumi.Input<string>;
        /**
         * A group of parameter settings that are used to configure the component for a specific recipe.
         */
        parameters?: pulumi.Input<pulumi.Input<inputs.imagebuilder.ImageRecipeComponentParameterArgs>[]>;
    }
    /**
     * Contains a key/value pair that sets the named component parameter.
     */
    interface ImageRecipeComponentParameterArgs {
        /**
         * The name of the component parameter to set.
         */
        name: pulumi.Input<string>;
        /**
         * Sets the value for the named component parameter.
         */
        value: pulumi.Input<pulumi.Input<string>[]>;
    }
    /**
     * Amazon EBS-specific block device mapping specifications.
     */
    interface ImageRecipeEbsInstanceBlockDeviceSpecificationArgs {
        /**
         * Use to configure delete on termination of the associated device.
         */
        deleteOnTermination?: pulumi.Input<boolean>;
        /**
         * Use to configure device encryption.
         */
        encrypted?: pulumi.Input<boolean>;
        /**
         * Use to configure device IOPS.
         */
        iops?: pulumi.Input<number>;
        /**
         * Use to configure the KMS key to use when encrypting the device.
         */
        kmsKeyId?: pulumi.Input<string>;
        /**
         * The snapshot that defines the device contents.
         */
        snapshotId?: pulumi.Input<string>;
        /**
         * For GP3 volumes only - The throughput in MiB/s that the volume supports.
         */
        throughput?: pulumi.Input<number>;
        /**
         * Use to override the device's volume size.
         */
        volumeSize?: pulumi.Input<number>;
        /**
         * Use to override the device's volume type.
         */
        volumeType?: pulumi.Input<enums.imagebuilder.ImageRecipeEbsInstanceBlockDeviceSpecificationVolumeType>;
    }
    /**
     * Defines block device mappings for the instance used to configure your image.
     */
    interface ImageRecipeInstanceBlockDeviceMappingArgs {
        /**
         * The device to which these mappings apply.
         */
        deviceName?: pulumi.Input<string>;
        /**
         * Use to manage Amazon EBS-specific configuration for this mapping.
         */
        ebs?: pulumi.Input<inputs.imagebuilder.ImageRecipeEbsInstanceBlockDeviceSpecificationArgs>;
        /**
         * Use to remove a mapping from the parent image.
         */
        noDevice?: pulumi.Input<string>;
        /**
         * Use to manage instance ephemeral devices.
         */
        virtualName?: pulumi.Input<string>;
    }
    /**
     * Contains settings for the SSM agent on your build instance.
     */
    interface ImageRecipeSystemsManagerAgentArgs {
        /**
         * Controls whether the SSM agent is removed from your final build image, prior to creating the new AMI. If this is set to true, then the agent is removed from the final image. If it's set to false, then the agent is left in, so that it is included in the new AMI. The default value is false.
         */
        uninstallAfterBuild?: pulumi.Input<boolean>;
    }
    /**
     * Contains settings for Image Builder image resource and container image scans.
     */
    interface ImageScanningConfigurationArgs {
        /**
         * Contains ECR settings for vulnerability scans.
         */
        ecrConfiguration?: pulumi.Input<inputs.imagebuilder.ImageEcrConfigurationArgs>;
        /**
         * This sets whether Image Builder keeps a snapshot of the vulnerability scans that Amazon Inspector runs against the build instance when you create a new image.
         */
        imageScanningEnabled?: pulumi.Input<boolean>;
    }
    /**
     * The image tests configuration used when creating this image.
     */
    interface ImageTestsConfigurationArgs {
        /**
         * ImageTestsEnabled
         */
        imageTestsEnabled?: pulumi.Input<boolean>;
        /**
         * TimeoutMinutes
         */
        timeoutMinutes?: pulumi.Input<number>;
    }
    /**
     * The workflow configuration of the image
     */
    interface ImageWorkflowConfigurationArgs {
        /**
         * Define execution decision in case of workflow failure
         */
        onFailure?: pulumi.Input<enums.imagebuilder.ImageWorkflowConfigurationOnFailure>;
        /**
         * The parallel group name
         */
        parallelGroup?: pulumi.Input<string>;
        /**
         * The parameters associated with the workflow
         */
        parameters?: pulumi.Input<pulumi.Input<inputs.imagebuilder.ImageWorkflowParameterArgs>[]>;
        /**
         * The Amazon Resource Name (ARN) of the workflow
         */
        workflowArn?: pulumi.Input<string>;
    }
    /**
     * A parameter associated with the workflow
     */
    interface ImageWorkflowParameterArgs {
        /**
         * The name of the workflow parameter to set.
         */
        name?: pulumi.Input<string>;
        /**
         * Sets the value for the named workflow parameter.
         */
        value?: pulumi.Input<pulumi.Input<string>[]>;
    }
    /**
     * The instance metadata option settings for the infrastructure configuration.
     */
    interface InfrastructureConfigurationInstanceMetadataOptionsArgs {
        /**
         * Limit the number of hops that an instance metadata request can traverse to reach its destination.
         */
        httpPutResponseHopLimit?: pulumi.Input<number>;
        /**
         * Indicates whether a signed token header is required for instance metadata retrieval requests. The values affect the response as follows:
         */
        httpTokens?: pulumi.Input<enums.imagebuilder.InfrastructureConfigurationInstanceMetadataOptionsHttpTokens>;
    }
    /**
     * The logging configuration of the infrastructure configuration.
     */
    interface InfrastructureConfigurationLoggingArgs {
        /**
         * The Amazon S3 logging configuration.
         */
        s3Logs?: pulumi.Input<inputs.imagebuilder.InfrastructureConfigurationS3LogsArgs>;
    }
    /**
     * The placement options
     */
    interface InfrastructureConfigurationPlacementArgs {
        /**
         * AvailabilityZone
         */
        availabilityZone?: pulumi.Input<string>;
        /**
         * HostId
         */
        hostId?: pulumi.Input<string>;
        /**
         * HostResourceGroupArn
         */
        hostResourceGroupArn?: pulumi.Input<string>;
        /**
         * Tenancy
         */
        tenancy?: pulumi.Input<enums.imagebuilder.InfrastructureConfigurationPlacementTenancy>;
    }
    /**
     * The S3 path in which to store the logs.
     */
    interface InfrastructureConfigurationS3LogsArgs {
        /**
         * S3BucketName
         */
        s3BucketName?: pulumi.Input<string>;
        /**
         * S3KeyPrefix
         */
        s3KeyPrefix?: pulumi.Input<string>;
    }
    /**
     * The action of the policy detail.
     */
    interface LifecyclePolicyActionArgs {
        /**
         * Specifies the resources that the lifecycle policy applies to.
         */
        includeResources?: pulumi.Input<inputs.imagebuilder.LifecyclePolicyIncludeResourcesArgs>;
        /**
         * The action type of the policy detail.
         */
        type: pulumi.Input<enums.imagebuilder.LifecyclePolicyActionType>;
    }
    /**
     * The AMI exclusion rules for the policy detail.
     */
    interface LifecyclePolicyAmiExclusionRulesArgs {
        /**
         * Use to apply lifecycle policy actions on whether the AMI is public.
         */
        isPublic?: pulumi.Input<boolean>;
        /**
         * Use to apply lifecycle policy actions on AMIs launched before a certain time.
         */
        lastLaunched?: pulumi.Input<inputs.imagebuilder.LifecyclePolicyLastLaunchedArgs>;
        /**
         * Use to apply lifecycle policy actions on AMIs distributed to a set of regions.
         */
        regions?: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * Use to apply lifecycle policy actions on AMIs shared with a set of regions.
         */
        sharedAccounts?: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * The AMIs to select by tag.
         */
        tagMap?: pulumi.Input<{
            [key: string]: pulumi.Input<string>;
        }>;
    }
    /**
     * The exclusion rules to apply of the policy detail.
     */
    interface LifecyclePolicyExclusionRulesArgs {
        /**
         * Lists configuration values that apply to AMIs that Image Builder should exclude from the lifecycle action.
         */
        amis?: pulumi.Input<inputs.imagebuilder.LifecyclePolicyAmiExclusionRulesArgs>;
        /**
         * The Image Builder tags to filter on.
         */
        tagMap?: pulumi.Input<{
            [key: string]: pulumi.Input<string>;
        }>;
    }
    /**
     * The filters to apply of the policy detail.
     */
    interface LifecyclePolicyFilterArgs {
        /**
         * The minimum number of Image Builder resources to retain.
         */
        retainAtLeast?: pulumi.Input<number>;
        /**
         * The filter type.
         */
        type: pulumi.Input<enums.imagebuilder.LifecyclePolicyFilterType>;
        /**
         * The value's time unit.
         */
        unit?: pulumi.Input<enums.imagebuilder.LifecyclePolicyTimeUnit>;
        /**
         * The filter value.
         */
        value: pulumi.Input<number>;
    }
    /**
     * The included resources of the policy detail.
     */
    interface LifecyclePolicyIncludeResourcesArgs {
        /**
         * Use to configure lifecycle actions on AMIs.
         */
        amis?: pulumi.Input<boolean>;
        /**
         * Use to configure lifecycle actions on containers.
         */
        containers?: pulumi.Input<boolean>;
        /**
         * Use to configure lifecycle actions on snapshots.
         */
        snapshots?: pulumi.Input<boolean>;
    }
    /**
     * The last launched time of a resource.
     */
    interface LifecyclePolicyLastLaunchedArgs {
        /**
         * The value's time unit.
         */
        unit: pulumi.Input<enums.imagebuilder.LifecyclePolicyTimeUnit>;
        /**
         * The last launched value.
         */
        value: pulumi.Input<number>;
    }
    /**
     * The policy detail of the lifecycle policy.
     */
    interface LifecyclePolicyPolicyDetailArgs {
        /**
         * Configuration details for the policy action.
         */
        action: pulumi.Input<inputs.imagebuilder.LifecyclePolicyActionArgs>;
        /**
         * Additional rules to specify resources that should be exempt from policy actions.
         */
        exclusionRules?: pulumi.Input<inputs.imagebuilder.LifecyclePolicyExclusionRulesArgs>;
        /**
         * Specifies the resources that the lifecycle policy applies to.
         */
        filter: pulumi.Input<inputs.imagebuilder.LifecyclePolicyFilterArgs>;
    }
    /**
     * The recipe to apply the lifecycle policy for.
     */
    interface LifecyclePolicyRecipeSelectionArgs {
        /**
         * The recipe name.
         */
        name: pulumi.Input<string>;
        /**
         * The recipe version.
         */
        semanticVersion: pulumi.Input<string>;
    }
    /**
     * The resource selection for the lifecycle policy.
     */
    interface LifecyclePolicyResourceSelectionArgs {
        /**
         * The recipes to select.
         */
        recipes?: pulumi.Input<pulumi.Input<inputs.imagebuilder.LifecyclePolicyRecipeSelectionArgs>[]>;
        /**
         * The Image Builder resources to select by tag.
         */
        tagMap?: pulumi.Input<{
            [key: string]: pulumi.Input<string>;
        }>;
    }
}
export declare namespace inspector {
    interface AssessmentTemplateTagArgs {
        /**
         * A tag key.
         */
        key: pulumi.Input<string>;
        /**
         * A value assigned to a tag key.
         */
        value: pulumi.Input<string>;
    }
    interface ResourceGroupTagArgs {
        /**
         * A tag key.
         */
        key: pulumi.Input<string>;
        /**
         * A value assigned to a tag key.
         */
        value: pulumi.Input<string>;
    }
}
export declare namespace inspectorv2 {
    interface CisScanConfigurationCisTargetsArgs {
        accountIds: pulumi.Input<pulumi.Input<string>[]>;
        targetResourceTags: pulumi.Input<{
            [key: string]: any;
        }>;
    }
    interface CisScanConfigurationDailyScheduleArgs {
        startTime: pulumi.Input<inputs.inspectorv2.CisScanConfigurationTimeArgs>;
    }
    interface CisScanConfigurationMonthlyScheduleArgs {
        day: pulumi.Input<enums.inspectorv2.CisScanConfigurationDay>;
        startTime: pulumi.Input<inputs.inspectorv2.CisScanConfigurationTimeArgs>;
    }
    interface CisScanConfigurationOneTimeScheduleArgs {
    }
    /**
     * Choose a Schedule cadence
     */
    interface CisScanConfigurationScheduleArgs {
        daily?: pulumi.Input<inputs.inspectorv2.CisScanConfigurationDailyScheduleArgs>;
        monthly?: pulumi.Input<inputs.inspectorv2.CisScanConfigurationMonthlyScheduleArgs>;
        oneTime?: pulumi.Input<inputs.inspectorv2.CisScanConfigurationOneTimeScheduleArgs>;
        weekly?: pulumi.Input<inputs.inspectorv2.CisScanConfigurationWeeklyScheduleArgs>;
    }
    interface CisScanConfigurationTimeArgs {
        timeOfDay: pulumi.Input<string>;
        timeZone: pulumi.Input<string>;
    }
    interface CisScanConfigurationWeeklyScheduleArgs {
        days: pulumi.Input<pulumi.Input<enums.inspectorv2.CisScanConfigurationDay>[]>;
        startTime: pulumi.Input<inputs.inspectorv2.CisScanConfigurationTimeArgs>;
    }
    interface FilterCriteriaArgs {
        /**
         * Details of the AWS account IDs used to filter findings.
         */
        awsAccountId?: pulumi.Input<pulumi.Input<inputs.inspectorv2.FilterStringFilterArgs>[]>;
        /**
         * Details of the component IDs used to filter findings.
         */
        componentId?: pulumi.Input<pulumi.Input<inputs.inspectorv2.FilterStringFilterArgs>[]>;
        /**
         * Details of the component types used to filter findings.
         */
        componentType?: pulumi.Input<pulumi.Input<inputs.inspectorv2.FilterStringFilterArgs>[]>;
        /**
         * Details of the Amazon EC2 instance image IDs used to filter findings.
         */
        ec2InstanceImageId?: pulumi.Input<pulumi.Input<inputs.inspectorv2.FilterStringFilterArgs>[]>;
        /**
         * Details of the Amazon EC2 instance subnet IDs used to filter findings.
         */
        ec2InstanceSubnetId?: pulumi.Input<pulumi.Input<inputs.inspectorv2.FilterStringFilterArgs>[]>;
        /**
         * Details of the Amazon EC2 instance VPC IDs used to filter findings.
         */
        ec2InstanceVpcId?: pulumi.Input<pulumi.Input<inputs.inspectorv2.FilterStringFilterArgs>[]>;
        /**
         * Details of the Amazon ECR image architecture types used to filter findings.
         */
        ecrImageArchitecture?: pulumi.Input<pulumi.Input<inputs.inspectorv2.FilterStringFilterArgs>[]>;
        /**
         * Details of the Amazon ECR image hashes used to filter findings.
         */
        ecrImageHash?: pulumi.Input<pulumi.Input<inputs.inspectorv2.FilterStringFilterArgs>[]>;
        /**
         * Details on the Amazon ECR image push date and time used to filter findings.
         */
        ecrImagePushedAt?: pulumi.Input<pulumi.Input<inputs.inspectorv2.FilterDateFilterArgs>[]>;
        /**
         * Details on the Amazon ECR registry used to filter findings.
         */
        ecrImageRegistry?: pulumi.Input<pulumi.Input<inputs.inspectorv2.FilterStringFilterArgs>[]>;
        /**
         * Details on the name of the Amazon ECR repository used to filter findings.
         */
        ecrImageRepositoryName?: pulumi.Input<pulumi.Input<inputs.inspectorv2.FilterStringFilterArgs>[]>;
        /**
         * The tags attached to the Amazon ECR container image.
         */
        ecrImageTags?: pulumi.Input<pulumi.Input<inputs.inspectorv2.FilterStringFilterArgs>[]>;
        /**
         * Details on the finding ARNs used to filter findings.
         */
        findingArn?: pulumi.Input<pulumi.Input<inputs.inspectorv2.FilterStringFilterArgs>[]>;
        /**
         * Details on the finding status types used to filter findings.
         */
        findingStatus?: pulumi.Input<pulumi.Input<inputs.inspectorv2.FilterStringFilterArgs>[]>;
        /**
         * Details on the finding types used to filter findings.
         */
        findingType?: pulumi.Input<pulumi.Input<inputs.inspectorv2.FilterStringFilterArgs>[]>;
        /**
         * Details on the date and time a finding was first seen used to filter findings.
         */
        firstObservedAt?: pulumi.Input<pulumi.Input<inputs.inspectorv2.FilterDateFilterArgs>[]>;
        /**
         * The Amazon Inspector score to filter on.
         */
        inspectorScore?: pulumi.Input<pulumi.Input<inputs.inspectorv2.FilterNumberFilterArgs>[]>;
        /**
         * Details on the date and time a finding was last seen used to filter findings.
         */
        lastObservedAt?: pulumi.Input<pulumi.Input<inputs.inspectorv2.FilterDateFilterArgs>[]>;
        /**
         * Details on network protocol used to filter findings.
         */
        networkProtocol?: pulumi.Input<pulumi.Input<inputs.inspectorv2.FilterStringFilterArgs>[]>;
        /**
         * Details on the port ranges used to filter findings.
         */
        portRange?: pulumi.Input<pulumi.Input<inputs.inspectorv2.FilterPortRangeFilterArgs>[]>;
        /**
         * Details on the related vulnerabilities used to filter findings.
         */
        relatedVulnerabilities?: pulumi.Input<pulumi.Input<inputs.inspectorv2.FilterStringFilterArgs>[]>;
        /**
         * Details on the resource IDs used to filter findings.
         */
        resourceId?: pulumi.Input<pulumi.Input<inputs.inspectorv2.FilterStringFilterArgs>[]>;
        /**
         * Details on the resource tags used to filter findings.
         */
        resourceTags?: pulumi.Input<pulumi.Input<inputs.inspectorv2.FilterMapFilterArgs>[]>;
        /**
         * Details on the resource types used to filter findings.
         */
        resourceType?: pulumi.Input<pulumi.Input<inputs.inspectorv2.FilterStringFilterArgs>[]>;
        /**
         * Details on the severity used to filter findings.
         */
        severity?: pulumi.Input<pulumi.Input<inputs.inspectorv2.FilterStringFilterArgs>[]>;
        /**
         * Details on the finding title used to filter findings.
         */
        title?: pulumi.Input<pulumi.Input<inputs.inspectorv2.FilterStringFilterArgs>[]>;
        /**
         * Details on the date and time a finding was last updated at used to filter findings.
         */
        updatedAt?: pulumi.Input<pulumi.Input<inputs.inspectorv2.FilterDateFilterArgs>[]>;
        /**
         * Details on the vendor severity used to filter findings.
         */
        vendorSeverity?: pulumi.Input<pulumi.Input<inputs.inspectorv2.FilterStringFilterArgs>[]>;
        /**
         * Details on the vulnerability ID used to filter findings.
         */
        vulnerabilityId?: pulumi.Input<pulumi.Input<inputs.inspectorv2.FilterStringFilterArgs>[]>;
        /**
         * Details on the vulnerability score to filter findings by.
         */
        vulnerabilitySource?: pulumi.Input<pulumi.Input<inputs.inspectorv2.FilterStringFilterArgs>[]>;
        /**
         * Details on the vulnerable packages used to filter findings.
         */
        vulnerablePackages?: pulumi.Input<pulumi.Input<inputs.inspectorv2.FilterPackageFilterArgs>[]>;
    }
    interface FilterDateFilterArgs {
        endInclusive?: pulumi.Input<number>;
        startInclusive?: pulumi.Input<number>;
    }
    interface FilterMapFilterArgs {
        comparison: pulumi.Input<enums.inspectorv2.FilterMapComparison>;
        key?: pulumi.Input<string>;
        value?: pulumi.Input<string>;
    }
    interface FilterNumberFilterArgs {
        lowerInclusive?: pulumi.Input<number>;
        upperInclusive?: pulumi.Input<number>;
    }
    interface FilterPackageFilterArgs {
        architecture?: pulumi.Input<inputs.inspectorv2.FilterStringFilterArgs>;
        epoch?: pulumi.Input<inputs.inspectorv2.FilterNumberFilterArgs>;
        name?: pulumi.Input<inputs.inspectorv2.FilterStringFilterArgs>;
        release?: pulumi.Input<inputs.inspectorv2.FilterStringFilterArgs>;
        sourceLayerHash?: pulumi.Input<inputs.inspectorv2.FilterStringFilterArgs>;
        version?: pulumi.Input<inputs.inspectorv2.FilterStringFilterArgs>;
    }
    interface FilterPortRangeFilterArgs {
        beginInclusive?: pulumi.Input<number>;
        endInclusive?: pulumi.Input<number>;
    }
    interface FilterStringFilterArgs {
        comparison: pulumi.Input<enums.inspectorv2.FilterStringComparison>;
        value: pulumi.Input<string>;
    }
}
export declare namespace internetmonitor {
    interface MonitorHealthEventsConfigArgs {
        /**
         * The configuration that determines the threshold and other conditions for when Internet Monitor creates a health event for a local availability issue.
         */
        availabilityLocalHealthEventsConfig?: pulumi.Input<inputs.internetmonitor.MonitorLocalHealthEventsConfigArgs>;
        /**
         * The health event threshold percentage set for availability scores. When the overall availability score is at or below this percentage, Internet Monitor creates a health event.
         */
        availabilityScoreThreshold?: pulumi.Input<number>;
        /**
         * The configuration that determines the threshold and other conditions for when Internet Monitor creates a health event for a local performance issue.
         */
        performanceLocalHealthEventsConfig?: pulumi.Input<inputs.internetmonitor.MonitorLocalHealthEventsConfigArgs>;
        /**
         * The health event threshold percentage set for performance scores. When the overall performance score is at or below this percentage, Internet Monitor creates a health event.
         */
        performanceScoreThreshold?: pulumi.Input<number>;
    }
    interface MonitorInternetMeasurementsLogDeliveryArgs {
        /**
         * The configuration for publishing Amazon CloudWatch Internet Monitor internet measurements to Amazon S3.
         */
        s3Config?: pulumi.Input<inputs.internetmonitor.MonitorS3ConfigArgs>;
    }
    interface MonitorLocalHealthEventsConfigArgs {
        /**
         * The health event threshold percentage set for a local health score.
         */
        healthScoreThreshold?: pulumi.Input<number>;
        /**
         * The minimum percentage of overall traffic for an application that must be impacted by an issue before Internet Monitor creates an event when a threshold is crossed for a local health score.
         *
         * If you don't set a minimum traffic impact threshold, the default value is 0.01%.
         */
        minTrafficImpact?: pulumi.Input<number>;
        /**
         * The status of whether Internet Monitor creates a health event based on a threshold percentage set for a local health score. The status can be `ENABLED` or `DISABLED` .
         */
        status?: pulumi.Input<enums.internetmonitor.MonitorLocalHealthEventsConfigStatus>;
    }
    interface MonitorS3ConfigArgs {
        /**
         * The Amazon S3 bucket name for internet measurements publishing.
         */
        bucketName?: pulumi.Input<string>;
        /**
         * An optional Amazon S3 bucket prefix for internet measurements publishing.
         */
        bucketPrefix?: pulumi.Input<string>;
        /**
         * The status of publishing Internet Monitor internet measurements to an Amazon S3 bucket. The delivery status is `ENABLED` if you choose to deliver internet measurements to an S3 bucket, and `DISABLED` otherwise.
         */
        logDeliveryStatus?: pulumi.Input<enums.internetmonitor.MonitorS3ConfigLogDeliveryStatus>;
    }
}
export declare namespace invoicing {
    interface InvoiceUnitRuleArgs {
        /**
         * The list of `LINKED_ACCOUNT` IDs where charges are included within the invoice unit.
         */
        linkedAccounts: pulumi.Input<pulumi.Input<string>[]>;
    }
}
export declare namespace iot {
    /**
     * The criteria that determine when and how a job abort takes place.
     */
    interface AbortConfigPropertiesArgs {
        /**
         * The list of criteria that determine when and how to abort the job.
         */
        criteriaList: pulumi.Input<pulumi.Input<inputs.iot.JobTemplateAbortCriteriaArgs>[]>;
    }
    /**
     * The configuration for a specific audit check.
     */
    interface AccountAuditConfigurationAuditCheckConfigurationArgs {
        /**
         * True if the check is enabled.
         */
        enabled?: pulumi.Input<boolean>;
    }
    /**
     * Specifies which audit checks are enabled and disabled for this account.
     */
    interface AccountAuditConfigurationAuditCheckConfigurationsArgs {
        /**
         * Checks the permissiveness of an authenticated Amazon Cognito identity pool role. For this check, AWS IoT Device Defender audits all Amazon Cognito identity pools that have been used to connect to the AWS IoT message broker during the 31 days before the audit is performed.
         */
        authenticatedCognitoRoleOverlyPermissiveCheck?: pulumi.Input<inputs.iot.AccountAuditConfigurationAuditCheckConfigurationArgs>;
        /**
         * Checks if a CA certificate is expiring. This check applies to CA certificates expiring within 30 days or that have expired.
         */
        caCertificateExpiringCheck?: pulumi.Input<inputs.iot.AccountAuditConfigurationAuditCheckConfigurationArgs>;
        /**
         * Checks the quality of the CA certificate key. The quality checks if the key is in a valid format, not expired, and if the key meets a minimum required size. This check applies to CA certificates that are `ACTIVE` or `PENDING_TRANSFER` .
         */
        caCertificateKeyQualityCheck?: pulumi.Input<inputs.iot.AccountAuditConfigurationAuditCheckConfigurationArgs>;
        /**
         * Checks if multiple devices connect using the same client ID.
         */
        conflictingClientIdsCheck?: pulumi.Input<inputs.iot.AccountAuditConfigurationAuditCheckConfigurationArgs>;
        /**
         * Checks when a device certificate has been active for a number of days greater than or equal to the number you specify.
         */
        deviceCertificateAgeCheck?: pulumi.Input<inputs.iot.AccountAuditConfigurationDeviceCertAgeAuditCheckConfigurationArgs>;
        /**
         * Checks if a device certificate is expiring. By default, this check applies to device certificates expiring within 30 days or that have expired. You can modify this threshold by configuring the DeviceCertExpirationAuditCheckConfiguration.
         */
        deviceCertificateExpiringCheck?: pulumi.Input<inputs.iot.AccountAuditConfigurationDeviceCertExpirationAuditCheckConfigurationArgs>;
        /**
         * Checks the quality of the device certificate key. The quality checks if the key is in a valid format, not expired, signed by a registered certificate authority, and if the key meets a minimum required size.
         */
        deviceCertificateKeyQualityCheck?: pulumi.Input<inputs.iot.AccountAuditConfigurationAuditCheckConfigurationArgs>;
        /**
         * Checks if multiple concurrent connections use the same X.509 certificate to authenticate with AWS IoT .
         */
        deviceCertificateSharedCheck?: pulumi.Input<inputs.iot.AccountAuditConfigurationAuditCheckConfigurationArgs>;
        /**
         * Checks if device certificates are still active despite being revoked by an intermediate CA.
         */
        intermediateCaRevokedForActiveDeviceCertificatesCheck?: pulumi.Input<inputs.iot.AccountAuditConfigurationAuditCheckConfigurationArgs>;
        /**
         * Checks if an AWS IoT policy is potentially misconfigured. Misconfigured policies, including overly permissive policies, can cause security incidents like allowing devices access to unintended resources. This check is a warning for you to make sure that only intended actions are allowed before updating the policy.
         */
        ioTPolicyPotentialMisConfigurationCheck?: pulumi.Input<inputs.iot.AccountAuditConfigurationAuditCheckConfigurationArgs>;
        /**
         * Checks the permissiveness of a policy attached to an authenticated Amazon Cognito identity pool role.
         */
        iotPolicyOverlyPermissiveCheck?: pulumi.Input<inputs.iot.AccountAuditConfigurationAuditCheckConfigurationArgs>;
        /**
         * Checks if a role alias has access to services that haven't been used for the AWS IoT device in the last year.
         */
        iotRoleAliasAllowsAccessToUnusedServicesCheck?: pulumi.Input<inputs.iot.AccountAuditConfigurationAuditCheckConfigurationArgs>;
        /**
         * Checks if the temporary credentials provided by AWS IoT role aliases are overly permissive.
         */
        iotRoleAliasOverlyPermissiveCheck?: pulumi.Input<inputs.iot.AccountAuditConfigurationAuditCheckConfigurationArgs>;
        /**
         * Checks if AWS IoT logs are disabled.
         */
        loggingDisabledCheck?: pulumi.Input<inputs.iot.AccountAuditConfigurationAuditCheckConfigurationArgs>;
        /**
         * Checks if a revoked CA certificate is still active.
         */
        revokedCaCertificateStillActiveCheck?: pulumi.Input<inputs.iot.AccountAuditConfigurationAuditCheckConfigurationArgs>;
        /**
         * Checks if a revoked device certificate is still active.
         */
        revokedDeviceCertificateStillActiveCheck?: pulumi.Input<inputs.iot.AccountAuditConfigurationAuditCheckConfigurationArgs>;
        /**
         * Checks if policy attached to an unauthenticated Amazon Cognito identity pool role is too permissive.
         */
        unauthenticatedCognitoRoleOverlyPermissiveCheck?: pulumi.Input<inputs.iot.AccountAuditConfigurationAuditCheckConfigurationArgs>;
    }
    interface AccountAuditConfigurationAuditNotificationTargetArgs {
        /**
         * True if notifications to the target are enabled.
         */
        enabled?: pulumi.Input<boolean>;
        /**
         * The ARN of the role that grants permission to send notifications to the target.
         */
        roleArn?: pulumi.Input<string>;
        /**
         * The ARN of the target (SNS topic) to which audit notifications are sent.
         */
        targetArn?: pulumi.Input<string>;
    }
    /**
     * Information about the targets to which audit notifications are sent.
     */
    interface AccountAuditConfigurationAuditNotificationTargetConfigurationsArgs {
        /**
         * The `Sns` notification target.
         */
        sns?: pulumi.Input<inputs.iot.AccountAuditConfigurationAuditNotificationTargetArgs>;
    }
    /**
     * A structure containing the configName and corresponding configValue for configuring audit checks.
     */
    interface AccountAuditConfigurationCertAgeCheckCustomConfigurationArgs {
        /**
         * The number of days that defines when a device certificate is considered to have aged. The check will report a finding if a certificate has been active for a number of days greater than or equal to this threshold value.
         */
        certAgeThresholdInDays?: pulumi.Input<string>;
    }
    /**
     * A structure containing the configName and corresponding configValue for configuring audit checks.
     */
    interface AccountAuditConfigurationCertExpirationCheckCustomConfigurationArgs {
        /**
         * The number of days before expiration that defines when a device certificate is considered to be approaching expiration. The check will report a finding if a certificate will expire within this number of days.
         */
        certExpirationThresholdInDays?: pulumi.Input<string>;
    }
    /**
     * A structure containing the configName and corresponding configValue for configuring DeviceCertAgeCheck.
     */
    interface AccountAuditConfigurationDeviceCertAgeAuditCheckConfigurationArgs {
        /**
         * Configuration settings for the device certificate age check, including the threshold in days for certificate age. This configuration is of type `CertAgeCheckCustomConfiguration` .
         */
        configuration?: pulumi.Input<inputs.iot.AccountAuditConfigurationCertAgeCheckCustomConfigurationArgs>;
        /**
         * True if the check is enabled.
         */
        enabled?: pulumi.Input<boolean>;
    }
    /**
     * A structure containing the configName and corresponding configValue for configuring DeviceCertExpirationCheck.
     */
    interface AccountAuditConfigurationDeviceCertExpirationAuditCheckConfigurationArgs {
        /**
         * Configuration settings for the device certificate expiration check, including the threshold in days before expiration. This configuration is of type `CertExpirationCheckCustomConfiguration`
         */
        configuration?: pulumi.Input<inputs.iot.AccountAuditConfigurationCertExpirationCheckCustomConfigurationArgs>;
        /**
         * True if the check is enabled.
         */
        enabled?: pulumi.Input<boolean>;
    }
    /**
     * The properties of the billing group.
     */
    interface BillingGroupPropertiesPropertiesArgs {
        /**
         * The description of the billing group.
         */
        billingGroupDescription?: pulumi.Input<string>;
    }
    interface CaCertificateRegistrationConfigArgs {
        /**
         * The ARN of the role.
         */
        roleArn?: pulumi.Input<string>;
        /**
         * The template body.
         */
        templateBody?: pulumi.Input<string>;
        /**
         * The name of the provisioning template.
         */
        templateName?: pulumi.Input<string>;
    }
    interface CommandParameterArgs {
        defaultValue?: pulumi.Input<inputs.iot.CommandParameterValueArgs>;
        description?: pulumi.Input<string>;
        name: pulumi.Input<string>;
        value?: pulumi.Input<inputs.iot.CommandParameterValueArgs>;
    }
    interface CommandParameterValueArgs {
        b?: pulumi.Input<boolean>;
        bin?: pulumi.Input<string>;
        d?: pulumi.Input<number>;
        i?: pulumi.Input<number>;
        l?: pulumi.Input<string>;
        s?: pulumi.Input<string>;
        ul?: pulumi.Input<string>;
    }
    interface CommandPayloadArgs {
        content?: pulumi.Input<string>;
        contentType?: pulumi.Input<string>;
    }
    interface DomainConfigurationAuthorizerConfigArgs {
        /**
         * A Boolean that specifies whether the domain configuration's authorization service can be overridden.
         */
        allowAuthorizerOverride?: pulumi.Input<boolean>;
        /**
         * The name of the authorization service for a domain configuration.
         */
        defaultAuthorizerName?: pulumi.Input<string>;
    }
    interface DomainConfigurationClientCertificateConfigArgs {
        /**
         * The ARN of the Lambda function that IoT invokes after mutual TLS authentication during the connection.
         */
        clientCertificateCallbackArn?: pulumi.Input<string>;
    }
    interface DomainConfigurationServerCertificateConfigArgs {
        /**
         * A Boolean value that indicates whether Online Certificate Status Protocol (OCSP) server certificate check is enabled or not. For more information, see [Configurable endpoints](https://docs.aws.amazon.com//iot/latest/developerguide/iot-custom-endpoints-configurable.html) from the AWS IoT Core Developer Guide.
         */
        enableOcspCheck?: pulumi.Input<boolean>;
        /**
         * The Amazon Resource Name (ARN) for an X.509 certificate stored in ACM. If provided, AWS IoT Core will use this certificate to validate the signature of the received OCSP response. The OCSP responder must sign responses using either this authorized responder certificate or the issuing certificate, depending on whether the ARN is provided or not. The certificate must be in the same account and region as the domain configuration.
         */
        ocspAuthorizedResponderArn?: pulumi.Input<string>;
        /**
         * The Amazon Resource Name (ARN) for a Lambda function that acts as a Request for Comments (RFC) 6960-compliant Online Certificate Status Protocol (OCSP) responder, supporting basic OCSP responses. The Lambda function accepts a base64-encoding of the OCSP request in the Distinguished Encoding Rules (DER) format. The Lambda function's response is also a base64-encoded OCSP response in the DER format. The response size must not exceed 4 kilobytes (KiB). The Lambda function must be in the same account and region as the domain configuration.
         */
        ocspLambdaArn?: pulumi.Input<string>;
    }
    interface DomainConfigurationTlsConfigArgs {
        /**
         * The security policy for a domain configuration. For more information, see [Security policies](https://docs.aws.amazon.com/iot/latest/developerguide/transport-security.html#tls-policy-table) in the *AWS IoT Core developer guide* .
         */
        securityPolicy?: pulumi.Input<string>;
    }
    /**
     * Aggregation types supported by Fleet Indexing
     */
    interface FleetMetricAggregationTypeArgs {
        /**
         * Fleet Indexing aggregation type names such as Statistics, Percentiles and Cardinality
         */
        name: pulumi.Input<string>;
        /**
         * Fleet Indexing aggregation type values
         */
        values: pulumi.Input<pulumi.Input<string>[]>;
    }
    /**
     * Allows you to create the criteria to retry a job.
     */
    interface JobExecutionsRetryConfigPropertiesArgs {
        /**
         * The list of criteria that determines how many retries are allowed for each failure type for a job.
         */
        retryCriteriaList?: pulumi.Input<pulumi.Input<inputs.iot.JobTemplateRetryCriteriaArgs>[]>;
    }
    /**
     * Allows you to create a staged rollout of a job.
     */
    interface JobExecutionsRolloutConfigPropertiesArgs {
        /**
         * The rate of increase for a job rollout. This parameter allows you to define an exponential rate for a job rollout.
         */
        exponentialRolloutRate?: pulumi.Input<inputs.iot.JobTemplateExponentialRolloutRateArgs>;
        /**
         * The maximum number of things that will be notified of a pending job, per minute. This parameter allows you to create a staged rollout.
         */
        maximumPerMinute?: pulumi.Input<number>;
    }
    /**
     * The criteria that determine when and how a job abort takes place.
     */
    interface JobTemplateAbortCriteriaArgs {
        /**
         * The type of job action to take to initiate the job abort.
         */
        action: pulumi.Input<enums.iot.JobTemplateAction>;
        /**
         * The type of job execution failures that can initiate a job abort.
         */
        failureType: pulumi.Input<enums.iot.JobTemplateFailureType>;
        /**
         * The minimum number of things which must receive job execution notifications before the job can be aborted.
         */
        minNumberOfExecutedThings: pulumi.Input<number>;
        /**
         * The minimum percentage of job execution failures that must occur to initiate the job abort.
         */
        thresholdPercentage: pulumi.Input<number>;
    }
    /**
     * Allows you to create an exponential rate of rollout for a job.
     */
    interface JobTemplateExponentialRolloutRateArgs {
        /**
         * The minimum number of things that will be notified of a pending job, per minute at the start of job rollout. This parameter allows you to define the initial rate of rollout.
         */
        baseRatePerMinute: pulumi.Input<number>;
        /**
         * The exponential factor to increase the rate of rollout for a job.
         */
        incrementFactor: pulumi.Input<number>;
        /**
         * The criteria to initiate the increase in rate of rollout for a job.
         */
        rateIncreaseCriteria: pulumi.Input<inputs.iot.JobTemplateRateIncreaseCriteriaArgs>;
    }
    /**
     * Specifies a start time and duration for a scheduled Job.
     */
    interface JobTemplateMaintenanceWindowArgs {
        /**
         * Displays the duration of the next maintenance window.
         */
        durationInMinutes?: pulumi.Input<number>;
        /**
         * Displays the start time of the next maintenance window.
         */
        startTime?: pulumi.Input<string>;
    }
    interface JobTemplateRateIncreaseCriteriaArgs {
        /**
         * The threshold for number of notified things that will initiate the increase in rate of rollout.
         */
        numberOfNotifiedThings?: pulumi.Input<number>;
        /**
         * The threshold for number of succeeded things that will initiate the increase in rate of rollout.
         */
        numberOfSucceededThings?: pulumi.Input<number>;
    }
    /**
     * Specifies how many times a failure type should be retried.
     */
    interface JobTemplateRetryCriteriaArgs {
        /**
         * The type of job execution failures that can initiate a job retry.
         */
        failureType?: pulumi.Input<enums.iot.JobTemplateJobRetryFailureType>;
        /**
         * The number of retries allowed for a failure type for the job.
         */
        numberOfRetries?: pulumi.Input<number>;
    }
    /**
     * A structure containing the mqtt topic for metrics export.
     */
    interface MetricsExportConfigPropertiesArgs {
        /**
         * The topic for metrics export.
         */
        mqttTopic: pulumi.Input<string>;
        /**
         * The ARN of the role that grants permission to publish to mqtt topic.
         */
        roleArn: pulumi.Input<string>;
    }
    /**
     * The set of parameters for this mitigation action. You can specify only one type of parameter (in other words, you can apply only one action for each defined mitigation action).
     */
    interface MitigationActionActionParamsArgs {
        /**
         * Specifies the group to which you want to add the devices.
         */
        addThingsToThingGroupParams?: pulumi.Input<inputs.iot.MitigationActionAddThingsToThingGroupParamsArgs>;
        /**
         * Specifies the logging level and the role with permissions for logging. You cannot specify a logging level of `DISABLED` .
         */
        enableIoTLoggingParams?: pulumi.Input<inputs.iot.MitigationActionEnableIoTLoggingParamsArgs>;
        /**
         * Specifies the topic to which the finding should be published.
         */
        publishFindingToSnsParams?: pulumi.Input<inputs.iot.MitigationActionPublishFindingToSnsParamsArgs>;
        /**
         * Replaces the policy version with a default or blank policy. You specify the template name. Only a value of `BLANK_POLICY` is currently supported.
         */
        replaceDefaultPolicyVersionParams?: pulumi.Input<inputs.iot.MitigationActionReplaceDefaultPolicyVersionParamsArgs>;
        /**
         * Specifies the new state for the CA certificate. Only a value of `DEACTIVATE` is currently supported.
         */
        updateCaCertificateParams?: pulumi.Input<inputs.iot.MitigationActionUpdateCaCertificateParamsArgs>;
        /**
         * Specifies the new state for a device certificate. Only a value of `DEACTIVATE` is currently supported.
         */
        updateDeviceCertificateParams?: pulumi.Input<inputs.iot.MitigationActionUpdateDeviceCertificateParamsArgs>;
    }
    /**
     * Parameters to define a mitigation action that moves devices associated with a certificate to one or more specified thing groups, typically for quarantine.
     */
    interface MitigationActionAddThingsToThingGroupParamsArgs {
        /**
         * Specifies if this mitigation action can move the things that triggered the mitigation action out of one or more dynamic thing groups.
         */
        overrideDynamicGroups?: pulumi.Input<boolean>;
        /**
         * The list of groups to which you want to add the things that triggered the mitigation action.
         */
        thingGroupNames: pulumi.Input<pulumi.Input<string>[]>;
    }
    /**
     * Parameters to define a mitigation action that enables AWS IoT logging at a specified level of detail.
     */
    interface MitigationActionEnableIoTLoggingParamsArgs {
        /**
         *  Specifies which types of information are logged.
         */
        logLevel: pulumi.Input<enums.iot.MitigationActionEnableIoTLoggingParamsLogLevel>;
        /**
         *  The ARN of the IAM role used for logging.
         */
        roleArnForLogging: pulumi.Input<string>;
    }
    /**
     * Parameters, to define a mitigation action that publishes findings to Amazon SNS. You can implement your own custom actions in response to the Amazon SNS messages.
     */
    interface MitigationActionPublishFindingToSnsParamsArgs {
        /**
         * The ARN of the topic to which you want to publish the findings.
         */
        topicArn: pulumi.Input<string>;
    }
    /**
     * Parameters to define a mitigation action that adds a blank policy to restrict permissions.
     */
    interface MitigationActionReplaceDefaultPolicyVersionParamsArgs {
        /**
         * The name of the template to be applied. The only supported value is `BLANK_POLICY` .
         */
        templateName: pulumi.Input<enums.iot.MitigationActionReplaceDefaultPolicyVersionParamsTemplateName>;
    }
    /**
     * Parameters to define a mitigation action that changes the state of the CA certificate to inactive.
     */
    interface MitigationActionUpdateCaCertificateParamsArgs {
        /**
         * The action that you want to apply to the CA certificate. The only supported value is `DEACTIVATE` .
         */
        action: pulumi.Input<enums.iot.MitigationActionUpdateCaCertificateParamsAction>;
    }
    /**
     * Parameters to define a mitigation action that changes the state of the device certificate to inactive.
     */
    interface MitigationActionUpdateDeviceCertificateParamsArgs {
        /**
         * The action that you want to apply to the device certificate. The only supported value is `DEACTIVATE` .
         */
        action: pulumi.Input<enums.iot.MitigationActionUpdateDeviceCertificateParamsAction>;
    }
    /**
     * Configuration for pre-signed S3 URLs.
     */
    interface PresignedUrlConfigPropertiesArgs {
        /**
         * How long (in seconds) pre-signed URLs are valid. Valid values are 60 - 3600, the default value is 3600 seconds. Pre-signed URLs are generated when Jobs receives an MQTT request for the job document.
         */
        expiresInSec?: pulumi.Input<number>;
        /**
         * The ARN of an IAM role that grants grants permission to download files from the S3 bucket where the job data/updates are stored. The role must also grant permission for IoT to download the files.
         *
         * > For information about addressing the confused deputy problem, see [cross-service confused deputy prevention](https://docs.aws.amazon.com/iot/latest/developerguide/cross-service-confused-deputy-prevention.html) in the *AWS IoT Core developer guide* .
         */
        roleArn: pulumi.Input<string>;
    }
    interface ProvisioningTemplateProvisioningHookArgs {
        /**
         * The payload that was sent to the target function. The valid payload is `"2020-04-01"` .
         */
        payloadVersion?: pulumi.Input<string>;
        /**
         * The ARN of the target function.
         */
        targetArn?: pulumi.Input<string>;
    }
    /**
     * A structure containing the alert target ARN and the role ARN.
     */
    interface SecurityProfileAlertTargetArgs {
        /**
         * The ARN of the notification target to which alerts are sent.
         */
        alertTargetArn: pulumi.Input<string>;
        /**
         * The ARN of the role that grants permission to send alerts to the notification target.
         */
        roleArn: pulumi.Input<string>;
    }
    /**
     * A security profile behavior.
     */
    interface SecurityProfileBehaviorArgs {
        /**
         * The criteria that determine if a device is behaving normally in regard to the `metric` .
         *
         * > In the AWS IoT console, you can choose to be sent an alert through Amazon SNS when AWS IoT Device Defender detects that a device is behaving anomalously.
         */
        criteria?: pulumi.Input<inputs.iot.SecurityProfileBehaviorCriteriaArgs>;
        /**
         * Value indicates exporting metrics related to the behavior when it is true.
         */
        exportMetric?: pulumi.Input<boolean>;
        /**
         * What is measured by the behavior.
         */
        metric?: pulumi.Input<string>;
        /**
         * The dimension of the metric.
         */
        metricDimension?: pulumi.Input<inputs.iot.SecurityProfileMetricDimensionArgs>;
        /**
         * The name for the behavior.
         */
        name: pulumi.Input<string>;
        /**
         * Manage Detect alarm SNS notifications by setting behavior notification to on or suppressed. Detect will continue to performing device behavior evaluations. However, suppressed alarms wouldn't be forwarded for SNS notification.
         */
        suppressAlerts?: pulumi.Input<boolean>;
    }
    /**
     * The criteria by which the behavior is determined to be normal.
     */
    interface SecurityProfileBehaviorCriteriaArgs {
        /**
         * The operator that relates the thing measured (metric) to the criteria (containing a value or statisticalThreshold).
         */
        comparisonOperator?: pulumi.Input<enums.iot.SecurityProfileBehaviorCriteriaComparisonOperator>;
        /**
         * If a device is in violation of the behavior for the specified number of consecutive datapoints, an alarm occurs. If not specified, the default is 1.
         */
        consecutiveDatapointsToAlarm?: pulumi.Input<number>;
        /**
         * If an alarm has occurred and the offending device is no longer in violation of the behavior for the specified number of consecutive datapoints, the alarm is cleared. If not specified, the default is 1.
         */
        consecutiveDatapointsToClear?: pulumi.Input<number>;
        /**
         * Use this to specify the time duration over which the behavior is evaluated.
         */
        durationSeconds?: pulumi.Input<number>;
        /**
         * The confidence level of the detection model.
         */
        mlDetectionConfig?: pulumi.Input<inputs.iot.SecurityProfileMachineLearningDetectionConfigArgs>;
        /**
         * A statistical ranking (percentile)that indicates a threshold value by which a behavior is determined to be in compliance or in violation of the behavior.
         */
        statisticalThreshold?: pulumi.Input<inputs.iot.SecurityProfileStatisticalThresholdArgs>;
        /**
         * The value to be compared with the `metric` .
         */
        value?: pulumi.Input<inputs.iot.SecurityProfileMetricValueArgs>;
    }
    /**
     * The configuration of an ML Detect Security Profile.
     */
    interface SecurityProfileMachineLearningDetectionConfigArgs {
        /**
         * The sensitivity of anomalous behavior evaluation. Can be Low, Medium, or High.
         */
        confidenceLevel?: pulumi.Input<enums.iot.SecurityProfileMachineLearningDetectionConfigConfidenceLevel>;
    }
    /**
     * The dimension of a metric.
     */
    interface SecurityProfileMetricDimensionArgs {
        /**
         * A unique identifier for the dimension.
         */
        dimensionName: pulumi.Input<string>;
        /**
         * Defines how the dimensionValues of a dimension are interpreted.
         */
        operator?: pulumi.Input<enums.iot.SecurityProfileMetricDimensionOperator>;
    }
    /**
     * The metric you want to retain. Dimensions are optional.
     */
    interface SecurityProfileMetricToRetainArgs {
        /**
         * The value indicates exporting metrics related to the `MetricToRetain` when it's true.
         */
        exportMetric?: pulumi.Input<boolean>;
        /**
         * What is measured by the behavior.
         */
        metric: pulumi.Input<string>;
        /**
         * The dimension of the metric.
         */
        metricDimension?: pulumi.Input<inputs.iot.SecurityProfileMetricDimensionArgs>;
    }
    /**
     * The value to be compared with the metric.
     */
    interface SecurityProfileMetricValueArgs {
        /**
         * If the ComparisonOperator calls for a set of CIDRs, use this to specify that set to be compared with the metric.
         */
        cidrs?: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * If the ComparisonOperator calls for a numeric value, use this to specify that (integer) numeric value to be compared with the metric.
         */
        count?: pulumi.Input<string>;
        /**
         * The numeral value of a metric.
         */
        number?: pulumi.Input<number>;
        /**
         * The numeral values of a metric.
         */
        numbers?: pulumi.Input<pulumi.Input<number>[]>;
        /**
         * If the ComparisonOperator calls for a set of ports, use this to specify that set to be compared with the metric.
         */
        ports?: pulumi.Input<pulumi.Input<number>[]>;
        /**
         * The string values of a metric.
         */
        strings?: pulumi.Input<pulumi.Input<string>[]>;
    }
    /**
     * A statistical ranking (percentile) which indicates a threshold value by which a behavior is determined to be in compliance or in violation of the behavior.
     */
    interface SecurityProfileStatisticalThresholdArgs {
        /**
         * The percentile which resolves to a threshold value by which compliance with a behavior is determined
         */
        statistic?: pulumi.Input<enums.iot.SecurityProfileStatisticalThresholdStatistic>;
    }
    /**
     * The artifact location of the package version
     */
    interface SoftwarePackageVersionPackageVersionArtifactArgs {
        s3Location: pulumi.Input<inputs.iot.SoftwarePackageVersionS3LocationArgs>;
    }
    /**
     * The Amazon S3 location
     */
    interface SoftwarePackageVersionS3LocationArgs {
        /**
         * The S3 bucket
         */
        bucket: pulumi.Input<string>;
        /**
         * The S3 key
         */
        key: pulumi.Input<string>;
        /**
         * The S3 version
         */
        version: pulumi.Input<string>;
    }
    /**
     * The sbom zip archive location of the package version
     */
    interface SoftwarePackageVersionSbomArgs {
        s3Location: pulumi.Input<inputs.iot.SoftwarePackageVersionS3LocationArgs>;
    }
    interface ThingAttributePayloadArgs {
        /**
         * A JSON string containing up to three key-value pair in JSON format. For example:
         *
         * `{\"attributes\":{\"string1\":\"string2\"}}`
         */
        attributes?: pulumi.Input<{
            [key: string]: pulumi.Input<string>;
        }>;
    }
    interface ThingGroupAttributePayloadArgs {
        /**
         * A JSON string containing up to three key-value pair in JSON format. For example:
         *
         * `{\"attributes\":{\"string1\":\"string2\"}}`
         */
        attributes?: pulumi.Input<{
            [key: string]: pulumi.Input<string>;
        }>;
    }
    /**
     * Thing group properties.
     */
    interface ThingGroupPropertiesPropertiesArgs {
        /**
         * The thing group attributes in JSON format.
         */
        attributePayload?: pulumi.Input<inputs.iot.ThingGroupAttributePayloadArgs>;
        /**
         * The thing group description.
         */
        thingGroupDescription?: pulumi.Input<string>;
    }
    interface ThingTypePropagatingAttributeArgs {
        /**
         * The attribute associated with the connection details.
         */
        connectionAttribute?: pulumi.Input<enums.iot.ThingTypePropagatingAttributeConnectionAttribute>;
        /**
         * The thing attribute that is propagating for MQTT 5 message enrichment.
         */
        thingAttribute?: pulumi.Input<string>;
        /**
         * The key of the MQTT 5 user property, which is a key-value pair.
         */
        userPropertyKey: pulumi.Input<string>;
    }
    /**
     * The thing type properties for the thing type to create. It contains information about the new thing type including a description, a list of searchable thing attribute names, and a list of propagating attributes. After a thing type is created, you can only update `Mqtt5Configuration` .
     */
    interface ThingTypePropertiesPropertiesArgs {
        /**
         * The configuration to add user-defined properties to enrich MQTT 5 messages.
         */
        mqtt5Configuration?: pulumi.Input<inputs.iot.ThingTypePropertiesPropertiesMqtt5ConfigurationPropertiesArgs>;
        /**
         * A list of searchable thing attribute names.
         */
        searchableAttributes?: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * The description of the thing type.
         */
        thingTypeDescription?: pulumi.Input<string>;
    }
    /**
     * The configuration to add user-defined properties to enrich MQTT 5 messages.
     */
    interface ThingTypePropertiesPropertiesMqtt5ConfigurationPropertiesArgs {
        propagatingAttributes?: pulumi.Input<pulumi.Input<inputs.iot.ThingTypePropagatingAttributeArgs>[]>;
    }
    /**
     * Specifies the amount of time each device has to finish its execution of the job.
     */
    interface TimeoutConfigPropertiesArgs {
        /**
         * Specifies the amount of time, in minutes, this device has to finish execution of this job. The timeout interval can be anywhere between 1 minute and 7 days (1 to 10080 minutes). The in progress timer can't be updated and will apply to all job executions for the job. Whenever a job execution remains in the IN_PROGRESS status for longer than this interval, the job execution will fail and switch to the terminal `TIMED_OUT` status.
         */
        inProgressTimeoutInMinutes: pulumi.Input<number>;
    }
    interface TopicRuleActionArgs {
        /**
         * Change the state of a CloudWatch alarm.
         */
        cloudwatchAlarm?: pulumi.Input<inputs.iot.TopicRuleCloudwatchAlarmActionArgs>;
        /**
         * Sends data to CloudWatch.
         */
        cloudwatchLogs?: pulumi.Input<inputs.iot.TopicRuleCloudwatchLogsActionArgs>;
        /**
         * Capture a CloudWatch metric.
         */
        cloudwatchMetric?: pulumi.Input<inputs.iot.TopicRuleCloudwatchMetricActionArgs>;
        /**
         * Write to a DynamoDB table. This is a new version of the DynamoDB action. It allows you to write each attribute in an MQTT message payload into a separate DynamoDB column.
         */
        dynamoDBv2?: pulumi.Input<inputs.iot.TopicRuleDynamoDBv2ActionArgs>;
        /**
         * Write to a DynamoDB table.
         */
        dynamoDb?: pulumi.Input<inputs.iot.TopicRuleDynamoDbActionArgs>;
        /**
         * Write data to an Amazon OpenSearch Service domain.
         *
         * > The `Elasticsearch` action can only be used by existing rule actions. To create a new rule action or to update an existing rule action, use the `OpenSearch` rule action instead. For more information, see [OpenSearchAction](https://docs.aws.amazon.com//iot/latest/apireference/API_OpenSearchAction.html) .
         */
        elasticsearch?: pulumi.Input<inputs.iot.TopicRuleElasticsearchActionArgs>;
        /**
         * Write to an Amazon Kinesis Firehose stream.
         */
        firehose?: pulumi.Input<inputs.iot.TopicRuleFirehoseActionArgs>;
        /**
         * Send data to an HTTPS endpoint.
         */
        http?: pulumi.Input<inputs.iot.TopicRuleHttpActionArgs>;
        /**
         * Sends message data to an AWS IoT Analytics channel.
         */
        iotAnalytics?: pulumi.Input<inputs.iot.TopicRuleIotAnalyticsActionArgs>;
        /**
         * Sends an input to an AWS IoT Events detector.
         */
        iotEvents?: pulumi.Input<inputs.iot.TopicRuleIotEventsActionArgs>;
        /**
         * Sends data from the MQTT message that triggered the rule to AWS IoT SiteWise asset properties.
         */
        iotSiteWise?: pulumi.Input<inputs.iot.TopicRuleIotSiteWiseActionArgs>;
        /**
         * Send messages to an Amazon Managed Streaming for Apache Kafka (Amazon MSK) or self-managed Apache Kafka cluster.
         */
        kafka?: pulumi.Input<inputs.iot.TopicRuleKafkaActionArgs>;
        /**
         * Write data to an Amazon Kinesis stream.
         */
        kinesis?: pulumi.Input<inputs.iot.TopicRuleKinesisActionArgs>;
        /**
         * Invoke a Lambda function.
         */
        lambda?: pulumi.Input<inputs.iot.TopicRuleLambdaActionArgs>;
        /**
         * Sends device location data to [Amazon Location Service](https://docs.aws.amazon.com//location/latest/developerguide/welcome.html) .
         */
        location?: pulumi.Input<inputs.iot.TopicRuleLocationActionArgs>;
        /**
         * Write data to an Amazon OpenSearch Service domain.
         */
        openSearch?: pulumi.Input<inputs.iot.TopicRuleOpenSearchActionArgs>;
        /**
         * Publish to another MQTT topic.
         */
        republish?: pulumi.Input<inputs.iot.TopicRuleRepublishActionArgs>;
        /**
         * Write to an Amazon S3 bucket.
         */
        s3?: pulumi.Input<inputs.iot.TopicRuleS3ActionArgs>;
        /**
         * Publish to an Amazon SNS topic.
         */
        sns?: pulumi.Input<inputs.iot.TopicRuleSnsActionArgs>;
        /**
         * Publish to an Amazon SQS queue.
         */
        sqs?: pulumi.Input<inputs.iot.TopicRuleSqsActionArgs>;
        /**
         * Starts execution of a Step Functions state machine.
         */
        stepFunctions?: pulumi.Input<inputs.iot.TopicRuleStepFunctionsActionArgs>;
        /**
         * Writes attributes from an MQTT message.
         */
        timestream?: pulumi.Input<inputs.iot.TopicRuleTimestreamActionArgs>;
    }
    interface TopicRuleAssetPropertyTimestampArgs {
        /**
         * Optional. A string that contains the nanosecond time offset. Accepts substitution templates.
         */
        offsetInNanos?: pulumi.Input<string>;
        /**
         * A string that contains the time in seconds since epoch. Accepts substitution templates.
         */
        timeInSeconds: pulumi.Input<string>;
    }
    interface TopicRuleAssetPropertyValueArgs {
        /**
         * Optional. A string that describes the quality of the value. Accepts substitution templates. Must be `GOOD` , `BAD` , or `UNCERTAIN` .
         */
        quality?: pulumi.Input<string>;
        /**
         * The asset property value timestamp.
         */
        timestamp: pulumi.Input<inputs.iot.TopicRuleAssetPropertyTimestampArgs>;
        /**
         * The value of the asset property.
         */
        value: pulumi.Input<inputs.iot.TopicRuleAssetPropertyVariantArgs>;
    }
    interface TopicRuleAssetPropertyVariantArgs {
        /**
         * Optional. A string that contains the boolean value ( `true` or `false` ) of the value entry. Accepts substitution templates.
         */
        booleanValue?: pulumi.Input<string>;
        /**
         * Optional. A string that contains the double value of the value entry. Accepts substitution templates.
         */
        doubleValue?: pulumi.Input<string>;
        /**
         * Optional. A string that contains the integer value of the value entry. Accepts substitution templates.
         */
        integerValue?: pulumi.Input<string>;
        /**
         * Optional. The string value of the value entry. Accepts substitution templates.
         */
        stringValue?: pulumi.Input<string>;
    }
    interface TopicRuleCloudwatchAlarmActionArgs {
        /**
         * The CloudWatch alarm name.
         */
        alarmName: pulumi.Input<string>;
        /**
         * The IAM role that allows access to the CloudWatch alarm.
         */
        roleArn: pulumi.Input<string>;
        /**
         * The reason for the alarm change.
         */
        stateReason: pulumi.Input<string>;
        /**
         * The value of the alarm state. Acceptable values are: OK, ALARM, INSUFFICIENT_DATA.
         */
        stateValue: pulumi.Input<string>;
    }
    interface TopicRuleCloudwatchLogsActionArgs {
        /**
         * Indicates whether batches of log records will be extracted and uploaded into CloudWatch.
         */
        batchMode?: pulumi.Input<boolean>;
        /**
         * The CloudWatch log name.
         */
        logGroupName: pulumi.Input<string>;
        /**
         * The IAM role that allows access to the CloudWatch log.
         */
        roleArn: pulumi.Input<string>;
    }
    interface TopicRuleCloudwatchMetricActionArgs {
        /**
         * The CloudWatch metric name.
         */
        metricName: pulumi.Input<string>;
        /**
         * The CloudWatch metric namespace name.
         */
        metricNamespace: pulumi.Input<string>;
        /**
         * An optional [Unix timestamp](https://docs.aws.amazon.com/AmazonCloudWatch/latest/DeveloperGuide/cloudwatch_concepts.html#about_timestamp) .
         */
        metricTimestamp?: pulumi.Input<string>;
        /**
         * The [metric unit](https://docs.aws.amazon.com/AmazonCloudWatch/latest/DeveloperGuide/cloudwatch_concepts.html#Unit) supported by CloudWatch.
         */
        metricUnit: pulumi.Input<string>;
        /**
         * The CloudWatch metric value.
         */
        metricValue: pulumi.Input<string>;
        /**
         * The IAM role that allows access to the CloudWatch metric.
         */
        roleArn: pulumi.Input<string>;
    }
    interface TopicRuleDestinationHttpUrlDestinationSummaryArgs {
        /**
         * The URL used to confirm the HTTP topic rule destination URL.
         */
        confirmationUrl?: pulumi.Input<string>;
    }
    interface TopicRuleDestinationVpcDestinationPropertiesArgs {
        /**
         * The ARN of a role that has permission to create and attach to elastic network interfaces (ENIs).
         */
        roleArn?: pulumi.Input<string>;
        /**
         * The security groups of the VPC destination.
         */
        securityGroups?: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * The subnet IDs of the VPC destination.
         */
        subnetIds?: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * The ID of the VPC.
         */
        vpcId?: pulumi.Input<string>;
    }
    interface TopicRuleDynamoDBv2ActionArgs {
        /**
         * Specifies the DynamoDB table to which the message data will be written. For example:
         *
         * `{ "dynamoDBv2": { "roleArn": "aws:iam:12341251:my-role" "putItem": { "tableName": "my-table" } } }`
         *
         * Each attribute in the message payload will be written to a separate column in the DynamoDB database.
         */
        putItem?: pulumi.Input<inputs.iot.TopicRulePutItemInputArgs>;
        /**
         * The ARN of the IAM role that grants access to the DynamoDB table.
         */
        roleArn?: pulumi.Input<string>;
    }
    interface TopicRuleDynamoDbActionArgs {
        /**
         * The hash key name.
         */
        hashKeyField: pulumi.Input<string>;
        /**
         * The hash key type. Valid values are "STRING" or "NUMBER"
         */
        hashKeyType?: pulumi.Input<string>;
        /**
         * The hash key value.
         */
        hashKeyValue: pulumi.Input<string>;
        /**
         * The action payload. This name can be customized.
         */
        payloadField?: pulumi.Input<string>;
        /**
         * The range key name.
         */
        rangeKeyField?: pulumi.Input<string>;
        /**
         * The range key type. Valid values are "STRING" or "NUMBER"
         */
        rangeKeyType?: pulumi.Input<string>;
        /**
         * The range key value.
         */
        rangeKeyValue?: pulumi.Input<string>;
        /**
         * The ARN of the IAM role that grants access to the DynamoDB table.
         */
        roleArn: pulumi.Input<string>;
        /**
         * The name of the DynamoDB table.
         */
        tableName: pulumi.Input<string>;
    }
    interface TopicRuleElasticsearchActionArgs {
        /**
         * The endpoint of your OpenSearch domain.
         */
        endpoint: pulumi.Input<string>;
        /**
         * The unique identifier for the document you are storing.
         */
        id: pulumi.Input<string>;
        /**
         * The index where you want to store your data.
         */
        index: pulumi.Input<string>;
        /**
         * The IAM role ARN that has access to OpenSearch.
         */
        roleArn: pulumi.Input<string>;
        /**
         * The type of document you are storing.
         */
        type: pulumi.Input<string>;
    }
    interface TopicRuleFirehoseActionArgs {
        /**
         * Whether to deliver the Kinesis Data Firehose stream as a batch by using [`PutRecordBatch`](https://docs.aws.amazon.com/firehose/latest/APIReference/API_PutRecordBatch.html) . The default value is `false` .
         *
         * When `batchMode` is `true` and the rule's SQL statement evaluates to an Array, each Array element forms one record in the [`PutRecordBatch`](https://docs.aws.amazon.com/firehose/latest/APIReference/API_PutRecordBatch.html) request. The resulting array can't have more than 500 records.
         */
        batchMode?: pulumi.Input<boolean>;
        /**
         * The delivery stream name.
         */
        deliveryStreamName: pulumi.Input<string>;
        /**
         * The IAM role that grants access to the Amazon Kinesis Firehose stream.
         */
        roleArn: pulumi.Input<string>;
        /**
         * A character separator that will be used to separate records written to the Firehose stream. Valid values are: '\n' (newline), '\t' (tab), '\r\n' (Windows newline), ',' (comma).
         */
        separator?: pulumi.Input<string>;
    }
    interface TopicRuleHttpActionArgs {
        /**
         * The authentication method to use when sending data to an HTTPS endpoint.
         */
        auth?: pulumi.Input<inputs.iot.TopicRuleHttpAuthorizationArgs>;
        /**
         * The URL to which AWS IoT sends a confirmation message. The value of the confirmation URL must be a prefix of the endpoint URL. If you do not specify a confirmation URL AWS IoT uses the endpoint URL as the confirmation URL. If you use substitution templates in the confirmationUrl, you must create and enable topic rule destinations that match each possible value of the substitution template before traffic is allowed to your endpoint URL.
         */
        confirmationUrl?: pulumi.Input<string>;
        /**
         * The HTTP headers to send with the message data.
         */
        headers?: pulumi.Input<pulumi.Input<inputs.iot.TopicRuleHttpActionHeaderArgs>[]>;
        /**
         * The endpoint URL. If substitution templates are used in the URL, you must also specify a `confirmationUrl` . If this is a new destination, a new `TopicRuleDestination` is created if possible.
         */
        url: pulumi.Input<string>;
    }
    interface TopicRuleHttpActionHeaderArgs {
        /**
         * The HTTP header key.
         */
        key: pulumi.Input<string>;
        /**
         * The HTTP header value. Substitution templates are supported.
         */
        value: pulumi.Input<string>;
    }
    interface TopicRuleHttpAuthorizationArgs {
        /**
         * Use Sig V4 authorization. For more information, see [Signature Version 4 Signing Process](https://docs.aws.amazon.com/general/latest/gr/signature-version-4.html) .
         */
        sigv4?: pulumi.Input<inputs.iot.TopicRuleSigV4AuthorizationArgs>;
    }
    interface TopicRuleIotAnalyticsActionArgs {
        /**
         * Whether to process the action as a batch. The default value is `false` .
         *
         * When `batchMode` is `true` and the rule SQL statement evaluates to an Array, each Array element is delivered as a separate message when passed by [`BatchPutMessage`](https://docs.aws.amazon.com/iotanalytics/latest/APIReference/API_BatchPutMessage.html) The resulting array can't have more than 100 messages.
         */
        batchMode?: pulumi.Input<boolean>;
        /**
         * The name of the IoT Analytics channel to which message data will be sent.
         */
        channelName: pulumi.Input<string>;
        /**
         * The ARN of the role which has a policy that grants IoT Analytics permission to send message data via IoT Analytics (iotanalytics:BatchPutMessage).
         */
        roleArn: pulumi.Input<string>;
    }
    interface TopicRuleIotEventsActionArgs {
        /**
         * Whether to process the event actions as a batch. The default value is `false` .
         *
         * When `batchMode` is `true` , you can't specify a `messageId` .
         *
         * When `batchMode` is `true` and the rule SQL statement evaluates to an Array, each Array element is treated as a separate message when Events by calling [`BatchPutMessage`](https://docs.aws.amazon.com/iotevents/latest/apireference/API_iotevents-data_BatchPutMessage.html) . The resulting array can't have more than 10 messages.
         */
        batchMode?: pulumi.Input<boolean>;
        /**
         * The name of the AWS IoT Events input.
         */
        inputName: pulumi.Input<string>;
        /**
         * The ID of the message. The default `messageId` is a new UUID value.
         *
         * When `batchMode` is `true` , you can't specify a `messageId` --a new UUID value will be assigned.
         *
         * Assign a value to this property to ensure that only one input (message) with a given `messageId` will be processed by an AWS IoT Events detector.
         */
        messageId?: pulumi.Input<string>;
        /**
         * The ARN of the role that grants AWS IoT permission to send an input to an AWS IoT Events detector. ("Action":"iotevents:BatchPutMessage").
         */
        roleArn: pulumi.Input<string>;
    }
    interface TopicRuleIotSiteWiseActionArgs {
        /**
         * A list of asset property value entries.
         */
        putAssetPropertyValueEntries: pulumi.Input<pulumi.Input<inputs.iot.TopicRulePutAssetPropertyValueEntryArgs>[]>;
        /**
         * The ARN of the role that grants AWS IoT permission to send an asset property value to AWS IoT SiteWise. ( `"Action": "iotsitewise:BatchPutAssetPropertyValue"` ). The trust policy can restrict access to specific asset hierarchy paths.
         */
        roleArn: pulumi.Input<string>;
    }
    interface TopicRuleKafkaActionArgs {
        /**
         * Properties of the Apache Kafka producer client.
         */
        clientProperties: pulumi.Input<{
            [key: string]: pulumi.Input<string>;
        }>;
        /**
         * The ARN of Kafka action's VPC `TopicRuleDestination` .
         */
        destinationArn: pulumi.Input<string>;
        /**
         * The list of Kafka headers that you specify.
         */
        headers?: pulumi.Input<pulumi.Input<inputs.iot.TopicRuleKafkaActionHeaderArgs>[]>;
        /**
         * The Kafka message key.
         */
        key?: pulumi.Input<string>;
        /**
         * The Kafka message partition.
         */
        partition?: pulumi.Input<string>;
        /**
         * The Kafka topic for messages to be sent to the Kafka broker.
         */
        topic: pulumi.Input<string>;
    }
    interface TopicRuleKafkaActionHeaderArgs {
        /**
         * The key of the Kafka header.
         */
        key: pulumi.Input<string>;
        /**
         * The value of the Kafka header.
         */
        value: pulumi.Input<string>;
    }
    interface TopicRuleKinesisActionArgs {
        /**
         * The partition key.
         */
        partitionKey?: pulumi.Input<string>;
        /**
         * The ARN of the IAM role that grants access to the Amazon Kinesis stream.
         */
        roleArn: pulumi.Input<string>;
        /**
         * The name of the Amazon Kinesis stream.
         */
        streamName: pulumi.Input<string>;
    }
    interface TopicRuleLambdaActionArgs {
        /**
         * The ARN of the Lambda function.
         */
        functionArn?: pulumi.Input<string>;
    }
    interface TopicRuleLocationActionArgs {
        /**
         * The unique ID of the device providing the location data.
         */
        deviceId: pulumi.Input<string>;
        /**
         * A string that evaluates to a double value that represents the latitude of the device's location.
         */
        latitude: pulumi.Input<string>;
        /**
         * A string that evaluates to a double value that represents the longitude of the device's location.
         */
        longitude: pulumi.Input<string>;
        /**
         * The IAM role that grants permission to write to the Amazon Location resource.
         */
        roleArn: pulumi.Input<string>;
        /**
         * The time that the location data was sampled. The default value is the time the MQTT message was processed.
         */
        timestamp?: pulumi.Input<inputs.iot.TopicRuleTimestampArgs>;
        /**
         * The name of the tracker resource in Amazon Location in which the location is updated.
         */
        trackerName: pulumi.Input<string>;
    }
    interface TopicRuleOpenSearchActionArgs {
        /**
         * The endpoint of your OpenSearch domain.
         */
        endpoint: pulumi.Input<string>;
        /**
         * The unique identifier for the document you are storing.
         */
        id: pulumi.Input<string>;
        /**
         * The OpenSearch index where you want to store your data.
         */
        index: pulumi.Input<string>;
        /**
         * The IAM role ARN that has access to OpenSearch.
         */
        roleArn: pulumi.Input<string>;
        /**
         * The type of document you are storing.
         */
        type: pulumi.Input<string>;
    }
    interface TopicRulePayloadArgs {
        /**
         * The actions associated with the rule.
         */
        actions: pulumi.Input<pulumi.Input<inputs.iot.TopicRuleActionArgs>[]>;
        /**
         * The version of the SQL rules engine to use when evaluating the rule.
         *
         * The default value is 2015-10-08.
         */
        awsIotSqlVersion?: pulumi.Input<string>;
        /**
         * The description of the rule.
         */
        description?: pulumi.Input<string>;
        /**
         * The action to take when an error occurs.
         */
        errorAction?: pulumi.Input<inputs.iot.TopicRuleActionArgs>;
        /**
         * Specifies whether the rule is disabled.
         */
        ruleDisabled?: pulumi.Input<boolean>;
        /**
         * The SQL statement used to query the topic. For more information, see [AWS IoT SQL Reference](https://docs.aws.amazon.com/iot/latest/developerguide/iot-sql-reference.html) in the *AWS IoT Developer Guide* .
         */
        sql: pulumi.Input<string>;
    }
    interface TopicRulePutAssetPropertyValueEntryArgs {
        /**
         * The ID of the AWS IoT SiteWise asset. You must specify either a `propertyAlias` or both an `aliasId` and a `propertyId` . Accepts substitution templates.
         */
        assetId?: pulumi.Input<string>;
        /**
         * Optional. A unique identifier for this entry that you can define to better track which message caused an error in case of failure. Accepts substitution templates. Defaults to a new UUID.
         */
        entryId?: pulumi.Input<string>;
        /**
         * The name of the property alias associated with your asset property. You must specify either a `propertyAlias` or both an `aliasId` and a `propertyId` . Accepts substitution templates.
         */
        propertyAlias?: pulumi.Input<string>;
        /**
         * The ID of the asset's property. You must specify either a `propertyAlias` or both an `aliasId` and a `propertyId` . Accepts substitution templates.
         */
        propertyId?: pulumi.Input<string>;
        /**
         * A list of property values to insert that each contain timestamp, quality, and value (TQV) information.
         */
        propertyValues: pulumi.Input<pulumi.Input<inputs.iot.TopicRuleAssetPropertyValueArgs>[]>;
    }
    interface TopicRulePutItemInputArgs {
        /**
         * The table where the message data will be written.
         */
        tableName: pulumi.Input<string>;
    }
    interface TopicRuleRepublishActionArgs {
        /**
         * MQTT Version 5.0 headers information. For more information, see [MQTT](https://docs.aws.amazon.com//iot/latest/developerguide/mqtt.html) in the IoT Core Developer Guide.
         */
        headers?: pulumi.Input<inputs.iot.TopicRuleRepublishActionHeadersArgs>;
        /**
         * The Quality of Service (QoS) level to use when republishing messages. The default value is 0.
         */
        qos?: pulumi.Input<number>;
        /**
         * The ARN of the IAM role that grants access.
         */
        roleArn: pulumi.Input<string>;
        /**
         * The name of the MQTT topic.
         */
        topic: pulumi.Input<string>;
    }
    interface TopicRuleRepublishActionHeadersArgs {
        /**
         * A UTF-8 encoded string that describes the content of the publishing message.
         *
         * For more information, see [Content Type](https://docs.aws.amazon.com/https://docs.oasis-open.org/mqtt/mqtt/v5.0/os/mqtt-v5.0-os.html#_Toc3901118) in the MQTT Version 5.0 specification.
         *
         * Supports [substitution templates](https://docs.aws.amazon.com//iot/latest/developerguide/iot-substitution-templates.html) .
         */
        contentType?: pulumi.Input<string>;
        /**
         * The base64-encoded binary data used by the sender of the request message to identify which request the response message is for.
         *
         * For more information, see [Correlation Data](https://docs.aws.amazon.com/https://docs.oasis-open.org/mqtt/mqtt/v5.0/os/mqtt-v5.0-os.html#_Toc3901115) in the MQTT Version 5.0 specification.
         *
         * Supports [substitution templates](https://docs.aws.amazon.com//iot/latest/developerguide/iot-substitution-templates.html) .
         *
         * > This binary data must be base64-encoded.
         */
        correlationData?: pulumi.Input<string>;
        /**
         * A user-defined integer value that represents the message expiry interval at the broker. If the messages haven't been sent to the subscribers within that interval, the message expires and is removed. The value of `messageExpiry` represents the number of seconds before it expires. For more information about the limits of `messageExpiry` , see [Message broker and protocol limits and quotas](https://docs.aws.amazon.com//general/latest/gr/iot-core.html#limits_iot) in the IoT Core Reference Guide.
         *
         * Supports [substitution templates](https://docs.aws.amazon.com//iot/latest/developerguide/iot-substitution-templates.html) .
         */
        messageExpiry?: pulumi.Input<string>;
        /**
         * An `Enum` string value that indicates whether the payload is formatted as UTF-8.
         *
         * Valid values are `UNSPECIFIED_BYTES` and `UTF8_DATA` .
         *
         * For more information, see [Payload Format Indicator](https://docs.aws.amazon.com/https://docs.oasis-open.org/mqtt/mqtt/v5.0/os/mqtt-v5.0-os.html#_Toc3901111) from the MQTT Version 5.0 specification.
         *
         * Supports [substitution templates](https://docs.aws.amazon.com//iot/latest/developerguide/iot-substitution-templates.html) .
         */
        payloadFormatIndicator?: pulumi.Input<string>;
        /**
         * A UTF-8 encoded string that's used as the topic name for a response message. The response topic is used to describe the topic to which the receiver should publish as part of the request-response flow. The topic must not contain wildcard characters.
         *
         * For more information, see [Response Topic](https://docs.aws.amazon.com/https://docs.oasis-open.org/mqtt/mqtt/v5.0/os/mqtt-v5.0-os.html#_Toc3901114) in the MQTT Version 5.0 specification.
         *
         * Supports [substitution templates](https://docs.aws.amazon.com//iot/latest/developerguide/iot-substitution-templates.html) .
         */
        responseTopic?: pulumi.Input<string>;
        /**
         * An array of key-value pairs that you define in the MQTT5 header.
         */
        userProperties?: pulumi.Input<pulumi.Input<inputs.iot.TopicRuleUserPropertyArgs>[]>;
    }
    interface TopicRuleS3ActionArgs {
        /**
         * The Amazon S3 bucket.
         */
        bucketName: pulumi.Input<string>;
        /**
         * The Amazon S3 canned ACL that controls access to the object identified by the object key. For more information, see [S3 canned ACLs](https://docs.aws.amazon.com/AmazonS3/latest/dev/acl-overview.html#canned-acl) .
         */
        cannedAcl?: pulumi.Input<enums.iot.TopicRuleCannedAccessControlList>;
        /**
         * The object key. For more information, see [Actions, resources, and condition keys for Amazon S3](https://docs.aws.amazon.com/AmazonS3/latest/dev/list_amazons3.html) .
         */
        key: pulumi.Input<string>;
        /**
         * The ARN of the IAM role that grants access.
         */
        roleArn: pulumi.Input<string>;
    }
    interface TopicRuleSigV4AuthorizationArgs {
        /**
         * The ARN of the signing role.
         */
        roleArn: pulumi.Input<string>;
        /**
         * The service name to use while signing with Sig V4.
         */
        serviceName: pulumi.Input<string>;
        /**
         * The signing region.
         */
        signingRegion: pulumi.Input<string>;
    }
    interface TopicRuleSnsActionArgs {
        /**
         * (Optional) The message format of the message to publish. Accepted values are "JSON" and "RAW". The default value of the attribute is "RAW". SNS uses this setting to determine if the payload should be parsed and relevant platform-specific bits of the payload should be extracted. For more information, see [Amazon SNS Message and JSON Formats](https://docs.aws.amazon.com/sns/latest/dg/json-formats.html) in the *Amazon Simple Notification Service Developer Guide* .
         */
        messageFormat?: pulumi.Input<string>;
        /**
         * The ARN of the IAM role that grants access.
         */
        roleArn: pulumi.Input<string>;
        /**
         * The ARN of the SNS topic.
         */
        targetArn: pulumi.Input<string>;
    }
    interface TopicRuleSqsActionArgs {
        /**
         * The URL of the Amazon SQS queue.
         */
        queueUrl: pulumi.Input<string>;
        /**
         * The ARN of the IAM role that grants access.
         */
        roleArn: pulumi.Input<string>;
        /**
         * Specifies whether to use Base64 encoding.
         */
        useBase64?: pulumi.Input<boolean>;
    }
    interface TopicRuleStepFunctionsActionArgs {
        /**
         * (Optional) A name will be given to the state machine execution consisting of this prefix followed by a UUID. Step Functions automatically creates a unique name for each state machine execution if one is not provided.
         */
        executionNamePrefix?: pulumi.Input<string>;
        /**
         * The ARN of the role that grants IoT permission to start execution of a state machine ("Action":"states:StartExecution").
         */
        roleArn: pulumi.Input<string>;
        /**
         * The name of the Step Functions state machine whose execution will be started.
         */
        stateMachineName: pulumi.Input<string>;
    }
    interface TopicRuleTimestampArgs {
        /**
         * The precision of the timestamp value that results from the expression described in `value` .
         */
        unit?: pulumi.Input<string>;
        /**
         * An expression that returns a long epoch time value.
         */
        value: pulumi.Input<string>;
    }
    interface TopicRuleTimestreamActionArgs {
        /**
         * The name of an Amazon Timestream database that has the table to write records into.
         */
        databaseName: pulumi.Input<string>;
        /**
         * Metadata attributes of the time series that are written in each measure record.
         */
        dimensions: pulumi.Input<pulumi.Input<inputs.iot.TopicRuleTimestreamDimensionArgs>[]>;
        /**
         * The Amazon Resource Name (ARN) of the role that grants AWS IoT permission to write to the Timestream database table.
         */
        roleArn: pulumi.Input<string>;
        /**
         * The table where the message data will be written.
         */
        tableName: pulumi.Input<string>;
        /**
         * The value to use for the entry's timestamp. If blank, the time that the entry was processed is used.
         */
        timestamp?: pulumi.Input<inputs.iot.TopicRuleTimestreamTimestampArgs>;
    }
    interface TopicRuleTimestreamDimensionArgs {
        name: pulumi.Input<string>;
        value: pulumi.Input<string>;
    }
    interface TopicRuleTimestreamTimestampArgs {
        /**
         * The precision of the timestamp value that results from the expression described in `value` .
         */
        unit: pulumi.Input<string>;
        /**
         * An expression that returns a long epoch time value.
         */
        value: pulumi.Input<string>;
    }
    interface TopicRuleUserPropertyArgs {
        key: pulumi.Input<string>;
        value: pulumi.Input<string>;
    }
}
export declare namespace iotanalytics {
    interface ChannelCustomerManagedS3Args {
        /**
         * The name of the S3 bucket in which channel data is stored.
         */
        bucket: pulumi.Input<string>;
        /**
         * (Optional) The prefix used to create the keys of the channel data objects. Each object in an S3 bucket has a key that is its unique identifier within the bucket (each object in a bucket has exactly one key). The prefix must end with a forward slash (/).
         */
        keyPrefix?: pulumi.Input<string>;
        /**
         * The ARN of the role that grants AWS IoT Analytics permission to interact with your Amazon S3 resources.
         */
        roleArn: pulumi.Input<string>;
    }
    interface ChannelRetentionPeriodArgs {
        /**
         * The number of days that message data is kept. The `unlimited` parameter must be false.
         */
        numberOfDays?: pulumi.Input<number>;
        /**
         * If true, message data is kept indefinitely.
         */
        unlimited?: pulumi.Input<boolean>;
    }
    interface ChannelServiceManagedS3Args {
    }
    interface ChannelStorageArgs {
        /**
         * Used to store channel data in an S3 bucket that you manage. If customer managed storage is selected, the `retentionPeriod` parameter is ignored. You can't change the choice of S3 storage after the data store is created.
         */
        customerManagedS3?: pulumi.Input<inputs.iotanalytics.ChannelCustomerManagedS3Args>;
        /**
         * Used to store channel data in an S3 bucket managed by AWS IoT Analytics . You can't change the choice of S3 storage after the data store is created.
         */
        serviceManagedS3?: pulumi.Input<inputs.iotanalytics.ChannelServiceManagedS3Args>;
    }
    interface DatasetActionArgs {
        /**
         * The name of the data set action by which data set contents are automatically created.
         */
        actionName: pulumi.Input<string>;
        /**
         * Information which allows the system to run a containerized application in order to create the data set contents. The application must be in a Docker container along with any needed support libraries.
         */
        containerAction?: pulumi.Input<inputs.iotanalytics.DatasetContainerActionArgs>;
        /**
         * An "SqlQueryDatasetAction" object that uses an SQL query to automatically create data set contents.
         */
        queryAction?: pulumi.Input<inputs.iotanalytics.DatasetQueryActionArgs>;
    }
    interface DatasetContainerActionArgs {
        /**
         * The ARN of the role which gives permission to the system to access needed resources in order to run the "containerAction". This includes, at minimum, permission to retrieve the data set contents which are the input to the containerized application.
         */
        executionRoleArn: pulumi.Input<string>;
        /**
         * The ARN of the Docker container stored in your account. The Docker container contains an application and needed support libraries and is used to generate data set contents.
         */
        image: pulumi.Input<string>;
        /**
         * Configuration of the resource which executes the "containerAction".
         */
        resourceConfiguration: pulumi.Input<inputs.iotanalytics.DatasetResourceConfigurationArgs>;
        /**
         * The values of variables used within the context of the execution of the containerized application (basically, parameters passed to the application). Each variable must have a name and a value given by one of "stringValue", "datasetContentVersionValue", or "outputFileUriValue".
         */
        variables?: pulumi.Input<pulumi.Input<inputs.iotanalytics.DatasetVariableArgs>[]>;
    }
    interface DatasetContentDeliveryRuleArgs {
        /**
         * The destination to which dataset contents are delivered.
         */
        destination: pulumi.Input<inputs.iotanalytics.DatasetContentDeliveryRuleDestinationArgs>;
        /**
         * The name of the dataset content delivery rules entry.
         */
        entryName?: pulumi.Input<string>;
    }
    interface DatasetContentDeliveryRuleDestinationArgs {
        /**
         * Configuration information for delivery of dataset contents to AWS IoT Events .
         */
        iotEventsDestinationConfiguration?: pulumi.Input<inputs.iotanalytics.DatasetIotEventsDestinationConfigurationArgs>;
        /**
         * Configuration information for delivery of dataset contents to Amazon S3.
         */
        s3DestinationConfiguration?: pulumi.Input<inputs.iotanalytics.DatasetS3DestinationConfigurationArgs>;
    }
    interface DatasetContentVersionValueArgs {
        /**
         * The name of the dataset whose latest contents are used as input to the notebook or application.
         */
        datasetName: pulumi.Input<string>;
    }
    interface DatasetDeltaTimeArgs {
        /**
         * The number of seconds of estimated in-flight lag time of message data. When you create dataset contents using message data from a specified timeframe, some message data might still be in flight when processing begins, and so do not arrive in time to be processed. Use this field to make allowances for the in flight time of your message data, so that data not processed from a previous timeframe is included with the next timeframe. Otherwise, missed message data would be excluded from processing during the next timeframe too, because its timestamp places it within the previous timeframe.
         */
        offsetSeconds: pulumi.Input<number>;
        /**
         * An expression by which the time of the message data might be determined. This can be the name of a timestamp field or a SQL expression that is used to derive the time the message data was generated.
         */
        timeExpression: pulumi.Input<string>;
    }
    interface DatasetDeltaTimeSessionWindowConfigurationArgs {
        /**
         * A time interval. You can use `timeoutInMinutes` so that AWS IoT Analytics can batch up late data notifications that have been generated since the last execution. AWS IoT Analytics sends one batch of notifications to Amazon CloudWatch Events at one time.
         *
         * For more information about how to write a timestamp expression, see [Date and Time Functions and Operators](https://docs.aws.amazon.com/https://prestodb.io/docs/current/functions/datetime.html) , in the *Presto 0.172 Documentation* .
         */
        timeoutInMinutes: pulumi.Input<number>;
    }
    interface DatasetFilterArgs {
        /**
         * Used to limit data to that which has arrived since the last execution of the action.
         */
        deltaTime?: pulumi.Input<inputs.iotanalytics.DatasetDeltaTimeArgs>;
    }
    interface DatasetGlueConfigurationArgs {
        /**
         * The name of the database in your AWS Glue Data Catalog in which the table is located. An AWS Glue Data Catalog database contains metadata tables.
         */
        databaseName: pulumi.Input<string>;
        /**
         * The name of the table in your AWS Glue Data Catalog that is used to perform the ETL operations. An AWS Glue Data Catalog table contains partitioned data and descriptions of data sources and targets.
         */
        tableName: pulumi.Input<string>;
    }
    interface DatasetIotEventsDestinationConfigurationArgs {
        /**
         * The name of the AWS IoT Events input to which dataset contents are delivered.
         */
        inputName: pulumi.Input<string>;
        /**
         * The ARN of the role that grants AWS IoT Analytics permission to deliver dataset contents to an AWS IoT Events input.
         */
        roleArn: pulumi.Input<string>;
    }
    interface DatasetLateDataRuleArgs {
        /**
         * The information needed to configure the late data rule.
         */
        ruleConfiguration: pulumi.Input<inputs.iotanalytics.DatasetLateDataRuleConfigurationArgs>;
        /**
         * The name of the late data rule.
         */
        ruleName?: pulumi.Input<string>;
    }
    interface DatasetLateDataRuleConfigurationArgs {
        /**
         * The information needed to configure a delta time session window.
         */
        deltaTimeSessionWindowConfiguration?: pulumi.Input<inputs.iotanalytics.DatasetDeltaTimeSessionWindowConfigurationArgs>;
    }
    interface DatasetOutputFileUriValueArgs {
        /**
         * The URI of the location where dataset contents are stored, usually the URI of a file in an S3 bucket.
         */
        fileName: pulumi.Input<string>;
    }
    interface DatasetQueryActionArgs {
        /**
         * Pre-filters applied to message data.
         */
        filters?: pulumi.Input<pulumi.Input<inputs.iotanalytics.DatasetFilterArgs>[]>;
        /**
         * An "SqlQueryDatasetAction" object that uses an SQL query to automatically create data set contents.
         */
        sqlQuery: pulumi.Input<string>;
    }
    interface DatasetResourceConfigurationArgs {
        /**
         * The type of the compute resource used to execute the `containerAction` . Possible values are: `ACU_1` (vCPU=4, memory=16 GiB) or `ACU_2` (vCPU=8, memory=32 GiB).
         */
        computeType: pulumi.Input<enums.iotanalytics.DatasetResourceConfigurationComputeType>;
        /**
         * The size, in GB, of the persistent storage available to the resource instance used to execute the `containerAction` (min: 1, max: 50).
         */
        volumeSizeInGb: pulumi.Input<number>;
    }
    interface DatasetRetentionPeriodArgs {
        /**
         * The number of days that message data is kept. The `unlimited` parameter must be false.
         */
        numberOfDays?: pulumi.Input<number>;
        /**
         * If true, message data is kept indefinitely.
         */
        unlimited?: pulumi.Input<boolean>;
    }
    interface DatasetS3DestinationConfigurationArgs {
        /**
         * The name of the S3 bucket to which dataset contents are delivered.
         */
        bucket: pulumi.Input<string>;
        /**
         * Configuration information for coordination with AWS Glue , a fully managed extract, transform and load (ETL) service.
         */
        glueConfiguration?: pulumi.Input<inputs.iotanalytics.DatasetGlueConfigurationArgs>;
        /**
         * The key of the dataset contents object in an S3 bucket. Each object has a key that is a unique identifier. Each object has exactly one key.
         *
         * You can create a unique key with the following options:
         *
         * - Use `!{iotanalytics:scheduleTime}` to insert the time of a scheduled SQL query run.
         * - Use `!{iotanalytics:versionId}` to insert a unique hash that identifies a dataset content.
         * - Use `!{iotanalytics:creationTime}` to insert the creation time of a dataset content.
         *
         * The following example creates a unique key for a CSV file: `dataset/mydataset/!{iotanalytics:scheduleTime}/!{iotanalytics:versionId}.csv`
         *
         * > If you don't use `!{iotanalytics:versionId}` to specify the key, you might get duplicate keys. For example, you might have two dataset contents with the same `scheduleTime` but different `versionId` s. This means that one dataset content overwrites the other.
         */
        key: pulumi.Input<string>;
        /**
         * The ARN of the role that grants AWS IoT Analytics permission to interact with your Amazon S3 and AWS Glue resources.
         */
        roleArn: pulumi.Input<string>;
    }
    interface DatasetScheduleArgs {
        /**
         * The expression that defines when to trigger an update. For more information, see [Schedule Expressions for Rules](https://docs.aws.amazon.com/AmazonCloudWatch/latest/events/ScheduledEvents.html) in the Amazon CloudWatch documentation.
         */
        scheduleExpression: pulumi.Input<string>;
    }
    interface DatasetTriggerArgs {
        /**
         * The "Schedule" when the trigger is initiated.
         */
        schedule?: pulumi.Input<inputs.iotanalytics.DatasetScheduleArgs>;
        /**
         * Information about the data set whose content generation triggers the new data set content generation.
         */
        triggeringDataset?: pulumi.Input<inputs.iotanalytics.DatasetTriggeringDatasetArgs>;
    }
    interface DatasetTriggeringDatasetArgs {
        /**
         * The name of the data set whose content generation triggers the new data set content generation.
         */
        datasetName: pulumi.Input<string>;
    }
    interface DatasetVariableArgs {
        /**
         * The value of the variable as a structure that specifies a dataset content version.
         */
        datasetContentVersionValue?: pulumi.Input<inputs.iotanalytics.DatasetContentVersionValueArgs>;
        /**
         * The value of the variable as a double (numeric).
         */
        doubleValue?: pulumi.Input<number>;
        /**
         * The value of the variable as a structure that specifies an output file URI.
         */
        outputFileUriValue?: pulumi.Input<inputs.iotanalytics.DatasetOutputFileUriValueArgs>;
        /**
         * The value of the variable as a string.
         */
        stringValue?: pulumi.Input<string>;
        /**
         * The name of the variable.
         */
        variableName: pulumi.Input<string>;
    }
    interface DatasetVersioningConfigurationArgs {
        /**
         * How many versions of dataset contents are kept. The `unlimited` parameter must be `false` .
         */
        maxVersions?: pulumi.Input<number>;
        /**
         * If true, unlimited versions of dataset contents are kept.
         */
        unlimited?: pulumi.Input<boolean>;
    }
    interface DatastoreColumnArgs {
        /**
         * The name of the column.
         */
        name: pulumi.Input<string>;
        /**
         * The type of data. For more information about the supported data types, see [Common data types](https://docs.aws.amazon.com/glue/latest/dg/aws-glue-api-common.html) in the *AWS Glue Developer Guide* .
         */
        type: pulumi.Input<string>;
    }
    interface DatastoreCustomerManagedS3Args {
        /**
         * The name of the Amazon S3 bucket where your data is stored.
         */
        bucket: pulumi.Input<string>;
        /**
         * (Optional) The prefix used to create the keys of the data store data objects. Each object in an Amazon S3 bucket has a key that is its unique identifier in the bucket. Each object in a bucket has exactly one key. The prefix must end with a forward slash (/).
         */
        keyPrefix?: pulumi.Input<string>;
        /**
         * The ARN of the role that grants AWS IoT Analytics permission to interact with your Amazon S3 resources.
         */
        roleArn: pulumi.Input<string>;
    }
    interface DatastoreCustomerManagedS3StorageArgs {
        /**
         * The name of the Amazon S3 bucket where your data is stored.
         */
        bucket: pulumi.Input<string>;
        /**
         * (Optional) The prefix used to create the keys of the data store data objects. Each object in an Amazon S3 bucket has a key that is its unique identifier in the bucket. Each object in a bucket has exactly one key. The prefix must end with a forward slash (/).
         */
        keyPrefix?: pulumi.Input<string>;
    }
    interface DatastoreFileFormatConfigurationArgs {
        /**
         * Contains the configuration information of the JSON format.
         */
        jsonConfiguration?: pulumi.Input<inputs.iotanalytics.DatastoreJsonConfigurationArgs>;
        /**
         * Contains the configuration information of the Parquet format.
         */
        parquetConfiguration?: pulumi.Input<inputs.iotanalytics.DatastoreParquetConfigurationArgs>;
    }
    interface DatastoreIotSiteWiseMultiLayerStorageArgs {
        /**
         * Stores data used by AWS IoT SiteWise in an Amazon S3 bucket that you manage.
         */
        customerManagedS3Storage?: pulumi.Input<inputs.iotanalytics.DatastoreCustomerManagedS3StorageArgs>;
    }
    interface DatastoreJsonConfigurationArgs {
    }
    interface DatastoreParquetConfigurationArgs {
        /**
         * Information needed to define a schema.
         */
        schemaDefinition?: pulumi.Input<inputs.iotanalytics.DatastoreSchemaDefinitionArgs>;
    }
    interface DatastorePartitionArgs {
        /**
         * A partition dimension defined by an attribute.
         */
        partition?: pulumi.Input<inputs.iotanalytics.PartitionArgs>;
        /**
         * A partition dimension defined by a timestamp attribute.
         */
        timestampPartition?: pulumi.Input<inputs.iotanalytics.DatastoreTimestampPartitionArgs>;
    }
    interface DatastorePartitionsArgs {
        /**
         * A list of partition dimensions in a data store.
         */
        partitions?: pulumi.Input<pulumi.Input<inputs.iotanalytics.DatastorePartitionArgs>[]>;
    }
    interface DatastoreRetentionPeriodArgs {
        /**
         * The number of days that message data is kept. The `unlimited` parameter must be false.
         */
        numberOfDays?: pulumi.Input<number>;
        /**
         * If true, message data is kept indefinitely.
         */
        unlimited?: pulumi.Input<boolean>;
    }
    interface DatastoreSchemaDefinitionArgs {
        /**
         * Specifies one or more columns that store your data.
         *
         * Each schema can have up to 100 columns. Each column can have up to 100 nested types.
         */
        columns?: pulumi.Input<pulumi.Input<inputs.iotanalytics.DatastoreColumnArgs>[]>;
    }
    interface DatastoreServiceManagedS3Args {
    }
    interface DatastoreStorageArgs {
        /**
         * Use this to store data store data in an S3 bucket that you manage. The choice of service-managed or customer-managed S3 storage cannot be changed after creation of the data store.
         */
        customerManagedS3?: pulumi.Input<inputs.iotanalytics.DatastoreCustomerManagedS3Args>;
        /**
         * Use this to store data used by AWS IoT SiteWise in an Amazon S3 bucket that you manage. You can't change the choice of Amazon S3 storage after your data store is created.
         */
        iotSiteWiseMultiLayerStorage?: pulumi.Input<inputs.iotanalytics.DatastoreIotSiteWiseMultiLayerStorageArgs>;
        /**
         * Use this to store data store data in an S3 bucket managed by the AWS IoT Analytics service. The choice of service-managed or customer-managed S3 storage cannot be changed after creation of the data store.
         */
        serviceManagedS3?: pulumi.Input<inputs.iotanalytics.DatastoreServiceManagedS3Args>;
    }
    interface DatastoreTimestampPartitionArgs {
        /**
         * The attribute name of the partition defined by a timestamp.
         */
        attributeName: pulumi.Input<string>;
        /**
         * The timestamp format of a partition defined by a timestamp. The default format is seconds since epoch (January 1, 1970 at midnight UTC time).
         */
        timestampFormat?: pulumi.Input<string>;
    }
    interface PartitionArgs {
        /**
         * The name of the attribute that defines a partition dimension.
         */
        attributeName: pulumi.Input<string>;
    }
    interface PipelineActivityArgs {
        /**
         * Adds other attributes based on existing attributes in the message.
         */
        addAttributes?: pulumi.Input<inputs.iotanalytics.PipelineAddAttributesArgs>;
        /**
         * Determines the source of the messages to be processed.
         */
        channel?: pulumi.Input<inputs.iotanalytics.PipelineChannelArgs>;
        /**
         * Specifies where to store the processed message data.
         */
        datastore?: pulumi.Input<inputs.iotanalytics.PipelineDatastoreArgs>;
        /**
         * Adds data from the AWS IoT device registry to your message.
         */
        deviceRegistryEnrich?: pulumi.Input<inputs.iotanalytics.PipelineDeviceRegistryEnrichArgs>;
        /**
         * Adds information from the AWS IoT Device Shadows service to a message.
         */
        deviceShadowEnrich?: pulumi.Input<inputs.iotanalytics.PipelineDeviceShadowEnrichArgs>;
        /**
         * Filters a message based on its attributes.
         */
        filter?: pulumi.Input<inputs.iotanalytics.PipelineFilterArgs>;
        /**
         * Runs a Lambda function to modify the message.
         */
        lambda?: pulumi.Input<inputs.iotanalytics.PipelineLambdaArgs>;
        /**
         * Computes an arithmetic expression using the message's attributes and adds it to the message.
         */
        math?: pulumi.Input<inputs.iotanalytics.PipelineMathArgs>;
        /**
         * Removes attributes from a message.
         */
        removeAttributes?: pulumi.Input<inputs.iotanalytics.PipelineRemoveAttributesArgs>;
        /**
         * Creates a new message using only the specified attributes from the original message.
         */
        selectAttributes?: pulumi.Input<inputs.iotanalytics.PipelineSelectAttributesArgs>;
    }
    interface PipelineAddAttributesArgs {
        /**
         * A list of 1-50 "AttributeNameMapping" objects that map an existing attribute to a new attribute.
         *
         * > The existing attributes remain in the message, so if you want to remove the originals, use "RemoveAttributeActivity".
         */
        attributes: pulumi.Input<{
            [key: string]: pulumi.Input<string>;
        }>;
        /**
         * The name of the 'addAttributes' activity.
         */
        name: pulumi.Input<string>;
        /**
         * The next activity in the pipeline.
         */
        next?: pulumi.Input<string>;
    }
    interface PipelineChannelArgs {
        /**
         * The name of the channel from which the messages are processed.
         */
        channelName: pulumi.Input<string>;
        /**
         * The name of the 'channel' activity.
         */
        name: pulumi.Input<string>;
        /**
         * The next activity in the pipeline.
         */
        next?: pulumi.Input<string>;
    }
    interface PipelineDatastoreArgs {
        /**
         * The name of the data store where processed messages are stored.
         */
        datastoreName: pulumi.Input<string>;
        /**
         * The name of the datastore activity.
         */
        name: pulumi.Input<string>;
    }
    interface PipelineDeviceRegistryEnrichArgs {
        /**
         * The name of the attribute that is added to the message.
         */
        attribute: pulumi.Input<string>;
        /**
         * The name of the 'deviceRegistryEnrich' activity.
         */
        name: pulumi.Input<string>;
        /**
         * The next activity in the pipeline.
         */
        next?: pulumi.Input<string>;
        /**
         * The ARN of the role that allows access to the device's registry information.
         */
        roleArn: pulumi.Input<string>;
        /**
         * The name of the IoT device whose registry information is added to the message.
         */
        thingName: pulumi.Input<string>;
    }
    interface PipelineDeviceShadowEnrichArgs {
        /**
         * The name of the attribute that is added to the message.
         */
        attribute: pulumi.Input<string>;
        /**
         * The name of the 'deviceShadowEnrich' activity.
         */
        name: pulumi.Input<string>;
        /**
         * The next activity in the pipeline.
         */
        next?: pulumi.Input<string>;
        /**
         * The ARN of the role that allows access to the device's shadow.
         */
        roleArn: pulumi.Input<string>;
        /**
         * The name of the IoT device whose shadow information is added to the message.
         */
        thingName: pulumi.Input<string>;
    }
    interface PipelineFilterArgs {
        /**
         * An expression that looks like an SQL WHERE clause that must return a Boolean value.
         */
        filter: pulumi.Input<string>;
        /**
         * The name of the 'filter' activity.
         */
        name: pulumi.Input<string>;
        /**
         * The next activity in the pipeline.
         */
        next?: pulumi.Input<string>;
    }
    interface PipelineLambdaArgs {
        /**
         * The number of messages passed to the Lambda function for processing.
         *
         * The AWS Lambda function must be able to process all of these messages within five minutes, which is the maximum timeout duration for Lambda functions.
         */
        batchSize: pulumi.Input<number>;
        /**
         * The name of the Lambda function that is run on the message.
         */
        lambdaName: pulumi.Input<string>;
        /**
         * The name of the 'lambda' activity.
         */
        name: pulumi.Input<string>;
        /**
         * The next activity in the pipeline.
         */
        next?: pulumi.Input<string>;
    }
    interface PipelineMathArgs {
        /**
         * The name of the attribute that contains the result of the math operation.
         */
        attribute: pulumi.Input<string>;
        /**
         * An expression that uses one or more existing attributes and must return an integer value.
         */
        math: pulumi.Input<string>;
        /**
         * The name of the 'math' activity.
         */
        name: pulumi.Input<string>;
        /**
         * The next activity in the pipeline.
         */
        next?: pulumi.Input<string>;
    }
    interface PipelineRemoveAttributesArgs {
        /**
         * A list of 1-50 attributes to remove from the message.
         */
        attributes: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * The name of the 'removeAttributes' activity.
         */
        name: pulumi.Input<string>;
        /**
         * The next activity in the pipeline.
         */
        next?: pulumi.Input<string>;
    }
    interface PipelineSelectAttributesArgs {
        /**
         * A list of the attributes to select from the message.
         */
        attributes: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * The name of the 'selectAttributes' activity.
         */
        name: pulumi.Input<string>;
        /**
         * The next activity in the pipeline.
         */
        next?: pulumi.Input<string>;
    }
}
export declare namespace iotcoredeviceadvisor {
    /**
     * The configuration of the Suite Definition. Listed below are the required elements of the `SuiteDefinitionConfiguration` .
     *
     * - ***devicePermissionRoleArn*** - The device permission arn.
     *
     * This is a required element.
     *
     * *Type:* String
     * - ***devices*** - The list of configured devices under test. For more information on devices under test, see [DeviceUnderTest](https://docs.aws.amazon.com/iot/latest/apireference/API_iotdeviceadvisor_DeviceUnderTest.html)
     *
     * Not a required element.
     *
     * *Type:* List of devices under test
     * - ***intendedForQualification*** - The tests intended for qualification in a suite.
     *
     * Not a required element.
     *
     * *Type:* Boolean
     * - ***rootGroup*** - The test suite root group. For more information on creating and using root groups see the [Device Advisor workflow](https://docs.aws.amazon.com/iot/latest/developerguide/device-advisor-workflow.html) .
     *
     * This is a required element.
     *
     * *Type:* String
     * - ***suiteDefinitionName*** - The Suite Definition Configuration name.
     *
     * This is a required element.
     *
     * *Type:* String
     */
    interface SuiteDefinitionConfigurationPropertiesArgs {
        /**
         * Gets the device permission ARN. This is a required parameter.
         */
        devicePermissionRoleArn: pulumi.Input<string>;
        /**
         * Gets the devices configured.
         */
        devices?: pulumi.Input<pulumi.Input<inputs.iotcoredeviceadvisor.SuiteDefinitionDeviceUnderTestArgs>[]>;
        /**
         * Gets the tests intended for qualification in a suite.
         */
        intendedForQualification?: pulumi.Input<boolean>;
        /**
         * Gets the test suite root group. This is a required parameter. For updating or creating the latest qualification suite, if `intendedForQualification` is set to true, `rootGroup` can be an empty string. If `intendedForQualification` is false, `rootGroup` cannot be an empty string. If `rootGroup` is empty, and `intendedForQualification` is set to true, all the qualification tests are included, and the configuration is default.
         *
         * For a qualification suite, the minimum length is 0, and the maximum is 2048. For a non-qualification suite, the minimum length is 1, and the maximum is 2048.
         */
        rootGroup: pulumi.Input<string>;
        /**
         * Gets the suite definition name. This is a required parameter.
         */
        suiteDefinitionName?: pulumi.Input<string>;
    }
    interface SuiteDefinitionDeviceUnderTestArgs {
        certificateArn?: pulumi.Input<string>;
        thingArn?: pulumi.Input<string>;
    }
}
export declare namespace iotevents {
    /**
     * Specifies whether to get notified for alarm state changes.
     */
    interface AlarmModelAcknowledgeFlowArgs {
        /**
         * The value must be ``TRUE`` or ``FALSE``. If ``TRUE``, you receive a notification when the alarm state changes. You must choose to acknowledge the notification before the alarm state can return to ``NORMAL``. If ``FALSE``, you won't receive notifications. The alarm automatically changes to the ``NORMAL`` state when the input property value returns to the specified range.
         */
        enabled?: pulumi.Input<boolean>;
    }
    /**
     * Specifies one of the following actions to receive notifications when the alarm state changes.
     */
    interface AlarmModelAlarmActionArgs {
        /**
         * Defines an action to write to the Amazon DynamoDB table that you created. The default action payload contains all the information about the detector model instance and the event that triggered the action. You can customize the [payload](https://docs.aws.amazon.com/iotevents/latest/apireference/API_Payload.html). A separate column of the DynamoDB table receives one attribute-value pair in the payload that you specify.
         *  You must use expressions for all parameters in ``DynamoDBv2Action``. The expressions accept literals, operators, functions, references, and substitution templates.
         *   **Examples**
         *  +  For literal values, the expressions must contain single quotes. For example, the value for the ``tableName`` parameter can be ``'GreenhouseTemperatureTable'``.
         *   +  For references, you must specify either variables or input values. For example, the value for the ``tableName`` parameter can be ``$variable.ddbtableName``.
         *   +  For a substitution template, you must use ``${}``, and the template must be in single quotes. A substitution template can also contain a combination of literals, operators, functions, references, and substitution templates.
         *  In the following example, the value for the ``contentExpression`` parameter in ``Payload`` uses a substitution template.
         *   ``'{\"sensorID\": \"${$input.GreenhouseInput.sensor_id}\", \"temperature\": \"${$input.GreenhouseInput.temperature * 9 / 5 + 32}\"}'``
         *   +  For a string concatenation, you must use ``+``. A string concatenation can also contain a combination of literals, operators, functions, references, and substitution templates.
         *  In the following example, the value for the ``tableName`` parameter uses a string concatenation.
         *   ``'GreenhouseTemperatureTable ' + $input.GreenhouseInput.date``
         *
         *  For more information, see [Expressions](https://docs.aws.amazon.com/iotevents/latest/developerguide/iotevents-expressions.html) in the *Developer Guide*.
         *  The value for the ``type`` parameter in ``Payload`` must be ``JSON``.
         */
        dynamoDBv2?: pulumi.Input<inputs.iotevents.AlarmModelDynamoDBv2Args>;
        /**
         * Defines an action to write to the Amazon DynamoDB table that you created. The standard action payload contains all the information about the detector model instance and the event that triggered the action. You can customize the [payload](https://docs.aws.amazon.com/iotevents/latest/apireference/API_Payload.html). One column of the DynamoDB table receives all attribute-value pairs in the payload that you specify.
         *  You must use expressions for all parameters in ``DynamoDBAction``. The expressions accept literals, operators, functions, references, and substitution templates.
         *   **Examples**
         *  +  For literal values, the expressions must contain single quotes. For example, the value for the ``hashKeyType`` parameter can be ``'STRING'``.
         *   +  For references, you must specify either variables or input values. For example, the value for the ``hashKeyField`` parameter can be ``$input.GreenhouseInput.name``.
         *   +  For a substitution template, you must use ``${}``, and the template must be in single quotes. A substitution template can also contain a combination of literals, operators, functions, references, and substitution templates.
         *  In the following example, the value for the ``hashKeyValue`` parameter uses a substitution template.
         *   ``'${$input.GreenhouseInput.temperature * 6 / 5 + 32} in Fahrenheit'``
         *   +  For a string concatenation, you must use ``+``. A string concatenation can also contain a combination of literals, operators, functions, references, and substitution templates.
         *  In the following example, the value for the ``tableName`` parameter uses a string concatenation.
         *   ``'GreenhouseTemperatureTable ' + $input.GreenhouseInput.date``
         *
         *  For more information, see [Expressions](https://docs.aws.amazon.com/iotevents/latest/developerguide/iotevents-expressions.html) in the *Developer Guide*.
         *  If the defined payload type is a string, ``DynamoDBAction`` writes non-JSON data to the DynamoDB table as binary data. The DynamoDB console displays the data as Base64-encoded text. The value for the ``payloadField`` parameter is ``<payload-field>_raw``.
         */
        dynamoDb?: pulumi.Input<inputs.iotevents.AlarmModelDynamoDbArgs>;
        /**
         * Sends information about the detector model instance and the event that triggered the action to an Amazon Kinesis Data Firehose delivery stream.
         */
        firehose?: pulumi.Input<inputs.iotevents.AlarmModelFirehoseArgs>;
        /**
         * Sends an ITE input, passing in information about the detector model instance and the event that triggered the action.
         */
        iotEvents?: pulumi.Input<inputs.iotevents.AlarmModelIotEventsArgs>;
        /**
         * Sends information about the detector model instance and the event that triggered the action to a specified asset property in ITSW.
         *  You must use expressions for all parameters in ``IotSiteWiseAction``. The expressions accept literals, operators, functions, references, and substitutions templates.
         *   **Examples**
         *  +  For literal values, the expressions must contain single quotes. For example, the value for the ``propertyAlias`` parameter can be ``'/company/windfarm/3/turbine/7/temperature'``.
         *   +  For references, you must specify either variables or input values. For example, the value for the ``assetId`` parameter can be ``$input.TurbineInput.assetId1``.
         *   +  For a substitution template, you must use ``${}``, and the template must be in single quotes. A substitution template can also contain a combination of literals, operators, functions, references, and substitution templates.
         *  In the following example, the value for the ``propertyAlias`` parameter uses a substitution template.
         *   ``'company/windfarm/${$input.TemperatureInput.sensorData.windfarmID}/turbine/ ${$input.TemperatureInput.sensorData.turbineID}/temperature'``
         *
         *  You must specify either ``propertyAlias`` or both ``assetId`` and ``propertyId`` to identify the target asset property in ITSW.
         *  For more information, see [Expressions](https://docs.aws.amazon.com/iotevents/latest/developerguide/iotevents-expressions.html) in the *Developer Guide*.
         */
        iotSiteWise?: pulumi.Input<inputs.iotevents.AlarmModelIotSiteWiseArgs>;
        /**
         * Information required to publish the MQTT message through the IoT message broker.
         */
        iotTopicPublish?: pulumi.Input<inputs.iotevents.AlarmModelIotTopicPublishArgs>;
        /**
         * Calls a Lambda function, passing in information about the detector model instance and the event that triggered the action.
         */
        lambda?: pulumi.Input<inputs.iotevents.AlarmModelLambdaArgs>;
        /**
         * Information required to publish the Amazon SNS message.
         */
        sns?: pulumi.Input<inputs.iotevents.AlarmModelSnsArgs>;
        /**
         * Sends information about the detector model instance and the event that triggered the action to an Amazon SQS queue.
         */
        sqs?: pulumi.Input<inputs.iotevents.AlarmModelSqsArgs>;
    }
    /**
     * Contains the configuration information of alarm state changes.
     */
    interface AlarmModelAlarmCapabilitiesArgs {
        /**
         * Specifies whether to get notified for alarm state changes.
         */
        acknowledgeFlow?: pulumi.Input<inputs.iotevents.AlarmModelAcknowledgeFlowArgs>;
        /**
         * Specifies the default alarm state. The configuration applies to all alarms that were created based on this alarm model.
         */
        initializationConfiguration?: pulumi.Input<inputs.iotevents.AlarmModelInitializationConfigurationArgs>;
    }
    /**
     * Contains information about one or more alarm actions.
     */
    interface AlarmModelAlarmEventActionsArgs {
        /**
         * Specifies one or more supported actions to receive notifications when the alarm state changes.
         */
        alarmActions?: pulumi.Input<pulumi.Input<inputs.iotevents.AlarmModelAlarmActionArgs>[]>;
    }
    /**
     * Defines when your alarm is invoked.
     */
    interface AlarmModelAlarmRuleArgs {
        /**
         * A rule that compares an input property value to a threshold value with a comparison operator.
         */
        simpleRule?: pulumi.Input<inputs.iotevents.AlarmModelSimpleRuleArgs>;
    }
    /**
     * A structure that contains timestamp information. For more information, see [TimeInNanos](https://docs.aws.amazon.com/iot-sitewise/latest/APIReference/API_TimeInNanos.html) in the *API Reference*.
     *  You must use expressions for all parameters in ``AssetPropertyTimestamp``. The expressions accept literals, operators, functions, references, and substitution templates.
     *   **Examples**
     *  +  For literal values, the expressions must contain single quotes. For example, the value for the ``timeInSeconds`` parameter can be ``'1586400675'``.
     *   +  For references, you must specify either variables or input values. For example, the value for the ``offsetInNanos`` parameter can be ``$variable.time``.
     *   +  For a substitution template, you must use ``${}``, and the template must be in single quotes. A substitution template can also contain a combination of literals, operators, functions, references, and substitution templates.
     *  In the following example, the value for the ``timeInSeconds`` parameter uses a substitution template.
     *   ``'${$input.TemperatureInput.sensorData.timestamp / 1000}'``
     *
     *  For more information, see [Expressions](https://docs.aws.amazon.com/iotevents/latest/developerguide/iotevents-expressions.html) in the *Developer Guide*.
     */
    interface AlarmModelAssetPropertyTimestampArgs {
        /**
         * The nanosecond offset converted from ``timeInSeconds``. The valid range is between 0-999999999.
         */
        offsetInNanos?: pulumi.Input<string>;
        /**
         * The timestamp, in seconds, in the Unix epoch format. The valid range is between 1-31556889864403199.
         */
        timeInSeconds: pulumi.Input<string>;
    }
    /**
     * A structure that contains value information. For more information, see [AssetPropertyValue](https://docs.aws.amazon.com/iot-sitewise/latest/APIReference/API_AssetPropertyValue.html) in the *API Reference*.
     *  You must use expressions for all parameters in ``AssetPropertyValue``. The expressions accept literals, operators, functions, references, and substitution templates.
     *   **Examples**
     *  +  For literal values, the expressions must contain single quotes. For example, the value for the ``quality`` parameter can be ``'GOOD'``.
     *   +  For references, you must specify either variables or input values. For example, the value for the ``quality`` parameter can be ``$input.TemperatureInput.sensorData.quality``.
     *
     *  For more information, see [Expressions](https://docs.aws.amazon.com/iotevents/latest/developerguide/iotevents-expressions.html) in the *Developer Guide*.
     */
    interface AlarmModelAssetPropertyValueArgs {
        /**
         * The quality of the asset property value. The value must be ``'GOOD'``, ``'BAD'``, or ``'UNCERTAIN'``.
         */
        quality?: pulumi.Input<string>;
        /**
         * The timestamp associated with the asset property value. The default is the current event time.
         */
        timestamp?: pulumi.Input<inputs.iotevents.AlarmModelAssetPropertyTimestampArgs>;
        /**
         * The value to send to an asset property.
         */
        value: pulumi.Input<inputs.iotevents.AlarmModelAssetPropertyVariantArgs>;
    }
    /**
     * A structure that contains an asset property value. For more information, see [Variant](https://docs.aws.amazon.com/iot-sitewise/latest/APIReference/API_Variant.html) in the *API Reference*.
     *  You must use expressions for all parameters in ``AssetPropertyVariant``. The expressions accept literals, operators, functions, references, and substitution templates.
     *   **Examples**
     *  +  For literal values, the expressions must contain single quotes. For example, the value for the ``integerValue`` parameter can be ``'100'``.
     *   +  For references, you must specify either variables or parameters. For example, the value for the ``booleanValue`` parameter can be ``$variable.offline``.
     *   +  For a substitution template, you must use ``${}``, and the template must be in single quotes. A substitution template can also contain a combination of literals, operators, functions, references, and substitution templates.
     *  In the following example, the value for the ``doubleValue`` parameter uses a substitution template.
     *   ``'${$input.TemperatureInput.sensorData.temperature * 6 / 5 + 32}'``
     *
     *  For more information, see [Expressions](https://docs.aws.amazon.com/iotevents/latest/developerguide/iotevents-expressions.html) in the *Developer Guide*.
     *  You must specify one of the following value types, depending on the ``dataType`` of the specified asset property. For more information, see [AssetProperty](https://docs.aws.amazon.com/iot-sitewise/latest/APIReference/API_AssetProperty.html) in the *API Reference*.
     */
    interface AlarmModelAssetPropertyVariantArgs {
        /**
         * The asset property value is a Boolean value that must be ``'TRUE'`` or ``'FALSE'``. You must use an expression, and the evaluated result should be a Boolean value.
         */
        booleanValue?: pulumi.Input<string>;
        /**
         * The asset property value is a double. You must use an expression, and the evaluated result should be a double.
         */
        doubleValue?: pulumi.Input<string>;
        /**
         * The asset property value is an integer. You must use an expression, and the evaluated result should be an integer.
         */
        integerValue?: pulumi.Input<string>;
        /**
         * The asset property value is a string. You must use an expression, and the evaluated result should be a string.
         */
        stringValue?: pulumi.Input<string>;
    }
    /**
     * Defines an action to write to the Amazon DynamoDB table that you created. The default action payload contains all the information about the detector model instance and the event that triggered the action. You can customize the [payload](https://docs.aws.amazon.com/iotevents/latest/apireference/API_Payload.html). A separate column of the DynamoDB table receives one attribute-value pair in the payload that you specify.
     *  You must use expressions for all parameters in ``DynamoDBv2Action``. The expressions accept literals, operators, functions, references, and substitution templates.
     *   **Examples**
     *  +  For literal values, the expressions must contain single quotes. For example, the value for the ``tableName`` parameter can be ``'GreenhouseTemperatureTable'``.
     *   +  For references, you must specify either variables or input values. For example, the value for the ``tableName`` parameter can be ``$variable.ddbtableName``.
     *   +  For a substitution template, you must use ``${}``, and the template must be in single quotes. A substitution template can also contain a combination of literals, operators, functions, references, and substitution templates.
     *  In the following example, the value for the ``contentExpression`` parameter in ``Payload`` uses a substitution template.
     *   ``'{\"sensorID\": \"${$input.GreenhouseInput.sensor_id}\", \"temperature\": \"${$input.GreenhouseInput.temperature * 9 / 5 + 32}\"}'``
     *   +  For a string concatenation, you must use ``+``. A string concatenation can also contain a combination of literals, operators, functions, references, and substitution templates.
     *  In the following example, the value for the ``tableName`` parameter uses a string concatenation.
     *   ``'GreenhouseTemperatureTable ' + $input.GreenhouseInput.date``
     *
     *  For more information, see [Expressions](https://docs.aws.amazon.com/iotevents/latest/developerguide/iotevents-expressions.html) in the *Developer Guide*.
     *  The value for the ``type`` parameter in ``Payload`` must be ``JSON``.
     */
    interface AlarmModelDynamoDBv2Args {
        /**
         * Information needed to configure the payload.
         *  By default, ITE generates a standard payload in JSON for any action. This action payload contains all attribute-value pairs that have the information about the detector model instance and the event triggered the action. To configure the action payload, you can use ``contentExpression``.
         */
        payload?: pulumi.Input<inputs.iotevents.AlarmModelPayloadArgs>;
        /**
         * The name of the DynamoDB table.
         */
        tableName: pulumi.Input<string>;
    }
    /**
     * Defines an action to write to the Amazon DynamoDB table that you created. The standard action payload contains all the information about the detector model instance and the event that triggered the action. You can customize the [payload](https://docs.aws.amazon.com/iotevents/latest/apireference/API_Payload.html). One column of the DynamoDB table receives all attribute-value pairs in the payload that you specify.
     *  You must use expressions for all parameters in ``DynamoDBAction``. The expressions accept literals, operators, functions, references, and substitution templates.
     *   **Examples**
     *  +  For literal values, the expressions must contain single quotes. For example, the value for the ``hashKeyType`` parameter can be ``'STRING'``.
     *   +  For references, you must specify either variables or input values. For example, the value for the ``hashKeyField`` parameter can be ``$input.GreenhouseInput.name``.
     *   +  For a substitution template, you must use ``${}``, and the template must be in single quotes. A substitution template can also contain a combination of literals, operators, functions, references, and substitution templates.
     *  In the following example, the value for the ``hashKeyValue`` parameter uses a substitution template.
     *   ``'${$input.GreenhouseInput.temperature * 6 / 5 + 32} in Fahrenheit'``
     *   +  For a string concatenation, you must use ``+``. A string concatenation can also contain a combination of literals, operators, functions, references, and substitution templates.
     *  In the following example, the value for the ``tableName`` parameter uses a string concatenation.
     *   ``'GreenhouseTemperatureTable ' + $input.GreenhouseInput.date``
     *
     *  For more information, see [Expressions](https://docs.aws.amazon.com/iotevents/latest/developerguide/iotevents-expressions.html) in the *Developer Guide*.
     *  If the defined payload type is a string, ``DynamoDBAction`` writes non-JSON data to the DynamoDB table as binary data. The DynamoDB console displays the data as Base64-encoded text. The value for the ``payloadField`` parameter is ``<payload-field>_raw``.
     */
    interface AlarmModelDynamoDbArgs {
        /**
         * The name of the hash key (also called the partition key). The ``hashKeyField`` value must match the partition key of the target DynamoDB table.
         */
        hashKeyField: pulumi.Input<string>;
        /**
         * The data type for the hash key (also called the partition key). You can specify the following values:
         *   +   ``'STRING'`` - The hash key is a string.
         *   +   ``'NUMBER'`` - The hash key is a number.
         *
         *  If you don't specify ``hashKeyType``, the default value is ``'STRING'``.
         */
        hashKeyType?: pulumi.Input<string>;
        /**
         * The value of the hash key (also called the partition key).
         */
        hashKeyValue: pulumi.Input<string>;
        /**
         * The type of operation to perform. You can specify the following values:
         *   +   ``'INSERT'`` - Insert data as a new item into the DynamoDB table. This item uses the specified hash key as a partition key. If you specified a range key, the item uses the range key as a sort key.
         *   +   ``'UPDATE'`` - Update an existing item of the DynamoDB table with new data. This item's partition key must match the specified hash key. If you specified a range key, the range key must match the item's sort key.
         *   +   ``'DELETE'`` - Delete an existing item of the DynamoDB table. This item's partition key must match the specified hash key. If you specified a range key, the range key must match the item's sort key.
         *
         *  If you don't specify this parameter, ITE triggers the ``'INSERT'`` operation.
         */
        operation?: pulumi.Input<string>;
        /**
         * Information needed to configure the payload.
         *  By default, ITE generates a standard payload in JSON for any action. This action payload contains all attribute-value pairs that have the information about the detector model instance and the event triggered the action. To configure the action payload, you can use ``contentExpression``.
         */
        payload?: pulumi.Input<inputs.iotevents.AlarmModelPayloadArgs>;
        /**
         * The name of the DynamoDB column that receives the action payload.
         *  If you don't specify this parameter, the name of the DynamoDB column is ``payload``.
         */
        payloadField?: pulumi.Input<string>;
        /**
         * The name of the range key (also called the sort key). The ``rangeKeyField`` value must match the sort key of the target DynamoDB table.
         */
        rangeKeyField?: pulumi.Input<string>;
        /**
         * The data type for the range key (also called the sort key), You can specify the following values:
         *   +   ``'STRING'`` - The range key is a string.
         *   +   ``'NUMBER'`` - The range key is number.
         *
         *  If you don't specify ``rangeKeyField``, the default value is ``'STRING'``.
         */
        rangeKeyType?: pulumi.Input<string>;
        /**
         * The value of the range key (also called the sort key).
         */
        rangeKeyValue?: pulumi.Input<string>;
        /**
         * The name of the DynamoDB table. The ``tableName`` value must match the table name of the target DynamoDB table.
         */
        tableName: pulumi.Input<string>;
    }
    /**
     * Sends information about the detector model instance and the event that triggered the action to an Amazon Kinesis Data Firehose delivery stream.
     */
    interface AlarmModelFirehoseArgs {
        /**
         * The name of the Kinesis Data Firehose delivery stream where the data is written.
         */
        deliveryStreamName: pulumi.Input<string>;
        /**
         * You can configure the action payload when you send a message to an Amazon Data Firehose delivery stream.
         */
        payload?: pulumi.Input<inputs.iotevents.AlarmModelPayloadArgs>;
        /**
         * A character separator that is used to separate records written to the Kinesis Data Firehose delivery stream. Valid values are: '\n' (newline), '\t' (tab), '\r\n' (Windows newline), ',' (comma).
         */
        separator?: pulumi.Input<string>;
    }
    /**
     * Specifies the default alarm state. The configuration applies to all alarms that were created based on this alarm model.
     */
    interface AlarmModelInitializationConfigurationArgs {
        /**
         * The value must be ``TRUE`` or ``FALSE``. If ``FALSE``, all alarm instances created based on the alarm model are activated. The default value is ``TRUE``.
         */
        disabledOnInitialization: pulumi.Input<boolean>;
    }
    /**
     * Sends an ITE input, passing in information about the detector model instance and the event that triggered the action.
     */
    interface AlarmModelIotEventsArgs {
        /**
         * The name of the ITE input where the data is sent.
         */
        inputName: pulumi.Input<string>;
        /**
         * You can configure the action payload when you send a message to an ITE input.
         */
        payload?: pulumi.Input<inputs.iotevents.AlarmModelPayloadArgs>;
    }
    /**
     * Sends information about the detector model instance and the event that triggered the action to a specified asset property in ITSW.
     *  You must use expressions for all parameters in ``IotSiteWiseAction``. The expressions accept literals, operators, functions, references, and substitutions templates.
     *   **Examples**
     *  +  For literal values, the expressions must contain single quotes. For example, the value for the ``propertyAlias`` parameter can be ``'/company/windfarm/3/turbine/7/temperature'``.
     *   +  For references, you must specify either variables or input values. For example, the value for the ``assetId`` parameter can be ``$input.TurbineInput.assetId1``.
     *   +  For a substitution template, you must use ``${}``, and the template must be in single quotes. A substitution template can also contain a combination of literals, operators, functions, references, and substitution templates.
     *  In the following example, the value for the ``propertyAlias`` parameter uses a substitution template.
     *   ``'company/windfarm/${$input.TemperatureInput.sensorData.windfarmID}/turbine/ ${$input.TemperatureInput.sensorData.turbineID}/temperature'``
     *
     *  You must specify either ``propertyAlias`` or both ``assetId`` and ``propertyId`` to identify the target asset property in ITSW.
     *  For more information, see [Expressions](https://docs.aws.amazon.com/iotevents/latest/developerguide/iotevents-expressions.html) in the *Developer Guide*.
     */
    interface AlarmModelIotSiteWiseArgs {
        /**
         * The ID of the asset that has the specified property.
         */
        assetId?: pulumi.Input<string>;
        /**
         * A unique identifier for this entry. You can use the entry ID to track which data entry causes an error in case of failure. The default is a new unique identifier.
         */
        entryId?: pulumi.Input<string>;
        /**
         * The alias of the asset property.
         */
        propertyAlias?: pulumi.Input<string>;
        /**
         * The ID of the asset property.
         */
        propertyId?: pulumi.Input<string>;
        /**
         * The value to send to the asset property. This value contains timestamp, quality, and value (TQV) information.
         */
        propertyValue?: pulumi.Input<inputs.iotevents.AlarmModelAssetPropertyValueArgs>;
    }
    /**
     * Information required to publish the MQTT message through the IoT message broker.
     */
    interface AlarmModelIotTopicPublishArgs {
        /**
         * The MQTT topic of the message. You can use a string expression that includes variables (``$variable.<variable-name>``) and input values (``$input.<input-name>.<path-to-datum>``) as the topic string.
         */
        mqttTopic: pulumi.Input<string>;
        /**
         * You can configure the action payload when you publish a message to an IoTCore topic.
         */
        payload?: pulumi.Input<inputs.iotevents.AlarmModelPayloadArgs>;
    }
    /**
     * Calls a Lambda function, passing in information about the detector model instance and the event that triggered the action.
     */
    interface AlarmModelLambdaArgs {
        /**
         * The ARN of the Lambda function that is executed.
         */
        functionArn: pulumi.Input<string>;
        /**
         * You can configure the action payload when you send a message to a Lambda function.
         */
        payload?: pulumi.Input<inputs.iotevents.AlarmModelPayloadArgs>;
    }
    /**
     * Information needed to configure the payload.
     *  By default, ITE generates a standard payload in JSON for any action. This action payload contains all attribute-value pairs that have the information about the detector model instance and the event triggered the action. To configure the action payload, you can use ``contentExpression``.
     */
    interface AlarmModelPayloadArgs {
        /**
         * The content of the payload. You can use a string expression that includes quoted strings (``'<string>'``), variables (``$variable.<variable-name>``), input values (``$input.<input-name>.<path-to-datum>``), string concatenations, and quoted strings that contain ``${}`` as the content. The recommended maximum size of a content expression is 1 KB.
         */
        contentExpression: pulumi.Input<string>;
        /**
         * The value of the payload type can be either ``STRING`` or ``JSON``.
         */
        type: pulumi.Input<string>;
    }
    /**
     * A rule that compares an input property value to a threshold value with a comparison operator.
     */
    interface AlarmModelSimpleRuleArgs {
        /**
         * The comparison operator.
         */
        comparisonOperator: pulumi.Input<enums.iotevents.AlarmModelSimpleRuleComparisonOperator>;
        /**
         * The value on the left side of the comparison operator. You can specify an ITE input attribute as an input property.
         */
        inputProperty: pulumi.Input<string>;
        /**
         * The value on the right side of the comparison operator. You can enter a number or specify an ITE input attribute.
         */
        threshold: pulumi.Input<string>;
    }
    /**
     * Information required to publish the Amazon SNS message.
     */
    interface AlarmModelSnsArgs {
        /**
         * You can configure the action payload when you send a message as an Amazon SNS push notification.
         */
        payload?: pulumi.Input<inputs.iotevents.AlarmModelPayloadArgs>;
        /**
         * The ARN of the Amazon SNS target where the message is sent.
         */
        targetArn: pulumi.Input<string>;
    }
    /**
     * Sends information about the detector model instance and the event that triggered the action to an Amazon SQS queue.
     */
    interface AlarmModelSqsArgs {
        /**
         * You can configure the action payload when you send a message to an Amazon SQS queue.
         */
        payload?: pulumi.Input<inputs.iotevents.AlarmModelPayloadArgs>;
        /**
         * The URL of the SQS queue where the data is written.
         */
        queueUrl: pulumi.Input<string>;
        /**
         * Set this to TRUE if you want the data to be base-64 encoded before it is written to the queue. Otherwise, set this to FALSE.
         */
        useBase64?: pulumi.Input<boolean>;
    }
    /**
     * An action to be performed when the ``condition`` is TRUE.
     */
    interface DetectorModelActionArgs {
        /**
         * Information needed to clear the timer.
         */
        clearTimer?: pulumi.Input<inputs.iotevents.DetectorModelClearTimerArgs>;
        /**
         * Writes to the DynamoDB table that you created. The default action payload contains all attribute-value pairs that have the information about the detector model instance and the event that triggered the action. You can customize the [payload](https://docs.aws.amazon.com/iotevents/latest/apireference/API_Payload.html). A separate column of the DynamoDB table receives one attribute-value pair in the payload that you specify. For more information, see [Actions](https://docs.aws.amazon.com/iotevents/latest/developerguide/iotevents-event-actions.html) in *Developer Guide*.
         */
        dynamoDBv2?: pulumi.Input<inputs.iotevents.DetectorModelDynamoDBv2Args>;
        /**
         * Writes to the DynamoDB table that you created. The default action payload contains all attribute-value pairs that have the information about the detector model instance and the event that triggered the action. You can customize the [payload](https://docs.aws.amazon.com/iotevents/latest/apireference/API_Payload.html). One column of the DynamoDB table receives all attribute-value pairs in the payload that you specify. For more information, see [Actions](https://docs.aws.amazon.com/iotevents/latest/developerguide/iotevents-event-actions.html) in *Developer Guide*.
         */
        dynamoDb?: pulumi.Input<inputs.iotevents.DetectorModelDynamoDbArgs>;
        /**
         * Sends information about the detector model instance and the event that triggered the action to an Amazon Kinesis Data Firehose delivery stream.
         */
        firehose?: pulumi.Input<inputs.iotevents.DetectorModelFirehoseArgs>;
        /**
         * Sends ITE input, which passes information about the detector model instance and the event that triggered the action.
         */
        iotEvents?: pulumi.Input<inputs.iotevents.DetectorModelIotEventsArgs>;
        /**
         * Sends information about the detector model instance and the event that triggered the action to an asset property in ITSW .
         */
        iotSiteWise?: pulumi.Input<inputs.iotevents.DetectorModelIotSiteWiseArgs>;
        /**
         * Publishes an MQTT message with the given topic to the IoT message broker.
         */
        iotTopicPublish?: pulumi.Input<inputs.iotevents.DetectorModelIotTopicPublishArgs>;
        /**
         * Calls a Lambda function, passing in information about the detector model instance and the event that triggered the action.
         */
        lambda?: pulumi.Input<inputs.iotevents.DetectorModelLambdaArgs>;
        /**
         * Information needed to reset the timer.
         */
        resetTimer?: pulumi.Input<inputs.iotevents.DetectorModelResetTimerArgs>;
        /**
         * Information needed to set the timer.
         */
        setTimer?: pulumi.Input<inputs.iotevents.DetectorModelSetTimerArgs>;
        /**
         * Sets a variable to a specified value.
         */
        setVariable?: pulumi.Input<inputs.iotevents.DetectorModelSetVariableArgs>;
        /**
         * Sends an Amazon SNS message.
         */
        sns?: pulumi.Input<inputs.iotevents.DetectorModelSnsArgs>;
        /**
         * Sends an Amazon SNS message.
         */
        sqs?: pulumi.Input<inputs.iotevents.DetectorModelSqsArgs>;
    }
    /**
     * A structure that contains timestamp information. For more information, see [TimeInNanos](https://docs.aws.amazon.com/iot-sitewise/latest/APIReference/API_TimeInNanos.html) in the *API Reference*.
     *  You must use expressions for all parameters in ``AssetPropertyTimestamp``. The expressions accept literals, operators, functions, references, and substitution templates.
     *   **Examples**
     *  +  For literal values, the expressions must contain single quotes. For example, the value for the ``timeInSeconds`` parameter can be ``'1586400675'``.
     *   +  For references, you must specify either variables or input values. For example, the value for the ``offsetInNanos`` parameter can be ``$variable.time``.
     *   +  For a substitution template, you must use ``${}``, and the template must be in single quotes. A substitution template can also contain a combination of literals, operators, functions, references, and substitution templates.
     *  In the following example, the value for the ``timeInSeconds`` parameter uses a substitution template.
     *   ``'${$input.TemperatureInput.sensorData.timestamp / 1000}'``
     *
     *  For more information, see [Expressions](https://docs.aws.amazon.com/iotevents/latest/developerguide/iotevents-expressions.html) in the *Developer Guide*.
     */
    interface DetectorModelAssetPropertyTimestampArgs {
        /**
         * The nanosecond offset converted from ``timeInSeconds``. The valid range is between 0-999999999.
         */
        offsetInNanos?: pulumi.Input<string>;
        /**
         * The timestamp, in seconds, in the Unix epoch format. The valid range is between 1-31556889864403199.
         */
        timeInSeconds: pulumi.Input<string>;
    }
    /**
     * A structure that contains value information. For more information, see [AssetPropertyValue](https://docs.aws.amazon.com/iot-sitewise/latest/APIReference/API_AssetPropertyValue.html) in the *API Reference*.
     *  You must use expressions for all parameters in ``AssetPropertyValue``. The expressions accept literals, operators, functions, references, and substitution templates.
     *   **Examples**
     *  +  For literal values, the expressions must contain single quotes. For example, the value for the ``quality`` parameter can be ``'GOOD'``.
     *   +  For references, you must specify either variables or input values. For example, the value for the ``quality`` parameter can be ``$input.TemperatureInput.sensorData.quality``.
     *
     *  For more information, see [Expressions](https://docs.aws.amazon.com/iotevents/latest/developerguide/iotevents-expressions.html) in the *Developer Guide*.
     */
    interface DetectorModelAssetPropertyValueArgs {
        /**
         * The quality of the asset property value. The value must be ``'GOOD'``, ``'BAD'``, or ``'UNCERTAIN'``.
         */
        quality?: pulumi.Input<string>;
        /**
         * The timestamp associated with the asset property value. The default is the current event time.
         */
        timestamp?: pulumi.Input<inputs.iotevents.DetectorModelAssetPropertyTimestampArgs>;
        /**
         * The value to send to an asset property.
         */
        value: pulumi.Input<inputs.iotevents.DetectorModelAssetPropertyVariantArgs>;
    }
    /**
     * A structure that contains an asset property value. For more information, see [Variant](https://docs.aws.amazon.com/iot-sitewise/latest/APIReference/API_Variant.html) in the *API Reference*.
     *  You must use expressions for all parameters in ``AssetPropertyVariant``. The expressions accept literals, operators, functions, references, and substitution templates.
     *   **Examples**
     *  +  For literal values, the expressions must contain single quotes. For example, the value for the ``integerValue`` parameter can be ``'100'``.
     *   +  For references, you must specify either variables or parameters. For example, the value for the ``booleanValue`` parameter can be ``$variable.offline``.
     *   +  For a substitution template, you must use ``${}``, and the template must be in single quotes. A substitution template can also contain a combination of literals, operators, functions, references, and substitution templates.
     *  In the following example, the value for the ``doubleValue`` parameter uses a substitution template.
     *   ``'${$input.TemperatureInput.sensorData.temperature * 6 / 5 + 32}'``
     *
     *  For more information, see [Expressions](https://docs.aws.amazon.com/iotevents/latest/developerguide/iotevents-expressions.html) in the *Developer Guide*.
     *  You must specify one of the following value types, depending on the ``dataType`` of the specified asset property. For more information, see [AssetProperty](https://docs.aws.amazon.com/iot-sitewise/latest/APIReference/API_AssetProperty.html) in the *API Reference*.
     */
    interface DetectorModelAssetPropertyVariantArgs {
        /**
         * The asset property value is a Boolean value that must be ``'TRUE'`` or ``'FALSE'``. You must use an expression, and the evaluated result should be a Boolean value.
         */
        booleanValue?: pulumi.Input<string>;
        /**
         * The asset property value is a double. You must use an expression, and the evaluated result should be a double.
         */
        doubleValue?: pulumi.Input<string>;
        /**
         * The asset property value is an integer. You must use an expression, and the evaluated result should be an integer.
         */
        integerValue?: pulumi.Input<string>;
        /**
         * The asset property value is a string. You must use an expression, and the evaluated result should be a string.
         */
        stringValue?: pulumi.Input<string>;
    }
    /**
     * Information needed to clear the timer.
     */
    interface DetectorModelClearTimerArgs {
        /**
         * The name of the timer to clear.
         */
        timerName: pulumi.Input<string>;
    }
    /**
     * Information that defines how a detector operates.
     */
    interface DetectorModelDefinitionArgs {
        /**
         * The state that is entered at the creation of each detector (instance).
         */
        initialStateName: pulumi.Input<string>;
        /**
         * Information about the states of the detector.
         */
        states: pulumi.Input<pulumi.Input<inputs.iotevents.DetectorModelStateArgs>[]>;
    }
    /**
     * Defines an action to write to the Amazon DynamoDB table that you created. The default action payload contains all the information about the detector model instance and the event that triggered the action. You can customize the [payload](https://docs.aws.amazon.com/iotevents/latest/apireference/API_Payload.html). A separate column of the DynamoDB table receives one attribute-value pair in the payload that you specify.
     *  You must use expressions for all parameters in ``DynamoDBv2Action``. The expressions accept literals, operators, functions, references, and substitution templates.
     *   **Examples**
     *  +  For literal values, the expressions must contain single quotes. For example, the value for the ``tableName`` parameter can be ``'GreenhouseTemperatureTable'``.
     *   +  For references, you must specify either variables or input values. For example, the value for the ``tableName`` parameter can be ``$variable.ddbtableName``.
     *   +  For a substitution template, you must use ``${}``, and the template must be in single quotes. A substitution template can also contain a combination of literals, operators, functions, references, and substitution templates.
     *  In the following example, the value for the ``contentExpression`` parameter in ``Payload`` uses a substitution template.
     *   ``'{\"sensorID\": \"${$input.GreenhouseInput.sensor_id}\", \"temperature\": \"${$input.GreenhouseInput.temperature * 9 / 5 + 32}\"}'``
     *   +  For a string concatenation, you must use ``+``. A string concatenation can also contain a combination of literals, operators, functions, references, and substitution templates.
     *  In the following example, the value for the ``tableName`` parameter uses a string concatenation.
     *   ``'GreenhouseTemperatureTable ' + $input.GreenhouseInput.date``
     *
     *  For more information, see [Expressions](https://docs.aws.amazon.com/iotevents/latest/developerguide/iotevents-expressions.html) in the *Developer Guide*.
     *  The value for the ``type`` parameter in ``Payload`` must be ``JSON``.
     */
    interface DetectorModelDynamoDBv2Args {
        /**
         * Information needed to configure the payload.
         *  By default, ITE generates a standard payload in JSON for any action. This action payload contains all attribute-value pairs that have the information about the detector model instance and the event triggered the action. To configure the action payload, you can use ``contentExpression``.
         */
        payload?: pulumi.Input<inputs.iotevents.DetectorModelPayloadArgs>;
        /**
         * The name of the DynamoDB table.
         */
        tableName: pulumi.Input<string>;
    }
    /**
     * Defines an action to write to the Amazon DynamoDB table that you created. The standard action payload contains all the information about the detector model instance and the event that triggered the action. You can customize the [payload](https://docs.aws.amazon.com/iotevents/latest/apireference/API_Payload.html). One column of the DynamoDB table receives all attribute-value pairs in the payload that you specify.
     *  You must use expressions for all parameters in ``DynamoDBAction``. The expressions accept literals, operators, functions, references, and substitution templates.
     *   **Examples**
     *  +  For literal values, the expressions must contain single quotes. For example, the value for the ``hashKeyType`` parameter can be ``'STRING'``.
     *   +  For references, you must specify either variables or input values. For example, the value for the ``hashKeyField`` parameter can be ``$input.GreenhouseInput.name``.
     *   +  For a substitution template, you must use ``${}``, and the template must be in single quotes. A substitution template can also contain a combination of literals, operators, functions, references, and substitution templates.
     *  In the following example, the value for the ``hashKeyValue`` parameter uses a substitution template.
     *   ``'${$input.GreenhouseInput.temperature * 6 / 5 + 32} in Fahrenheit'``
     *   +  For a string concatenation, you must use ``+``. A string concatenation can also contain a combination of literals, operators, functions, references, and substitution templates.
     *  In the following example, the value for the ``tableName`` parameter uses a string concatenation.
     *   ``'GreenhouseTemperatureTable ' + $input.GreenhouseInput.date``
     *
     *  For more information, see [Expressions](https://docs.aws.amazon.com/iotevents/latest/developerguide/iotevents-expressions.html) in the *Developer Guide*.
     *  If the defined payload type is a string, ``DynamoDBAction`` writes non-JSON data to the DynamoDB table as binary data. The DynamoDB console displays the data as Base64-encoded text. The value for the ``payloadField`` parameter is ``<payload-field>_raw``.
     */
    interface DetectorModelDynamoDbArgs {
        /**
         * The name of the hash key (also called the partition key). The ``hashKeyField`` value must match the partition key of the target DynamoDB table.
         */
        hashKeyField: pulumi.Input<string>;
        /**
         * The data type for the hash key (also called the partition key). You can specify the following values:
         *   +   ``'STRING'`` - The hash key is a string.
         *   +   ``'NUMBER'`` - The hash key is a number.
         *
         *  If you don't specify ``hashKeyType``, the default value is ``'STRING'``.
         */
        hashKeyType?: pulumi.Input<string>;
        /**
         * The value of the hash key (also called the partition key).
         */
        hashKeyValue: pulumi.Input<string>;
        /**
         * The type of operation to perform. You can specify the following values:
         *   +   ``'INSERT'`` - Insert data as a new item into the DynamoDB table. This item uses the specified hash key as a partition key. If you specified a range key, the item uses the range key as a sort key.
         *   +   ``'UPDATE'`` - Update an existing item of the DynamoDB table with new data. This item's partition key must match the specified hash key. If you specified a range key, the range key must match the item's sort key.
         *   +   ``'DELETE'`` - Delete an existing item of the DynamoDB table. This item's partition key must match the specified hash key. If you specified a range key, the range key must match the item's sort key.
         *
         *  If you don't specify this parameter, ITE triggers the ``'INSERT'`` operation.
         */
        operation?: pulumi.Input<string>;
        /**
         * Information needed to configure the payload.
         *  By default, ITE generates a standard payload in JSON for any action. This action payload contains all attribute-value pairs that have the information about the detector model instance and the event triggered the action. To configure the action payload, you can use ``contentExpression``.
         */
        payload?: pulumi.Input<inputs.iotevents.DetectorModelPayloadArgs>;
        /**
         * The name of the DynamoDB column that receives the action payload.
         *  If you don't specify this parameter, the name of the DynamoDB column is ``payload``.
         */
        payloadField?: pulumi.Input<string>;
        /**
         * The name of the range key (also called the sort key). The ``rangeKeyField`` value must match the sort key of the target DynamoDB table.
         */
        rangeKeyField?: pulumi.Input<string>;
        /**
         * The data type for the range key (also called the sort key), You can specify the following values:
         *   +   ``'STRING'`` - The range key is a string.
         *   +   ``'NUMBER'`` - The range key is number.
         *
         *  If you don't specify ``rangeKeyField``, the default value is ``'STRING'``.
         */
        rangeKeyType?: pulumi.Input<string>;
        /**
         * The value of the range key (also called the sort key).
         */
        rangeKeyValue?: pulumi.Input<string>;
        /**
         * The name of the DynamoDB table. The ``tableName`` value must match the table name of the target DynamoDB table.
         */
        tableName: pulumi.Input<string>;
    }
    /**
     * Specifies the ``actions`` to be performed when the ``condition`` evaluates to TRUE.
     */
    interface DetectorModelEventArgs {
        /**
         * The actions to be performed.
         */
        actions?: pulumi.Input<pulumi.Input<inputs.iotevents.DetectorModelActionArgs>[]>;
        /**
         * Optional. The Boolean expression that, when TRUE, causes the ``actions`` to be performed. If not present, the actions are performed (=TRUE). If the expression result is not a Boolean value, the actions are not performed (=FALSE).
         */
        condition?: pulumi.Input<string>;
        /**
         * The name of the event.
         */
        eventName: pulumi.Input<string>;
    }
    /**
     * Sends information about the detector model instance and the event that triggered the action to an Amazon Kinesis Data Firehose delivery stream.
     */
    interface DetectorModelFirehoseArgs {
        /**
         * The name of the Kinesis Data Firehose delivery stream where the data is written.
         */
        deliveryStreamName: pulumi.Input<string>;
        /**
         * You can configure the action payload when you send a message to an Amazon Data Firehose delivery stream.
         */
        payload?: pulumi.Input<inputs.iotevents.DetectorModelPayloadArgs>;
        /**
         * A character separator that is used to separate records written to the Kinesis Data Firehose delivery stream. Valid values are: '\n' (newline), '\t' (tab), '\r\n' (Windows newline), ',' (comma).
         */
        separator?: pulumi.Input<string>;
    }
    /**
     * Sends an ITE input, passing in information about the detector model instance and the event that triggered the action.
     */
    interface DetectorModelIotEventsArgs {
        /**
         * The name of the ITE input where the data is sent.
         */
        inputName: pulumi.Input<string>;
        /**
         * You can configure the action payload when you send a message to an ITE input.
         */
        payload?: pulumi.Input<inputs.iotevents.DetectorModelPayloadArgs>;
    }
    /**
     * Sends information about the detector model instance and the event that triggered the action to a specified asset property in ITSW.
     *  You must use expressions for all parameters in ``IotSiteWiseAction``. The expressions accept literals, operators, functions, references, and substitutions templates.
     *   **Examples**
     *  +  For literal values, the expressions must contain single quotes. For example, the value for the ``propertyAlias`` parameter can be ``'/company/windfarm/3/turbine/7/temperature'``.
     *   +  For references, you must specify either variables or input values. For example, the value for the ``assetId`` parameter can be ``$input.TurbineInput.assetId1``.
     *   +  For a substitution template, you must use ``${}``, and the template must be in single quotes. A substitution template can also contain a combination of literals, operators, functions, references, and substitution templates.
     *  In the following example, the value for the ``propertyAlias`` parameter uses a substitution template.
     *   ``'company/windfarm/${$input.TemperatureInput.sensorData.windfarmID}/turbine/ ${$input.TemperatureInput.sensorData.turbineID}/temperature'``
     *
     *  You must specify either ``propertyAlias`` or both ``assetId`` and ``propertyId`` to identify the target asset property in ITSW.
     *  For more information, see [Expressions](https://docs.aws.amazon.com/iotevents/latest/developerguide/iotevents-expressions.html) in the *Developer Guide*.
     */
    interface DetectorModelIotSiteWiseArgs {
        /**
         * The ID of the asset that has the specified property.
         */
        assetId?: pulumi.Input<string>;
        /**
         * A unique identifier for this entry. You can use the entry ID to track which data entry causes an error in case of failure. The default is a new unique identifier.
         */
        entryId?: pulumi.Input<string>;
        /**
         * The alias of the asset property.
         */
        propertyAlias?: pulumi.Input<string>;
        /**
         * The ID of the asset property.
         */
        propertyId?: pulumi.Input<string>;
        /**
         * The value to send to the asset property. This value contains timestamp, quality, and value (TQV) information.
         */
        propertyValue: pulumi.Input<inputs.iotevents.DetectorModelAssetPropertyValueArgs>;
    }
    /**
     * Information required to publish the MQTT message through the IoT message broker.
     */
    interface DetectorModelIotTopicPublishArgs {
        /**
         * The MQTT topic of the message. You can use a string expression that includes variables (``$variable.<variable-name>``) and input values (``$input.<input-name>.<path-to-datum>``) as the topic string.
         */
        mqttTopic: pulumi.Input<string>;
        /**
         * You can configure the action payload when you publish a message to an IoTCore topic.
         */
        payload?: pulumi.Input<inputs.iotevents.DetectorModelPayloadArgs>;
    }
    /**
     * Calls a Lambda function, passing in information about the detector model instance and the event that triggered the action.
     */
    interface DetectorModelLambdaArgs {
        /**
         * The ARN of the Lambda function that is executed.
         */
        functionArn: pulumi.Input<string>;
        /**
         * You can configure the action payload when you send a message to a Lambda function.
         */
        payload?: pulumi.Input<inputs.iotevents.DetectorModelPayloadArgs>;
    }
    /**
     * When entering this state, perform these ``actions`` if the ``condition`` is TRUE.
     */
    interface DetectorModelOnEnterArgs {
        /**
         * Specifies the actions that are performed when the state is entered and the ``condition`` is ``TRUE``.
         */
        events?: pulumi.Input<pulumi.Input<inputs.iotevents.DetectorModelEventArgs>[]>;
    }
    /**
     * When exiting this state, perform these ``actions`` if the specified ``condition`` is ``TRUE``.
     */
    interface DetectorModelOnExitArgs {
        /**
         * Specifies the ``actions`` that are performed when the state is exited and the ``condition`` is ``TRUE``.
         */
        events?: pulumi.Input<pulumi.Input<inputs.iotevents.DetectorModelEventArgs>[]>;
    }
    /**
     * Specifies the actions performed when the ``condition`` evaluates to TRUE.
     */
    interface DetectorModelOnInputArgs {
        /**
         * Specifies the actions performed when the ``condition`` evaluates to TRUE.
         */
        events?: pulumi.Input<pulumi.Input<inputs.iotevents.DetectorModelEventArgs>[]>;
        /**
         * Specifies the actions performed, and the next state entered, when a ``condition`` evaluates to TRUE.
         */
        transitionEvents?: pulumi.Input<pulumi.Input<inputs.iotevents.DetectorModelTransitionEventArgs>[]>;
    }
    /**
     * Information needed to configure the payload.
     *  By default, ITE generates a standard payload in JSON for any action. This action payload contains all attribute-value pairs that have the information about the detector model instance and the event triggered the action. To configure the action payload, you can use ``contentExpression``.
     */
    interface DetectorModelPayloadArgs {
        /**
         * The content of the payload. You can use a string expression that includes quoted strings (``'<string>'``), variables (``$variable.<variable-name>``), input values (``$input.<input-name>.<path-to-datum>``), string concatenations, and quoted strings that contain ``${}`` as the content. The recommended maximum size of a content expression is 1 KB.
         */
        contentExpression: pulumi.Input<string>;
        /**
         * The value of the payload type can be either ``STRING`` or ``JSON``.
         */
        type: pulumi.Input<string>;
    }
    /**
     * Information required to reset the timer. The timer is reset to the previously evaluated result of the duration. The duration expression isn't reevaluated when you reset the timer.
     */
    interface DetectorModelResetTimerArgs {
        /**
         * The name of the timer to reset.
         */
        timerName: pulumi.Input<string>;
    }
    /**
     * Information needed to set the timer.
     */
    interface DetectorModelSetTimerArgs {
        /**
         * The duration of the timer, in seconds. You can use a string expression that includes numbers, variables (``$variable.<variable-name>``), and input values (``$input.<input-name>.<path-to-datum>``) as the duration. The range of the duration is 1-31622400 seconds. To ensure accuracy, the minimum duration is 60 seconds. The evaluated result of the duration is rounded down to the nearest whole number.
         */
        durationExpression?: pulumi.Input<string>;
        /**
         * The number of seconds until the timer expires. The minimum value is 60 seconds to ensure accuracy. The maximum value is 31622400 seconds.
         */
        seconds?: pulumi.Input<number>;
        /**
         * The name of the timer.
         */
        timerName: pulumi.Input<string>;
    }
    /**
     * Information about the variable and its new value.
     */
    interface DetectorModelSetVariableArgs {
        /**
         * The new value of the variable.
         */
        value: pulumi.Input<string>;
        /**
         * The name of the variable.
         */
        variableName: pulumi.Input<string>;
    }
    /**
     * Information required to publish the Amazon SNS message.
     */
    interface DetectorModelSnsArgs {
        /**
         * You can configure the action payload when you send a message as an Amazon SNS push notification.
         */
        payload?: pulumi.Input<inputs.iotevents.DetectorModelPayloadArgs>;
        /**
         * The ARN of the Amazon SNS target where the message is sent.
         */
        targetArn: pulumi.Input<string>;
    }
    /**
     * Sends information about the detector model instance and the event that triggered the action to an Amazon SQS queue.
     */
    interface DetectorModelSqsArgs {
        /**
         * You can configure the action payload when you send a message to an Amazon SQS queue.
         */
        payload?: pulumi.Input<inputs.iotevents.DetectorModelPayloadArgs>;
        /**
         * The URL of the SQS queue where the data is written.
         */
        queueUrl: pulumi.Input<string>;
        /**
         * Set this to TRUE if you want the data to be base-64 encoded before it is written to the queue. Otherwise, set this to FALSE.
         */
        useBase64?: pulumi.Input<boolean>;
    }
    /**
     * Information that defines a state of a detector.
     */
    interface DetectorModelStateArgs {
        /**
         * When entering this state, perform these ``actions`` if the ``condition`` is TRUE.
         */
        onEnter?: pulumi.Input<inputs.iotevents.DetectorModelOnEnterArgs>;
        /**
         * When exiting this state, perform these ``actions`` if the specified ``condition`` is ``TRUE``.
         */
        onExit?: pulumi.Input<inputs.iotevents.DetectorModelOnExitArgs>;
        /**
         * When an input is received and the ``condition`` is TRUE, perform the specified ``actions``.
         */
        onInput?: pulumi.Input<inputs.iotevents.DetectorModelOnInputArgs>;
        /**
         * The name of the state.
         */
        stateName: pulumi.Input<string>;
    }
    /**
     * Specifies the actions performed and the next state entered when a ``condition`` evaluates to TRUE.
     */
    interface DetectorModelTransitionEventArgs {
        /**
         * The actions to be performed.
         */
        actions?: pulumi.Input<pulumi.Input<inputs.iotevents.DetectorModelActionArgs>[]>;
        /**
         * Required. A Boolean expression that when TRUE causes the actions to be performed and the ``nextState`` to be entered.
         */
        condition: pulumi.Input<string>;
        /**
         * The name of the transition event.
         */
        eventName: pulumi.Input<string>;
        /**
         * The next state to enter.
         */
        nextState: pulumi.Input<string>;
    }
    /**
     * The attributes from the JSON payload that are made available by the input. Inputs are derived from messages sent to the ITE system using ``BatchPutMessage``. Each such message contains a JSON payload. Those attributes (and their paired values) specified here are available for use in the ``condition`` expressions used by detectors.
     */
    interface InputAttributeArgs {
        /**
         * An expression that specifies an attribute-value pair in a JSON structure. Use this to specify an attribute from the JSON payload that is made available by the input. Inputs are derived from messages sent to ITE (``BatchPutMessage``). Each such message contains a JSON payload. The attribute (and its paired value) specified here are available for use in the ``condition`` expressions used by detectors.
         *  Syntax: ``<field-name>.<field-name>...``
         */
        jsonPath: pulumi.Input<string>;
    }
    /**
     * The definition of the input.
     */
    interface InputDefinitionArgs {
        /**
         * The attributes from the JSON payload that are made available by the input. Inputs are derived from messages sent to the ITE system using ``BatchPutMessage``. Each such message contains a JSON payload, and those attributes (and their paired values) specified here are available for use in the ``condition`` expressions used by detectors that monitor this input.
         */
        attributes: pulumi.Input<pulumi.Input<inputs.iotevents.InputAttributeArgs>[]>;
    }
}
export declare namespace iotfleethub {
}
export declare namespace iotsitewise {
    /**
     * Contains information for an IAM role identity in an access policy.
     */
    interface AccessPolicyIamRoleArgs {
        /**
         * The ARN of the IAM role.
         */
        arn?: pulumi.Input<string>;
    }
    /**
     * Contains information for an IAM user identity in an access policy.
     */
    interface AccessPolicyIamUserArgs {
        /**
         * The ARN of the IAM user.
         */
        arn?: pulumi.Input<string>;
    }
    /**
     * The identity for this access policy. Choose either an SSO user or group or an IAM user or role.
     */
    interface AccessPolicyIdentityArgs {
        /**
         * An IAM role identity.
         */
        iamRole?: pulumi.Input<inputs.iotsitewise.AccessPolicyIamRoleArgs>;
        /**
         * An IAM user identity.
         */
        iamUser?: pulumi.Input<inputs.iotsitewise.AccessPolicyIamUserArgs>;
        /**
         * An IAM Identity Center user identity.
         */
        user?: pulumi.Input<inputs.iotsitewise.AccessPolicyUserArgs>;
    }
    /**
     * A portal resource.
     */
    interface AccessPolicyPortalArgs {
        /**
         * The ID of the portal.
         */
        id?: pulumi.Input<string>;
    }
    /**
     * A project resource.
     */
    interface AccessPolicyProjectArgs {
        /**
         * The ID of the project.
         */
        id?: pulumi.Input<string>;
    }
    /**
     * The AWS IoT SiteWise Monitor resource for this access policy. Choose either portal or project but not both.
     */
    interface AccessPolicyResourceArgs {
        /**
         * Identifies an AWS IoT SiteWise Monitor portal.
         */
        portal?: pulumi.Input<inputs.iotsitewise.AccessPolicyPortalArgs>;
        /**
         * Identifies a specific AWS IoT SiteWise Monitor project.
         */
        project?: pulumi.Input<inputs.iotsitewise.AccessPolicyProjectArgs>;
    }
    /**
     * Contains information for a user identity in an access policy.
     */
    interface AccessPolicyUserArgs {
        /**
         * The AWS SSO ID of the user.
         */
        id?: pulumi.Input<string>;
    }
    /**
     * Contains the configuration information of an alarm created in an AWS IoT SiteWise Monitor portal. You can use the alarm to monitor an asset property and get notified when the asset property value is outside a specified range.
     */
    interface AlarmsPropertiesArgs {
        /**
         * The ARN of the IAM role that allows the alarm to perform actions and access AWS resources and services, such as AWS IoT Events.
         */
        alarmRoleArn?: pulumi.Input<string>;
        /**
         * The ARN of the AWS Lambda function that manages alarm notifications. For more information, see Managing alarm notifications in the AWS IoT Events Developer Guide.
         */
        notificationLambdaArn?: pulumi.Input<string>;
    }
    /**
     * A hierarchy specifies allowed parent/child asset relationships.
     */
    interface AssetHierarchyArgs {
        /**
         * The ID of the child asset to be associated.
         */
        childAssetId: pulumi.Input<string>;
        /**
         * String-friendly customer provided external ID
         */
        externalId?: pulumi.Input<string>;
        /**
         * Customer provided actual UUID for property
         */
        id?: pulumi.Input<string>;
        /**
         * The LogicalID of a hierarchy in the parent asset's model.
         */
        logicalId?: pulumi.Input<string>;
    }
    interface AssetModelAttributeArgs {
        /**
         * The default value of the asset model property attribute. All assets that you create from the asset model contain this attribute value. You can update an attribute's value after you create an asset. For more information, see [Updating attribute values](https://docs.aws.amazon.com/iot-sitewise/latest/userguide/update-attribute-values.html) in the *AWS IoT SiteWise User Guide* .
         */
        defaultValue?: pulumi.Input<string>;
    }
    /**
     * Contains a composite model definition in an asset model. This composite model definition is applied to all assets created from the asset model.
     */
    interface AssetModelCompositeModelArgs {
        /**
         * The component model ID for which the composite model is composed of
         */
        composedAssetModelId?: pulumi.Input<string>;
        /**
         * The property definitions of the asset model. You can specify up to 200 properties per asset model.
         */
        compositeModelProperties?: pulumi.Input<pulumi.Input<inputs.iotsitewise.AssetModelPropertyArgs>[]>;
        /**
         * A description for the asset composite model.
         */
        description?: pulumi.Input<string>;
        /**
         * The External ID of the composite model
         */
        externalId?: pulumi.Input<string>;
        /**
         * The Actual ID of the composite model
         */
        id?: pulumi.Input<string>;
        /**
         * A unique, friendly name for the asset composite model.
         */
        name: pulumi.Input<string>;
        /**
         * The parent composite model External ID
         */
        parentAssetModelCompositeModelExternalId?: pulumi.Input<string>;
        /**
         * The path of the composite model. This is only for derived composite models
         */
        path?: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * The type of the composite model. For alarm composite models, this type is AWS/ALARM
         */
        type: pulumi.Input<string>;
    }
    interface AssetModelExpressionVariableArgs {
        /**
         * The friendly name of the variable to be used in the expression.
         */
        name: pulumi.Input<string>;
        /**
         * The variable that identifies an asset property from which to use values.
         */
        value: pulumi.Input<inputs.iotsitewise.AssetModelVariableValueArgs>;
    }
    /**
     * Contains information about an asset model hierarchy.
     */
    interface AssetModelHierarchyArgs {
        /**
         * The ID of the asset model. All assets in this hierarchy must be instances of the child AssetModelId asset model.
         */
        childAssetModelId: pulumi.Input<string>;
        /**
         * Customer provided external ID for hierarchy
         */
        externalId?: pulumi.Input<string>;
        /**
         * Customer provided actual ID for hierarchy
         */
        id?: pulumi.Input<string>;
        /**
         * Customer provided logical ID for hierarchy.
         */
        logicalId?: pulumi.Input<string>;
        /**
         * The name of the asset model hierarchy.
         */
        name: pulumi.Input<string>;
    }
    interface AssetModelMetricArgs {
        /**
         * The mathematical expression that defines the metric aggregation function. You can specify up to 10 functions per expression.
         */
        expression: pulumi.Input<string>;
        /**
         * The list of variables used in the expression.
         */
        variables: pulumi.Input<pulumi.Input<inputs.iotsitewise.AssetModelExpressionVariableArgs>[]>;
        /**
         * The window (time interval) over which AWS IoT SiteWise computes the metric's aggregation expression
         */
        window: pulumi.Input<inputs.iotsitewise.AssetModelMetricWindowArgs>;
    }
    /**
     * Contains a time interval window used for data aggregate computations (for example, average, sum, count, and so on).
     */
    interface AssetModelMetricWindowArgs {
        /**
         * The tumbling time interval window.
         */
        tumbling?: pulumi.Input<inputs.iotsitewise.AssetModelTumblingWindowArgs>;
    }
    /**
     * Contains information about an asset model property.
     */
    interface AssetModelPropertyArgs {
        /**
         * The data type of the asset model property.
         */
        dataType: pulumi.Input<enums.iotsitewise.AssetModelDataType>;
        /**
         * The data type of the structure for this property.
         */
        dataTypeSpec?: pulumi.Input<enums.iotsitewise.AssetModelDataTypeSpec>;
        /**
         * The External ID of the Asset Model Property
         */
        externalId?: pulumi.Input<string>;
        /**
         * The ID of the Asset Model Property
         */
        id?: pulumi.Input<string>;
        /**
         * Customer provided Logical ID for property.
         */
        logicalId?: pulumi.Input<string>;
        /**
         * The name of the asset model property.
         */
        name: pulumi.Input<string>;
        /**
         * The property type
         */
        type: pulumi.Input<inputs.iotsitewise.AssetModelPropertyTypeArgs>;
        /**
         * The unit of the asset model property, such as Newtons or RPM.
         */
        unit?: pulumi.Input<string>;
    }
    /**
     * The definition for property path which is used to reference properties in transforms/metrics
     */
    interface AssetModelPropertyPathDefinitionArgs {
        /**
         * The name of the property
         */
        name: pulumi.Input<string>;
    }
    /**
     * Contains a property type, which can be one of attribute, measurement, metric, or transform.
     */
    interface AssetModelPropertyTypeArgs {
        /**
         * Specifies an asset attribute property. An attribute generally contains static information, such as the serial number of an [IIoT](https://docs.aws.amazon.com/https://en.wikipedia.org/wiki/Internet_of_things#Industrial_applications) wind turbine.
         */
        attribute?: pulumi.Input<inputs.iotsitewise.AssetModelAttributeArgs>;
        /**
         * Specifies an asset metric property. A metric contains a mathematical expression that uses aggregate functions to process all input data points over a time interval and output a single data point, such as to calculate the average hourly temperature.
         */
        metric?: pulumi.Input<inputs.iotsitewise.AssetModelMetricArgs>;
        /**
         * Specifies an asset transform property. A transform contains a mathematical expression that maps a property's data points from one form to another, such as a unit conversion from Celsius to Fahrenheit.
         */
        transform?: pulumi.Input<inputs.iotsitewise.AssetModelTransformArgs>;
        /**
         * The type of property type, which can be one of `Attribute` , `Measurement` , `Metric` , or `Transform` .
         */
        typeName: pulumi.Input<enums.iotsitewise.AssetModelTypeName>;
    }
    interface AssetModelTransformArgs {
        /**
         * The mathematical expression that defines the transformation function. You can specify up to 10 functions per expression.
         */
        expression: pulumi.Input<string>;
        /**
         * The list of variables used in the expression.
         */
        variables: pulumi.Input<pulumi.Input<inputs.iotsitewise.AssetModelExpressionVariableArgs>[]>;
    }
    /**
     * Contains a tumbling window, which is a repeating fixed-sized, non-overlapping, and contiguous time interval. This window is used in metric and aggregation computations.
     */
    interface AssetModelTumblingWindowArgs {
        /**
         * The time interval for the tumbling window. The interval time must be between 1 minute and 1 week.
         *
         * AWS IoT SiteWise computes the `1w` interval the end of Sunday at midnight each week (UTC), the `1d` interval at the end of each day at midnight (UTC), the `1h` interval at the end of each hour, and so on.
         *
         * When AWS IoT SiteWise aggregates data points for metric computations, the start of each interval is exclusive and the end of each interval is inclusive. AWS IoT SiteWise places the computed data point at the end of the interval.
         */
        interval: pulumi.Input<string>;
        /**
         * The offset for the tumbling window. The `offset` parameter accepts the following:
         *
         * - The offset time.
         *
         * For example, if you specify `18h` for `offset` and `1d` for `interval` , AWS IoT SiteWise aggregates data in one of the following ways:
         *
         * - If you create the metric before or at 6 PM (UTC), you get the first aggregation result at 6 PM (UTC) on the day when you create the metric.
         * - If you create the metric after 6 PM (UTC), you get the first aggregation result at 6 PM (UTC) the next day.
         * - The ISO 8601 format.
         *
         * For example, if you specify `PT18H` for `offset` and `1d` for `interval` , AWS IoT SiteWise aggregates data in one of the following ways:
         *
         * - If you create the metric before or at 6 PM (UTC), you get the first aggregation result at 6 PM (UTC) on the day when you create the metric.
         * - If you create the metric after 6 PM (UTC), you get the first aggregation result at 6 PM (UTC) the next day.
         * - The 24-hour clock.
         *
         * For example, if you specify `00:03:00` for `offset` , `5m` for `interval` , and you create the metric at 2 PM (UTC), you get the first aggregation result at 2:03 PM (UTC). You get the second aggregation result at 2:08 PM (UTC).
         * - The offset time zone.
         *
         * For example, if you specify `2021-07-23T18:00-08` for `offset` and `1d` for `interval` , AWS IoT SiteWise aggregates data in one of the following ways:
         *
         * - If you create the metric before or at 6 PM (PST), you get the first aggregation result at 6 PM (PST) on the day when you create the metric.
         * - If you create the metric after 6 PM (PST), you get the first aggregation result at 6 PM (PST) the next day.
         */
        offset?: pulumi.Input<string>;
    }
    interface AssetModelVariableValueArgs {
        /**
         * The External ID of the hierarchy that is trying to be referenced
         */
        hierarchyExternalId?: pulumi.Input<string>;
        /**
         * The ID of the hierarchy that is trying to be referenced
         */
        hierarchyId?: pulumi.Input<string>;
        /**
         * The `LogicalID` of the hierarchy to query for the `PropertyLogicalID` .
         *
         * You use a `hierarchyLogicalID` instead of a model ID because you can have several hierarchies using the same model and therefore the same property. For example, you might have separately grouped assets that come from the same asset model. For more information, see [Defining relationships between asset models (hierarchies)](https://docs.aws.amazon.com/iot-sitewise/latest/userguide/asset-hierarchies.html) in the *AWS IoT SiteWise User Guide* .
         */
        hierarchyLogicalId?: pulumi.Input<string>;
        /**
         * The External ID of the property that is trying to be referenced
         */
        propertyExternalId?: pulumi.Input<string>;
        /**
         * The ID of the property that is trying to be referenced
         */
        propertyId?: pulumi.Input<string>;
        /**
         * The `LogicalID` of the property that is being referenced.
         */
        propertyLogicalId?: pulumi.Input<string>;
        /**
         * The path of the property that is trying to be referenced
         */
        propertyPath?: pulumi.Input<pulumi.Input<inputs.iotsitewise.AssetModelPropertyPathDefinitionArgs>[]>;
    }
    /**
     * The asset property's definition, alias, unit, and notification state.
     */
    interface AssetPropertyArgs {
        /**
         * The property alias that identifies the property.
         */
        alias?: pulumi.Input<string>;
        /**
         * String-friendly customer provided external ID
         */
        externalId?: pulumi.Input<string>;
        /**
         * Customer provided actual UUID for property
         */
        id?: pulumi.Input<string>;
        /**
         * Customer provided ID for property.
         */
        logicalId?: pulumi.Input<string>;
        /**
         * The MQTT notification state (ENABLED or DISABLED) for this asset property.
         */
        notificationState?: pulumi.Input<enums.iotsitewise.AssetPropertyNotificationState>;
        /**
         * The unit of measure (such as Newtons or RPM) of the asset property. If you don't specify a value for this parameter, the service uses the value of the assetModelProperty in the asset model.
         */
        unit?: pulumi.Input<string>;
    }
    interface DatasetKendraSourceDetailArgs {
        /**
         * The knowledgeBaseArn details for the Kendra dataset source.
         */
        knowledgeBaseArn: pulumi.Input<string>;
        /**
         * The roleARN details for the Kendra dataset source.
         */
        roleArn: pulumi.Input<string>;
    }
    interface DatasetSourceArgs {
        /**
         * The details of the dataset source associated with the dataset.
         */
        sourceDetail?: pulumi.Input<inputs.iotsitewise.DatasetSourceDetailArgs>;
        /**
         * The format of the dataset source associated with the dataset.
         */
        sourceFormat: pulumi.Input<enums.iotsitewise.DatasetSourceSourceFormat>;
        /**
         * The type of data source for the dataset.
         */
        sourceType: pulumi.Input<enums.iotsitewise.DatasetSourceSourceType>;
    }
    interface DatasetSourceDetailArgs {
        /**
         * Contains details about the Kendra dataset source.
         */
        kendra?: pulumi.Input<inputs.iotsitewise.DatasetKendraSourceDetailArgs>;
    }
    /**
     * Contains a summary of a gateway capability configuration.
     */
    interface GatewayCapabilitySummaryArgs {
        /**
         * The JSON document that defines the configuration for the gateway capability. For more information, see [Configuring data sources (CLI)](https://docs.aws.amazon.com/iot-sitewise/latest/userguide/configure-sources.html#configure-source-cli) in the *AWS IoT SiteWise User Guide* .
         */
        capabilityConfiguration?: pulumi.Input<string>;
        /**
         * The namespace of the capability configuration. For example, if you configure OPC-UA sources from the AWS IoT SiteWise console, your OPC-UA capability configuration has the namespace `iotsitewise:opcuacollector:version` , where `version` is a number such as `1` .
         */
        capabilityNamespace: pulumi.Input<string>;
    }
    /**
     * Contains the CoreDeviceThingName of AWS IoT Greengrass Group V2 that the gateway runs on.
     */
    interface GatewayGreengrassV2Args {
        /**
         * The operating system of the core device in AWS IoT Greengrass V2.
         */
        coreDeviceOperatingSystem?: pulumi.Input<enums.iotsitewise.GatewayGreengrassV2CoreDeviceOperatingSystem>;
        /**
         * The name of the CoreDevice in GreenGrass V2.
         */
        coreDeviceThingName: pulumi.Input<string>;
    }
    /**
     * Contains a gateway's platform information.
     */
    interface GatewayPlatformArgs {
        /**
         * A gateway that runs on AWS IoT Greengrass V2.
         */
        greengrassV2?: pulumi.Input<inputs.iotsitewise.GatewayGreengrassV2Args>;
        /**
         * A gateway that runs on Siemens Industrial Edge.
         */
        siemensIe?: pulumi.Input<inputs.iotsitewise.GatewaySiemensIeArgs>;
    }
    /**
     * Contains the IotCoreThingName of AWS IoT Thing that the gateway runs on.
     */
    interface GatewaySiemensIeArgs {
        /**
         * The name of the IoT Core Thing.
         */
        iotCoreThingName: pulumi.Input<string>;
    }
    /**
     * Container associated a certain PortalType.
     */
    interface PortalTypeEntryArgs {
        /**
         * The array of tools associated with the specified portal type. The possible values are `ASSISTANT` and `DASHBOARD` .
         */
        portalTools: pulumi.Input<pulumi.Input<string>[]>;
    }
}
export declare namespace iottwinmaker {
    /**
     * An object that sets information about a composite component type.
     */
    interface ComponentTypeCompositeComponentTypeArgs {
        /**
         * The id of the composite component type.
         */
        componentTypeId?: pulumi.Input<string>;
    }
    /**
     * The data connector.
     */
    interface ComponentTypeDataConnectorArgs {
        /**
         * A Boolean value that specifies whether the data connector is native to IoT TwinMaker.
         */
        isNative?: pulumi.Input<boolean>;
        /**
         * The Lambda function associated with this data connector.
         */
        lambda?: pulumi.Input<inputs.iottwinmaker.ComponentTypeLambdaFunctionArgs>;
    }
    /**
     * An object that specifies the data type of a property.
     */
    interface ComponentTypeDataTypeArgs {
        /**
         * The allowed values for this data type.
         */
        allowedValues?: pulumi.Input<pulumi.Input<inputs.iottwinmaker.ComponentTypeDataValueArgs>[]>;
        /**
         * The nested type in the data type.
         */
        nestedType?: pulumi.Input<inputs.iottwinmaker.ComponentTypeDataTypeArgs>;
        /**
         * A relationship that associates a component with another component.
         */
        relationship?: pulumi.Input<inputs.iottwinmaker.ComponentTypeRelationshipArgs>;
        /**
         * The underlying type of the data type.
         */
        type: pulumi.Input<enums.iottwinmaker.ComponentTypeDataTypeType>;
        /**
         * The unit of measure used in this data type.
         */
        unitOfMeasure?: pulumi.Input<string>;
    }
    /**
     * An object that specifies a value for a property.
     */
    interface ComponentTypeDataValueArgs {
        /**
         * A Boolean value.
         */
        booleanValue?: pulumi.Input<boolean>;
        /**
         * A double value.
         */
        doubleValue?: pulumi.Input<number>;
        /**
         * An expression that produces the value.
         */
        expression?: pulumi.Input<string>;
        /**
         * An integer value.
         */
        integerValue?: pulumi.Input<number>;
        /**
         * A list of multiple values.
         */
        listValue?: pulumi.Input<pulumi.Input<inputs.iottwinmaker.ComponentTypeDataValueArgs>[]>;
        /**
         * A long value.
         */
        longValue?: pulumi.Input<number>;
        /**
         * An object that maps strings to multiple DataValue objects.
         */
        mapValue?: pulumi.Input<{
            [key: string]: pulumi.Input<inputs.iottwinmaker.ComponentTypeDataValueArgs>;
        }>;
        /**
         * A value that relates a component to another component.
         */
        relationshipValue?: pulumi.Input<inputs.iottwinmaker.ComponentTypeDataValueRelationshipValuePropertiesArgs>;
        /**
         * A string value.
         */
        stringValue?: pulumi.Input<string>;
    }
    /**
     * A value that relates a component to another component.
     */
    interface ComponentTypeDataValueRelationshipValuePropertiesArgs {
        targetComponentName?: pulumi.Input<string>;
        targetEntityId?: pulumi.Input<string>;
    }
    /**
     * The function of component type.
     */
    interface ComponentTypeFunctionArgs {
        /**
         * The data connector.
         */
        implementedBy?: pulumi.Input<inputs.iottwinmaker.ComponentTypeDataConnectorArgs>;
        /**
         * The required properties of the function.
         */
        requiredProperties?: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * The scope of the function.
         */
        scope?: pulumi.Input<enums.iottwinmaker.ComponentTypeFunctionScope>;
    }
    interface ComponentTypeLambdaFunctionArgs {
        arn: pulumi.Input<string>;
    }
    /**
     * An object that sets information about a property.
     */
    interface ComponentTypePropertyDefinitionArgs {
        /**
         * An object that specifies information about a property.
         */
        configurations?: pulumi.Input<{
            [key: string]: pulumi.Input<string>;
        }>;
        /**
         * An object that contains information about the data type.
         */
        dataType?: pulumi.Input<inputs.iottwinmaker.ComponentTypeDataTypeArgs>;
        /**
         * An object that contains the default value.
         */
        defaultValue?: pulumi.Input<inputs.iottwinmaker.ComponentTypeDataValueArgs>;
        /**
         * A Boolean value that specifies whether the property ID comes from an external data store.
         */
        isExternalId?: pulumi.Input<boolean>;
        /**
         * A Boolean value that specifies whether the property is required.
         */
        isRequiredInEntity?: pulumi.Input<boolean>;
        /**
         * A Boolean value that specifies whether the property is stored externally.
         */
        isStoredExternally?: pulumi.Input<boolean>;
        /**
         * A Boolean value that specifies whether the property consists of time series data.
         */
        isTimeSeries?: pulumi.Input<boolean>;
    }
    /**
     * An object that sets information about a property group.
     */
    interface ComponentTypePropertyGroupArgs {
        /**
         * The type of property group.
         */
        groupType?: pulumi.Input<enums.iottwinmaker.ComponentTypePropertyGroupGroupType>;
        /**
         * The list of property names in the property group.
         */
        propertyNames?: pulumi.Input<pulumi.Input<string>[]>;
    }
    /**
     * The type of the relationship.
     */
    interface ComponentTypeRelationshipArgs {
        /**
         * The type of the relationship.
         */
        relationshipType?: pulumi.Input<string>;
        /**
         * The ID of the target component type associated with this relationship.
         */
        targetComponentTypeId?: pulumi.Input<string>;
    }
    interface EntityComponentArgs {
        /**
         * The name of the component.
         */
        componentName?: pulumi.Input<string>;
        /**
         * The ID of the component type.
         */
        componentTypeId?: pulumi.Input<string>;
        /**
         * The name of the property definition set in the component.
         */
        definedIn?: pulumi.Input<string>;
        /**
         * The description of the component.
         */
        description?: pulumi.Input<string>;
        /**
         * An object that maps strings to the properties to set in the component type. Each string in the mapping must be unique to this object.
         */
        properties?: pulumi.Input<{
            [key: string]: pulumi.Input<inputs.iottwinmaker.EntityPropertyArgs>;
        }>;
        /**
         * An object that maps strings to the property groups to set in the component type. Each string in the mapping must be unique to this object.
         */
        propertyGroups?: pulumi.Input<{
            [key: string]: pulumi.Input<inputs.iottwinmaker.EntityPropertyGroupArgs>;
        }>;
        /**
         * The current status of the entity.
         */
        status?: pulumi.Input<inputs.iottwinmaker.EntityStatusArgs>;
    }
    interface EntityCompositeComponentArgs {
        /**
         * The name of the component.
         */
        componentName?: pulumi.Input<string>;
        /**
         * The path of the component.
         */
        componentPath?: pulumi.Input<string>;
        /**
         * The ID of the component type.
         */
        componentTypeId?: pulumi.Input<string>;
        /**
         * The description of the component.
         */
        description?: pulumi.Input<string>;
        /**
         * An object that maps strings to the properties to set in the component type. Each string in the mapping must be unique to this object.
         */
        properties?: pulumi.Input<{
            [key: string]: pulumi.Input<inputs.iottwinmaker.EntityPropertyArgs>;
        }>;
        /**
         * An object that maps strings to the property groups to set in the component type. Each string in the mapping must be unique to this object.
         */
        propertyGroups?: pulumi.Input<{
            [key: string]: pulumi.Input<inputs.iottwinmaker.EntityPropertyGroupArgs>;
        }>;
        /**
         * The current status of the component.
         */
        status?: pulumi.Input<inputs.iottwinmaker.EntityStatusArgs>;
    }
    /**
     * An object that specifies the data type of a property.
     */
    interface EntityDataTypeArgs {
        /**
         * The allowed values for this data type.
         */
        allowedValues?: pulumi.Input<pulumi.Input<inputs.iottwinmaker.EntityDataValueArgs>[]>;
        /**
         * The nested type in the data type.
         */
        nestedType?: pulumi.Input<inputs.iottwinmaker.EntityDataTypeArgs>;
        /**
         * A relationship that associates a component with another component.
         */
        relationship?: pulumi.Input<inputs.iottwinmaker.EntityRelationshipArgs>;
        /**
         * The underlying type of the data type.
         */
        type?: pulumi.Input<enums.iottwinmaker.EntityDataTypeType>;
        /**
         * The unit of measure used in this data type.
         */
        unitOfMeasure?: pulumi.Input<string>;
    }
    /**
     * An object that specifies a value for a property.
     */
    interface EntityDataValueArgs {
        /**
         * A Boolean value.
         */
        booleanValue?: pulumi.Input<boolean>;
        /**
         * A double value.
         */
        doubleValue?: pulumi.Input<number>;
        /**
         * An expression that produces the value.
         */
        expression?: pulumi.Input<string>;
        /**
         * An integer value.
         */
        integerValue?: pulumi.Input<number>;
        /**
         * A list of multiple values.
         */
        listValue?: pulumi.Input<pulumi.Input<inputs.iottwinmaker.EntityDataValueArgs>[]>;
        /**
         * A long value.
         */
        longValue?: pulumi.Input<number>;
        /**
         * An object that maps strings to multiple DataValue objects.
         */
        mapValue?: pulumi.Input<{
            [key: string]: pulumi.Input<inputs.iottwinmaker.EntityDataValueArgs>;
        }>;
        /**
         * A value that relates a component to another component.
         */
        relationshipValue?: pulumi.Input<inputs.iottwinmaker.EntityDataValueRelationshipValuePropertiesArgs>;
        /**
         * A string value.
         */
        stringValue?: pulumi.Input<string>;
    }
    /**
     * A value that relates a component to another component.
     */
    interface EntityDataValueRelationshipValuePropertiesArgs {
        targetComponentName?: pulumi.Input<string>;
        targetEntityId?: pulumi.Input<string>;
    }
    /**
     * An object that specifies information about a property definition.
     */
    interface EntityDefinitionArgs {
        /**
         * An object that specifies information about a property configuration.
         */
        configuration?: pulumi.Input<{
            [key: string]: pulumi.Input<string>;
        }>;
        /**
         * An object that contains information about the data type.
         */
        dataType?: pulumi.Input<inputs.iottwinmaker.EntityDataTypeArgs>;
        /**
         * An object that contains the default value.
         */
        defaultValue?: pulumi.Input<inputs.iottwinmaker.EntityDataValueArgs>;
        /**
         * A Boolean value that specifies whether the property ID comes from an external data store.
         */
        isExternalId?: pulumi.Input<boolean>;
        /**
         * A Boolean value that specifies whether the property definition can be updated.
         */
        isFinal?: pulumi.Input<boolean>;
        /**
         * A Boolean value that specifies whether the property definition is imported from an external data store.
         */
        isImported?: pulumi.Input<boolean>;
        /**
         * A Boolean value that specifies whether the property definition is inherited from a parent entity.
         */
        isInherited?: pulumi.Input<boolean>;
        /**
         * A Boolean value that specifies whether the property is required.
         */
        isRequiredInEntity?: pulumi.Input<boolean>;
        /**
         * A Boolean value that specifies whether the property is stored externally.
         */
        isStoredExternally?: pulumi.Input<boolean>;
        /**
         * A Boolean value that specifies whether the property consists of time series data.
         */
        isTimeSeries?: pulumi.Input<boolean>;
    }
    /**
     * An object that specifies information about a property.
     */
    interface EntityPropertyArgs {
        /**
         * The definition of the property.
         */
        definition?: pulumi.Input<inputs.iottwinmaker.EntityDefinitionArgs>;
        /**
         * The value of the property.
         */
        value?: pulumi.Input<inputs.iottwinmaker.EntityDataValueArgs>;
    }
    /**
     * An object that specifies information about a property group.
     */
    interface EntityPropertyGroupArgs {
        /**
         * The type of property group.
         */
        groupType?: pulumi.Input<enums.iottwinmaker.EntityPropertyGroupGroupType>;
        /**
         * The list of property names in the property group.
         */
        propertyNames?: pulumi.Input<pulumi.Input<string>[]>;
    }
    /**
     * The type of the relationship.
     */
    interface EntityRelationshipArgs {
        /**
         * The type of the relationship.
         */
        relationshipType?: pulumi.Input<string>;
        /**
         * The ID of the target component type associated with this relationship.
         */
        targetComponentTypeId?: pulumi.Input<string>;
    }
    interface EntityStatusArgs {
        error?: pulumi.Input<any | inputs.iottwinmaker.EntityStatusErrorPropertiesArgs>;
        state?: pulumi.Input<enums.iottwinmaker.EntityStatusState>;
    }
    /**
     * Error object with Message and Code.
     */
    interface EntityStatusErrorPropertiesArgs {
        code?: pulumi.Input<enums.iottwinmaker.EntityStatusErrorPropertiesCode>;
        message?: pulumi.Input<string>;
    }
}
export declare namespace iotwireless {
    interface DeviceProfileLoRaWanDeviceProfileArgs {
        /**
         * The ClassBTimeout value.
         */
        classBTimeout?: pulumi.Input<number>;
        /**
         * The ClassCTimeout value.
         */
        classCTimeout?: pulumi.Input<number>;
        /**
         * The list of values that make up the FactoryPresetFreqs value. Valid range of values include a minimum value of 1000000 and a maximum value of 16700000.
         */
        factoryPresetFreqsList?: pulumi.Input<pulumi.Input<number>[]>;
        /**
         * The MAC version (such as OTAA 1.1 or OTAA 1.0.3) to use with this device profile.
         */
        macVersion?: pulumi.Input<string>;
        /**
         * The MaxDutyCycle value.
         */
        maxDutyCycle?: pulumi.Input<number>;
        /**
         * The MaxEIRP value.
         */
        maxEirp?: pulumi.Input<number>;
        /**
         * The PingSlotDR value.
         */
        pingSlotDr?: pulumi.Input<number>;
        /**
         * The PingSlotFreq value.
         */
        pingSlotFreq?: pulumi.Input<number>;
        /**
         * The PingSlotPeriod value.
         */
        pingSlotPeriod?: pulumi.Input<number>;
        /**
         * The version of regional parameters.
         */
        regParamsRevision?: pulumi.Input<string>;
        /**
         * The frequency band (RFRegion) value.
         */
        rfRegion?: pulumi.Input<string>;
        /**
         * The RXDataRate2 value.
         */
        rxDataRate2?: pulumi.Input<number>;
        /**
         * The RXDelay1 value.
         */
        rxDelay1?: pulumi.Input<number>;
        /**
         * The RXDROffset1 value.
         */
        rxDrOffset1?: pulumi.Input<number>;
        /**
         * The RXFreq2 value.
         */
        rxFreq2?: pulumi.Input<number>;
        /**
         * The Supports32BitFCnt value.
         */
        supports32BitFCnt?: pulumi.Input<boolean>;
        /**
         * The SupportsClassB value.
         */
        supportsClassB?: pulumi.Input<boolean>;
        /**
         * The SupportsClassC value.
         */
        supportsClassC?: pulumi.Input<boolean>;
        /**
         * The SupportsJoin value.
         */
        supportsJoin?: pulumi.Input<boolean>;
    }
    interface FuotaTaskLoRaWanArgs {
        /**
         * FUOTA task LoRaWAN RF region
         */
        rfRegion: pulumi.Input<string>;
        /**
         * FUOTA task LoRaWAN start time
         */
        startTime?: pulumi.Input<string>;
    }
    interface MulticastGroupLoRaWanArgs {
        /**
         * Multicast group LoRaWAN DL Class
         */
        dlClass: pulumi.Input<string>;
        /**
         * Multicast group number of devices in group. Returned after successful read.
         */
        numberOfDevicesInGroup?: pulumi.Input<number>;
        /**
         * Multicast group number of devices requested. Returned after successful read.
         */
        numberOfDevicesRequested?: pulumi.Input<number>;
        /**
         * Multicast group LoRaWAN RF region
         */
        rfRegion: pulumi.Input<string>;
    }
    interface ServiceProfileLoRaWanServiceProfileArgs {
        /**
         * The AddGWMetaData value.
         */
        addGwMetadata?: pulumi.Input<boolean>;
        /**
         * The ChannelMask value.
         *
         * This property is `ReadOnly` and can't be inputted for create. It's returned with `Fn::GetAtt`
         */
        channelMask?: pulumi.Input<string>;
        /**
         * The DevStatusReqFreq value.
         *
         * This property is `ReadOnly` and can't be inputted for create. It's returned with `Fn::GetAtt`
         */
        devStatusReqFreq?: pulumi.Input<number>;
        /**
         * The DLBucketSize value.
         *
         * This property is `ReadOnly` and can't be inputted for create. It's returned with `Fn::GetAtt`
         */
        dlBucketSize?: pulumi.Input<number>;
        /**
         * The DLRate value.
         *
         * This property is `ReadOnly` and can't be inputted for create. It's returned with `Fn::GetAtt`
         */
        dlRate?: pulumi.Input<number>;
        /**
         * The DLRatePolicy value.
         *
         * This property is `ReadOnly` and can't be inputted for create. It's returned with `Fn::GetAtt`
         */
        dlRatePolicy?: pulumi.Input<string>;
        /**
         * The DRMax value.
         *
         * This property is `ReadOnly` and can't be inputted for create. It's returned with `Fn::GetAtt`
         */
        drMax?: pulumi.Input<number>;
        /**
         * The DRMin value.
         *
         * This property is `ReadOnly` and can't be inputted for create. It's returned with `Fn::GetAtt`
         */
        drMin?: pulumi.Input<number>;
        /**
         * The HRAllowed value that describes whether handover roaming is allowed.
         *
         * This property is `ReadOnly` and can't be inputted for create. It's returned with `Fn::GetAtt`
         */
        hrAllowed?: pulumi.Input<boolean>;
        /**
         * The MinGwDiversity value.
         *
         * This property is `ReadOnly` and can't be inputted for create. It's returned with `Fn::GetAtt`
         */
        minGwDiversity?: pulumi.Input<number>;
        /**
         * The NwkGeoLoc value.
         *
         * This property is `ReadOnly` and can't be inputted for create. It's returned with `Fn::GetAtt`
         */
        nwkGeoLoc?: pulumi.Input<boolean>;
        /**
         * The PRAllowed value that describes whether passive roaming is allowed.
         *
         * This property is `ReadOnly` and can't be inputted for create. It's returned with `Fn::GetAtt`
         */
        prAllowed?: pulumi.Input<boolean>;
        /**
         * The RAAllowed value that describes whether roaming activation is allowed.
         */
        raAllowed?: pulumi.Input<boolean>;
        /**
         * The ReportDevStatusBattery value.
         *
         * This property is `ReadOnly` and can't be inputted for create. It's returned with `Fn::GetAtt`
         */
        reportDevStatusBattery?: pulumi.Input<boolean>;
        /**
         * The ReportDevStatusMargin value.
         *
         * This property is `ReadOnly` and can't be inputted for create. It's returned with `Fn::GetAtt`
         */
        reportDevStatusMargin?: pulumi.Input<boolean>;
        /**
         * The TargetPer value.
         *
         * This property is `ReadOnly` and can't be inputted for create. It's returned with `Fn::GetAtt`
         */
        targetPer?: pulumi.Input<number>;
        /**
         * The UlBucketSize value.
         *
         * This property is `ReadOnly` and can't be inputted for create. It's returned with `Fn::GetAtt`
         */
        ulBucketSize?: pulumi.Input<number>;
        /**
         * The ULRate value.
         *
         * This property is `ReadOnly` and can't be inputted for create. It's returned with `Fn::GetAtt`
         */
        ulRate?: pulumi.Input<number>;
        /**
         * The ULRatePolicy value.
         *
         * This property is `ReadOnly` and can't be inputted for create. It's returned with `Fn::GetAtt`
         */
        ulRatePolicy?: pulumi.Input<string>;
    }
    interface TaskDefinitionLoRaWanGatewayVersionArgs {
        /**
         * The model number of the wireless gateway.
         */
        model?: pulumi.Input<string>;
        /**
         * The version of the wireless gateway firmware.
         */
        packageVersion?: pulumi.Input<string>;
        /**
         * The basic station version of the wireless gateway.
         */
        station?: pulumi.Input<string>;
    }
    interface TaskDefinitionLoRaWanUpdateGatewayTaskCreateArgs {
        /**
         * The version of the gateways that should receive the update.
         */
        currentVersion?: pulumi.Input<inputs.iotwireless.TaskDefinitionLoRaWanGatewayVersionArgs>;
        /**
         * The CRC of the signature private key to check.
         */
        sigKeyCrc?: pulumi.Input<number>;
        /**
         * The signature used to verify the update firmware.
         */
        updateSignature?: pulumi.Input<string>;
        /**
         * The firmware version to update the gateway to.
         */
        updateVersion?: pulumi.Input<inputs.iotwireless.TaskDefinitionLoRaWanGatewayVersionArgs>;
    }
    interface TaskDefinitionLoRaWanUpdateGatewayTaskEntryArgs {
        /**
         * The version of the gateways that should receive the update.
         */
        currentVersion?: pulumi.Input<inputs.iotwireless.TaskDefinitionLoRaWanGatewayVersionArgs>;
        /**
         * The firmware version to update the gateway to.
         */
        updateVersion?: pulumi.Input<inputs.iotwireless.TaskDefinitionLoRaWanGatewayVersionArgs>;
    }
    interface TaskDefinitionUpdateWirelessGatewayTaskCreateArgs {
        /**
         * The properties that relate to the LoRaWAN wireless gateway.
         */
        loRaWan?: pulumi.Input<inputs.iotwireless.TaskDefinitionLoRaWanUpdateGatewayTaskCreateArgs>;
        /**
         * The IAM role used to read data from the S3 bucket.
         */
        updateDataRole?: pulumi.Input<string>;
        /**
         * The link to the S3 bucket.
         */
        updateDataSource?: pulumi.Input<string>;
    }
    /**
     * Trace content for your wireless gateway and wireless device resources
     */
    interface TraceContentPropertiesArgs {
        /**
         * The log level for a log message. The log levels can be disabled, or set to `ERROR` to display less verbose logs containing only error information, or to `INFO` for more detailed logs
         */
        logLevel?: pulumi.Input<enums.iotwireless.NetworkAnalyzerConfigurationLogLevel>;
        /**
         * `FrameInfo` of your wireless device resources for the trace content. Use FrameInfo to debug the communication between your LoRaWAN end devices and the network server.
         */
        wirelessDeviceFrameInfo?: pulumi.Input<enums.iotwireless.NetworkAnalyzerConfigurationWirelessDeviceFrameInfo>;
    }
    interface WirelessDeviceAbpV10xArgs {
        /**
         * The DevAddr value.
         */
        devAddr: pulumi.Input<string>;
        /**
         * Session keys for ABP v1.0.x.
         */
        sessionKeys: pulumi.Input<inputs.iotwireless.WirelessDeviceSessionKeysAbpV10xArgs>;
    }
    interface WirelessDeviceAbpV11Args {
        /**
         * The DevAddr value.
         */
        devAddr: pulumi.Input<string>;
        /**
         * Session keys for ABP v1.1.
         */
        sessionKeys: pulumi.Input<inputs.iotwireless.WirelessDeviceSessionKeysAbpV11Args>;
    }
    /**
     * LoRaWAN application configuration, which can be used to perform geolocation.
     */
    interface WirelessDeviceApplicationArgs {
        /**
         * The name of the position data destination that describes the AWS IoT rule that processes the device's position data for use by AWS IoT Core for LoRaWAN.
         */
        destinationName?: pulumi.Input<string>;
        /**
         * The Fport value.
         */
        fPort?: pulumi.Input<number>;
        /**
         * Application type, which can be specified to obtain real-time position information of your LoRaWAN device.
         */
        type?: pulumi.Input<enums.iotwireless.WirelessDeviceApplicationType>;
    }
    interface WirelessDeviceFPortsArgs {
        /**
         * A list of optional LoRaWAN application information, which can be used for geolocation.
         */
        applications?: pulumi.Input<pulumi.Input<inputs.iotwireless.WirelessDeviceApplicationArgs>[]>;
    }
    interface WirelessDeviceLoRaWanDeviceArgs {
        /**
         * ABP device object for LoRaWAN specification v1.0.x.
         */
        abpV10x?: pulumi.Input<inputs.iotwireless.WirelessDeviceAbpV10xArgs>;
        /**
         * ABP device object for create APIs for v1.1.
         */
        abpV11?: pulumi.Input<inputs.iotwireless.WirelessDeviceAbpV11Args>;
        /**
         * The DevEUI value.
         */
        devEui?: pulumi.Input<string>;
        /**
         * The ID of the device profile for the new wireless device.
         */
        deviceProfileId?: pulumi.Input<string>;
        /**
         * List of FPort assigned for different LoRaWAN application packages to use.
         */
        fPorts?: pulumi.Input<inputs.iotwireless.WirelessDeviceFPortsArgs>;
        /**
         * OTAA device object for create APIs for v1.0.x
         */
        otaaV10x?: pulumi.Input<inputs.iotwireless.WirelessDeviceOtaaV10xArgs>;
        /**
         * OTAA device object for v1.1 for create APIs.
         */
        otaaV11?: pulumi.Input<inputs.iotwireless.WirelessDeviceOtaaV11Args>;
        /**
         * The ID of the service profile.
         */
        serviceProfileId?: pulumi.Input<string>;
    }
    interface WirelessDeviceOtaaV10xArgs {
        /**
         * The AppEUI value. You specify this value when using LoRaWAN versions v1.0.2 or v1.0.3.
         */
        appEui: pulumi.Input<string>;
        /**
         * The AppKey value.
         */
        appKey: pulumi.Input<string>;
    }
    interface WirelessDeviceOtaaV11Args {
        /**
         * The AppKey is a secret key, which you should handle in a similar way as you would an application password. You can protect the AppKey value by storing it in the AWS Secrets Manager and use the [secretsmanager](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/dynamic-references.html#dynamic-references-secretsmanager) to reference this value.
         */
        appKey: pulumi.Input<string>;
        /**
         * The JoinEUI value.
         */
        joinEui: pulumi.Input<string>;
        /**
         * The NwkKey is a secret key, which you should handle in a similar way as you would an application password. You can protect the NwkKey value by storing it in the AWS Secrets Manager and use the [secretsmanager](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/dynamic-references.html#dynamic-references-secretsmanager) to reference this value.
         */
        nwkKey: pulumi.Input<string>;
    }
    interface WirelessDeviceSessionKeysAbpV10xArgs {
        /**
         * The AppSKey value.
         */
        appSKey: pulumi.Input<string>;
        /**
         * The NwkKey value.
         */
        nwkSKey: pulumi.Input<string>;
    }
    interface WirelessDeviceSessionKeysAbpV11Args {
        /**
         * The AppSKey is a secret key, which you should handle in a similar way as you would an application password. You can protect the AppSKey value by storing it in the AWS Secrets Manager and use the [secretsmanager](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/dynamic-references.html#dynamic-references-secretsmanager) to reference this value.
         */
        appSKey: pulumi.Input<string>;
        /**
         * The FNwkSIntKey is a secret key, which you should handle in a similar way as you would an application password. You can protect the FNwkSIntKey value by storing it in the AWS Secrets Manager and use the [secretsmanager](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/dynamic-references.html#dynamic-references-secretsmanager) to reference this value.
         */
        fNwkSIntKey: pulumi.Input<string>;
        /**
         * The NwkSEncKey is a secret key, which you should handle in a similar way as you would an application password. You can protect the NwkSEncKey value by storing it in the AWS Secrets Manager and use the [secretsmanager](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/dynamic-references.html#dynamic-references-secretsmanager) to reference this value.
         */
        nwkSEncKey: pulumi.Input<string>;
        /**
         * The SNwkSIntKey is a secret key, which you should handle in a similar way as you would an application password. You can protect the SNwkSIntKey value by storing it in the AWS Secrets Manager and use the [secretsmanager](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/dynamic-references.html#dynamic-references-secretsmanager) to reference this value.
         */
        sNwkSIntKey: pulumi.Input<string>;
    }
    interface WirelessGatewayLoRaWanGatewayArgs {
        /**
         * The gateway's EUI value.
         */
        gatewayEui: pulumi.Input<string>;
        /**
         * The frequency band (RFRegion) value.
         */
        rfRegion: pulumi.Input<string>;
    }
}
export declare namespace ivs {
    interface ChannelMultitrackInputConfigurationArgs {
        /**
         * Indicates whether multitrack input is enabled. Can be set to true only if channel type is STANDARD. Setting enabled to true with any other channel type will cause an exception. If true, then policy, maximumResolution, and containerFormat are required, and containerFormat must be set to FRAGMENTED_MP4. Default: false.
         */
        enabled?: pulumi.Input<boolean>;
        /**
         * Maximum resolution for multitrack input. Required if enabled is true.
         */
        maximumResolution?: pulumi.Input<enums.ivs.ChannelMultitrackInputConfigurationMaximumResolution>;
        /**
         * Indicates whether multitrack input is allowed or required. Required if enabled is true.
         */
        policy?: pulumi.Input<enums.ivs.ChannelMultitrackInputConfigurationPolicy>;
    }
    /**
     * Recording Destination Configuration.
     */
    interface RecordingConfigurationDestinationConfigurationArgs {
        /**
         * An S3 destination configuration where recorded videos will be stored. See the [S3DestinationConfiguration](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-ivs-recordingconfiguration-s3destinationconfiguration.html) property type for more information.
         */
        s3?: pulumi.Input<inputs.ivs.RecordingConfigurationS3DestinationConfigurationArgs>;
    }
    /**
     * Rendition Configuration describes which renditions should be recorded for a stream.
     */
    interface RecordingConfigurationRenditionConfigurationArgs {
        /**
         * Resolution Selection indicates which set of renditions are recorded for a stream.
         */
        renditionSelection?: pulumi.Input<enums.ivs.RecordingConfigurationRenditionConfigurationRenditionSelection>;
        /**
         * Renditions indicates which renditions are recorded for a stream.
         */
        renditions?: pulumi.Input<pulumi.Input<enums.ivs.RecordingConfigurationRenditionConfigurationRenditionsItem>[]>;
    }
    /**
     * Recording S3 Destination Configuration.
     */
    interface RecordingConfigurationS3DestinationConfigurationArgs {
        /**
         * Location (S3 bucket name) where recorded videos will be stored.
         */
        bucketName: pulumi.Input<string>;
    }
    /**
     * Recording Thumbnail Configuration.
     */
    interface RecordingConfigurationThumbnailConfigurationArgs {
        /**
         * Thumbnail Recording Mode, which determines whether thumbnails are recorded at an interval or are disabled.
         */
        recordingMode?: pulumi.Input<enums.ivs.RecordingConfigurationThumbnailConfigurationRecordingMode>;
        /**
         * Resolution indicates the desired resolution of recorded thumbnails.
         */
        resolution?: pulumi.Input<enums.ivs.RecordingConfigurationThumbnailConfigurationResolution>;
        /**
         * Storage indicates the format in which thumbnails are recorded.
         */
        storage?: pulumi.Input<pulumi.Input<enums.ivs.RecordingConfigurationThumbnailConfigurationStorageItem>[]>;
        /**
         * Target Interval Seconds defines the interval at which thumbnails are recorded. This field is required if RecordingMode is INTERVAL.
         */
        targetIntervalSeconds?: pulumi.Input<number>;
    }
    /**
     * Configuration object for individual participant recording, to attach to the new stage.
     */
    interface StageAutoParticipantRecordingConfigurationArgs {
        /**
         * Types of media to be recorded. Default: AUDIO_VIDEO.
         */
        mediaTypes?: pulumi.Input<pulumi.Input<enums.ivs.StageAutoParticipantRecordingConfigurationMediaTypesItem>[]>;
        /**
         * ARN of the StorageConfiguration resource to use for individual participant recording.
         */
        storageConfigurationArn: pulumi.Input<string>;
    }
    /**
     * A complex type that describes an S3 location where recorded videos will be stored.
     */
    interface StorageConfigurationS3StorageConfigurationArgs {
        /**
         * Location (S3 bucket name) where recorded videos will be stored. Note that the StorageConfiguration and S3 bucket must be in the same region as the Composition.
         */
        bucketName: pulumi.Input<string>;
    }
    /**
     * Video configuration. Default: video resolution 1280x720, bitrate 2500 kbps, 30 fps
     */
    interface VideoPropertiesArgs {
        /**
         * Bitrate for generated output, in bps. Default: 2500000.
         */
        bitrate?: pulumi.Input<number>;
        /**
         * Video frame rate, in fps. Default: 30.
         */
        framerate?: pulumi.Input<number>;
        /**
         * Video-resolution height. This must be an even number. Note that the maximum value is determined by width times height, such that the maximum total pixels is 2073600 (1920x1080 or 1080x1920). Default: 720.
         */
        height?: pulumi.Input<number>;
        /**
         * Video-resolution width. This must be an even number. Note that the maximum value is determined by width times height, such that the maximum total pixels is 2073600 (1920x1080 or 1080x1920). Default: 1280.
         */
        width?: pulumi.Input<number>;
    }
}
export declare namespace ivschat {
    /**
     * CloudWatch destination configuration for IVS Chat logging.
     */
    interface LoggingConfigurationCloudWatchLogsDestinationConfigurationArgs {
        /**
         * Name of the Amazon CloudWatch Logs log group where chat activity will be logged.
         */
        logGroupName: pulumi.Input<string>;
    }
    /**
     * Destination configuration for IVS Chat logging.
     */
    interface LoggingConfigurationDestinationConfigurationArgs {
        /**
         * An Amazon CloudWatch Logs destination configuration where chat activity will be logged.
         */
        cloudWatchLogs?: pulumi.Input<inputs.ivschat.LoggingConfigurationCloudWatchLogsDestinationConfigurationArgs>;
        /**
         * An Amazon Kinesis Data Firehose destination configuration where chat activity will be logged.
         */
        firehose?: pulumi.Input<inputs.ivschat.LoggingConfigurationFirehoseDestinationConfigurationArgs>;
        /**
         * An Amazon S3 destination configuration where chat activity will be logged.
         */
        s3?: pulumi.Input<inputs.ivschat.LoggingConfigurationS3DestinationConfigurationArgs>;
    }
    /**
     * Kinesis Firehose destination configuration for IVS Chat logging.
     */
    interface LoggingConfigurationFirehoseDestinationConfigurationArgs {
        /**
         * Name of the Amazon Kinesis Firehose delivery stream where chat activity will be logged.
         */
        deliveryStreamName: pulumi.Input<string>;
    }
    /**
     * S3 destination configuration for IVS Chat logging.
     */
    interface LoggingConfigurationS3DestinationConfigurationArgs {
        /**
         * Name of the Amazon S3 bucket where chat activity will be logged.
         */
        bucketName: pulumi.Input<string>;
    }
    /**
     * Configuration information for optional review of messages.
     */
    interface RoomMessageReviewHandlerArgs {
        /**
         * Specifies the fallback behavior if the handler does not return a valid response, encounters an error, or times out.
         */
        fallbackResult?: pulumi.Input<enums.ivschat.RoomMessageReviewHandlerFallbackResult>;
        /**
         * Identifier of the message review handler.
         */
        uri?: pulumi.Input<string>;
    }
}
export declare namespace kafkaconnect {
    /**
     * Details of how to connect to an Apache Kafka cluster.
     */
    interface ConnectorApacheKafkaClusterArgs {
        /**
         * The bootstrap servers string of the Apache Kafka cluster.
         */
        bootstrapServers: pulumi.Input<string>;
        /**
         * Details of an Amazon VPC which has network connectivity to the Apache Kafka cluster.
         */
        vpc: pulumi.Input<inputs.kafkaconnect.ConnectorVpcArgs>;
    }
    /**
     * Details about auto scaling of a connector.
     */
    interface ConnectorAutoScalingArgs {
        /**
         * The maximum number of workers for a connector.
         */
        maxWorkerCount: pulumi.Input<number>;
        /**
         * Specifies how many MSK Connect Units (MCU) as the minimum scaling unit.
         */
        mcuCount: pulumi.Input<number>;
        /**
         * The minimum number of workers for a connector.
         */
        minWorkerCount: pulumi.Input<number>;
        /**
         * The sacle-in policy for the connector.
         */
        scaleInPolicy: pulumi.Input<inputs.kafkaconnect.ConnectorScaleInPolicyArgs>;
        /**
         * The sacle-out policy for the connector.
         */
        scaleOutPolicy: pulumi.Input<inputs.kafkaconnect.ConnectorScaleOutPolicyArgs>;
    }
    /**
     * Information about the capacity allocated to the connector.
     */
    interface ConnectorCapacityArgs {
        /**
         * Information about the auto scaling parameters for the connector.
         */
        autoScaling?: pulumi.Input<inputs.kafkaconnect.ConnectorAutoScalingArgs>;
        /**
         * Details about a fixed capacity allocated to a connector.
         */
        provisionedCapacity?: pulumi.Input<inputs.kafkaconnect.ConnectorProvisionedCapacityArgs>;
    }
    /**
     * Details about delivering logs to Amazon CloudWatch Logs.
     */
    interface ConnectorCloudWatchLogsLogDeliveryArgs {
        /**
         * Specifies whether the logs get sent to the specified CloudWatch Logs destination.
         */
        enabled: pulumi.Input<boolean>;
        /**
         * The CloudWatch log group that is the destination for log delivery.
         */
        logGroup?: pulumi.Input<string>;
    }
    /**
     * Details about a custom plugin.
     */
    interface ConnectorCustomPluginArgs {
        /**
         * The Amazon Resource Name (ARN) of the custom plugin to use.
         */
        customPluginArn: pulumi.Input<string>;
        /**
         * The revision of the custom plugin to use.
         */
        revision: pulumi.Input<number>;
    }
    /**
     * Details about delivering logs to Amazon Kinesis Data Firehose.
     */
    interface ConnectorFirehoseLogDeliveryArgs {
        /**
         * The Kinesis Data Firehose delivery stream that is the destination for log delivery.
         */
        deliveryStream?: pulumi.Input<string>;
        /**
         * Specifies whether the logs get sent to the specified Kinesis Data Firehose delivery stream.
         */
        enabled: pulumi.Input<boolean>;
    }
    /**
     * Details of how to connect to the Kafka cluster.
     */
    interface ConnectorKafkaClusterArgs {
        /**
         * The Apache Kafka cluster to which the connector is connected.
         */
        apacheKafkaCluster: pulumi.Input<inputs.kafkaconnect.ConnectorApacheKafkaClusterArgs>;
    }
    /**
     * Details of the client authentication used by the Kafka cluster.
     */
    interface ConnectorKafkaClusterClientAuthenticationArgs {
        /**
         * The type of client authentication used to connect to the Apache Kafka cluster. Value NONE means that no client authentication is used.
         */
        authenticationType: pulumi.Input<enums.kafkaconnect.ConnectorKafkaClusterClientAuthenticationType>;
    }
    /**
     * Details of encryption in transit to the Kafka cluster.
     */
    interface ConnectorKafkaClusterEncryptionInTransitArgs {
        /**
         * The type of encryption in transit to the Apache Kafka cluster.
         */
        encryptionType: pulumi.Input<enums.kafkaconnect.ConnectorKafkaClusterEncryptionInTransitType>;
    }
    /**
     * Details of what logs are delivered and where they are delivered.
     */
    interface ConnectorLogDeliveryArgs {
        /**
         * The workers can send worker logs to different destination types. This configuration specifies the details of these destinations.
         */
        workerLogDelivery: pulumi.Input<inputs.kafkaconnect.ConnectorWorkerLogDeliveryArgs>;
    }
    /**
     * Details about a Kafka Connect plugin which will be used with the connector.
     */
    interface ConnectorPluginArgs {
        /**
         * Details about a custom plugin.
         */
        customPlugin: pulumi.Input<inputs.kafkaconnect.ConnectorCustomPluginArgs>;
    }
    /**
     * Details about a fixed capacity allocated to a connector.
     */
    interface ConnectorProvisionedCapacityArgs {
        /**
         * Specifies how many MSK Connect Units (MCU) are allocated to the connector.
         */
        mcuCount?: pulumi.Input<number>;
        /**
         * Number of workers for a connector.
         */
        workerCount: pulumi.Input<number>;
    }
    /**
     * Details about delivering logs to Amazon S3.
     */
    interface ConnectorS3LogDeliveryArgs {
        /**
         * The name of the S3 bucket that is the destination for log delivery.
         */
        bucket?: pulumi.Input<string>;
        /**
         * Specifies whether the logs get sent to the specified Amazon S3 destination.
         */
        enabled: pulumi.Input<boolean>;
        /**
         * The S3 prefix that is the destination for log delivery.
         */
        prefix?: pulumi.Input<string>;
    }
    /**
     * Information about the scale in policy of the connector.
     */
    interface ConnectorScaleInPolicyArgs {
        /**
         * Specifies the CPU utilization percentage threshold at which connector scale in should trigger.
         */
        cpuUtilizationPercentage: pulumi.Input<number>;
    }
    /**
     * Information about the scale out policy of the connector.
     */
    interface ConnectorScaleOutPolicyArgs {
        /**
         * Specifies the CPU utilization percentage threshold at which connector scale out should trigger.
         */
        cpuUtilizationPercentage: pulumi.Input<number>;
    }
    /**
     * Information about a VPC used with the connector.
     */
    interface ConnectorVpcArgs {
        /**
         * The AWS security groups to associate with the elastic network interfaces in order to specify what the connector has access to.
         */
        securityGroups: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * The list of subnets to connect to in the virtual private cloud (VPC). AWS creates elastic network interfaces inside these subnets.
         */
        subnets: pulumi.Input<pulumi.Input<string>[]>;
    }
    /**
     * Specifies the worker configuration to use with the connector.
     */
    interface ConnectorWorkerConfigurationArgs {
        /**
         * The revision of the worker configuration to use.
         */
        revision: pulumi.Input<number>;
        /**
         * The Amazon Resource Name (ARN) of the worker configuration to use.
         */
        workerConfigurationArn: pulumi.Input<string>;
    }
    /**
     * Specifies where worker logs are delivered.
     */
    interface ConnectorWorkerLogDeliveryArgs {
        /**
         * Details about delivering logs to Amazon CloudWatch Logs.
         */
        cloudWatchLogs?: pulumi.Input<inputs.kafkaconnect.ConnectorCloudWatchLogsLogDeliveryArgs>;
        /**
         * Details about delivering logs to Amazon Kinesis Data Firehose.
         */
        firehose?: pulumi.Input<inputs.kafkaconnect.ConnectorFirehoseLogDeliveryArgs>;
        /**
         * Details about delivering logs to Amazon S3.
         */
        s3?: pulumi.Input<inputs.kafkaconnect.ConnectorS3LogDeliveryArgs>;
    }
    /**
     * Information about the location of a custom plugin.
     */
    interface CustomPluginLocationArgs {
        /**
         * The S3 bucket Amazon Resource Name (ARN), file key, and object version of the plugin file stored in Amazon S3.
         */
        s3Location: pulumi.Input<inputs.kafkaconnect.CustomPluginS3LocationArgs>;
    }
    /**
     * The S3 bucket Amazon Resource Name (ARN), file key, and object version of the plugin file stored in Amazon S3.
     */
    interface CustomPluginS3LocationArgs {
        /**
         * The Amazon Resource Name (ARN) of an S3 bucket.
         */
        bucketArn: pulumi.Input<string>;
        /**
         * The file key for an object in an S3 bucket.
         */
        fileKey: pulumi.Input<string>;
        /**
         * The version of an object in an S3 bucket.
         */
        objectVersion?: pulumi.Input<string>;
    }
}
export declare namespace kendra {
    interface DataSourceAccessControlListConfigurationArgs {
        /**
         * Path to the AWS S3 bucket that contains the access control list files.
         */
        keyPath?: pulumi.Input<string>;
    }
    interface DataSourceAclConfigurationArgs {
        /**
         * A list of groups, separated by semi-colons, that filters a query response based on user context. The document is only returned to users that are in one of the groups specified in the `UserContext` field of the [Query](https://docs.aws.amazon.com/kendra/latest/dg/API_Query.html) operation.
         */
        allowedGroupsColumnName: pulumi.Input<string>;
    }
    interface DataSourceColumnConfigurationArgs {
        /**
         * One to five columns that indicate when a document in the database has changed.
         */
        changeDetectingColumns: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * The column that contains the contents of the document.
         */
        documentDataColumnName: pulumi.Input<string>;
        /**
         * The column that provides the document's identifier.
         */
        documentIdColumnName: pulumi.Input<string>;
        /**
         * The column that contains the title of the document.
         */
        documentTitleColumnName?: pulumi.Input<string>;
        /**
         * An array of objects that map database column names to the corresponding fields in an index. You must first create the fields in the index using the [UpdateIndex](https://docs.aws.amazon.com/kendra/latest/dg/API_UpdateIndex.html) operation.
         */
        fieldMappings?: pulumi.Input<pulumi.Input<inputs.kendra.DataSourceToIndexFieldMappingArgs>[]>;
    }
    interface DataSourceConfigurationArgs {
        /**
         * Provides the configuration information to connect to Confluence as your data source.
         */
        confluenceConfiguration?: pulumi.Input<inputs.kendra.DataSourceConfluenceConfigurationArgs>;
        /**
         * Provides the configuration information to connect to a database as your data source.
         */
        databaseConfiguration?: pulumi.Input<inputs.kendra.DataSourceDatabaseConfigurationArgs>;
        /**
         * Provides the configuration information to connect to Google Drive as your data source.
         */
        googleDriveConfiguration?: pulumi.Input<inputs.kendra.DataSourceGoogleDriveConfigurationArgs>;
        /**
         * Provides the configuration information to connect to Microsoft OneDrive as your data source.
         */
        oneDriveConfiguration?: pulumi.Input<inputs.kendra.DataSourceOneDriveConfigurationArgs>;
        /**
         * Provides the configuration information to connect to an Amazon S3 bucket as your data source.
         *
         * > Amazon Kendra now supports an upgraded Amazon S3 connector.
         * >
         * > You must now use the [TemplateConfiguration](https://docs.aws.amazon.com/kendra/latest/APIReference/API_TemplateConfiguration.html) object instead of the `S3DataSourceConfiguration` object to configure your connector.
         * >
         * > Connectors configured using the older console and API architecture will continue to function as configured. However, you won't be able to edit or update them. If you want to edit or update your connector configuration, you must create a new connector.
         * >
         * > We recommended migrating your connector workflow to the upgraded version. Support for connectors configured using the older architecture is scheduled to end by June 2024.
         */
        s3Configuration?: pulumi.Input<inputs.kendra.DataSourceS3DataSourceConfigurationArgs>;
        /**
         * Provides the configuration information to connect to Salesforce as your data source.
         */
        salesforceConfiguration?: pulumi.Input<inputs.kendra.DataSourceSalesforceConfigurationArgs>;
        /**
         * Provides the configuration information to connect to ServiceNow as your data source.
         */
        serviceNowConfiguration?: pulumi.Input<inputs.kendra.DataSourceServiceNowConfigurationArgs>;
        /**
         * Provides the configuration information to connect to Microsoft SharePoint as your data source.
         */
        sharePointConfiguration?: pulumi.Input<inputs.kendra.DataSourceSharePointConfigurationArgs>;
        /**
         * Provides the configuration information required for Amazon Kendra Web Crawler.
         */
        webCrawlerConfiguration?: pulumi.Input<inputs.kendra.DataSourceWebCrawlerConfigurationArgs>;
        /**
         * Provides the configuration information to connect to Amazon WorkDocs as your data source.
         */
        workDocsConfiguration?: pulumi.Input<inputs.kendra.DataSourceWorkDocsConfigurationArgs>;
    }
    interface DataSourceConfluenceAttachmentConfigurationArgs {
        /**
         * Maps attributes or field names of Confluence attachments to Amazon Kendra index field names. To create custom fields, use the `UpdateIndex` API before you map to Confluence fields. For more information, see [Mapping data source fields](https://docs.aws.amazon.com/kendra/latest/dg/field-mapping.html) . The Confluence data source field names must exist in your Confluence custom metadata.
         *
         * If you specify the `AttachentFieldMappings` parameter, you must specify at least one field mapping.
         */
        attachmentFieldMappings?: pulumi.Input<pulumi.Input<inputs.kendra.DataSourceConfluenceAttachmentToIndexFieldMappingArgs>[]>;
        /**
         * `TRUE` to index attachments of pages and blogs in Confluence.
         */
        crawlAttachments?: pulumi.Input<boolean>;
    }
    interface DataSourceConfluenceAttachmentToIndexFieldMappingArgs {
        dataSourceFieldName: pulumi.Input<enums.kendra.DataSourceConfluenceAttachmentFieldName>;
        dateFieldFormat?: pulumi.Input<string>;
        indexFieldName: pulumi.Input<string>;
    }
    interface DataSourceConfluenceBlogConfigurationArgs {
        /**
         * Maps attributes or field names of Confluence blogs to Amazon Kendra index field names. To create custom fields, use the `UpdateIndex` API before you map to Confluence fields. For more information, see [Mapping data source fields](https://docs.aws.amazon.com/kendra/latest/dg/field-mapping.html) . The Confluence data source field names must exist in your Confluence custom metadata.
         *
         * If you specify the `BlogFieldMappings` parameter, you must specify at least one field mapping.
         */
        blogFieldMappings?: pulumi.Input<pulumi.Input<inputs.kendra.DataSourceConfluenceBlogToIndexFieldMappingArgs>[]>;
    }
    interface DataSourceConfluenceBlogToIndexFieldMappingArgs {
        dataSourceFieldName: pulumi.Input<enums.kendra.DataSourceConfluenceBlogFieldName>;
        dateFieldFormat?: pulumi.Input<string>;
        indexFieldName: pulumi.Input<string>;
    }
    interface DataSourceConfluenceConfigurationArgs {
        /**
         * Configuration information for indexing attachments to Confluence blogs and pages.
         */
        attachmentConfiguration?: pulumi.Input<inputs.kendra.DataSourceConfluenceAttachmentConfigurationArgs>;
        /**
         * Configuration information for indexing Confluence blogs.
         */
        blogConfiguration?: pulumi.Input<inputs.kendra.DataSourceConfluenceBlogConfigurationArgs>;
        /**
         * A list of regular expression patterns to exclude certain blog posts, pages, spaces, or attachments in your Confluence. Content that matches the patterns are excluded from the index. Content that doesn't match the patterns is included in the index. If content matches both an inclusion and exclusion pattern, the exclusion pattern takes precedence and the content isn't included in the index.
         */
        exclusionPatterns?: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * A list of regular expression patterns to include certain blog posts, pages, spaces, or attachments in your Confluence. Content that matches the patterns are included in the index. Content that doesn't match the patterns is excluded from the index. If content matches both an inclusion and exclusion pattern, the exclusion pattern takes precedence and the content isn't included in the index.
         */
        inclusionPatterns?: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * Configuration information for indexing Confluence pages.
         */
        pageConfiguration?: pulumi.Input<inputs.kendra.DataSourceConfluencePageConfigurationArgs>;
        /**
         * The Amazon Resource Name (ARN) of an AWS Secrets Manager secret that contains the user name and password required to connect to the Confluence instance. If you use Confluence Cloud, you use a generated API token as the password.
         *
         * You can also provide authentication credentials in the form of a personal access token. For more information, see [Using a Confluence data source](https://docs.aws.amazon.com/kendra/latest/dg/data-source-confluence.html) .
         */
        secretArn: pulumi.Input<string>;
        /**
         * The URL of your Confluence instance. Use the full URL of the server. For example, *https://server.example.com:port/* . You can also use an IP address, for example, *https://192.168.1.113/* .
         */
        serverUrl: pulumi.Input<string>;
        /**
         * Configuration information for indexing Confluence spaces.
         */
        spaceConfiguration?: pulumi.Input<inputs.kendra.DataSourceConfluenceSpaceConfigurationArgs>;
        /**
         * The version or the type of Confluence installation to connect to.
         */
        version: pulumi.Input<enums.kendra.DataSourceConfluenceVersion>;
        /**
         * Configuration information for an Amazon Virtual Private Cloud to connect to your Confluence. For more information, see [Configuring a VPC](https://docs.aws.amazon.com/kendra/latest/dg/vpc-configuration.html) .
         */
        vpcConfiguration?: pulumi.Input<inputs.kendra.DataSourceVpcConfigurationArgs>;
    }
    interface DataSourceConfluencePageConfigurationArgs {
        /**
         * Maps attributes or field names of Confluence pages to Amazon Kendra index field names. To create custom fields, use the `UpdateIndex` API before you map to Confluence fields. For more information, see [Mapping data source fields](https://docs.aws.amazon.com/kendra/latest/dg/field-mapping.html) . The Confluence data source field names must exist in your Confluence custom metadata.
         *
         * If you specify the `PageFieldMappings` parameter, you must specify at least one field mapping.
         */
        pageFieldMappings?: pulumi.Input<pulumi.Input<inputs.kendra.DataSourceConfluencePageToIndexFieldMappingArgs>[]>;
    }
    interface DataSourceConfluencePageToIndexFieldMappingArgs {
        dataSourceFieldName: pulumi.Input<enums.kendra.DataSourceConfluencePageFieldName>;
        dateFieldFormat?: pulumi.Input<string>;
        indexFieldName: pulumi.Input<string>;
    }
    interface DataSourceConfluenceSpaceConfigurationArgs {
        /**
         * `TRUE` to index archived spaces.
         */
        crawlArchivedSpaces?: pulumi.Input<boolean>;
        /**
         * `TRUE` to index personal spaces. You can add restrictions to items in personal spaces. If personal spaces are indexed, queries without user context information may return restricted items from a personal space in their results. For more information, see [Filtering on user context](https://docs.aws.amazon.com/kendra/latest/dg/user-context-filter.html) .
         */
        crawlPersonalSpaces?: pulumi.Input<boolean>;
        /**
         * A list of space keys of Confluence spaces. If you include a key, the blogs, documents, and attachments in the space are not indexed. If a space is in both the `ExcludeSpaces` and the `IncludeSpaces` list, the space is excluded.
         */
        excludeSpaces?: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * A list of space keys for Confluence spaces. If you include a key, the blogs, documents, and attachments in the space are indexed. Spaces that aren't in the list aren't indexed. A space in the list must exist. Otherwise, Amazon Kendra logs an error when the data source is synchronized. If a space is in both the `IncludeSpaces` and the `ExcludeSpaces` list, the space is excluded.
         */
        includeSpaces?: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * Maps attributes or field names of Confluence spaces to Amazon Kendra index field names. To create custom fields, use the `UpdateIndex` API before you map to Confluence fields. For more information, see [Mapping data source fields](https://docs.aws.amazon.com/kendra/latest/dg/field-mapping.html) . The Confluence data source field names must exist in your Confluence custom metadata.
         *
         * If you specify the `SpaceFieldMappings` parameter, you must specify at least one field mapping.
         */
        spaceFieldMappings?: pulumi.Input<pulumi.Input<inputs.kendra.DataSourceConfluenceSpaceToIndexFieldMappingArgs>[]>;
    }
    interface DataSourceConfluenceSpaceToIndexFieldMappingArgs {
        dataSourceFieldName: pulumi.Input<enums.kendra.DataSourceConfluenceSpaceFieldName>;
        dateFieldFormat?: pulumi.Input<string>;
        indexFieldName: pulumi.Input<string>;
    }
    interface DataSourceConnectionConfigurationArgs {
        /**
         * The name of the host for the database. Can be either a string (host.subdomain.domain.tld) or an IPv4 or IPv6 address.
         */
        databaseHost: pulumi.Input<string>;
        /**
         * The name of the database containing the document data.
         */
        databaseName: pulumi.Input<string>;
        /**
         * The port that the database uses for connections.
         */
        databasePort: pulumi.Input<number>;
        /**
         * The Amazon Resource Name (ARN) of an AWS Secrets Manager secret that stores the credentials. The credentials should be a user-password pair. For more information, see [Using a Database Data Source](https://docs.aws.amazon.com/kendra/latest/dg/data-source-database.html) . For more information about AWS Secrets Manager , see [What Is AWS Secrets Manager](https://docs.aws.amazon.com/secretsmanager/latest/userguide/intro.html) in the *AWS Secrets Manager* user guide.
         */
        secretArn: pulumi.Input<string>;
        /**
         * The name of the table that contains the document data.
         */
        tableName: pulumi.Input<string>;
    }
    interface DataSourceCustomDocumentEnrichmentConfigurationArgs {
        /**
         * Configuration information to alter document attributes or metadata fields and content when ingesting documents into Amazon Kendra.
         */
        inlineConfigurations?: pulumi.Input<pulumi.Input<inputs.kendra.DataSourceInlineCustomDocumentEnrichmentConfigurationArgs>[]>;
        /**
         * Configuration information for invoking a Lambda function in AWS Lambda on the structured documents with their metadata and text extracted. You can use a Lambda function to apply advanced logic for creating, modifying, or deleting document metadata and content. For more information, see [Advanced data manipulation](https://docs.aws.amazon.com/kendra/latest/dg/custom-document-enrichment.html#advanced-data-manipulation) .
         */
        postExtractionHookConfiguration?: pulumi.Input<inputs.kendra.DataSourceHookConfigurationArgs>;
        /**
         * Configuration information for invoking a Lambda function in AWS Lambda on the original or raw documents before extracting their metadata and text. You can use a Lambda function to apply advanced logic for creating, modifying, or deleting document metadata and content. For more information, see [Advanced data manipulation](https://docs.aws.amazon.com/kendra/latest/dg/custom-document-enrichment.html#advanced-data-manipulation) .
         */
        preExtractionHookConfiguration?: pulumi.Input<inputs.kendra.DataSourceHookConfigurationArgs>;
        /**
         * The Amazon Resource Name (ARN) of an IAM role with permission to run `PreExtractionHookConfiguration` and `PostExtractionHookConfiguration` for altering document metadata and content during the document ingestion process. For more information, see [an IAM roles for Amazon Kendra](https://docs.aws.amazon.com/kendra/latest/dg/iam-roles.html) .
         */
        roleArn?: pulumi.Input<string>;
    }
    interface DataSourceDatabaseConfigurationArgs {
        /**
         * Information about the database column that provides information for user context filtering.
         */
        aclConfiguration?: pulumi.Input<inputs.kendra.DataSourceAclConfigurationArgs>;
        /**
         * Information about where the index should get the document information from the database.
         */
        columnConfiguration: pulumi.Input<inputs.kendra.DataSourceColumnConfigurationArgs>;
        /**
         * Configuration information that's required to connect to a database.
         */
        connectionConfiguration: pulumi.Input<inputs.kendra.DataSourceConnectionConfigurationArgs>;
        /**
         * The type of database engine that runs the database.
         */
        databaseEngineType: pulumi.Input<enums.kendra.DataSourceDatabaseEngineType>;
        /**
         * Provides information about how Amazon Kendra uses quote marks around SQL identifiers when querying a database data source.
         */
        sqlConfiguration?: pulumi.Input<inputs.kendra.DataSourceSqlConfigurationArgs>;
        /**
         * Provides information for connecting to an Amazon VPC.
         */
        vpcConfiguration?: pulumi.Input<inputs.kendra.DataSourceVpcConfigurationArgs>;
    }
    interface DataSourceDocumentAttributeConditionArgs {
        /**
         * The identifier of the document attribute used for the condition.
         *
         * For example, 'Source_URI' could be an identifier for the attribute or metadata field that contains source URIs associated with the documents.
         *
         * Amazon Kendra currently does not support `_document_body` as an attribute key used for the condition.
         */
        conditionDocumentAttributeKey: pulumi.Input<string>;
        /**
         * The value used by the operator.
         *
         * For example, you can specify the value 'financial' for strings in the 'Source_URI' field that partially match or contain this value.
         */
        conditionOnValue?: pulumi.Input<inputs.kendra.DataSourceDocumentAttributeValueArgs>;
        /**
         * The condition operator.
         *
         * For example, you can use 'Contains' to partially match a string.
         */
        operator: pulumi.Input<enums.kendra.DataSourceConditionOperator>;
    }
    interface DataSourceDocumentAttributeTargetArgs {
        targetDocumentAttributeKey: pulumi.Input<string>;
        targetDocumentAttributeValue?: pulumi.Input<inputs.kendra.DataSourceDocumentAttributeValueArgs>;
        targetDocumentAttributeValueDeletion?: pulumi.Input<boolean>;
    }
    interface DataSourceDocumentAttributeValueArgs {
        /**
         * A date expressed as an ISO 8601 string.
         *
         * It is important for the time zone to be included in the ISO 8601 date-time format. For example, 2012-03-25T12:30:10+01:00 is the ISO 8601 date-time format for March 25th 2012 at 12:30PM (plus 10 seconds) in Central European Time.
         */
        dateValue?: pulumi.Input<string>;
        /**
         * A long integer value.
         */
        longValue?: pulumi.Input<number>;
        /**
         * A list of strings. The default maximum length or number of strings is 10.
         */
        stringListValue?: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * A string, such as "department".
         */
        stringValue?: pulumi.Input<string>;
    }
    interface DataSourceDocumentsMetadataConfigurationArgs {
        /**
         * A prefix used to filter metadata configuration files in the AWS S3 bucket. The S3 bucket might contain multiple metadata files. Use `S3Prefix` to include only the desired metadata files.
         */
        s3Prefix?: pulumi.Input<string>;
    }
    interface DataSourceGoogleDriveConfigurationArgs {
        /**
         * A list of MIME types to exclude from the index. All documents matching the specified MIME type are excluded.
         *
         * For a list of MIME types, see [Using a Google Workspace Drive data source](https://docs.aws.amazon.com/kendra/latest/dg/data-source-google-drive.html) .
         */
        excludeMimeTypes?: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * A list of identifiers or shared drives to exclude from the index. All files and folders stored on the shared drive are excluded.
         */
        excludeSharedDrives?: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * A list of email addresses of the users. Documents owned by these users are excluded from the index. Documents shared with excluded users are indexed unless they are excluded in another way.
         */
        excludeUserAccounts?: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * A list of regular expression patterns to exclude certain items in your Google Drive, including shared drives and users' My Drives. Items that match the patterns are excluded from the index. Items that don't match the patterns are included in the index. If an item matches both an inclusion and exclusion pattern, the exclusion pattern takes precedence and the item isn't included in the index.
         */
        exclusionPatterns?: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * Maps Google Drive data source attributes or field names to Amazon Kendra index field names. To create custom fields, use the `UpdateIndex` API before you map to Google Drive fields. For more information, see [Mapping data source fields](https://docs.aws.amazon.com/kendra/latest/dg/field-mapping.html) . The Google Drive data source field names must exist in your Google Drive custom metadata.
         */
        fieldMappings?: pulumi.Input<pulumi.Input<inputs.kendra.DataSourceToIndexFieldMappingArgs>[]>;
        /**
         * A list of regular expression patterns to include certain items in your Google Drive, including shared drives and users' My Drives. Items that match the patterns are included in the index. Items that don't match the patterns are excluded from the index. If an item matches both an inclusion and exclusion pattern, the exclusion pattern takes precedence and the item isn't included in the index.
         */
        inclusionPatterns?: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * The Amazon Resource Name (ARN) of a AWS Secrets Manager secret that contains the credentials required to connect to Google Drive. For more information, see [Using a Google Workspace Drive data source](https://docs.aws.amazon.com/kendra/latest/dg/data-source-google-drive.html) .
         */
        secretArn: pulumi.Input<string>;
    }
    interface DataSourceHookConfigurationArgs {
        /**
         * The condition used for when a Lambda function should be invoked.
         *
         * For example, you can specify a condition that if there are empty date-time values, then Amazon Kendra should invoke a function that inserts the current date-time.
         */
        invocationCondition?: pulumi.Input<inputs.kendra.DataSourceDocumentAttributeConditionArgs>;
        /**
         * The Amazon Resource Name (ARN) of an IAM role with permission to run a Lambda function during ingestion. For more information, see [an IAM roles for Amazon Kendra](https://docs.aws.amazon.com/kendra/latest/dg/iam-roles.html) .
         */
        lambdaArn: pulumi.Input<string>;
        /**
         * Stores the original, raw documents or the structured, parsed documents before and after altering them. For more information, see [Data contracts for Lambda functions](https://docs.aws.amazon.com/kendra/latest/dg/custom-document-enrichment.html#cde-data-contracts-lambda) .
         */
        s3Bucket: pulumi.Input<string>;
    }
    interface DataSourceInlineCustomDocumentEnrichmentConfigurationArgs {
        condition?: pulumi.Input<inputs.kendra.DataSourceDocumentAttributeConditionArgs>;
        documentContentDeletion?: pulumi.Input<boolean>;
        target?: pulumi.Input<inputs.kendra.DataSourceDocumentAttributeTargetArgs>;
    }
    interface DataSourceOneDriveConfigurationArgs {
        /**
         * `TRUE` to disable local groups information.
         */
        disableLocalGroups?: pulumi.Input<boolean>;
        /**
         * A list of regular expression patterns to exclude certain documents in your OneDrive. Documents that match the patterns are excluded from the index. Documents that don't match the patterns are included in the index. If a document matches both an inclusion and exclusion pattern, the exclusion pattern takes precedence and the document isn't included in the index.
         *
         * The pattern is applied to the file name.
         */
        exclusionPatterns?: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * A list of `DataSourceToIndexFieldMapping` objects that map OneDrive data source attributes or field names to Amazon Kendra index field names. To create custom fields, use the `UpdateIndex` API before you map to OneDrive fields. For more information, see [Mapping data source fields](https://docs.aws.amazon.com/kendra/latest/dg/field-mapping.html) . The OneDrive data source field names must exist in your OneDrive custom metadata.
         */
        fieldMappings?: pulumi.Input<pulumi.Input<inputs.kendra.DataSourceToIndexFieldMappingArgs>[]>;
        /**
         * A list of regular expression patterns to include certain documents in your OneDrive. Documents that match the patterns are included in the index. Documents that don't match the patterns are excluded from the index. If a document matches both an inclusion and exclusion pattern, the exclusion pattern takes precedence and the document isn't included in the index.
         *
         * The pattern is applied to the file name.
         */
        inclusionPatterns?: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * A list of user accounts whose documents should be indexed.
         */
        oneDriveUsers: pulumi.Input<inputs.kendra.DataSourceOneDriveUsersArgs>;
        /**
         * The Amazon Resource Name (ARN) of an AWS Secrets Manager secret that contains the user name and password to connect to OneDrive. The user name should be the application ID for the OneDrive application, and the password is the application key for the OneDrive application.
         */
        secretArn: pulumi.Input<string>;
        /**
         * The Azure Active Directory domain of the organization.
         */
        tenantDomain: pulumi.Input<string>;
    }
    interface DataSourceOneDriveUsersArgs {
        /**
         * A list of users whose documents should be indexed. Specify the user names in email format, for example, `username@tenantdomain` . If you need to index the documents of more than 10 users, use the `OneDriveUserS3Path` field to specify the location of a file containing a list of users.
         */
        oneDriveUserList?: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * The S3 bucket location of a file containing a list of users whose documents should be indexed.
         */
        oneDriveUserS3Path?: pulumi.Input<inputs.kendra.DataSourceS3PathArgs>;
    }
    interface DataSourceProxyConfigurationArgs {
        /**
         * The Amazon Resource Name (ARN) of an AWS Secrets Manager secret. You create a secret to store your credentials in [AWS Secrets Manager](https://docs.aws.amazon.com/secretsmanager/latest/userguide/intro.html)
         *
         * The credentials are optional. You use a secret if web proxy credentials are required to connect to a website host. Amazon Kendra currently support basic authentication to connect to a web proxy server. The secret stores your credentials.
         */
        credentials?: pulumi.Input<string>;
        /**
         * The name of the website host you want to connect to via a web proxy server.
         *
         * For example, the host name of https://a.example.com/page1.html is "a.example.com".
         */
        host: pulumi.Input<string>;
        /**
         * The port number of the website host you want to connect to via a web proxy server.
         *
         * For example, the port for https://a.example.com/page1.html is 443, the standard port for HTTPS.
         */
        port: pulumi.Input<number>;
    }
    /**
     * S3 data source configuration
     */
    interface DataSourceS3DataSourceConfigurationArgs {
        /**
         * Provides the path to the S3 bucket that contains the user context filtering files for the data source. For the format of the file, see [Access control for S3 data sources](https://docs.aws.amazon.com/kendra/latest/dg/s3-acl.html) .
         */
        accessControlListConfiguration?: pulumi.Input<inputs.kendra.DataSourceAccessControlListConfigurationArgs>;
        /**
         * The name of the bucket that contains the documents.
         */
        bucketName: pulumi.Input<string>;
        /**
         * Specifies document metadata files that contain information such as the document access control information, source URI, document author, and custom attributes. Each metadata file contains metadata about a single document.
         */
        documentsMetadataConfiguration?: pulumi.Input<inputs.kendra.DataSourceDocumentsMetadataConfigurationArgs>;
        /**
         * A list of glob patterns (patterns that can expand a wildcard pattern into a list of path names that match the given pattern) for certain file names and file types to exclude from your index. If a document matches both an inclusion and exclusion prefix or pattern, the exclusion prefix takes precendence and the document is not indexed. Examples of glob patterns include:
         *
         * - *&#47;myapp/config/** —All files inside config directory.
         * - ***&#47;*.png* —All .png files in all directories.
         * - ***&#47;*.{png, ico, md}* —All .png, .ico or .md files in all directories.
         * - *&#47;myapp/src/**&#47;*.ts* —All .ts files inside src directory (and all its subdirectories).
         * - ***&#47;!(*.module).ts* —All .ts files but not .module.ts
         * - **.png , *.jpg* —All PNG and JPEG image files in a directory (files with the extensions .png and .jpg).
         * - **internal** —All files in a directory that contain 'internal' in the file name, such as 'internal', 'internal_only', 'company_internal'.
         * - ***&#47;*internal** —All internal-related files in a directory and its subdirectories.
         *
         * For more examples, see [Use of Exclude and Include Filters](https://docs.aws.amazon.com/cli/latest/reference/s3/#use-of-exclude-and-include-filters) in the AWS CLI Command Reference.
         */
        exclusionPatterns?: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * A list of glob patterns (patterns that can expand a wildcard pattern into a list of path names that match the given pattern) for certain file names and file types to include in your index. If a document matches both an inclusion and exclusion prefix or pattern, the exclusion prefix takes precendence and the document is not indexed. Examples of glob patterns include:
         *
         * - *&#47;myapp/config/** —All files inside config directory.
         * - ***&#47;*.png* —All .png files in all directories.
         * - ***&#47;*.{png, ico, md}* —All .png, .ico or .md files in all directories.
         * - *&#47;myapp/src/**&#47;*.ts* —All .ts files inside src directory (and all its subdirectories).
         * - ***&#47;!(*.module).ts* —All .ts files but not .module.ts
         * - **.png , *.jpg* —All PNG and JPEG image files in a directory (files with the extensions .png and .jpg).
         * - **internal** —All files in a directory that contain 'internal' in the file name, such as 'internal', 'internal_only', 'company_internal'.
         * - ***&#47;*internal** —All internal-related files in a directory and its subdirectories.
         *
         * For more examples, see [Use of Exclude and Include Filters](https://docs.aws.amazon.com/cli/latest/reference/s3/#use-of-exclude-and-include-filters) in the AWS CLI Command Reference.
         */
        inclusionPatterns?: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * A list of S3 prefixes for the documents that should be included in the index.
         */
        inclusionPrefixes?: pulumi.Input<pulumi.Input<string>[]>;
    }
    interface DataSourceS3PathArgs {
        /**
         * The name of the S3 bucket that contains the file.
         */
        bucket: pulumi.Input<string>;
        /**
         * The name of the file.
         */
        key: pulumi.Input<string>;
    }
    interface DataSourceSalesforceChatterFeedConfigurationArgs {
        /**
         * The name of the column in the Salesforce FeedItem table that contains the content to index. Typically this is the `Body` column.
         */
        documentDataFieldName: pulumi.Input<string>;
        /**
         * The name of the column in the Salesforce FeedItem table that contains the title of the document. This is typically the `Title` column.
         */
        documentTitleFieldName?: pulumi.Input<string>;
        /**
         * Maps fields from a Salesforce chatter feed into Amazon Kendra index fields.
         */
        fieldMappings?: pulumi.Input<pulumi.Input<inputs.kendra.DataSourceToIndexFieldMappingArgs>[]>;
        /**
         * Filters the documents in the feed based on status of the user. When you specify `ACTIVE_USERS` only documents from users who have an active account are indexed. When you specify `STANDARD_USER` only documents for Salesforce standard users are documented. You can specify both.
         */
        includeFilterTypes?: pulumi.Input<pulumi.Input<enums.kendra.DataSourceSalesforceChatterFeedIncludeFilterType>[]>;
    }
    interface DataSourceSalesforceConfigurationArgs {
        /**
         * Configuration information for Salesforce chatter feeds.
         */
        chatterFeedConfiguration?: pulumi.Input<inputs.kendra.DataSourceSalesforceChatterFeedConfigurationArgs>;
        /**
         * Indicates whether Amazon Kendra should index attachments to Salesforce objects.
         */
        crawlAttachments?: pulumi.Input<boolean>;
        /**
         * A list of regular expression patterns to exclude certain documents in your Salesforce. Documents that match the patterns are excluded from the index. Documents that don't match the patterns are included in the index. If a document matches both an inclusion and exclusion pattern, the exclusion pattern takes precedence and the document isn't included in the index.
         *
         * The pattern is applied to the name of the attached file.
         */
        excludeAttachmentFilePatterns?: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * A list of regular expression patterns to include certain documents in your Salesforce. Documents that match the patterns are included in the index. Documents that don't match the patterns are excluded from the index. If a document matches both an inclusion and exclusion pattern, the exclusion pattern takes precedence and the document isn't included in the index.
         *
         * The pattern is applied to the name of the attached file.
         */
        includeAttachmentFilePatterns?: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * Configuration information for the knowledge article types that Amazon Kendra indexes. Amazon Kendra indexes standard knowledge articles and the standard fields of knowledge articles, or the custom fields of custom knowledge articles, but not both.
         */
        knowledgeArticleConfiguration?: pulumi.Input<inputs.kendra.DataSourceSalesforceKnowledgeArticleConfigurationArgs>;
        /**
         * The Amazon Resource Name (ARN) of an AWS Secrets Manager secret that contains the key/value pairs required to connect to your Salesforce instance. The secret must contain a JSON structure with the following keys:
         *
         * - authenticationUrl - The OAUTH endpoint that Amazon Kendra connects to get an OAUTH token.
         * - consumerKey - The application public key generated when you created your Salesforce application.
         * - consumerSecret - The application private key generated when you created your Salesforce application.
         * - password - The password associated with the user logging in to the Salesforce instance.
         * - securityToken - The token associated with the user logging in to the Salesforce instance.
         * - username - The user name of the user logging in to the Salesforce instance.
         */
        secretArn: pulumi.Input<string>;
        /**
         * The instance URL for the Salesforce site that you want to index.
         */
        serverUrl: pulumi.Input<string>;
        /**
         * Configuration information for processing attachments to Salesforce standard objects.
         */
        standardObjectAttachmentConfiguration?: pulumi.Input<inputs.kendra.DataSourceSalesforceStandardObjectAttachmentConfigurationArgs>;
        /**
         * Configuration of the Salesforce standard objects that Amazon Kendra indexes.
         */
        standardObjectConfigurations?: pulumi.Input<pulumi.Input<inputs.kendra.DataSourceSalesforceStandardObjectConfigurationArgs>[]>;
    }
    interface DataSourceSalesforceCustomKnowledgeArticleTypeConfigurationArgs {
        documentDataFieldName: pulumi.Input<string>;
        documentTitleFieldName?: pulumi.Input<string>;
        fieldMappings?: pulumi.Input<pulumi.Input<inputs.kendra.DataSourceToIndexFieldMappingArgs>[]>;
        name: pulumi.Input<string>;
    }
    interface DataSourceSalesforceKnowledgeArticleConfigurationArgs {
        /**
         * Configuration information for custom Salesforce knowledge articles.
         */
        customKnowledgeArticleTypeConfigurations?: pulumi.Input<pulumi.Input<inputs.kendra.DataSourceSalesforceCustomKnowledgeArticleTypeConfigurationArgs>[]>;
        /**
         * Specifies the document states that should be included when Amazon Kendra indexes knowledge articles. You must specify at least one state.
         */
        includedStates: pulumi.Input<pulumi.Input<enums.kendra.DataSourceSalesforceKnowledgeArticleState>[]>;
        /**
         * Configuration information for standard Salesforce knowledge articles.
         */
        standardKnowledgeArticleTypeConfiguration?: pulumi.Input<inputs.kendra.DataSourceSalesforceStandardKnowledgeArticleTypeConfigurationArgs>;
    }
    interface DataSourceSalesforceStandardKnowledgeArticleTypeConfigurationArgs {
        /**
         * The name of the field that contains the document data to index.
         */
        documentDataFieldName: pulumi.Input<string>;
        /**
         * The name of the field that contains the document title.
         */
        documentTitleFieldName?: pulumi.Input<string>;
        /**
         * Maps attributes or field names of the knowledge article to Amazon Kendra index field names. To create custom fields, use the `UpdateIndex` API before you map to Salesforce fields. For more information, see [Mapping data source fields](https://docs.aws.amazon.com/kendra/latest/dg/field-mapping.html) . The Salesforce data source field names must exist in your Salesforce custom metadata.
         */
        fieldMappings?: pulumi.Input<pulumi.Input<inputs.kendra.DataSourceToIndexFieldMappingArgs>[]>;
    }
    interface DataSourceSalesforceStandardObjectAttachmentConfigurationArgs {
        /**
         * The name of the field used for the document title.
         */
        documentTitleFieldName?: pulumi.Input<string>;
        /**
         * One or more objects that map fields in attachments to Amazon Kendra index fields.
         */
        fieldMappings?: pulumi.Input<pulumi.Input<inputs.kendra.DataSourceToIndexFieldMappingArgs>[]>;
    }
    interface DataSourceSalesforceStandardObjectConfigurationArgs {
        documentDataFieldName: pulumi.Input<string>;
        documentTitleFieldName?: pulumi.Input<string>;
        fieldMappings?: pulumi.Input<pulumi.Input<inputs.kendra.DataSourceToIndexFieldMappingArgs>[]>;
        name: pulumi.Input<enums.kendra.DataSourceSalesforceStandardObjectName>;
    }
    interface DataSourceServiceNowConfigurationArgs {
        /**
         * The type of authentication used to connect to the ServiceNow instance. If you choose `HTTP_BASIC` , Amazon Kendra is authenticated using the user name and password provided in the AWS Secrets Manager secret in the `SecretArn` field. If you choose `OAUTH2` , Amazon Kendra is authenticated using the credentials of client ID, client secret, user name and password.
         *
         * When you use `OAUTH2` authentication, you must generate a token and a client secret using the ServiceNow console. For more information, see [Using a ServiceNow data source](https://docs.aws.amazon.com/kendra/latest/dg/data-source-servicenow.html) .
         */
        authenticationType?: pulumi.Input<enums.kendra.DataSourceServiceNowAuthenticationType>;
        /**
         * The ServiceNow instance that the data source connects to. The host endpoint should look like the following: *{instance}.service-now.com.*
         */
        hostUrl: pulumi.Input<string>;
        /**
         * Configuration information for crawling knowledge articles in the ServiceNow site.
         */
        knowledgeArticleConfiguration?: pulumi.Input<inputs.kendra.DataSourceServiceNowKnowledgeArticleConfigurationArgs>;
        /**
         * The Amazon Resource Name (ARN) of the AWS Secrets Manager secret that contains the user name and password required to connect to the ServiceNow instance. You can also provide OAuth authentication credentials of user name, password, client ID, and client secret. For more information, see [Using a ServiceNow data source](https://docs.aws.amazon.com/kendra/latest/dg/data-source-servicenow.html) .
         */
        secretArn: pulumi.Input<string>;
        /**
         * Configuration information for crawling service catalogs in the ServiceNow site.
         */
        serviceCatalogConfiguration?: pulumi.Input<inputs.kendra.DataSourceServiceNowServiceCatalogConfigurationArgs>;
        /**
         * The identifier of the release that the ServiceNow host is running. If the host is not running the `LONDON` release, use `OTHERS` .
         */
        serviceNowBuildVersion: pulumi.Input<enums.kendra.DataSourceServiceNowBuildVersionType>;
    }
    interface DataSourceServiceNowKnowledgeArticleConfigurationArgs {
        /**
         * `TRUE` to index attachments to knowledge articles.
         */
        crawlAttachments?: pulumi.Input<boolean>;
        /**
         * The name of the ServiceNow field that is mapped to the index document contents field in the Amazon Kendra index.
         */
        documentDataFieldName: pulumi.Input<string>;
        /**
         * The name of the ServiceNow field that is mapped to the index document title field.
         */
        documentTitleFieldName?: pulumi.Input<string>;
        /**
         * A list of regular expression patterns applied to exclude certain knowledge article attachments. Attachments that match the patterns are excluded from the index. Items that don't match the patterns are included in the index. If an item matches both an inclusion and exclusion pattern, the exclusion pattern takes precedence and the item isn't included in the index.
         */
        excludeAttachmentFilePatterns?: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * Maps attributes or field names of knoweldge articles to Amazon Kendra index field names. To create custom fields, use the `UpdateIndex` API before you map to ServiceNow fields. For more information, see [Mapping data source fields](https://docs.aws.amazon.com/kendra/latest/dg/field-mapping.html) . The ServiceNow data source field names must exist in your ServiceNow custom metadata.
         */
        fieldMappings?: pulumi.Input<pulumi.Input<inputs.kendra.DataSourceToIndexFieldMappingArgs>[]>;
        /**
         * A query that selects the knowledge articles to index. The query can return articles from multiple knowledge bases, and the knowledge bases can be public or private.
         *
         * The query string must be one generated by the ServiceNow console. For more information, see [Specifying documents to index with a query](https://docs.aws.amazon.com/kendra/latest/dg/servicenow-query.html) .
         */
        filterQuery?: pulumi.Input<string>;
        /**
         * A list of regular expression patterns applied to include knowledge article attachments. Attachments that match the patterns are included in the index. Items that don't match the patterns are excluded from the index. If an item matches both an inclusion and exclusion pattern, the exclusion pattern takes precedence and the item isn't included in the index.
         */
        includeAttachmentFilePatterns?: pulumi.Input<pulumi.Input<string>[]>;
    }
    interface DataSourceServiceNowServiceCatalogConfigurationArgs {
        /**
         * `TRUE` to index attachments to service catalog items.
         */
        crawlAttachments?: pulumi.Input<boolean>;
        /**
         * The name of the ServiceNow field that is mapped to the index document contents field in the Amazon Kendra index.
         */
        documentDataFieldName: pulumi.Input<string>;
        /**
         * The name of the ServiceNow field that is mapped to the index document title field.
         */
        documentTitleFieldName?: pulumi.Input<string>;
        /**
         * A list of regular expression patterns to exclude certain attachments of catalogs in your ServiceNow. Item that match the patterns are excluded from the index. Items that don't match the patterns are included in the index. If an item matches both an inclusion and exclusion pattern, the exclusion pattern takes precedence and the item isn't included in the index.
         *
         * The regex is applied to the file name of the attachment.
         */
        excludeAttachmentFilePatterns?: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * Maps attributes or field names of catalogs to Amazon Kendra index field names. To create custom fields, use the `UpdateIndex` API before you map to ServiceNow fields. For more information, see [Mapping data source fields](https://docs.aws.amazon.com/kendra/latest/dg/field-mapping.html) . The ServiceNow data source field names must exist in your ServiceNow custom metadata.
         */
        fieldMappings?: pulumi.Input<pulumi.Input<inputs.kendra.DataSourceToIndexFieldMappingArgs>[]>;
        /**
         * A list of regular expression patterns to include certain attachments of catalogs in your ServiceNow. Item that match the patterns are included in the index. Items that don't match the patterns are excluded from the index. If an item matches both an inclusion and exclusion pattern, the exclusion pattern takes precedence and the item isn't included in the index.
         *
         * The regex is applied to the file name of the attachment.
         */
        includeAttachmentFilePatterns?: pulumi.Input<pulumi.Input<string>[]>;
    }
    /**
     * SharePoint configuration
     */
    interface DataSourceSharePointConfigurationArgs {
        /**
         * `TRUE` to index document attachments.
         */
        crawlAttachments?: pulumi.Input<boolean>;
        /**
         * `TRUE` to disable local groups information.
         */
        disableLocalGroups?: pulumi.Input<boolean>;
        /**
         * The Microsoft SharePoint attribute field that contains the title of the document.
         */
        documentTitleFieldName?: pulumi.Input<string>;
        /**
         * A list of regular expression patterns. Documents that match the patterns are excluded from the index. Documents that don't match the patterns are included in the index. If a document matches both an exclusion pattern and an inclusion pattern, the document is not included in the index.
         *
         * The regex is applied to the display URL of the SharePoint document.
         */
        exclusionPatterns?: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * A list of `DataSourceToIndexFieldMapping` objects that map Microsoft SharePoint attributes or fields to Amazon Kendra index fields. You must first create the index fields using the [UpdateIndex](https://docs.aws.amazon.com/kendra/latest/dg/API_UpdateIndex.html) operation before you map SharePoint attributes. For more information, see [Mapping Data Source Fields](https://docs.aws.amazon.com/kendra/latest/dg/field-mapping.html) .
         */
        fieldMappings?: pulumi.Input<pulumi.Input<inputs.kendra.DataSourceToIndexFieldMappingArgs>[]>;
        /**
         * A list of regular expression patterns to include certain documents in your SharePoint. Documents that match the patterns are included in the index. Documents that don't match the patterns are excluded from the index. If a document matches both an inclusion and exclusion pattern, the exclusion pattern takes precedence and the document isn't included in the index.
         *
         * The regex applies to the display URL of the SharePoint document.
         */
        inclusionPatterns?: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * The Amazon Resource Name (ARN) of an AWS Secrets Manager secret that contains the user name and password required to connect to the SharePoint instance. For more information, see [Microsoft SharePoint](https://docs.aws.amazon.com/kendra/latest/dg/data-source-sharepoint.html) .
         */
        secretArn: pulumi.Input<string>;
        /**
         * The version of Microsoft SharePoint that you use.
         */
        sharePointVersion: pulumi.Input<enums.kendra.DataSourceSharePointConfigurationSharePointVersion>;
        /**
         * Information required to find a specific file in an Amazon S3 bucket.
         */
        sslCertificateS3Path?: pulumi.Input<inputs.kendra.DataSourceS3PathArgs>;
        /**
         * The Microsoft SharePoint site URLs for the documents you want to index.
         */
        urls: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * `TRUE` to use the SharePoint change log to determine which documents require updating in the index. Depending on the change log's size, it may take longer for Amazon Kendra to use the change log than to scan all of your documents in SharePoint.
         */
        useChangeLog?: pulumi.Input<boolean>;
        /**
         * Provides information for connecting to an Amazon VPC.
         */
        vpcConfiguration?: pulumi.Input<inputs.kendra.DataSourceVpcConfigurationArgs>;
    }
    interface DataSourceSqlConfigurationArgs {
        /**
         * Determines whether Amazon Kendra encloses SQL identifiers for tables and column names in double quotes (") when making a database query. You can set the value to `DOUBLE_QUOTES` or `NONE` .
         *
         * By default, Amazon Kendra passes SQL identifiers the way that they are entered into the data source configuration. It does not change the case of identifiers or enclose them in quotes.
         *
         * PostgreSQL internally converts uppercase characters to lower case characters in identifiers unless they are quoted. Choosing this option encloses identifiers in quotes so that PostgreSQL does not convert the character's case.
         *
         * For MySQL databases, you must enable the ansi_quotes option when you set this field to `DOUBLE_QUOTES` .
         */
        queryIdentifiersEnclosingOption?: pulumi.Input<enums.kendra.DataSourceQueryIdentifiersEnclosingOption>;
    }
    interface DataSourceToIndexFieldMappingArgs {
        dataSourceFieldName: pulumi.Input<string>;
        dateFieldFormat?: pulumi.Input<string>;
        indexFieldName: pulumi.Input<string>;
    }
    interface DataSourceVpcConfigurationArgs {
        /**
         * A list of identifiers of security groups within your Amazon VPC. The security groups should enable Amazon Kendra to connect to the data source.
         */
        securityGroupIds: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * A list of identifiers for subnets within your Amazon VPC. The subnets should be able to connect to each other in the VPC, and they should have outgoing access to the Internet through a NAT device.
         */
        subnetIds: pulumi.Input<pulumi.Input<string>[]>;
    }
    interface DataSourceWebCrawlerAuthenticationConfigurationArgs {
        /**
         * The list of configuration information that's required to connect to and crawl a website host using basic authentication credentials.
         *
         * The list includes the name and port number of the website host.
         */
        basicAuthentication?: pulumi.Input<pulumi.Input<inputs.kendra.DataSourceWebCrawlerBasicAuthenticationArgs>[]>;
    }
    interface DataSourceWebCrawlerBasicAuthenticationArgs {
        credentials: pulumi.Input<string>;
        host: pulumi.Input<string>;
        port: pulumi.Input<number>;
    }
    interface DataSourceWebCrawlerConfigurationArgs {
        /**
         * Configuration information required to connect to websites using authentication.
         *
         * You can connect to websites using basic authentication of user name and password. You use a secret in [AWS Secrets Manager](https://docs.aws.amazon.com/secretsmanager/latest/userguide/intro.html) to store your authentication credentials.
         *
         * You must provide the website host name and port number. For example, the host name of https://a.example.com/page1.html is "a.example.com" and the port is 443, the standard port for HTTPS.
         */
        authenticationConfiguration?: pulumi.Input<inputs.kendra.DataSourceWebCrawlerAuthenticationConfigurationArgs>;
        /**
         * The 'depth' or number of levels from the seed level to crawl. For example, the seed URL page is depth 1 and any hyperlinks on this page that are also crawled are depth 2.
         */
        crawlDepth?: pulumi.Input<number>;
        /**
         * The maximum size (in MB) of a web page or attachment to crawl.
         *
         * Files larger than this size (in MB) are skipped/not crawled.
         *
         * The default maximum size of a web page or attachment is set to 50 MB.
         */
        maxContentSizePerPageInMegaBytes?: pulumi.Input<number>;
        /**
         * The maximum number of URLs on a web page to include when crawling a website. This number is per web page.
         *
         * As a website’s web pages are crawled, any URLs the web pages link to are also crawled. URLs on a web page are crawled in order of appearance.
         *
         * The default maximum links per page is 100.
         */
        maxLinksPerPage?: pulumi.Input<number>;
        /**
         * The maximum number of URLs crawled per website host per minute.
         *
         * A minimum of one URL is required.
         *
         * The default maximum number of URLs crawled per website host per minute is 300.
         */
        maxUrlsPerMinuteCrawlRate?: pulumi.Input<number>;
        /**
         * Configuration information required to connect to your internal websites via a web proxy.
         *
         * You must provide the website host name and port number. For example, the host name of https://a.example.com/page1.html is "a.example.com" and the port is 443, the standard port for HTTPS.
         *
         * Web proxy credentials are optional and you can use them to connect to a web proxy server that requires basic authentication. To store web proxy credentials, you use a secret in [AWS Secrets Manager](https://docs.aws.amazon.com/secretsmanager/latest/userguide/intro.html) .
         */
        proxyConfiguration?: pulumi.Input<inputs.kendra.DataSourceProxyConfigurationArgs>;
        /**
         * A list of regular expression patterns to exclude certain URLs to crawl. URLs that match the patterns are excluded from the index. URLs that don't match the patterns are included in the index. If a URL matches both an inclusion and exclusion pattern, the exclusion pattern takes precedence and the URL file isn't included in the index.
         */
        urlExclusionPatterns?: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * A list of regular expression patterns to include certain URLs to crawl. URLs that match the patterns are included in the index. URLs that don't match the patterns are excluded from the index. If a URL matches both an inclusion and exclusion pattern, the exclusion pattern takes precedence and the URL file isn't included in the index.
         */
        urlInclusionPatterns?: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * Specifies the seed or starting point URLs of the websites or the sitemap URLs of the websites you want to crawl.
         *
         * You can include website subdomains. You can list up to 100 seed URLs and up to three sitemap URLs.
         *
         * You can only crawl websites that use the secure communication protocol, Hypertext Transfer Protocol Secure (HTTPS). If you receive an error when crawling a website, it could be that the website is blocked from crawling.
         *
         * *When selecting websites to index, you must adhere to the [Amazon Acceptable Use Policy](https://docs.aws.amazon.com/aup/) and all other Amazon terms. Remember that you must only use Amazon Kendra Web Crawler to index your own webpages, or webpages that you have authorization to index.*
         */
        urls: pulumi.Input<inputs.kendra.DataSourceWebCrawlerUrlsArgs>;
    }
    interface DataSourceWebCrawlerSeedUrlConfigurationArgs {
        /**
         * The list of seed or starting point URLs of the websites you want to crawl.
         *
         * The list can include a maximum of 100 seed URLs.
         */
        seedUrls: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * You can choose one of the following modes:
         *
         * - `HOST_ONLY` —crawl only the website host names. For example, if the seed URL is "abc.example.com", then only URLs with host name "abc.example.com" are crawled.
         * - `SUBDOMAINS` —crawl the website host names with subdomains. For example, if the seed URL is "abc.example.com", then "a.abc.example.com" and "b.abc.example.com" are also crawled.
         * - `EVERYTHING` —crawl the website host names with subdomains and other domains that the web pages link to.
         *
         * The default mode is set to `HOST_ONLY` .
         */
        webCrawlerMode?: pulumi.Input<enums.kendra.DataSourceWebCrawlerSeedUrlConfigurationWebCrawlerMode>;
    }
    interface DataSourceWebCrawlerSiteMapsConfigurationArgs {
        /**
         * The list of sitemap URLs of the websites you want to crawl.
         *
         * The list can include a maximum of three sitemap URLs.
         */
        siteMaps: pulumi.Input<pulumi.Input<string>[]>;
    }
    interface DataSourceWebCrawlerUrlsArgs {
        /**
         * Configuration of the seed or starting point URLs of the websites you want to crawl.
         *
         * You can choose to crawl only the website host names, or the website host names with subdomains, or the website host names with subdomains and other domains that the web pages link to.
         *
         * You can list up to 100 seed URLs.
         */
        seedUrlConfiguration?: pulumi.Input<inputs.kendra.DataSourceWebCrawlerSeedUrlConfigurationArgs>;
        /**
         * Configuration of the sitemap URLs of the websites you want to crawl.
         *
         * Only URLs belonging to the same website host names are crawled. You can list up to three sitemap URLs.
         */
        siteMapsConfiguration?: pulumi.Input<inputs.kendra.DataSourceWebCrawlerSiteMapsConfigurationArgs>;
    }
    interface DataSourceWorkDocsConfigurationArgs {
        /**
         * `TRUE` to include comments on documents in your index. Including comments in your index means each comment is a document that can be searched on.
         *
         * The default is set to `FALSE` .
         */
        crawlComments?: pulumi.Input<boolean>;
        /**
         * A list of regular expression patterns to exclude certain files in your Amazon WorkDocs site repository. Files that match the patterns are excluded from the index. Files that don’t match the patterns are included in the index. If a file matches both an inclusion and exclusion pattern, the exclusion pattern takes precedence and the file isn't included in the index.
         */
        exclusionPatterns?: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * A list of `DataSourceToIndexFieldMapping` objects that map Amazon WorkDocs data source attributes or field names to Amazon Kendra index field names. To create custom fields, use the `UpdateIndex` API before you map to Amazon WorkDocs fields. For more information, see [Mapping data source fields](https://docs.aws.amazon.com/kendra/latest/dg/field-mapping.html) . The Amazon WorkDocs data source field names must exist in your Amazon WorkDocs custom metadata.
         */
        fieldMappings?: pulumi.Input<pulumi.Input<inputs.kendra.DataSourceToIndexFieldMappingArgs>[]>;
        /**
         * A list of regular expression patterns to include certain files in your Amazon WorkDocs site repository. Files that match the patterns are included in the index. Files that don't match the patterns are excluded from the index. If a file matches both an inclusion and exclusion pattern, the exclusion pattern takes precedence and the file isn't included in the index.
         */
        inclusionPatterns?: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * The identifier of the directory corresponding to your Amazon WorkDocs site repository.
         *
         * You can find the organization ID in the [AWS Directory Service](https://docs.aws.amazon.com/directoryservicev2/) by going to *Active Directory* , then *Directories* . Your Amazon WorkDocs site directory has an ID, which is the organization ID. You can also set up a new Amazon WorkDocs directory in the AWS Directory Service console and enable a Amazon WorkDocs site for the directory in the Amazon WorkDocs console.
         */
        organizationId: pulumi.Input<string>;
        /**
         * `TRUE` to use the Amazon WorkDocs change log to determine which documents require updating in the index. Depending on the change log's size, it may take longer for Amazon Kendra to use the change log than to scan all of your documents in Amazon WorkDocs.
         */
        useChangeLog?: pulumi.Input<boolean>;
    }
    interface FaqS3PathArgs {
        /**
         * The name of the S3 bucket that contains the file.
         */
        bucket: pulumi.Input<string>;
        /**
         * The name of the file.
         */
        key: pulumi.Input<string>;
    }
    interface IndexCapacityUnitsConfigurationArgs {
        /**
         * The amount of extra query capacity for an index and [GetQuerySuggestions](https://docs.aws.amazon.com/kendra/latest/dg/API_GetQuerySuggestions.html) capacity.
         *
         * A single extra capacity unit for an index provides 0.1 queries per second or approximately 8,000 queries per day. You can add up to 100 extra capacity units.
         *
         * `GetQuerySuggestions` capacity is five times the provisioned query capacity for an index, or the base capacity of 2.5 calls per second, whichever is higher. For example, the base capacity for an index is 0.1 queries per second, and `GetQuerySuggestions` capacity has a base of 2.5 calls per second. If you add another 0.1 queries per second to total 0.2 queries per second for an index, the `GetQuerySuggestions` capacity is 2.5 calls per second (higher than five times 0.2 queries per second).
         */
        queryCapacityUnits: pulumi.Input<number>;
        /**
         * The amount of extra storage capacity for an index. A single capacity unit provides 30 GB of storage space or 100,000 documents, whichever is reached first. You can add up to 100 extra capacity units.
         */
        storageCapacityUnits: pulumi.Input<number>;
    }
    interface IndexDocumentMetadataConfigurationArgs {
        name: pulumi.Input<string>;
        relevance?: pulumi.Input<inputs.kendra.IndexRelevanceArgs>;
        search?: pulumi.Input<inputs.kendra.IndexSearchArgs>;
        type: pulumi.Input<enums.kendra.IndexDocumentAttributeValueType>;
    }
    interface IndexJsonTokenTypeConfigurationArgs {
        groupAttributeField: pulumi.Input<string>;
        userNameAttributeField: pulumi.Input<string>;
    }
    interface IndexJwtTokenTypeConfigurationArgs {
        claimRegex?: pulumi.Input<string>;
        groupAttributeField?: pulumi.Input<string>;
        issuer?: pulumi.Input<string>;
        keyLocation: pulumi.Input<enums.kendra.IndexKeyLocation>;
        secretManagerArn?: pulumi.Input<string>;
        url?: pulumi.Input<string>;
        userNameAttributeField?: pulumi.Input<string>;
    }
    interface IndexRelevanceArgs {
        duration?: pulumi.Input<string>;
        freshness?: pulumi.Input<boolean>;
        importance?: pulumi.Input<number>;
        rankOrder?: pulumi.Input<enums.kendra.IndexOrder>;
        valueImportanceItems?: pulumi.Input<pulumi.Input<inputs.kendra.IndexValueImportanceItemArgs>[]>;
    }
    interface IndexSearchArgs {
        displayable?: pulumi.Input<boolean>;
        facetable?: pulumi.Input<boolean>;
        searchable?: pulumi.Input<boolean>;
        sortable?: pulumi.Input<boolean>;
    }
    interface IndexServerSideEncryptionConfigurationArgs {
        /**
         * The identifier of the AWS KMS key . Amazon Kendra doesn't support asymmetric keys.
         */
        kmsKeyId?: pulumi.Input<string>;
    }
    interface IndexUserTokenConfigurationArgs {
        jsonTokenTypeConfiguration?: pulumi.Input<inputs.kendra.IndexJsonTokenTypeConfigurationArgs>;
        jwtTokenTypeConfiguration?: pulumi.Input<inputs.kendra.IndexJwtTokenTypeConfigurationArgs>;
    }
    interface IndexValueImportanceItemArgs {
        key?: pulumi.Input<string>;
        value?: pulumi.Input<number>;
    }
}
export declare namespace kendraranking {
    interface ExecutionPlanCapacityUnitsConfigurationArgs {
        /**
         * The amount of extra capacity for your rescore execution plan.
         *
         * A single extra capacity unit for a rescore execution plan provides 0.01 rescore requests per second. You can add up to 1000 extra capacity units.
         */
        rescoreCapacityUnits: pulumi.Input<number>;
    }
}
export declare namespace kinesis {
    /**
     * When specified, enables or updates server-side encryption using an AWS KMS key for a specified stream. Removing this property from your stack template and updating your stack disables encryption.
     */
    interface StreamEncryptionArgs {
        /**
         * The encryption type to use. The only valid value is KMS.
         */
        encryptionType: pulumi.Input<enums.kinesis.StreamEncryptionEncryptionType>;
        /**
         * The GUID for the customer-managed AWS KMS key to use for encryption. This value can be a globally unique identifier, a fully specified Amazon Resource Name (ARN) to either an alias or a key, or an alias name prefixed by "alias/".You can also use a master key owned by Kinesis Data Streams by specifying the alias aws/kinesis.
         */
        keyId: pulumi.Input<string>;
    }
    /**
     * When specified, enables or updates the mode of stream. Default is PROVISIONED.
     */
    interface StreamModeDetailsArgs {
        /**
         * The mode of the stream
         */
        streamMode: pulumi.Input<enums.kinesis.StreamModeDetailsStreamMode>;
    }
}
export declare namespace kinesisanalyticsv2 {
    /**
     * The configuration parameters for the default Amazon Glue database. You use this database for SQL queries that you write in a Kinesis Data Analytics Studio notebook.
     */
    interface ApplicationCatalogConfigurationArgs {
        /**
         * The configuration parameters for the default Amazon Glue database. You use this database for Apache Flink SQL queries and table API transforms that you write in a Kinesis Data Analytics Studio notebook.
         */
        glueDataCatalogConfiguration?: pulumi.Input<inputs.kinesisanalyticsv2.ApplicationGlueDataCatalogConfigurationArgs>;
    }
    /**
     * Describes an application's checkpointing configuration. Checkpointing is the process of persisting application state for fault tolerance. For more information, see Checkpoints for Fault Tolerance in the Apache Flink Documentation.
     */
    interface ApplicationCheckpointConfigurationArgs {
        /**
         * Describes the interval in milliseconds between checkpoint operations.
         */
        checkpointInterval?: pulumi.Input<number>;
        /**
         * Describes whether checkpointing is enabled for a Flink-based Kinesis Data Analytics application.
         */
        checkpointingEnabled?: pulumi.Input<boolean>;
        /**
         * Describes whether the application uses Kinesis Data Analytics' default checkpointing behavior. You must set this property to `CUSTOM` in order to set the `CheckpointingEnabled`, `CheckpointInterval`, or `MinPauseBetweenCheckpoints` parameters.
         */
        configurationType: pulumi.Input<enums.kinesisanalyticsv2.ApplicationCheckpointConfigurationConfigurationType>;
        /**
         * Describes the minimum time in milliseconds after a checkpoint operation completes that a new checkpoint operation can start. If a checkpoint operation takes longer than the CheckpointInterval, the application otherwise performs continual checkpoint operations. For more information, see Tuning Checkpointing in the Apache Flink Documentation.
         */
        minPauseBetweenCheckpoints?: pulumi.Input<number>;
    }
    /**
     * Describes code configuration for an application.
     */
    interface ApplicationCodeConfigurationArgs {
        /**
         * The location and type of the application code.
         */
        codeContent: pulumi.Input<inputs.kinesisanalyticsv2.ApplicationCodeContentArgs>;
        /**
         * Specifies whether the code content is in text or zip format.
         */
        codeContentType: pulumi.Input<enums.kinesisanalyticsv2.ApplicationCodeConfigurationCodeContentType>;
    }
    /**
     * Specifies either the application code, or the location of the application code, for a Flink-based Kinesis Data Analytics application.
     */
    interface ApplicationCodeContentArgs {
        /**
         * Information about the Amazon S3 bucket that contains the application code.
         */
        s3ContentLocation?: pulumi.Input<inputs.kinesisanalyticsv2.ApplicationS3ContentLocationArgs>;
        /**
         * The text-format code for a Flink-based Kinesis Data Analytics application.
         */
        textContent?: pulumi.Input<string>;
        /**
         * The zip-format code for a Flink-based Kinesis Data Analytics application.
         */
        zipFileContent?: pulumi.Input<string>;
    }
    /**
     * Specifies the creation parameters for a Kinesis Data Analytics application.
     */
    interface ApplicationConfigurationArgs {
        /**
         * The code location and type parameters for a Flink-based Kinesis Data Analytics application.
         */
        applicationCodeConfiguration?: pulumi.Input<inputs.kinesisanalyticsv2.ApplicationCodeConfigurationArgs>;
        /**
         * Describes whether snapshots are enabled for a Flink-based Kinesis Data Analytics application.
         */
        applicationSnapshotConfiguration?: pulumi.Input<inputs.kinesisanalyticsv2.ApplicationSnapshotConfigurationArgs>;
        /**
         * Describes whether system initiated rollbacks are enabled for a Flink-based Kinesis Data Analytics application.
         */
        applicationSystemRollbackConfiguration?: pulumi.Input<inputs.kinesisanalyticsv2.ApplicationSystemRollbackConfigurationArgs>;
        /**
         * Describes execution properties for a Flink-based Kinesis Data Analytics application.
         */
        environmentProperties?: pulumi.Input<inputs.kinesisanalyticsv2.ApplicationEnvironmentPropertiesArgs>;
        /**
         * The creation and update parameters for a Flink-based Kinesis Data Analytics application.
         */
        flinkApplicationConfiguration?: pulumi.Input<inputs.kinesisanalyticsv2.ApplicationFlinkApplicationConfigurationArgs>;
        /**
         * The creation and update parameters for a SQL-based Kinesis Data Analytics application.
         */
        sqlApplicationConfiguration?: pulumi.Input<inputs.kinesisanalyticsv2.ApplicationSqlApplicationConfigurationArgs>;
        /**
         * The array of descriptions of VPC configurations available to the application.
         */
        vpcConfigurations?: pulumi.Input<pulumi.Input<inputs.kinesisanalyticsv2.ApplicationVpcConfigurationArgs>[]>;
        /**
         * The configuration parameters for a Kinesis Data Analytics Studio notebook.
         */
        zeppelinApplicationConfiguration?: pulumi.Input<inputs.kinesisanalyticsv2.ApplicationZeppelinApplicationConfigurationArgs>;
    }
    /**
     * For a SQL-based Kinesis Data Analytics application, provides additional mapping information when the record format uses delimiters, such as CSV. For example, the following sample records use CSV format, where the records use the '\n' as the row delimiter and a comma (",") as the column delimiter:
     * `"name1", "address1"`
     * `"name2", "address2"`
     */
    interface ApplicationCsvMappingParametersArgs {
        /**
         * The column delimiter. For example, in a CSV format, a comma (",") is the typical column delimiter.
         */
        recordColumnDelimiter: pulumi.Input<string>;
        /**
         * The row delimiter. For example, in a CSV format, '\n' is the typical row delimiter.
         */
        recordRowDelimiter: pulumi.Input<string>;
    }
    /**
     * The configuration of connectors and user-defined functions.
     */
    interface ApplicationCustomArtifactConfigurationArgs {
        /**
         * Set this to either `UDF` or `DEPENDENCY_JAR`. `UDF` stands for user-defined functions. This type of artifact must be in an S3 bucket. A `DEPENDENCY_JAR` can be in either Maven or an S3 bucket.
         */
        artifactType: pulumi.Input<enums.kinesisanalyticsv2.ApplicationCustomArtifactConfigurationArtifactType>;
        /**
         * The parameters required to fully specify a Maven reference.
         */
        mavenReference?: pulumi.Input<inputs.kinesisanalyticsv2.ApplicationMavenReferenceArgs>;
        /**
         * The location of the custom artifacts.
         */
        s3ContentLocation?: pulumi.Input<inputs.kinesisanalyticsv2.ApplicationS3ContentLocationArgs>;
    }
    /**
     * The information required to deploy a Kinesis Data Analytics Studio notebook as an application with durable state.
     */
    interface ApplicationDeployAsApplicationConfigurationArgs {
        /**
         * The description of an Amazon S3 object that contains the Amazon Data Analytics application, including the Amazon Resource Name (ARN) of the S3 bucket, the name of the Amazon S3 object that contains the data, and the version number of the Amazon S3 object that contains the data.
         */
        s3ContentLocation: pulumi.Input<inputs.kinesisanalyticsv2.ApplicationS3ContentBaseLocationArgs>;
    }
    /**
     * Describes execution properties for a Flink-based Kinesis Data Analytics application.
     */
    interface ApplicationEnvironmentPropertiesArgs {
        /**
         * Describes the execution property groups.
         */
        propertyGroups?: pulumi.Input<pulumi.Input<inputs.kinesisanalyticsv2.ApplicationPropertyGroupArgs>[]>;
    }
    /**
     * Describes configuration parameters for a Flink-based Kinesis Data Analytics application or a Studio notebook.
     */
    interface ApplicationFlinkApplicationConfigurationArgs {
        /**
         * Describes an application's checkpointing configuration. Checkpointing is the process of persisting application state for fault tolerance. For more information, see Checkpoints for Fault Tolerance in the Apache Flink Documentation.
         */
        checkpointConfiguration?: pulumi.Input<inputs.kinesisanalyticsv2.ApplicationCheckpointConfigurationArgs>;
        /**
         * Describes configuration parameters for Amazon CloudWatch logging for an application.
         */
        monitoringConfiguration?: pulumi.Input<inputs.kinesisanalyticsv2.ApplicationMonitoringConfigurationArgs>;
        /**
         * Describes parameters for how an application executes multiple tasks simultaneously.
         */
        parallelismConfiguration?: pulumi.Input<inputs.kinesisanalyticsv2.ApplicationParallelismConfigurationArgs>;
    }
    /**
     * Describes the starting parameters for a Flink-based Kinesis Data Analytics application.
     */
    interface ApplicationFlinkRunConfigurationArgs {
        /**
         * When restoring from a snapshot, specifies whether the runtime is allowed to skip a state that cannot be mapped to the new program. Defaults to false. If you update your application without specifying this parameter, AllowNonRestoredState will be set to false, even if it was previously set to true.
         */
        allowNonRestoredState?: pulumi.Input<boolean>;
    }
    /**
     * The configuration of the Glue Data Catalog that you use for Apache Flink SQL queries and table API transforms that you write in an application.
     */
    interface ApplicationGlueDataCatalogConfigurationArgs {
        /**
         * The Amazon Resource Name (ARN) of the database.
         */
        databaseArn?: pulumi.Input<string>;
    }
    /**
     * When you configure the application input for a SQL-based Kinesis Data Analytics application, you specify the streaming source, the in-application stream name that is created, and the mapping between the two.
     */
    interface ApplicationInputArgs {
        /**
         * Describes the number of in-application streams to create.
         */
        inputParallelism?: pulumi.Input<inputs.kinesisanalyticsv2.ApplicationInputParallelismArgs>;
        /**
         * The InputProcessingConfiguration for the input. An input processor transforms records as they are received from the stream, before the application's SQL code executes. Currently, the only input processing configuration available is InputLambdaProcessor.
         */
        inputProcessingConfiguration?: pulumi.Input<inputs.kinesisanalyticsv2.ApplicationInputProcessingConfigurationArgs>;
        /**
         * Describes the format of the data in the streaming source, and how each data element maps to corresponding columns in the in-application stream that is being created.
         */
        inputSchema: pulumi.Input<inputs.kinesisanalyticsv2.ApplicationInputSchemaArgs>;
        /**
         * If the streaming source is an Amazon Kinesis Data Firehose delivery stream, identifies the delivery stream's ARN.
         */
        kinesisFirehoseInput?: pulumi.Input<inputs.kinesisanalyticsv2.ApplicationKinesisFirehoseInputArgs>;
        /**
         * If the streaming source is an Amazon Kinesis data stream, identifies the stream's Amazon Resource Name (ARN).
         */
        kinesisStreamsInput?: pulumi.Input<inputs.kinesisanalyticsv2.ApplicationKinesisStreamsInputArgs>;
        /**
         * The name prefix to use when creating an in-application stream. Suppose that you specify a prefix `"MyInApplicationStream"`. Kinesis Data Analytics then creates one or more (as per the InputParallelism count you specified) in-application streams with the names `"MyInApplicationStream_001"`, `"MyInApplicationStream_002"`, and so on.
         */
        namePrefix: pulumi.Input<string>;
    }
    /**
     * An object that contains the Amazon Resource Name (ARN) of the Amazon Lambda function that is used to preprocess records in the stream in a SQL-based Kinesis Data Analytics application.
     */
    interface ApplicationInputLambdaProcessorArgs {
        /**
         * The ARN of the Amazon Lambda function that operates on records in the stream.
         */
        resourceArn: pulumi.Input<string>;
    }
    /**
     * For a SQL-based Kinesis Data Analytics application, describes the number of in-application streams to create for a given streaming source.
     */
    interface ApplicationInputParallelismArgs {
        /**
         * The number of in-application streams to create.
         */
        count?: pulumi.Input<number>;
    }
    /**
     * For an SQL-based Amazon Kinesis Data Analytics application, describes a processor that is used to preprocess the records in the stream before being processed by your application code. Currently, the only input processor available is Amazon Lambda.
     */
    interface ApplicationInputProcessingConfigurationArgs {
        /**
         * The InputLambdaProcessor that is used to preprocess the records in the stream before being processed by your application code.
         */
        inputLambdaProcessor?: pulumi.Input<inputs.kinesisanalyticsv2.ApplicationInputLambdaProcessorArgs>;
    }
    /**
     * For a SQL-based Kinesis Data Analytics application, describes the format of the data in the streaming source, and how each data element maps to corresponding columns created in the in-application stream.
     */
    interface ApplicationInputSchemaArgs {
        /**
         * A list of `RecordColumn` objects.
         */
        recordColumns: pulumi.Input<pulumi.Input<inputs.kinesisanalyticsv2.ApplicationRecordColumnArgs>[]>;
        /**
         * Specifies the encoding of the records in the streaming source. For example, UTF-8.
         */
        recordEncoding?: pulumi.Input<enums.kinesisanalyticsv2.ApplicationInputSchemaRecordEncoding>;
        /**
         * Specifies the format of the records on the streaming source.
         */
        recordFormat: pulumi.Input<inputs.kinesisanalyticsv2.ApplicationRecordFormatArgs>;
    }
    /**
     * For a SQL-based Kinesis Data Analytics application, provides additional mapping information when JSON is the record format on the streaming source.
     */
    interface ApplicationJsonMappingParametersArgs {
        /**
         * The path to the top-level parent that contains the records.
         */
        recordRowPath: pulumi.Input<string>;
    }
    /**
     * For a SQL-based Kinesis Data Analytics application, identifies a Kinesis Data Firehose delivery stream as the streaming source. You provide the delivery stream's Amazon Resource Name (ARN).
     */
    interface ApplicationKinesisFirehoseInputArgs {
        /**
         * The Amazon Resource Name (ARN) of the delivery stream.
         */
        resourceArn: pulumi.Input<string>;
    }
    /**
     * Identifies a Kinesis data stream as the streaming source. You provide the stream's Amazon Resource Name (ARN).
     */
    interface ApplicationKinesisStreamsInputArgs {
        /**
         * The ARN of the input Kinesis data stream to read.
         */
        resourceArn: pulumi.Input<string>;
    }
    /**
     * Describes the maintenance configuration for the application.
     */
    interface ApplicationMaintenanceConfigurationArgs {
        /**
         * The start time for the maintenance window.
         */
        applicationMaintenanceWindowStartTime: pulumi.Input<string>;
    }
    /**
     * When you configure a SQL-based Kinesis Data Analytics application's input at the time of creating or updating an application, provides additional mapping information specific to the record format (such as JSON, CSV, or record fields delimited by some delimiter) on the streaming source.
     */
    interface ApplicationMappingParametersArgs {
        /**
         * Provides additional mapping information when the record format uses delimiters (for example, CSV).
         */
        csvMappingParameters?: pulumi.Input<inputs.kinesisanalyticsv2.ApplicationCsvMappingParametersArgs>;
        /**
         * Provides additional mapping information when JSON is the record format on the streaming source.
         */
        jsonMappingParameters?: pulumi.Input<inputs.kinesisanalyticsv2.ApplicationJsonMappingParametersArgs>;
    }
    /**
     * The information required to specify a Maven reference. You can use Maven references to specify dependency JAR files.
     */
    interface ApplicationMavenReferenceArgs {
        /**
         * The artifact ID of the Maven reference.
         */
        artifactId: pulumi.Input<string>;
        /**
         * The group ID of the Maven reference.
         */
        groupId: pulumi.Input<string>;
        /**
         * The version of the Maven reference.
         */
        version: pulumi.Input<string>;
    }
    /**
     * Describes configuration parameters for Amazon CloudWatch logging for a Java-based Kinesis Data Analytics application. For more information about CloudWatch logging, see Monitoring.
     */
    interface ApplicationMonitoringConfigurationArgs {
        /**
         * Describes whether to use the default CloudWatch logging configuration for an application. You must set this property to CUSTOM in order to set the LogLevel or MetricsLevel parameters.
         */
        configurationType: pulumi.Input<enums.kinesisanalyticsv2.ApplicationMonitoringConfigurationConfigurationType>;
        /**
         * Describes the verbosity of the CloudWatch Logs for an application.
         */
        logLevel?: pulumi.Input<enums.kinesisanalyticsv2.ApplicationMonitoringConfigurationLogLevel>;
        /**
         * Describes the granularity of the CloudWatch Logs for an application. The Parallelism level is not recommended for applications with a Parallelism over 64 due to excessive costs.
         */
        metricsLevel?: pulumi.Input<enums.kinesisanalyticsv2.ApplicationMonitoringConfigurationMetricsLevel>;
    }
    /**
     * Describes parameters for how a Flink-based Kinesis Data Analytics application executes multiple tasks simultaneously. For more information about parallelism, see Parallel Execution in the Apache Flink Documentation
     */
    interface ApplicationParallelismConfigurationArgs {
        /**
         * Describes whether the Kinesis Data Analytics service can increase the parallelism of the application in response to increased throughput.
         */
        autoScalingEnabled?: pulumi.Input<boolean>;
        /**
         * Describes whether the application uses the default parallelism for the Kinesis Data Analytics service. You must set this property to `CUSTOM` in order to change your application's `AutoScalingEnabled`, `Parallelism`, or `ParallelismPerKPU` properties.
         */
        configurationType: pulumi.Input<enums.kinesisanalyticsv2.ApplicationParallelismConfigurationConfigurationType>;
        /**
         * Describes the initial number of parallel tasks that a Java-based Kinesis Data Analytics application can perform. The Kinesis Data Analytics service can increase this number automatically if ParallelismConfiguration:AutoScalingEnabled is set to true.
         */
        parallelism?: pulumi.Input<number>;
        /**
         * Describes the number of parallel tasks that a Java-based Kinesis Data Analytics application can perform per Kinesis Processing Unit (KPU) used by the application. For more information about KPUs, see Amazon Kinesis Data Analytics Pricing.
         */
        parallelismPerKpu?: pulumi.Input<number>;
    }
    /**
     * Property key-value pairs passed into an application.
     */
    interface ApplicationPropertyGroupArgs {
        /**
         * Describes the key of an application execution property key-value pair.
         */
        propertyGroupId?: pulumi.Input<string>;
        /**
         * Describes the value of an application execution property key-value pair.
         */
        propertyMap?: pulumi.Input<{
            [key: string]: pulumi.Input<string>;
        }>;
    }
    /**
     * For a SQL-based Kinesis Data Analytics application, describes the mapping of each data element in the streaming source to the corresponding column in the in-application stream.
     * Also used to describe the format of the reference data source.
     */
    interface ApplicationRecordColumnArgs {
        /**
         * A reference to the data element in the streaming input or the reference data source.
         */
        mapping?: pulumi.Input<string>;
        /**
         * The name of the column that is created in the in-application input stream or reference table.
         */
        name: pulumi.Input<string>;
        /**
         * The type of column created in the in-application input stream or reference table.
         */
        sqlType: pulumi.Input<string>;
    }
    /**
     * For a SQL-based Kinesis Data Analytics application, describes the record format and relevant mapping information that should be applied to schematize the records on the stream.
     */
    interface ApplicationRecordFormatArgs {
        /**
         * When you configure application input at the time of creating or updating an application, provides additional mapping information specific to the record format (such as JSON, CSV, or record fields delimited by some delimiter) on the streaming source.
         */
        mappingParameters?: pulumi.Input<inputs.kinesisanalyticsv2.ApplicationMappingParametersArgs>;
        /**
         * The type of record format.
         */
        recordFormatType: pulumi.Input<enums.kinesisanalyticsv2.ApplicationRecordFormatRecordFormatType>;
    }
    /**
     * Describes the restore behavior of a restarting application.
     */
    interface ApplicationRestoreConfigurationArgs {
        /**
         * Specifies how the application should be restored.
         */
        applicationRestoreType: pulumi.Input<enums.kinesisanalyticsv2.ApplicationRestoreConfigurationApplicationRestoreType>;
        /**
         * The identifier of an existing snapshot of application state to use to restart an application. The application uses this value if RESTORE_FROM_CUSTOM_SNAPSHOT is specified for the ApplicationRestoreType.
         */
        snapshotName?: pulumi.Input<string>;
    }
    /**
     * Identifies the run configuration (start parameters) of a Kinesis Data Analytics application. This section is evaluated only on stack updates for applications in running RUNNING state and has no effect during manual application start.
     */
    interface ApplicationRunConfigurationArgs {
        /**
         * Describes the restore behavior of a restarting application.
         */
        applicationRestoreConfiguration?: pulumi.Input<inputs.kinesisanalyticsv2.ApplicationRestoreConfigurationArgs>;
        /**
         * Describes the starting parameters for a Flink-based Kinesis Data Analytics application.
         */
        flinkRunConfiguration?: pulumi.Input<inputs.kinesisanalyticsv2.ApplicationFlinkRunConfigurationArgs>;
    }
    /**
     * The base location of the Amazon Data Analytics application.
     */
    interface ApplicationS3ContentBaseLocationArgs {
        /**
         * The base path for the S3 bucket.
         */
        basePath?: pulumi.Input<string>;
        /**
         * The Amazon Resource Name (ARN) of the S3 bucket.
         */
        bucketArn: pulumi.Input<string>;
    }
    /**
     * The location of an application or a custom artifact.
     */
    interface ApplicationS3ContentLocationArgs {
        /**
         * The Amazon Resource Name (ARN) for the S3 bucket containing the application code.
         */
        bucketArn: pulumi.Input<string>;
        /**
         * The file key for the object containing the application code.
         */
        fileKey: pulumi.Input<string>;
        /**
         * The version of the object containing the application code.
         */
        objectVersion?: pulumi.Input<string>;
    }
    /**
     * Describes whether snapshots are enabled for a Flink-based Kinesis Data Analytics application.
     */
    interface ApplicationSnapshotConfigurationArgs {
        /**
         * Describes whether snapshots are enabled for a Flink-based Kinesis Data Analytics application.
         */
        snapshotsEnabled: pulumi.Input<boolean>;
    }
    /**
     * Describes the inputs, outputs, and reference data sources for a SQL-based Kinesis Data Analytics application.
     */
    interface ApplicationSqlApplicationConfigurationArgs {
        /**
         * The array of Input objects describing the input streams used by the application.
         */
        inputs?: pulumi.Input<pulumi.Input<inputs.kinesisanalyticsv2.ApplicationInputArgs>[]>;
    }
    /**
     * Describes whether system initiated rollbacks are enabled for a Flink-based Kinesis Data Analytics application.
     */
    interface ApplicationSystemRollbackConfigurationArgs {
        /**
         * Describes whether system initiated rollbacks are enabled for a Flink-based Kinesis Data Analytics application.
         */
        rollbackEnabled: pulumi.Input<boolean>;
    }
    /**
     * Describes the parameters of a VPC used by the application.
     */
    interface ApplicationVpcConfigurationArgs {
        /**
         * The array of SecurityGroup IDs used by the VPC configuration.
         */
        securityGroupIds: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * The array of Subnet IDs used by the VPC configuration.
         */
        subnetIds: pulumi.Input<pulumi.Input<string>[]>;
    }
    /**
     * The configuration of a Kinesis Data Analytics Studio notebook.
     */
    interface ApplicationZeppelinApplicationConfigurationArgs {
        /**
         * The Amazon Glue Data Catalog that you use in queries in a Kinesis Data Analytics Studio notebook.
         */
        catalogConfiguration?: pulumi.Input<inputs.kinesisanalyticsv2.ApplicationCatalogConfigurationArgs>;
        /**
         * A list of CustomArtifactConfiguration objects.
         */
        customArtifactsConfiguration?: pulumi.Input<pulumi.Input<inputs.kinesisanalyticsv2.ApplicationCustomArtifactConfigurationArgs>[]>;
        /**
         * The information required to deploy a Kinesis Data Analytics Studio notebook as an application with durable state.
         */
        deployAsApplicationConfiguration?: pulumi.Input<inputs.kinesisanalyticsv2.ApplicationDeployAsApplicationConfigurationArgs>;
        /**
         * The monitoring configuration of a Kinesis Data Analytics Studio notebook.
         */
        monitoringConfiguration?: pulumi.Input<inputs.kinesisanalyticsv2.ApplicationZeppelinMonitoringConfigurationArgs>;
    }
    /**
     * Describes configuration parameters for Amazon CloudWatch logging for a Kinesis Data Analytics Studio notebook. For more information about CloudWatch logging, see Monitoring.
     */
    interface ApplicationZeppelinMonitoringConfigurationArgs {
        /**
         * The verbosity of the CloudWatch Logs for an application. You can set it to `INFO`, `WARN`, `ERROR`, or `DEBUG`.
         */
        logLevel?: pulumi.Input<enums.kinesisanalyticsv2.ApplicationZeppelinMonitoringConfigurationLogLevel>;
    }
}
export declare namespace kinesisfirehose {
    interface DeliveryStreamAmazonOpenSearchServerlessBufferingHintsArgs {
        /**
         * Buffer incoming data for the specified period of time, in seconds, before delivering it to the destination. The default value is 300 (5 minutes).
         */
        intervalInSeconds?: pulumi.Input<number>;
        /**
         * Buffer incoming data to the specified size, in MBs, before delivering it to the destination. The default value is 5.
         *
         * We recommend setting this parameter to a value greater than the amount of data you typically ingest into the Firehose stream in 10 seconds. For example, if you typically ingest data at 1 MB/sec, the value should be 10 MB or higher.
         */
        sizeInMbs?: pulumi.Input<number>;
    }
    interface DeliveryStreamAmazonOpenSearchServerlessDestinationConfigurationArgs {
        /**
         * The buffering options. If no value is specified, the default values for AmazonopensearchserviceBufferingHints are used.
         */
        bufferingHints?: pulumi.Input<inputs.kinesisfirehose.DeliveryStreamAmazonOpenSearchServerlessBufferingHintsArgs>;
        cloudWatchLoggingOptions?: pulumi.Input<inputs.kinesisfirehose.DeliveryStreamCloudWatchLoggingOptionsArgs>;
        /**
         * The endpoint to use when communicating with the collection in the Serverless offering for Amazon OpenSearch Service.
         */
        collectionEndpoint?: pulumi.Input<string>;
        /**
         * The Serverless offering for Amazon OpenSearch Service index name.
         */
        indexName: pulumi.Input<string>;
        processingConfiguration?: pulumi.Input<inputs.kinesisfirehose.DeliveryStreamProcessingConfigurationArgs>;
        /**
         * The retry behavior in case Firehose is unable to deliver documents to the Serverless offering for Amazon OpenSearch Service. The default value is 300 (5 minutes).
         */
        retryOptions?: pulumi.Input<inputs.kinesisfirehose.DeliveryStreamAmazonOpenSearchServerlessRetryOptionsArgs>;
        /**
         * The Amazon Resource Name (ARN) of the IAM role to be assumed by Firehose for calling the Serverless offering for Amazon OpenSearch Service Configuration API and for indexing documents.
         */
        roleArn: pulumi.Input<string>;
        /**
         * Defines how documents should be delivered to Amazon S3. When it is set to FailedDocumentsOnly, Firehose writes any documents that could not be indexed to the configured Amazon S3 destination, with AmazonOpenSearchService-failed/ appended to the key prefix. When set to AllDocuments, Firehose delivers all incoming records to Amazon S3, and also writes failed documents with AmazonOpenSearchService-failed/ appended to the prefix.
         */
        s3BackupMode?: pulumi.Input<enums.kinesisfirehose.DeliveryStreamAmazonOpenSearchServerlessDestinationConfigurationS3BackupMode>;
        s3Configuration: pulumi.Input<inputs.kinesisfirehose.DeliveryStreamS3DestinationConfigurationArgs>;
        vpcConfiguration?: pulumi.Input<inputs.kinesisfirehose.DeliveryStreamVpcConfigurationArgs>;
    }
    interface DeliveryStreamAmazonOpenSearchServerlessRetryOptionsArgs {
        /**
         * After an initial failure to deliver to the Serverless offering for Amazon OpenSearch Service, the total amount of time during which Firehose retries delivery (including the first attempt). After this time has elapsed, the failed documents are written to Amazon S3. Default value is 300 seconds (5 minutes). A value of 0 (zero) results in no retries.
         */
        durationInSeconds?: pulumi.Input<number>;
    }
    interface DeliveryStreamAmazonopensearchserviceBufferingHintsArgs {
        /**
         * Buffer incoming data for the specified period of time, in seconds, before delivering it to the destination. The default value is 300 (5 minutes).
         */
        intervalInSeconds?: pulumi.Input<number>;
        /**
         * Buffer incoming data to the specified size, in MBs, before delivering it to the destination. The default value is 5. We recommend setting this parameter to a value greater than the amount of data you typically ingest into the delivery stream in 10 seconds. For example, if you typically ingest data at 1 MB/sec, the value should be 10 MB or higher.
         */
        sizeInMbs?: pulumi.Input<number>;
    }
    interface DeliveryStreamAmazonopensearchserviceDestinationConfigurationArgs {
        /**
         * The buffering options. If no value is specified, the default values for AmazonopensearchserviceBufferingHints are used.
         */
        bufferingHints?: pulumi.Input<inputs.kinesisfirehose.DeliveryStreamAmazonopensearchserviceBufferingHintsArgs>;
        /**
         * Describes the Amazon CloudWatch logging options for your delivery stream.
         */
        cloudWatchLoggingOptions?: pulumi.Input<inputs.kinesisfirehose.DeliveryStreamCloudWatchLoggingOptionsArgs>;
        /**
         * The endpoint to use when communicating with the cluster. Specify either this ClusterEndpoint or the DomainARN field.
         */
        clusterEndpoint?: pulumi.Input<string>;
        /**
         * Indicates the method for setting up document ID. The supported methods are Firehose generated document ID and OpenSearch Service generated document ID.
         */
        documentIdOptions?: pulumi.Input<inputs.kinesisfirehose.DeliveryStreamDocumentIdOptionsArgs>;
        /**
         * The ARN of the Amazon OpenSearch Service domain.
         */
        domainArn?: pulumi.Input<string>;
        /**
         * The Amazon OpenSearch Service index name.
         */
        indexName: pulumi.Input<string>;
        /**
         * The Amazon OpenSearch Service index rotation period. Index rotation appends a timestamp to the IndexName to facilitate the expiration of old data.
         */
        indexRotationPeriod?: pulumi.Input<enums.kinesisfirehose.DeliveryStreamAmazonopensearchserviceDestinationConfigurationIndexRotationPeriod>;
        /**
         * Describes a data processing configuration.
         */
        processingConfiguration?: pulumi.Input<inputs.kinesisfirehose.DeliveryStreamProcessingConfigurationArgs>;
        /**
         * The retry behavior in case Kinesis Data Firehose is unable to deliver documents to Amazon OpenSearch Service. The default value is 300 (5 minutes).
         */
        retryOptions?: pulumi.Input<inputs.kinesisfirehose.DeliveryStreamAmazonopensearchserviceRetryOptionsArgs>;
        /**
         * The Amazon Resource Name (ARN) of the IAM role to be assumed by Kinesis Data Firehose for calling the Amazon OpenSearch Service Configuration API and for indexing documents.
         */
        roleArn: pulumi.Input<string>;
        /**
         * Defines how documents should be delivered to Amazon S3.
         */
        s3BackupMode?: pulumi.Input<enums.kinesisfirehose.DeliveryStreamAmazonopensearchserviceDestinationConfigurationS3BackupMode>;
        /**
         * Describes the configuration of a destination in Amazon S3.
         */
        s3Configuration: pulumi.Input<inputs.kinesisfirehose.DeliveryStreamS3DestinationConfigurationArgs>;
        /**
         * The Amazon OpenSearch Service type name.
         */
        typeName?: pulumi.Input<string>;
        /**
         * The details of the VPC of the Amazon OpenSearch Service destination.
         */
        vpcConfiguration?: pulumi.Input<inputs.kinesisfirehose.DeliveryStreamVpcConfigurationArgs>;
    }
    interface DeliveryStreamAmazonopensearchserviceRetryOptionsArgs {
        /**
         * After an initial failure to deliver to Amazon OpenSearch Service, the total amount of time during which Kinesis Data Firehose retries delivery (including the first attempt). After this time has elapsed, the failed documents are written to Amazon S3. Default value is 300 seconds (5 minutes). A value of 0 (zero) results in no retries.
         */
        durationInSeconds?: pulumi.Input<number>;
    }
    interface DeliveryStreamAuthenticationConfigurationArgs {
        /**
         * The type of connectivity used to access the Amazon MSK cluster.
         */
        connectivity: pulumi.Input<enums.kinesisfirehose.DeliveryStreamAuthenticationConfigurationConnectivity>;
        /**
         * The ARN of the role used to access the Amazon MSK cluster.
         */
        roleArn: pulumi.Input<string>;
    }
    interface DeliveryStreamBufferingHintsArgs {
        /**
         * The length of time, in seconds, that Kinesis Data Firehose buffers incoming data before delivering it to the destination. For valid values, see the `IntervalInSeconds` content for the [BufferingHints](https://docs.aws.amazon.com/firehose/latest/APIReference/API_BufferingHints.html) data type in the *Amazon Kinesis Data Firehose API Reference* .
         */
        intervalInSeconds?: pulumi.Input<number>;
        /**
         * The size of the buffer, in MBs, that Kinesis Data Firehose uses for incoming data before delivering it to the destination. For valid values, see the `SizeInMBs` content for the [BufferingHints](https://docs.aws.amazon.com/firehose/latest/APIReference/API_BufferingHints.html) data type in the *Amazon Kinesis Data Firehose API Reference* .
         */
        sizeInMbs?: pulumi.Input<number>;
    }
    interface DeliveryStreamCatalogConfigurationArgs {
        /**
         * Specifies the Glue catalog ARN identifier of the destination Apache Iceberg Tables. You must specify the ARN in the format `arn:aws:glue:region:account-id:catalog` .
         */
        catalogArn?: pulumi.Input<string>;
    }
    interface DeliveryStreamCloudWatchLoggingOptionsArgs {
        /**
         * Indicates whether CloudWatch Logs logging is enabled.
         */
        enabled?: pulumi.Input<boolean>;
        /**
         * The name of the CloudWatch Logs log group that contains the log stream that Kinesis Data Firehose will use.
         *
         * Conditional. If you enable logging, you must specify this property.
         */
        logGroupName?: pulumi.Input<string>;
        /**
         * The name of the CloudWatch Logs log stream that Kinesis Data Firehose uses to send logs about data delivery.
         *
         * Conditional. If you enable logging, you must specify this property.
         */
        logStreamName?: pulumi.Input<string>;
    }
    interface DeliveryStreamCopyCommandArgs {
        /**
         * Parameters to use with the Amazon Redshift `COPY` command. For examples, see the `CopyOptions` content for the [CopyCommand](https://docs.aws.amazon.com/firehose/latest/APIReference/API_CopyCommand.html) data type in the *Amazon Kinesis Data Firehose API Reference* .
         */
        copyOptions?: pulumi.Input<string>;
        /**
         * A comma-separated list of column names.
         */
        dataTableColumns?: pulumi.Input<string>;
        /**
         * The name of the target table. The table must already exist in the database.
         */
        dataTableName: pulumi.Input<string>;
    }
    interface DeliveryStreamDataFormatConversionConfigurationArgs {
        /**
         * Defaults to `true` . Set it to `false` if you want to disable format conversion while preserving the configuration details.
         */
        enabled?: pulumi.Input<boolean>;
        /**
         * Specifies the deserializer that you want Firehose to use to convert the format of your data from JSON. This parameter is required if `Enabled` is set to true.
         */
        inputFormatConfiguration?: pulumi.Input<inputs.kinesisfirehose.DeliveryStreamInputFormatConfigurationArgs>;
        /**
         * Specifies the serializer that you want Firehose to use to convert the format of your data to the Parquet or ORC format. This parameter is required if `Enabled` is set to true.
         */
        outputFormatConfiguration?: pulumi.Input<inputs.kinesisfirehose.DeliveryStreamOutputFormatConfigurationArgs>;
        /**
         * Specifies the AWS Glue Data Catalog table that contains the column information. This parameter is required if `Enabled` is set to true.
         */
        schemaConfiguration?: pulumi.Input<inputs.kinesisfirehose.DeliveryStreamSchemaConfigurationArgs>;
    }
    interface DeliveryStreamDatabaseColumnsArgs {
        exclude?: pulumi.Input<pulumi.Input<string>[]>;
        include?: pulumi.Input<pulumi.Input<string>[]>;
    }
    interface DeliveryStreamDatabaseSourceAuthenticationConfigurationArgs {
        secretsManagerConfiguration: pulumi.Input<inputs.kinesisfirehose.DeliveryStreamSecretsManagerConfigurationArgs>;
    }
    interface DeliveryStreamDatabaseSourceConfigurationArgs {
        /**
         * The list of column patterns in source database endpoint for Firehose to read from.
         *
         * Amazon Data Firehose is in preview release and is subject to change.
         */
        columns?: pulumi.Input<inputs.kinesisfirehose.DeliveryStreamDatabaseColumnsArgs>;
        /**
         * The structure to configure the authentication methods for Firehose to connect to source database endpoint.
         *
         * Amazon Data Firehose is in preview release and is subject to change.
         */
        databaseSourceAuthenticationConfiguration: pulumi.Input<inputs.kinesisfirehose.DeliveryStreamDatabaseSourceAuthenticationConfigurationArgs>;
        /**
         * The details of the VPC Endpoint Service which Firehose uses to create a PrivateLink to the database.
         *
         * Amazon Data Firehose is in preview release and is subject to change.
         */
        databaseSourceVpcConfiguration: pulumi.Input<inputs.kinesisfirehose.DeliveryStreamDatabaseSourceVpcConfigurationArgs>;
        /**
         * The list of database patterns in source database endpoint for Firehose to read from.
         *
         * Amazon Data Firehose is in preview release and is subject to change.
         */
        databases: pulumi.Input<inputs.kinesisfirehose.DeliveryStreamDatabasesArgs>;
        digest?: pulumi.Input<string>;
        /**
         * The endpoint of the database server.
         *
         * Amazon Data Firehose is in preview release and is subject to change.
         */
        endpoint: pulumi.Input<string>;
        /**
         * The port of the database. This can be one of the following values.
         *
         * - 3306 for MySQL database type
         * - 5432 for PostgreSQL database type
         *
         * Amazon Data Firehose is in preview release and is subject to change.
         */
        port: pulumi.Input<number>;
        publicCertificate?: pulumi.Input<string>;
        /**
         * The fully qualified name of the table in source database endpoint that Firehose uses to track snapshot progress.
         *
         * Amazon Data Firehose is in preview release and is subject to change.
         */
        snapshotWatermarkTable: pulumi.Input<string>;
        /**
         * The mode to enable or disable SSL when Firehose connects to the database endpoint.
         *
         * Amazon Data Firehose is in preview release and is subject to change.
         */
        sslMode?: pulumi.Input<enums.kinesisfirehose.DeliveryStreamDatabaseSourceConfigurationSslMode>;
        /**
         * The optional list of table and column names used as unique key columns when taking snapshot if the tables don’t have primary keys configured.
         *
         * Amazon Data Firehose is in preview release and is subject to change.
         */
        surrogateKeys?: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * The list of table patterns in source database endpoint for Firehose to read from.
         *
         * Amazon Data Firehose is in preview release and is subject to change.
         */
        tables: pulumi.Input<inputs.kinesisfirehose.DeliveryStreamDatabaseTablesArgs>;
        /**
         * The type of database engine. This can be one of the following values.
         *
         * - MySQL
         * - PostgreSQL
         *
         * Amazon Data Firehose is in preview release and is subject to change.
         */
        type: pulumi.Input<enums.kinesisfirehose.DeliveryStreamDatabaseSourceConfigurationType>;
    }
    interface DeliveryStreamDatabaseSourceVpcConfigurationArgs {
        /**
         * The VPC endpoint service name which Firehose uses to create a PrivateLink to the database. The endpoint service must have the Firehose service principle `firehose.amazonaws.com` as an allowed principal on the VPC endpoint service. The VPC endpoint service name is a string that looks like `com.amazonaws.vpce.<region>.<vpc-endpoint-service-id>` .
         *
         * Amazon Data Firehose is in preview release and is subject to change.
         */
        vpcEndpointServiceName: pulumi.Input<string>;
    }
    interface DeliveryStreamDatabaseTablesArgs {
        exclude?: pulumi.Input<pulumi.Input<string>[]>;
        include?: pulumi.Input<pulumi.Input<string>[]>;
    }
    interface DeliveryStreamDatabasesArgs {
        exclude?: pulumi.Input<pulumi.Input<string>[]>;
        include?: pulumi.Input<pulumi.Input<string>[]>;
    }
    interface DeliveryStreamDeserializerArgs {
        /**
         * The native Hive / HCatalog JsonSerDe. Used by Firehose for deserializing data, which means converting it from the JSON format in preparation for serializing it to the Parquet or ORC format. This is one of two deserializers you can choose, depending on which one offers the functionality you need. The other option is the OpenX SerDe.
         */
        hiveJsonSerDe?: pulumi.Input<inputs.kinesisfirehose.DeliveryStreamHiveJsonSerDeArgs>;
        /**
         * The OpenX SerDe. Used by Firehose for deserializing data, which means converting it from the JSON format in preparation for serializing it to the Parquet or ORC format. This is one of two deserializers you can choose, depending on which one offers the functionality you need. The other option is the native Hive / HCatalog JsonSerDe.
         */
        openXJsonSerDe?: pulumi.Input<inputs.kinesisfirehose.DeliveryStreamOpenXJsonSerDeArgs>;
    }
    interface DeliveryStreamDestinationTableConfigurationArgs {
        destinationDatabaseName: pulumi.Input<string>;
        destinationTableName: pulumi.Input<string>;
        s3ErrorOutputPrefix?: pulumi.Input<string>;
        uniqueKeys?: pulumi.Input<pulumi.Input<string>[]>;
    }
    interface DeliveryStreamDirectPutSourceConfigurationArgs {
        /**
         * The value that you configure for this parameter is for information purpose only and does not affect Firehose delivery throughput limit. You can use the [Firehose Limits form](https://docs.aws.amazon.com/https://support.console.aws.amazon.com/support/home#/case/create%3FissueType=service-limit-increase%26limitType=kinesis-firehose-limits) to request a throughput limit increase.
         */
        throughputHintInMbs?: pulumi.Input<number>;
    }
    interface DeliveryStreamDocumentIdOptionsArgs {
        /**
         * When the `FIREHOSE_DEFAULT` option is chosen, Firehose generates a unique document ID for each record based on a unique internal identifier. The generated document ID is stable across multiple delivery attempts, which helps prevent the same record from being indexed multiple times with different document IDs.
         *
         * When the `NO_DOCUMENT_ID` option is chosen, Firehose does not include any document IDs in the requests it sends to the Amazon OpenSearch Service. This causes the Amazon OpenSearch Service domain to generate document IDs. In case of multiple delivery attempts, this may cause the same record to be indexed more than once with different document IDs. This option enables write-heavy operations, such as the ingestion of logs and observability data, to consume less resources in the Amazon OpenSearch Service domain, resulting in improved performance.
         */
        defaultDocumentIdFormat: pulumi.Input<enums.kinesisfirehose.DeliveryStreamDocumentIdOptionsDefaultDocumentIdFormat>;
    }
    interface DeliveryStreamDynamicPartitioningConfigurationArgs {
        /**
         * Specifies whether dynamic partitioning is enabled for this Kinesis Data Firehose delivery stream.
         */
        enabled?: pulumi.Input<boolean>;
        /**
         * Specifies the retry behavior in case Kinesis Data Firehose is unable to deliver data to an Amazon S3 prefix.
         */
        retryOptions?: pulumi.Input<inputs.kinesisfirehose.DeliveryStreamRetryOptionsArgs>;
    }
    interface DeliveryStreamElasticsearchBufferingHintsArgs {
        /**
         * The length of time, in seconds, that Kinesis Data Firehose buffers incoming data before delivering it to the destination. For valid values, see the `IntervalInSeconds` content for the [BufferingHints](https://docs.aws.amazon.com/firehose/latest/APIReference/API_BufferingHints.html) data type in the *Amazon Kinesis Data Firehose API Reference* .
         */
        intervalInSeconds?: pulumi.Input<number>;
        /**
         * The size of the buffer, in MBs, that Kinesis Data Firehose uses for incoming data before delivering it to the destination. For valid values, see the `SizeInMBs` content for the [BufferingHints](https://docs.aws.amazon.com/firehose/latest/APIReference/API_BufferingHints.html) data type in the *Amazon Kinesis Data Firehose API Reference* .
         */
        sizeInMbs?: pulumi.Input<number>;
    }
    interface DeliveryStreamElasticsearchDestinationConfigurationArgs {
        /**
         * Configures how Kinesis Data Firehose buffers incoming data while delivering it to the Amazon ES domain.
         */
        bufferingHints?: pulumi.Input<inputs.kinesisfirehose.DeliveryStreamElasticsearchBufferingHintsArgs>;
        /**
         * The Amazon CloudWatch Logs logging options for the delivery stream.
         */
        cloudWatchLoggingOptions?: pulumi.Input<inputs.kinesisfirehose.DeliveryStreamCloudWatchLoggingOptionsArgs>;
        /**
         * The endpoint to use when communicating with the cluster. Specify either this `ClusterEndpoint` or the `DomainARN` field.
         */
        clusterEndpoint?: pulumi.Input<string>;
        /**
         * Indicates the method for setting up document ID. The supported methods are Firehose generated document ID and OpenSearch Service generated document ID.
         */
        documentIdOptions?: pulumi.Input<inputs.kinesisfirehose.DeliveryStreamDocumentIdOptionsArgs>;
        /**
         * The ARN of the Amazon ES domain. The IAM role must have permissions for `DescribeElasticsearchDomain` , `DescribeElasticsearchDomains` , and `DescribeElasticsearchDomainConfig` after assuming the role specified in *RoleARN* .
         *
         * Specify either `ClusterEndpoint` or `DomainARN` .
         */
        domainArn?: pulumi.Input<string>;
        /**
         * The name of the Elasticsearch index to which Kinesis Data Firehose adds data for indexing.
         */
        indexName: pulumi.Input<string>;
        /**
         * The frequency of Elasticsearch index rotation. If you enable index rotation, Kinesis Data Firehose appends a portion of the UTC arrival timestamp to the specified index name, and rotates the appended timestamp accordingly. For more information, see [Index Rotation for the Amazon ES Destination](https://docs.aws.amazon.com/firehose/latest/dev/basic-deliver.html#es-index-rotation) in the *Amazon Kinesis Data Firehose Developer Guide* .
         */
        indexRotationPeriod?: pulumi.Input<enums.kinesisfirehose.DeliveryStreamElasticsearchDestinationConfigurationIndexRotationPeriod>;
        /**
         * The data processing configuration for the Kinesis Data Firehose delivery stream.
         */
        processingConfiguration?: pulumi.Input<inputs.kinesisfirehose.DeliveryStreamProcessingConfigurationArgs>;
        /**
         * The retry behavior when Kinesis Data Firehose is unable to deliver data to Amazon ES.
         */
        retryOptions?: pulumi.Input<inputs.kinesisfirehose.DeliveryStreamElasticsearchRetryOptionsArgs>;
        /**
         * The Amazon Resource Name (ARN) of the IAM role to be assumed by Kinesis Data Firehose for calling the Amazon ES Configuration API and for indexing documents. For more information, see [Controlling Access with Amazon Kinesis Data Firehose](https://docs.aws.amazon.com/firehose/latest/dev/controlling-access.html) .
         */
        roleArn: pulumi.Input<string>;
        /**
         * The condition under which Kinesis Data Firehose delivers data to Amazon Simple Storage Service (Amazon S3). You can send Amazon S3 all documents (all data) or only the documents that Kinesis Data Firehose could not deliver to the Amazon ES destination. For more information and valid values, see the `S3BackupMode` content for the [ElasticsearchDestinationConfiguration](https://docs.aws.amazon.com/firehose/latest/APIReference/API_ElasticsearchDestinationConfiguration.html) data type in the *Amazon Kinesis Data Firehose API Reference* .
         */
        s3BackupMode?: pulumi.Input<enums.kinesisfirehose.DeliveryStreamElasticsearchDestinationConfigurationS3BackupMode>;
        /**
         * The S3 bucket where Kinesis Data Firehose backs up incoming data.
         */
        s3Configuration: pulumi.Input<inputs.kinesisfirehose.DeliveryStreamS3DestinationConfigurationArgs>;
        /**
         * The Elasticsearch type name that Amazon ES adds to documents when indexing data.
         */
        typeName?: pulumi.Input<string>;
        /**
         * The details of the VPC of the Amazon ES destination.
         */
        vpcConfiguration?: pulumi.Input<inputs.kinesisfirehose.DeliveryStreamVpcConfigurationArgs>;
    }
    interface DeliveryStreamElasticsearchRetryOptionsArgs {
        /**
         * After an initial failure to deliver to Amazon ES, the total amount of time during which Kinesis Data Firehose re-attempts delivery (including the first attempt). If Kinesis Data Firehose can't deliver the data within the specified time, it writes the data to the backup S3 bucket. For valid values, see the `DurationInSeconds` content for the [ElasticsearchRetryOptions](https://docs.aws.amazon.com/firehose/latest/APIReference/API_ElasticsearchRetryOptions.html) data type in the *Amazon Kinesis Data Firehose API Reference* .
         */
        durationInSeconds?: pulumi.Input<number>;
    }
    interface DeliveryStreamEncryptionConfigurationArgs {
        /**
         * The AWS Key Management Service ( AWS KMS) encryption key that Amazon S3 uses to encrypt your data.
         */
        kmsEncryptionConfig?: pulumi.Input<inputs.kinesisfirehose.DeliveryStreamKmsEncryptionConfigArgs>;
        /**
         * Disables encryption. For valid values, see the `NoEncryptionConfig` content for the [EncryptionConfiguration](https://docs.aws.amazon.com/firehose/latest/APIReference/API_EncryptionConfiguration.html) data type in the *Amazon Kinesis Data Firehose API Reference* .
         */
        noEncryptionConfig?: pulumi.Input<enums.kinesisfirehose.DeliveryStreamEncryptionConfigurationNoEncryptionConfig>;
    }
    interface DeliveryStreamEncryptionConfigurationInputArgs {
        /**
         * If you set `KeyType` to `CUSTOMER_MANAGED_CMK` , you must specify the Amazon Resource Name (ARN) of the CMK. If you set `KeyType` to `AWS _OWNED_CMK` , Firehose uses a service-account CMK.
         */
        keyArn?: pulumi.Input<string>;
        /**
         * Indicates the type of customer master key (CMK) to use for encryption. The default setting is `AWS_OWNED_CMK` . For more information about CMKs, see [Customer Master Keys (CMKs)](https://docs.aws.amazon.com/kms/latest/developerguide/concepts.html#master_keys) .
         *
         * You can use a CMK of type CUSTOMER_MANAGED_CMK to encrypt up to 500 delivery streams.
         *
         * > To encrypt your delivery stream, use symmetric CMKs. Kinesis Data Firehose doesn't support asymmetric CMKs. For information about symmetric and asymmetric CMKs, see [About Symmetric and Asymmetric CMKs](https://docs.aws.amazon.com/kms/latest/developerguide/symm-asymm-concepts.html) in the AWS Key Management Service developer guide.
         */
        keyType: pulumi.Input<enums.kinesisfirehose.DeliveryStreamEncryptionConfigurationInputKeyType>;
    }
    interface DeliveryStreamExtendedS3DestinationConfigurationArgs {
        /**
         * The Amazon Resource Name (ARN) of the Amazon S3 bucket. For constraints, see [ExtendedS3DestinationConfiguration](https://docs.aws.amazon.com/firehose/latest/APIReference/API_ExtendedS3DestinationConfiguration.html) in the *Amazon Kinesis Data Firehose API Reference* .
         */
        bucketArn: pulumi.Input<string>;
        /**
         * The buffering option.
         */
        bufferingHints?: pulumi.Input<inputs.kinesisfirehose.DeliveryStreamBufferingHintsArgs>;
        /**
         * The Amazon CloudWatch logging options for your Firehose stream.
         */
        cloudWatchLoggingOptions?: pulumi.Input<inputs.kinesisfirehose.DeliveryStreamCloudWatchLoggingOptionsArgs>;
        /**
         * The compression format. If no value is specified, the default is `UNCOMPRESSED` .
         */
        compressionFormat?: pulumi.Input<enums.kinesisfirehose.DeliveryStreamExtendedS3DestinationConfigurationCompressionFormat>;
        /**
         * The time zone you prefer. UTC is the default.
         */
        customTimeZone?: pulumi.Input<string>;
        /**
         * The serializer, deserializer, and schema for converting data from the JSON format to the Parquet or ORC format before writing it to Amazon S3.
         */
        dataFormatConversionConfiguration?: pulumi.Input<inputs.kinesisfirehose.DeliveryStreamDataFormatConversionConfigurationArgs>;
        /**
         * The configuration of the dynamic partitioning mechanism that creates targeted data sets from the streaming data by partitioning it based on partition keys.
         */
        dynamicPartitioningConfiguration?: pulumi.Input<inputs.kinesisfirehose.DeliveryStreamDynamicPartitioningConfigurationArgs>;
        /**
         * The encryption configuration for the Kinesis Data Firehose delivery stream. The default value is `NoEncryption` .
         */
        encryptionConfiguration?: pulumi.Input<inputs.kinesisfirehose.DeliveryStreamEncryptionConfigurationArgs>;
        /**
         * A prefix that Kinesis Data Firehose evaluates and adds to failed records before writing them to S3. This prefix appears immediately following the bucket name. For information about how to specify this prefix, see [Custom Prefixes for Amazon S3 Objects](https://docs.aws.amazon.com/firehose/latest/dev/s3-prefixes.html) .
         */
        errorOutputPrefix?: pulumi.Input<string>;
        /**
         * Specify a file extension. It will override the default file extension
         */
        fileExtension?: pulumi.Input<string>;
        /**
         * The `YYYY/MM/DD/HH` time format prefix is automatically used for delivered Amazon S3 files. For more information, see [ExtendedS3DestinationConfiguration](https://docs.aws.amazon.com/firehose/latest/APIReference/API_ExtendedS3DestinationConfiguration.html) in the *Amazon Kinesis Data Firehose API Reference* .
         */
        prefix?: pulumi.Input<string>;
        /**
         * The data processing configuration for the Kinesis Data Firehose delivery stream.
         */
        processingConfiguration?: pulumi.Input<inputs.kinesisfirehose.DeliveryStreamProcessingConfigurationArgs>;
        /**
         * The Amazon Resource Name (ARN) of the AWS credentials. For constraints, see [ExtendedS3DestinationConfiguration](https://docs.aws.amazon.com/firehose/latest/APIReference/API_ExtendedS3DestinationConfiguration.html) in the *Amazon Kinesis Data Firehose API Reference* .
         */
        roleArn: pulumi.Input<string>;
        /**
         * The configuration for backup in Amazon S3.
         */
        s3BackupConfiguration?: pulumi.Input<inputs.kinesisfirehose.DeliveryStreamS3DestinationConfigurationArgs>;
        /**
         * The Amazon S3 backup mode. After you create a Firehose stream, you can update it to enable Amazon S3 backup if it is disabled. If backup is enabled, you can't update the Firehose stream to disable it.
         */
        s3BackupMode?: pulumi.Input<enums.kinesisfirehose.DeliveryStreamExtendedS3DestinationConfigurationS3BackupMode>;
    }
    interface DeliveryStreamHiveJsonSerDeArgs {
        /**
         * Indicates how you want Firehose to parse the date and timestamps that may be present in your input data JSON. To specify these format strings, follow the pattern syntax of JodaTime's DateTimeFormat format strings. For more information, see [Class DateTimeFormat](https://docs.aws.amazon.com/https://www.joda.org/joda-time/apidocs/org/joda/time/format/DateTimeFormat.html) . You can also use the special value `millis` to parse timestamps in epoch milliseconds. If you don't specify a format, Firehose uses `java.sql.Timestamp::valueOf` by default.
         */
        timestampFormats?: pulumi.Input<pulumi.Input<string>[]>;
    }
    interface DeliveryStreamHttpEndpointCommonAttributeArgs {
        /**
         * The name of the HTTP endpoint common attribute.
         */
        attributeName: pulumi.Input<string>;
        /**
         * The value of the HTTP endpoint common attribute.
         */
        attributeValue: pulumi.Input<string>;
    }
    interface DeliveryStreamHttpEndpointConfigurationArgs {
        /**
         * The access key required for Kinesis Firehose to authenticate with the HTTP endpoint selected as the destination.
         */
        accessKey?: pulumi.Input<string>;
        /**
         * The name of the HTTP endpoint selected as the destination.
         */
        name?: pulumi.Input<string>;
        /**
         * The URL of the HTTP endpoint selected as the destination.
         */
        url: pulumi.Input<string>;
    }
    interface DeliveryStreamHttpEndpointDestinationConfigurationArgs {
        /**
         * The buffering options that can be used before data is delivered to the specified destination. Kinesis Data Firehose treats these options as hints, and it might choose to use more optimal values. The SizeInMBs and IntervalInSeconds parameters are optional. However, if you specify a value for one of them, you must also provide a value for the other.
         */
        bufferingHints?: pulumi.Input<inputs.kinesisfirehose.DeliveryStreamBufferingHintsArgs>;
        /**
         * Describes the Amazon CloudWatch logging options for your delivery stream.
         */
        cloudWatchLoggingOptions?: pulumi.Input<inputs.kinesisfirehose.DeliveryStreamCloudWatchLoggingOptionsArgs>;
        /**
         * The configuration of the HTTP endpoint selected as the destination.
         */
        endpointConfiguration: pulumi.Input<inputs.kinesisfirehose.DeliveryStreamHttpEndpointConfigurationArgs>;
        /**
         * Describes the data processing configuration.
         */
        processingConfiguration?: pulumi.Input<inputs.kinesisfirehose.DeliveryStreamProcessingConfigurationArgs>;
        /**
         * The configuration of the request sent to the HTTP endpoint specified as the destination.
         */
        requestConfiguration?: pulumi.Input<inputs.kinesisfirehose.DeliveryStreamHttpEndpointRequestConfigurationArgs>;
        /**
         * Describes the retry behavior in case Kinesis Data Firehose is unable to deliver data to the specified HTTP endpoint destination, or if it doesn't receive a valid acknowledgment of receipt from the specified HTTP endpoint destination.
         */
        retryOptions?: pulumi.Input<inputs.kinesisfirehose.DeliveryStreamRetryOptionsArgs>;
        /**
         * Kinesis Data Firehose uses this IAM role for all the permissions that the delivery stream needs.
         */
        roleArn?: pulumi.Input<string>;
        /**
         * Describes the S3 bucket backup options for the data that Kinesis Data Firehose delivers to the HTTP endpoint destination. You can back up all documents (AllData) or only the documents that Kinesis Data Firehose could not deliver to the specified HTTP endpoint destination (FailedDataOnly).
         */
        s3BackupMode?: pulumi.Input<string>;
        /**
         * Describes the configuration of a destination in Amazon S3.
         */
        s3Configuration: pulumi.Input<inputs.kinesisfirehose.DeliveryStreamS3DestinationConfigurationArgs>;
        /**
         * The configuration that defines how you access secrets for HTTP Endpoint destination.
         */
        secretsManagerConfiguration?: pulumi.Input<inputs.kinesisfirehose.DeliveryStreamSecretsManagerConfigurationArgs>;
    }
    interface DeliveryStreamHttpEndpointRequestConfigurationArgs {
        /**
         * Describes the metadata sent to the HTTP endpoint destination.
         */
        commonAttributes?: pulumi.Input<pulumi.Input<inputs.kinesisfirehose.DeliveryStreamHttpEndpointCommonAttributeArgs>[]>;
        /**
         * Kinesis Data Firehose uses the content encoding to compress the body of a request before sending the request to the destination. For more information, see Content-Encoding in MDN Web Docs, the official Mozilla documentation.
         */
        contentEncoding?: pulumi.Input<enums.kinesisfirehose.DeliveryStreamHttpEndpointRequestConfigurationContentEncoding>;
    }
    interface DeliveryStreamIcebergDestinationConfigurationArgs {
        /**
         * Describes whether all incoming data for this delivery stream will be append only (inserts only and not for updates and deletes) for Iceberg delivery. This feature is only applicable for Apache Iceberg Tables.
         *
         * The default value is false. If you set this value to true, Firehose automatically increases the throughput limit of a stream based on the throttling levels of the stream. If you set this parameter to true for a stream with updates and deletes, you will see out of order delivery.
         */
        appendOnly?: pulumi.Input<boolean>;
        bufferingHints?: pulumi.Input<inputs.kinesisfirehose.DeliveryStreamBufferingHintsArgs>;
        /**
         * Configuration describing where the destination Apache Iceberg Tables are persisted.
         */
        catalogConfiguration: pulumi.Input<inputs.kinesisfirehose.DeliveryStreamCatalogConfigurationArgs>;
        cloudWatchLoggingOptions?: pulumi.Input<inputs.kinesisfirehose.DeliveryStreamCloudWatchLoggingOptionsArgs>;
        /**
         * Provides a list of `DestinationTableConfigurations` which Firehose uses to deliver data to Apache Iceberg Tables. Firehose will write data with insert if table specific configuration is not provided here.
         */
        destinationTableConfigurationList?: pulumi.Input<pulumi.Input<inputs.kinesisfirehose.DeliveryStreamDestinationTableConfigurationArgs>[]>;
        processingConfiguration?: pulumi.Input<inputs.kinesisfirehose.DeliveryStreamProcessingConfigurationArgs>;
        retryOptions?: pulumi.Input<inputs.kinesisfirehose.DeliveryStreamRetryOptionsArgs>;
        /**
         * The Amazon Resource Name (ARN) of the IAM role to be assumed by Firehose for calling Apache Iceberg Tables.
         */
        roleArn: pulumi.Input<string>;
        /**
         * Describes how Firehose will backup records. Currently,S3 backup only supports `FailedDataOnly` .
         */
        s3BackupMode?: pulumi.Input<enums.kinesisfirehose.DeliveryStreamIcebergDestinationConfigurations3BackupMode>;
        s3Configuration: pulumi.Input<inputs.kinesisfirehose.DeliveryStreamS3DestinationConfigurationArgs>;
    }
    interface DeliveryStreamInputFormatConfigurationArgs {
        /**
         * Specifies which deserializer to use. You can choose either the Apache Hive JSON SerDe or the OpenX JSON SerDe. If both are non-null, the server rejects the request.
         */
        deserializer?: pulumi.Input<inputs.kinesisfirehose.DeliveryStreamDeserializerArgs>;
    }
    interface DeliveryStreamKinesisStreamSourceConfigurationArgs {
        /**
         * The ARN of the source Kinesis data stream.
         */
        kinesisStreamArn: pulumi.Input<string>;
        /**
         * The ARN of the role that provides access to the source Kinesis data stream.
         */
        roleArn: pulumi.Input<string>;
    }
    interface DeliveryStreamKmsEncryptionConfigArgs {
        /**
         * The Amazon Resource Name (ARN) of the AWS KMS encryption key that Amazon S3 uses to encrypt data delivered by the Kinesis Data Firehose stream. The key must belong to the same region as the destination S3 bucket.
         */
        awskmsKeyArn: pulumi.Input<string>;
    }
    interface DeliveryStreamMskSourceConfigurationArgs {
        /**
         * The authentication configuration of the Amazon MSK cluster.
         */
        authenticationConfiguration: pulumi.Input<inputs.kinesisfirehose.DeliveryStreamAuthenticationConfigurationArgs>;
        /**
         * The ARN of the Amazon MSK cluster.
         */
        mskClusterArn: pulumi.Input<string>;
        /**
         * The start date and time in UTC for the offset position within your MSK topic from where Firehose begins to read. By default, this is set to timestamp when Firehose becomes Active.
         *
         * If you want to create a Firehose stream with Earliest start position from SDK or CLI, you need to set the `ReadFromTimestamp` parameter to Epoch (1970-01-01T00:00:00Z).
         */
        readFromTimestamp?: pulumi.Input<string>;
        /**
         * The topic name within the Amazon MSK cluster.
         */
        topicName: pulumi.Input<string>;
    }
    interface DeliveryStreamOpenXJsonSerDeArgs {
        /**
         * When set to `true` , which is the default, Firehose converts JSON keys to lowercase before deserializing them.
         */
        caseInsensitive?: pulumi.Input<boolean>;
        /**
         * Maps column names to JSON keys that aren't identical to the column names. This is useful when the JSON contains keys that are Hive keywords. For example, `timestamp` is a Hive keyword. If you have a JSON key named `timestamp` , set this parameter to `{"ts": "timestamp"}` to map this key to a column named `ts` .
         */
        columnToJsonKeyMappings?: pulumi.Input<{
            [key: string]: pulumi.Input<string>;
        }>;
        /**
         * When set to `true` , specifies that the names of the keys include dots and that you want Firehose to replace them with underscores. This is useful because Apache Hive does not allow dots in column names. For example, if the JSON contains a key whose name is "a.b", you can define the column name to be "a_b" when using this option.
         *
         * The default is `false` .
         */
        convertDotsInJsonKeysToUnderscores?: pulumi.Input<boolean>;
    }
    interface DeliveryStreamOrcSerDeArgs {
        /**
         * The Hadoop Distributed File System (HDFS) block size. This is useful if you intend to copy the data from Amazon S3 to HDFS before querying. The default is 256 MiB and the minimum is 64 MiB. Firehose uses this value for padding calculations.
         */
        blockSizeBytes?: pulumi.Input<number>;
        /**
         * The column names for which you want Firehose to create bloom filters. The default is `null` .
         */
        bloomFilterColumns?: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * The Bloom filter false positive probability (FPP). The lower the FPP, the bigger the Bloom filter. The default value is 0.05, the minimum is 0, and the maximum is 1.
         */
        bloomFilterFalsePositiveProbability?: pulumi.Input<number>;
        /**
         * The compression code to use over data blocks. The default is `SNAPPY` .
         */
        compression?: pulumi.Input<string>;
        /**
         * Represents the fraction of the total number of non-null rows. To turn off dictionary encoding, set this fraction to a number that is less than the number of distinct keys in a dictionary. To always use dictionary encoding, set this threshold to 1.
         */
        dictionaryKeyThreshold?: pulumi.Input<number>;
        /**
         * Set this to `true` to indicate that you want stripes to be padded to the HDFS block boundaries. This is useful if you intend to copy the data from Amazon S3 to HDFS before querying. The default is `false` .
         */
        enablePadding?: pulumi.Input<boolean>;
        /**
         * The version of the file to write. The possible values are `V0_11` and `V0_12` . The default is `V0_12` .
         */
        formatVersion?: pulumi.Input<string>;
        /**
         * A number between 0 and 1 that defines the tolerance for block padding as a decimal fraction of stripe size. The default value is 0.05, which means 5 percent of stripe size.
         *
         * For the default values of 64 MiB ORC stripes and 256 MiB HDFS blocks, the default block padding tolerance of 5 percent reserves a maximum of 3.2 MiB for padding within the 256 MiB block. In such a case, if the available size within the block is more than 3.2 MiB, a new, smaller stripe is inserted to fit within that space. This ensures that no stripe crosses block boundaries and causes remote reads within a node-local task.
         *
         * Kinesis Data Firehose ignores this parameter when `EnablePadding` is `false` .
         */
        paddingTolerance?: pulumi.Input<number>;
        /**
         * The number of rows between index entries. The default is 10,000 and the minimum is 1,000.
         */
        rowIndexStride?: pulumi.Input<number>;
        /**
         * The number of bytes in each stripe. The default is 64 MiB and the minimum is 8 MiB.
         */
        stripeSizeBytes?: pulumi.Input<number>;
    }
    interface DeliveryStreamOutputFormatConfigurationArgs {
        /**
         * Specifies which serializer to use. You can choose either the ORC SerDe or the Parquet SerDe. If both are non-null, the server rejects the request.
         */
        serializer?: pulumi.Input<inputs.kinesisfirehose.DeliveryStreamSerializerArgs>;
    }
    interface DeliveryStreamParquetSerDeArgs {
        /**
         * The Hadoop Distributed File System (HDFS) block size. This is useful if you intend to copy the data from Amazon S3 to HDFS before querying. The default is 256 MiB and the minimum is 64 MiB. Firehose uses this value for padding calculations.
         */
        blockSizeBytes?: pulumi.Input<number>;
        /**
         * The compression code to use over data blocks. The possible values are `UNCOMPRESSED` , `SNAPPY` , and `GZIP` , with the default being `SNAPPY` . Use `SNAPPY` for higher decompression speed. Use `GZIP` if the compression ratio is more important than speed.
         */
        compression?: pulumi.Input<string>;
        /**
         * Indicates whether to enable dictionary compression.
         */
        enableDictionaryCompression?: pulumi.Input<boolean>;
        /**
         * The maximum amount of padding to apply. This is useful if you intend to copy the data from Amazon S3 to HDFS before querying. The default is 0.
         */
        maxPaddingBytes?: pulumi.Input<number>;
        /**
         * The Parquet page size. Column chunks are divided into pages. A page is conceptually an indivisible unit (in terms of compression and encoding). The minimum value is 64 KiB and the default is 1 MiB.
         */
        pageSizeBytes?: pulumi.Input<number>;
        /**
         * Indicates the version of row format to output. The possible values are `V1` and `V2` . The default is `V1` .
         */
        writerVersion?: pulumi.Input<string>;
    }
    interface DeliveryStreamProcessingConfigurationArgs {
        /**
         * Indicates whether data processing is enabled (true) or disabled (false).
         */
        enabled?: pulumi.Input<boolean>;
        /**
         * The data processors.
         */
        processors?: pulumi.Input<pulumi.Input<inputs.kinesisfirehose.DeliveryStreamProcessorArgs>[]>;
    }
    interface DeliveryStreamProcessorArgs {
        /**
         * The processor parameters.
         */
        parameters?: pulumi.Input<pulumi.Input<inputs.kinesisfirehose.DeliveryStreamProcessorParameterArgs>[]>;
        /**
         * The type of processor. Valid values: `Lambda` .
         */
        type: pulumi.Input<enums.kinesisfirehose.DeliveryStreamProcessorType>;
    }
    interface DeliveryStreamProcessorParameterArgs {
        /**
         * The name of the parameter. Currently the following default values are supported: 3 for `NumberOfRetries` and 60 for the `BufferIntervalInSeconds` . The `BufferSizeInMBs` ranges between 0.2 MB and up to 3MB. The default buffering hint is 1MB for all destinations, except Splunk. For Splunk, the default buffering hint is 256 KB.
         */
        parameterName: pulumi.Input<string>;
        /**
         * The parameter value.
         */
        parameterValue: pulumi.Input<string>;
    }
    interface DeliveryStreamRedshiftDestinationConfigurationArgs {
        /**
         * The CloudWatch logging options for your Firehose stream.
         */
        cloudWatchLoggingOptions?: pulumi.Input<inputs.kinesisfirehose.DeliveryStreamCloudWatchLoggingOptionsArgs>;
        /**
         * The connection string that Kinesis Data Firehose uses to connect to the Amazon Redshift cluster.
         */
        clusterJdbcurl: pulumi.Input<string>;
        /**
         * Configures the Amazon Redshift `COPY` command that Kinesis Data Firehose uses to load data into the cluster from the Amazon S3 bucket.
         */
        copyCommand: pulumi.Input<inputs.kinesisfirehose.DeliveryStreamCopyCommandArgs>;
        /**
         * The password for the Amazon Redshift user that you specified in the `Username` property.
         */
        password?: pulumi.Input<string>;
        /**
         * The data processing configuration for the Kinesis Data Firehose delivery stream.
         */
        processingConfiguration?: pulumi.Input<inputs.kinesisfirehose.DeliveryStreamProcessingConfigurationArgs>;
        /**
         * The retry behavior in case Firehose is unable to deliver documents to Amazon Redshift. Default value is 3600 (60 minutes).
         */
        retryOptions?: pulumi.Input<inputs.kinesisfirehose.DeliveryStreamRedshiftRetryOptionsArgs>;
        /**
         * The ARN of the AWS Identity and Access Management (IAM) role that grants Kinesis Data Firehose access to your Amazon S3 bucket and AWS KMS (if you enable data encryption). For more information, see [Grant Kinesis Data Firehose Access to an Amazon Redshift Destination](https://docs.aws.amazon.com/firehose/latest/dev/controlling-access.html#using-iam-rs) in the *Amazon Kinesis Data Firehose Developer Guide* .
         */
        roleArn: pulumi.Input<string>;
        /**
         * The configuration for backup in Amazon S3.
         */
        s3BackupConfiguration?: pulumi.Input<inputs.kinesisfirehose.DeliveryStreamS3DestinationConfigurationArgs>;
        /**
         * The Amazon S3 backup mode. After you create a Firehose stream, you can update it to enable Amazon S3 backup if it is disabled. If backup is enabled, you can't update the Firehose stream to disable it.
         */
        s3BackupMode?: pulumi.Input<enums.kinesisfirehose.DeliveryStreamRedshiftDestinationConfigurationS3BackupMode>;
        /**
         * The S3 bucket where Kinesis Data Firehose first delivers data. After the data is in the bucket, Kinesis Data Firehose uses the `COPY` command to load the data into the Amazon Redshift cluster. For the Amazon S3 bucket's compression format, don't specify `SNAPPY` or `ZIP` because the Amazon Redshift `COPY` command doesn't support them.
         */
        s3Configuration: pulumi.Input<inputs.kinesisfirehose.DeliveryStreamS3DestinationConfigurationArgs>;
        /**
         * The configuration that defines how you access secrets for Amazon Redshift.
         */
        secretsManagerConfiguration?: pulumi.Input<inputs.kinesisfirehose.DeliveryStreamSecretsManagerConfigurationArgs>;
        /**
         * The Amazon Redshift user that has permission to access the Amazon Redshift cluster. This user must have `INSERT` privileges for copying data from the Amazon S3 bucket to the cluster.
         */
        username?: pulumi.Input<string>;
    }
    interface DeliveryStreamRedshiftRetryOptionsArgs {
        /**
         * The length of time during which Firehose retries delivery after a failure, starting from the initial request and including the first attempt. The default value is 3600 seconds (60 minutes). Firehose does not retry if the value of `DurationInSeconds` is 0 (zero) or if the first delivery attempt takes longer than the current value.
         */
        durationInSeconds?: pulumi.Input<number>;
    }
    interface DeliveryStreamRetryOptionsArgs {
        /**
         * The total amount of time that Kinesis Data Firehose spends on retries. This duration starts after the initial attempt to send data to the custom destination via HTTPS endpoint fails. It doesn't include the periods during which Kinesis Data Firehose waits for acknowledgment from the specified destination after each attempt.
         */
        durationInSeconds?: pulumi.Input<number>;
    }
    interface DeliveryStreamS3DestinationConfigurationArgs {
        /**
         * The Amazon Resource Name (ARN) of the Amazon S3 bucket to send data to.
         */
        bucketArn: pulumi.Input<string>;
        /**
         * Configures how Kinesis Data Firehose buffers incoming data while delivering it to the Amazon S3 bucket.
         */
        bufferingHints?: pulumi.Input<inputs.kinesisfirehose.DeliveryStreamBufferingHintsArgs>;
        /**
         * The CloudWatch logging options for your Firehose stream.
         */
        cloudWatchLoggingOptions?: pulumi.Input<inputs.kinesisfirehose.DeliveryStreamCloudWatchLoggingOptionsArgs>;
        /**
         * The type of compression that Kinesis Data Firehose uses to compress the data that it delivers to the Amazon S3 bucket. For valid values, see the `CompressionFormat` content for the [S3DestinationConfiguration](https://docs.aws.amazon.com/firehose/latest/APIReference/API_S3DestinationConfiguration.html) data type in the *Amazon Kinesis Data Firehose API Reference* .
         */
        compressionFormat?: pulumi.Input<enums.kinesisfirehose.DeliveryStreamS3DestinationConfigurationCompressionFormat>;
        /**
         * Configures Amazon Simple Storage Service (Amazon S3) server-side encryption. Kinesis Data Firehose uses AWS Key Management Service ( AWS KMS) to encrypt the data that it delivers to your Amazon S3 bucket.
         */
        encryptionConfiguration?: pulumi.Input<inputs.kinesisfirehose.DeliveryStreamEncryptionConfigurationArgs>;
        /**
         * A prefix that Kinesis Data Firehose evaluates and adds to failed records before writing them to S3. This prefix appears immediately following the bucket name. For information about how to specify this prefix, see [Custom Prefixes for Amazon S3 Objects](https://docs.aws.amazon.com/firehose/latest/dev/s3-prefixes.html) .
         */
        errorOutputPrefix?: pulumi.Input<string>;
        /**
         * A prefix that Kinesis Data Firehose adds to the files that it delivers to the Amazon S3 bucket. The prefix helps you identify the files that Kinesis Data Firehose delivered.
         */
        prefix?: pulumi.Input<string>;
        /**
         * The ARN of an AWS Identity and Access Management (IAM) role that grants Kinesis Data Firehose access to your Amazon S3 bucket and AWS KMS (if you enable data encryption). For more information, see [Grant Kinesis Data Firehose Access to an Amazon S3 Destination](https://docs.aws.amazon.com/firehose/latest/dev/controlling-access.html#using-iam-s3) in the *Amazon Kinesis Data Firehose Developer Guide* .
         */
        roleArn: pulumi.Input<string>;
    }
    interface DeliveryStreamSchemaConfigurationArgs {
        /**
         * The ID of the AWS Glue Data Catalog. If you don't supply this, the AWS account ID is used by default.
         */
        catalogId?: pulumi.Input<string>;
        /**
         * Specifies the name of the AWS Glue database that contains the schema for the output data.
         *
         * > If the `SchemaConfiguration` request parameter is used as part of invoking the `CreateDeliveryStream` API, then the `DatabaseName` property is required and its value must be specified.
         */
        databaseName?: pulumi.Input<string>;
        /**
         * If you don't specify an AWS Region, the default is the current Region.
         */
        region?: pulumi.Input<string>;
        /**
         * The role that Firehose can use to access AWS Glue. This role must be in the same account you use for Firehose. Cross-account roles aren't allowed.
         *
         * > If the `SchemaConfiguration` request parameter is used as part of invoking the `CreateDeliveryStream` API, then the `RoleARN` property is required and its value must be specified.
         */
        roleArn?: pulumi.Input<string>;
        /**
         * Specifies the AWS Glue table that contains the column information that constitutes your data schema.
         *
         * > If the `SchemaConfiguration` request parameter is used as part of invoking the `CreateDeliveryStream` API, then the `TableName` property is required and its value must be specified.
         */
        tableName?: pulumi.Input<string>;
        /**
         * Specifies the table version for the output data schema. If you don't specify this version ID, or if you set it to `LATEST` , Firehose uses the most recent version. This means that any updates to the table are automatically picked up.
         */
        versionId?: pulumi.Input<string>;
    }
    interface DeliveryStreamSecretsManagerConfigurationArgs {
        /**
         * Specifies whether you want to use the secrets manager feature. When set as `True` the secrets manager configuration overwrites the existing secrets in the destination configuration. When it's set to `False` Firehose falls back to the credentials in the destination configuration.
         */
        enabled: pulumi.Input<boolean>;
        /**
         * Specifies the role that Firehose assumes when calling the Secrets Manager API operation. When you provide the role, it overrides any destination specific role defined in the destination configuration. If you do not provide the then we use the destination specific role. This parameter is required for Splunk.
         */
        roleArn?: pulumi.Input<string>;
        /**
         * The ARN of the secret that stores your credentials. It must be in the same region as the Firehose stream and the role. The secret ARN can reside in a different account than the Firehose stream and role as Firehose supports cross-account secret access. This parameter is required when *Enabled* is set to `True` .
         */
        secretArn?: pulumi.Input<string>;
    }
    interface DeliveryStreamSerializerArgs {
        /**
         * A serializer to use for converting data to the ORC format before storing it in Amazon S3. For more information, see [Apache ORC](https://docs.aws.amazon.com/https://orc.apache.org/docs/) .
         */
        orcSerDe?: pulumi.Input<inputs.kinesisfirehose.DeliveryStreamOrcSerDeArgs>;
        /**
         * A serializer to use for converting data to the Parquet format before storing it in Amazon S3. For more information, see [Apache Parquet](https://docs.aws.amazon.com/https://parquet.apache.org/docs/contribution-guidelines/) .
         */
        parquetSerDe?: pulumi.Input<inputs.kinesisfirehose.DeliveryStreamParquetSerDeArgs>;
    }
    interface DeliveryStreamSnowflakeBufferingHintsArgs {
        /**
         * Buffer incoming data for the specified period of time, in seconds, before delivering it to the destination. The default value is 0.
         */
        intervalInSeconds?: pulumi.Input<number>;
        /**
         * Buffer incoming data to the specified size, in MBs, before delivering it to the destination. The default value is 128.
         */
        sizeInMbs?: pulumi.Input<number>;
    }
    interface DeliveryStreamSnowflakeDestinationConfigurationArgs {
        /**
         * URL for accessing your Snowflake account. This URL must include your [account identifier](https://docs.aws.amazon.com/https://docs.snowflake.com/en/user-guide/admin-account-identifier) . Note that the protocol (https://) and port number are optional.
         */
        accountUrl: pulumi.Input<string>;
        /**
         * Describes the buffering to perform before delivering data to the Snowflake destination. If you do not specify any value, Firehose uses the default values.
         */
        bufferingHints?: pulumi.Input<inputs.kinesisfirehose.DeliveryStreamSnowflakeBufferingHintsArgs>;
        cloudWatchLoggingOptions?: pulumi.Input<inputs.kinesisfirehose.DeliveryStreamCloudWatchLoggingOptionsArgs>;
        /**
         * The name of the record content column.
         */
        contentColumnName?: pulumi.Input<string>;
        /**
         * Choose to load JSON keys mapped to table column names or choose to split the JSON payload where content is mapped to a record content column and source metadata is mapped to a record metadata column.
         */
        dataLoadingOption?: pulumi.Input<enums.kinesisfirehose.DeliveryStreamSnowflakeDestinationConfigurationDataLoadingOption>;
        /**
         * All data in Snowflake is maintained in databases.
         */
        database: pulumi.Input<string>;
        /**
         * Passphrase to decrypt the private key when the key is encrypted. For information, see [Using Key Pair Authentication & Key Rotation](https://docs.aws.amazon.com/https://docs.snowflake.com/en/user-guide/data-load-snowpipe-streaming-configuration#using-key-pair-authentication-key-rotation) .
         */
        keyPassphrase?: pulumi.Input<string>;
        /**
         * Specify a column name in the table, where the metadata information has to be loaded. When you enable this field, you will see the following column in the snowflake table, which differs based on the source type.
         *
         * For Direct PUT as source
         *
         * `{ "firehoseDeliveryStreamName" : "streamname", "IngestionTime" : "timestamp" }`
         *
         * For Kinesis Data Stream as source
         *
         * `"kinesisStreamName" : "streamname", "kinesisShardId" : "Id", "kinesisPartitionKey" : "key", "kinesisSequenceNumber" : "1234", "subsequenceNumber" : "2334", "IngestionTime" : "timestamp" }`
         */
        metaDataColumnName?: pulumi.Input<string>;
        /**
         * The private key used to encrypt your Snowflake client. For information, see [Using Key Pair Authentication & Key Rotation](https://docs.aws.amazon.com/https://docs.snowflake.com/en/user-guide/data-load-snowpipe-streaming-configuration#using-key-pair-authentication-key-rotation) .
         */
        privateKey?: pulumi.Input<string>;
        processingConfiguration?: pulumi.Input<inputs.kinesisfirehose.DeliveryStreamProcessingConfigurationArgs>;
        /**
         * The time period where Firehose will retry sending data to the chosen HTTP endpoint.
         */
        retryOptions?: pulumi.Input<inputs.kinesisfirehose.DeliveryStreamSnowflakeRetryOptionsArgs>;
        /**
         * The Amazon Resource Name (ARN) of the Snowflake role
         */
        roleArn: pulumi.Input<string>;
        /**
         * Choose an S3 backup mode
         */
        s3BackupMode?: pulumi.Input<enums.kinesisfirehose.DeliveryStreamSnowflakeDestinationConfigurationS3BackupMode>;
        s3Configuration: pulumi.Input<inputs.kinesisfirehose.DeliveryStreamS3DestinationConfigurationArgs>;
        /**
         * Each database consists of one or more schemas, which are logical groupings of database objects, such as tables and views
         */
        schema: pulumi.Input<string>;
        /**
         * The configuration that defines how you access secrets for Snowflake.
         */
        secretsManagerConfiguration?: pulumi.Input<inputs.kinesisfirehose.DeliveryStreamSecretsManagerConfigurationArgs>;
        /**
         * Optionally configure a Snowflake role. Otherwise the default user role will be used.
         */
        snowflakeRoleConfiguration?: pulumi.Input<inputs.kinesisfirehose.DeliveryStreamSnowflakeRoleConfigurationArgs>;
        /**
         * The VPCE ID for Firehose to privately connect with Snowflake. The ID format is com.amazonaws.vpce.[region].vpce-svc-<[id]>. For more information, see [Amazon PrivateLink & Snowflake](https://docs.aws.amazon.com/https://docs.snowflake.com/en/user-guide/admin-security-privatelink)
         */
        snowflakeVpcConfiguration?: pulumi.Input<inputs.kinesisfirehose.DeliveryStreamSnowflakeVpcConfigurationArgs>;
        /**
         * All data in Snowflake is stored in database tables, logically structured as collections of columns and rows.
         */
        table: pulumi.Input<string>;
        /**
         * User login name for the Snowflake account.
         */
        user?: pulumi.Input<string>;
    }
    interface DeliveryStreamSnowflakeRetryOptionsArgs {
        /**
         * the time period where Firehose will retry sending data to the chosen HTTP endpoint.
         */
        durationInSeconds?: pulumi.Input<number>;
    }
    interface DeliveryStreamSnowflakeRoleConfigurationArgs {
        /**
         * Enable Snowflake role
         */
        enabled?: pulumi.Input<boolean>;
        /**
         * The Snowflake role you wish to configure
         */
        snowflakeRole?: pulumi.Input<string>;
    }
    interface DeliveryStreamSnowflakeVpcConfigurationArgs {
        /**
         * The VPCE ID for Firehose to privately connect with Snowflake. The ID format is com.amazonaws.vpce.[region].vpce-svc-<[id]>. For more information, see [Amazon PrivateLink & Snowflake](https://docs.aws.amazon.com/https://docs.snowflake.com/en/user-guide/admin-security-privatelink)
         */
        privateLinkVpceId: pulumi.Input<string>;
    }
    interface DeliveryStreamSplunkBufferingHintsArgs {
        /**
         * Buffer incoming data for the specified period of time, in seconds, before delivering it to the destination. The default value is 60 (1 minute).
         */
        intervalInSeconds?: pulumi.Input<number>;
        /**
         * Buffer incoming data to the specified size, in MBs, before delivering it to the destination. The default value is 5.
         */
        sizeInMbs?: pulumi.Input<number>;
    }
    interface DeliveryStreamSplunkDestinationConfigurationArgs {
        /**
         * The buffering options. If no value is specified, the default values for Splunk are used.
         */
        bufferingHints?: pulumi.Input<inputs.kinesisfirehose.DeliveryStreamSplunkBufferingHintsArgs>;
        /**
         * The Amazon CloudWatch logging options for your Firehose stream.
         */
        cloudWatchLoggingOptions?: pulumi.Input<inputs.kinesisfirehose.DeliveryStreamCloudWatchLoggingOptionsArgs>;
        /**
         * The amount of time that Firehose waits to receive an acknowledgment from Splunk after it sends it data. At the end of the timeout period, Firehose either tries to send the data again or considers it an error, based on your retry settings.
         */
        hecAcknowledgmentTimeoutInSeconds?: pulumi.Input<number>;
        /**
         * The HTTP Event Collector (HEC) endpoint to which Firehose sends your data.
         */
        hecEndpoint: pulumi.Input<string>;
        /**
         * This type can be either `Raw` or `Event` .
         */
        hecEndpointType: pulumi.Input<enums.kinesisfirehose.DeliveryStreamSplunkDestinationConfigurationHecEndpointType>;
        /**
         * This is a GUID that you obtain from your Splunk cluster when you create a new HEC endpoint.
         */
        hecToken?: pulumi.Input<string>;
        /**
         * The data processing configuration.
         */
        processingConfiguration?: pulumi.Input<inputs.kinesisfirehose.DeliveryStreamProcessingConfigurationArgs>;
        /**
         * The retry behavior in case Firehose is unable to deliver data to Splunk, or if it doesn't receive an acknowledgment of receipt from Splunk.
         */
        retryOptions?: pulumi.Input<inputs.kinesisfirehose.DeliveryStreamSplunkRetryOptionsArgs>;
        /**
         * Defines how documents should be delivered to Amazon S3. When set to `FailedEventsOnly` , Firehose writes any data that could not be indexed to the configured Amazon S3 destination. When set to `AllEvents` , Firehose delivers all incoming records to Amazon S3, and also writes failed documents to Amazon S3. The default value is `FailedEventsOnly` .
         *
         * You can update this backup mode from `FailedEventsOnly` to `AllEvents` . You can't update it from `AllEvents` to `FailedEventsOnly` .
         */
        s3BackupMode?: pulumi.Input<string>;
        /**
         * The configuration for the backup Amazon S3 location.
         */
        s3Configuration: pulumi.Input<inputs.kinesisfirehose.DeliveryStreamS3DestinationConfigurationArgs>;
        /**
         * The configuration that defines how you access secrets for Splunk.
         */
        secretsManagerConfiguration?: pulumi.Input<inputs.kinesisfirehose.DeliveryStreamSecretsManagerConfigurationArgs>;
    }
    interface DeliveryStreamSplunkRetryOptionsArgs {
        /**
         * The total amount of time that Firehose spends on retries. This duration starts after the initial attempt to send data to Splunk fails. It doesn't include the periods during which Firehose waits for acknowledgment from Splunk after each attempt.
         */
        durationInSeconds?: pulumi.Input<number>;
    }
    interface DeliveryStreamVpcConfigurationArgs {
        /**
         * The ARN of the IAM role that you want the delivery stream to use to create endpoints in the destination VPC. You can use your existing Kinesis Data Firehose delivery role or you can specify a new role. In either case, make sure that the role trusts the Kinesis Data Firehose service principal and that it grants the following permissions:
         *
         * - `ec2:DescribeVpcs`
         * - `ec2:DescribeVpcAttribute`
         * - `ec2:DescribeSubnets`
         * - `ec2:DescribeSecurityGroups`
         * - `ec2:DescribeNetworkInterfaces`
         * - `ec2:CreateNetworkInterface`
         * - `ec2:CreateNetworkInterfacePermission`
         * - `ec2:DeleteNetworkInterface`
         *
         * If you revoke these permissions after you create the delivery stream, Kinesis Data Firehose can't scale out by creating more ENIs when necessary. You might therefore see a degradation in performance.
         */
        roleArn: pulumi.Input<string>;
        /**
         * The IDs of the security groups that you want Kinesis Data Firehose to use when it creates ENIs in the VPC of the Amazon ES destination. You can use the same security group that the Amazon ES domain uses or different ones. If you specify different security groups here, ensure that they allow outbound HTTPS traffic to the Amazon ES domain's security group. Also ensure that the Amazon ES domain's security group allows HTTPS traffic from the security groups specified here. If you use the same security group for both your delivery stream and the Amazon ES domain, make sure the security group inbound rule allows HTTPS traffic.
         */
        securityGroupIds: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * The IDs of the subnets that Kinesis Data Firehose uses to create ENIs in the VPC of the Amazon ES destination. Make sure that the routing tables and inbound and outbound rules allow traffic to flow from the subnets whose IDs are specified here to the subnets that have the destination Amazon ES endpoints. Kinesis Data Firehose creates at least one ENI in each of the subnets that are specified here. Do not delete or modify these ENIs.
         *
         * The number of ENIs that Kinesis Data Firehose creates in the subnets specified here scales up and down automatically based on throughput. To enable Kinesis Data Firehose to scale up the number of ENIs to match throughput, ensure that you have sufficient quota. To help you calculate the quota you need, assume that Kinesis Data Firehose can create up to three ENIs for this delivery stream for each of the subnets specified here.
         */
        subnetIds: pulumi.Input<pulumi.Input<string>[]>;
    }
}
export declare namespace kinesisvideo {
}
export declare namespace kms {
}
export declare namespace lakeformation {
    /**
     * An object representing the Data Cells Filter's Columns. Either Column Names or a Wildcard is required.
     */
    interface DataCellsFilterColumnWildcardArgs {
        /**
         * A list of column names to be excluded from the Data Cells Filter.
         */
        excludedColumnNames?: pulumi.Input<pulumi.Input<string>[]>;
    }
    /**
     * An object representing the Data Cells Filter's Row Filter. Either a Filter Expression or a Wildcard is required.
     */
    interface DataCellsFilterRowFilterArgs {
        /**
         * An empty object representing a row wildcard.
         */
        allRowsWildcard?: any;
        /**
         * A PartiQL predicate.
         */
        filterExpression?: pulumi.Input<string>;
    }
    interface PrincipalPermissionsCatalogResourceArgs {
    }
    /**
     * A wildcard object, consisting of an optional list of excluded column names or indexes.
     */
    interface PrincipalPermissionsColumnWildcardArgs {
        /**
         * Excludes column names. Any column with this name will be excluded.
         */
        excludedColumnNames?: pulumi.Input<pulumi.Input<string>[]>;
    }
    /**
     * A structure that describes certain columns on certain rows.
     */
    interface PrincipalPermissionsDataCellsFilterResourceArgs {
        /**
         * A database in the GLUDC.
         */
        databaseName: pulumi.Input<string>;
        /**
         * The name given by the user to the data filter cell.
         */
        name: pulumi.Input<string>;
        /**
         * The ID of the catalog to which the table belongs.
         */
        tableCatalogId: pulumi.Input<string>;
        /**
         * The name of the table.
         */
        tableName: pulumi.Input<string>;
    }
    /**
     * The LFlong principal.
     */
    interface PrincipalPermissionsDataLakePrincipalArgs {
        /**
         * An identifier for the LFlong principal.
         */
        dataLakePrincipalIdentifier?: pulumi.Input<string>;
    }
    /**
     * A structure for a data location object where permissions are granted or revoked.
     */
    interface PrincipalPermissionsDataLocationResourceArgs {
        /**
         * The identifier for the GLUDC where the location is registered with LFlong.
         */
        catalogId: pulumi.Input<string>;
        /**
         * The Amazon Resource Name (ARN) that uniquely identifies the data location resource.
         */
        resourceArn: pulumi.Input<string>;
    }
    /**
     * A structure for the database object.
     */
    interface PrincipalPermissionsDatabaseResourceArgs {
        /**
         * The identifier for the Data Catalog. By default, it is the account ID of the caller.
         */
        catalogId: pulumi.Input<string>;
        /**
         * The name of the database resource. Unique to the Data Catalog.
         */
        name: pulumi.Input<string>;
    }
    /**
     * The LF-tag key and values attached to a resource.
     */
    interface PrincipalPermissionsLfTagArgs {
        /**
         * The key-name for the LF-tag.
         */
        tagKey?: pulumi.Input<string>;
        /**
         * A list of possible values of the corresponding ``TagKey`` of an LF-tag key-value pair.
         */
        tagValues?: pulumi.Input<pulumi.Input<string>[]>;
    }
    /**
     * A structure containing an LF-tag key and values for a resource.
     */
    interface PrincipalPermissionsLfTagKeyResourceArgs {
        /**
         * The identifier for the GLUDC where the location is registered with GLUDC.
         */
        catalogId: pulumi.Input<string>;
        /**
         * The key-name for the LF-tag.
         */
        tagKey: pulumi.Input<string>;
        /**
         * A list of possible values for the corresponding ``TagKey`` of an LF-tag key-value pair.
         */
        tagValues: pulumi.Input<pulumi.Input<string>[]>;
    }
    /**
     * A list of LF-tag conditions that define a resource's LF-tag policy.
     *  A structure that allows an admin to grant user permissions on certain conditions. For example, granting a role access to all columns that do not have the LF-tag 'PII' in tables that have the LF-tag 'Prod'.
     */
    interface PrincipalPermissionsLfTagPolicyResourceArgs {
        /**
         * The identifier for the GLUDC. The GLUDC is the persistent metadata store. It contains database definitions, table definitions, and other control information to manage your LFlong environment.
         */
        catalogId: pulumi.Input<string>;
        /**
         * A list of LF-tag conditions that apply to the resource's LF-tag policy.
         */
        expression: pulumi.Input<pulumi.Input<inputs.lakeformation.PrincipalPermissionsLfTagArgs>[]>;
        /**
         * The resource type for which the LF-tag policy applies.
         */
        resourceType: pulumi.Input<enums.lakeformation.PrincipalPermissionsResourceType>;
    }
    /**
     * A structure for the resource.
     */
    interface PrincipalPermissionsResourceArgs {
        /**
         * The identifier for the Data Catalog. By default, the account ID. The Data Catalog is the persistent metadata store. It contains database definitions, table definitions, and other control information to manage your LFlong environment.
         */
        catalog?: pulumi.Input<inputs.lakeformation.PrincipalPermissionsCatalogResourceArgs>;
        /**
         * A data cell filter.
         */
        dataCellsFilter?: pulumi.Input<inputs.lakeformation.PrincipalPermissionsDataCellsFilterResourceArgs>;
        /**
         * The location of an Amazon S3 path where permissions are granted or revoked.
         */
        dataLocation?: pulumi.Input<inputs.lakeformation.PrincipalPermissionsDataLocationResourceArgs>;
        /**
         * The database for the resource. Unique to the Data Catalog. A database is a set of associated table definitions organized into a logical group. You can Grant and Revoke database permissions to a principal.
         */
        database?: pulumi.Input<inputs.lakeformation.PrincipalPermissionsDatabaseResourceArgs>;
        /**
         * The LF-tag key and values attached to a resource.
         */
        lfTag?: pulumi.Input<inputs.lakeformation.PrincipalPermissionsLfTagKeyResourceArgs>;
        /**
         * A list of LF-tag conditions that define a resource's LF-tag policy.
         */
        lfTagPolicy?: pulumi.Input<inputs.lakeformation.PrincipalPermissionsLfTagPolicyResourceArgs>;
        /**
         * The table for the resource. A table is a metadata definition that represents your data. You can Grant and Revoke table privileges to a principal.
         */
        table?: pulumi.Input<inputs.lakeformation.PrincipalPermissionsTableResourceArgs>;
        /**
         * The table with columns for the resource. A principal with permissions to this resource can select metadata from the columns of a table in the Data Catalog and the underlying data in Amazon S3.
         */
        tableWithColumns?: pulumi.Input<inputs.lakeformation.PrincipalPermissionsTableWithColumnsResourceArgs>;
    }
    /**
     * A structure for the table object. A table is a metadata definition that represents your data. You can Grant and Revoke table privileges to a principal.
     */
    interface PrincipalPermissionsTableResourceArgs {
        /**
         * The identifier for the Data Catalog. By default, it is the account ID of the caller.
         */
        catalogId: pulumi.Input<string>;
        /**
         * The name of the database for the table. Unique to a Data Catalog. A database is a set of associated table definitions organized into a logical group. You can Grant and Revoke database privileges to a principal.
         */
        databaseName: pulumi.Input<string>;
        /**
         * The name of the table.
         */
        name?: pulumi.Input<string>;
        /**
         * A wildcard object representing every table under a database.
         *  At least one of ``TableResource$Name`` or ``TableResource$TableWildcard`` is required.
         */
        tableWildcard?: pulumi.Input<inputs.lakeformation.PrincipalPermissionsTableWildcardArgs>;
    }
    interface PrincipalPermissionsTableWildcardArgs {
    }
    /**
     * A structure for a table with columns object. This object is only used when granting a SELECT permission.
     *  This object must take a value for at least one of ``ColumnsNames``, ``ColumnsIndexes``, or ``ColumnsWildcard``.
     */
    interface PrincipalPermissionsTableWithColumnsResourceArgs {
        /**
         * The identifier for the GLUDC where the location is registered with LFlong.
         */
        catalogId: pulumi.Input<string>;
        /**
         * The list of column names for the table. At least one of ``ColumnNames`` or ``ColumnWildcard`` is required.
         */
        columnNames?: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * A wildcard specified by a ``ColumnWildcard`` object. At least one of ``ColumnNames`` or ``ColumnWildcard`` is required.
         */
        columnWildcard?: pulumi.Input<inputs.lakeformation.PrincipalPermissionsColumnWildcardArgs>;
        /**
         * The name of the database for the table with columns resource. Unique to the Data Catalog. A database is a set of associated table definitions organized into a logical group. You can Grant and Revoke database privileges to a principal.
         */
        databaseName: pulumi.Input<string>;
        /**
         * The name of the table resource. A table is a metadata definition that represents your data. You can Grant and Revoke table privileges to a principal.
         */
        name: pulumi.Input<string>;
    }
    interface TagAssociationCatalogResourceArgs {
    }
    interface TagAssociationDatabaseResourceArgs {
        /**
         * The identifier for the Data Catalog . By default, it should be the account ID of the caller.
         */
        catalogId: pulumi.Input<string>;
        /**
         * The name of the database resource. Unique to the Data Catalog.
         */
        name: pulumi.Input<string>;
    }
    interface TagAssociationLfTagPairArgs {
        catalogId: pulumi.Input<string>;
        tagKey: pulumi.Input<string>;
        tagValues: pulumi.Input<pulumi.Input<string>[]>;
    }
    interface TagAssociationResourceArgs {
        /**
         * The identifier for the Data Catalog. By default, the account ID. The Data Catalog is the persistent metadata store. It contains database definitions, table definitions, and other control information to manage your AWS Lake Formation environment.
         */
        catalog?: pulumi.Input<inputs.lakeformation.TagAssociationCatalogResourceArgs>;
        /**
         * The database for the resource. Unique to the Data Catalog. A database is a set of associated table definitions organized into a logical group. You can Grant and Revoke database permissions to a principal.
         */
        database?: pulumi.Input<inputs.lakeformation.TagAssociationDatabaseResourceArgs>;
        /**
         * The table for the resource. A table is a metadata definition that represents your data. You can Grant and Revoke table privileges to a principal.
         */
        table?: pulumi.Input<inputs.lakeformation.TagAssociationTableResourceArgs>;
        /**
         * The table with columns for the resource. A principal with permissions to this resource can select metadata from the columns of a table in the Data Catalog and the underlying data in Amazon S3.
         */
        tableWithColumns?: pulumi.Input<inputs.lakeformation.TagAssociationTableWithColumnsResourceArgs>;
    }
    interface TagAssociationTableResourceArgs {
        /**
         * The identifier for the Data Catalog . By default, it is the account ID of the caller.
         */
        catalogId: pulumi.Input<string>;
        /**
         * The name of the database for the table. Unique to a Data Catalog. A database is a set of associated table definitions organized into a logical group. You can Grant and Revoke database privileges to a principal.
         */
        databaseName: pulumi.Input<string>;
        /**
         * The name of the table.
         */
        name?: pulumi.Input<string>;
        /**
         * A wildcard object representing every table under a database.This is an object with no properties that effectively behaves as a true or false depending on whether not it is passed as a parameter. The valid inputs for a property with this type in either yaml or json is null or {}.
         *
         * At least one of `TableResource$Name` or `TableResource$TableWildcard` is required.
         */
        tableWildcard?: pulumi.Input<inputs.lakeformation.TagAssociationTableWildcardArgs>;
    }
    interface TagAssociationTableWildcardArgs {
    }
    interface TagAssociationTableWithColumnsResourceArgs {
        /**
         * A wildcard object representing every table under a database.
         *
         * At least one of TableResource$Name or TableResource$TableWildcard is required.
         */
        catalogId: pulumi.Input<string>;
        /**
         * The list of column names for the table. At least one of `ColumnNames` or `ColumnWildcard` is required.
         */
        columnNames: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * The name of the database for the table with columns resource. Unique to the Data Catalog. A database is a set of associated table definitions organized into a logical group. You can Grant and Revoke database privileges to a principal.
         */
        databaseName: pulumi.Input<string>;
        /**
         * The name of the table resource. A table is a metadata definition that represents your data. You can Grant and Revoke table privileges to a principal.
         */
        name: pulumi.Input<string>;
    }
}
export declare namespace lambda {
    /**
     * A provisioned concurrency configuration for a function's alias.
     */
    interface AliasProvisionedConcurrencyConfigurationArgs {
        /**
         * The amount of provisioned concurrency to allocate for the alias.
         */
        provisionedConcurrentExecutions: pulumi.Input<number>;
    }
    /**
     * The traffic-shifting configuration of a Lambda function alias.
     */
    interface AliasRoutingConfigurationArgs {
        /**
         * The second version, and the percentage of traffic that's routed to it.
         */
        additionalVersionWeights?: pulumi.Input<pulumi.Input<inputs.lambda.AliasVersionWeightArgs>[]>;
    }
    /**
     * The traffic-shifting configuration of a Lambda function alias.
     */
    interface AliasVersionWeightArgs {
        /**
         * The qualifier of the second version.
         */
        functionVersion: pulumi.Input<string>;
        /**
         * The percentage of traffic that the alias routes to the second version.
         */
        functionWeight: pulumi.Input<number>;
    }
    /**
     * When the CodeSigningConfig is later on attached to a function, the function code will be expected to be signed by profiles from this list
     */
    interface CodeSigningConfigAllowedPublishersArgs {
        /**
         * List of Signing profile version Arns
         */
        signingProfileVersionArns: pulumi.Input<pulumi.Input<string>[]>;
    }
    /**
     * Policies to control how to act if a signature is invalid
     */
    interface CodeSigningConfigCodeSigningPoliciesArgs {
        /**
         * Indicates how Lambda operations involve updating the code artifact will operate. Default to Warn if not provided
         */
        untrustedArtifactOnDeployment: pulumi.Input<enums.lambda.CodeSigningConfigCodeSigningPoliciesUntrustedArtifactOnDeployment>;
    }
    /**
     * A destination for events after they have been sent to a function for processing.
     */
    interface EventInvokeConfigDestinationConfigArgs {
        /**
         * The destination configuration for failed invocations.
         *
         * > When using an Amazon SQS queue as a destination, FIFO queues cannot be used.
         */
        onFailure?: pulumi.Input<inputs.lambda.EventInvokeConfigOnFailureArgs>;
        /**
         * The destination configuration for successful invocations.
         *
         * > When using an Amazon SQS queue as a destination, FIFO queues cannot be used.
         */
        onSuccess?: pulumi.Input<inputs.lambda.EventInvokeConfigOnSuccessArgs>;
    }
    /**
     * The destination configuration for failed invocations.
     */
    interface EventInvokeConfigOnFailureArgs {
        /**
         * The Amazon Resource Name (ARN) of the destination resource.
         */
        destination: pulumi.Input<string>;
    }
    /**
     * The destination configuration for successful invocations.
     */
    interface EventInvokeConfigOnSuccessArgs {
        /**
         * The Amazon Resource Name (ARN) of the destination resource.
         */
        destination: pulumi.Input<string>;
    }
    /**
     * Specific configuration settings for an Amazon Managed Streaming for Apache Kafka (Amazon MSK) event source.
     */
    interface EventSourceMappingAmazonManagedKafkaEventSourceConfigArgs {
        /**
         * The identifier for the Kafka consumer group to join. The consumer group ID must be unique among all your Kafka event sources. After creating a Kafka event source mapping with the consumer group ID specified, you cannot update this value. For more information, see [Customizable consumer group ID](https://docs.aws.amazon.com/lambda/latest/dg/with-msk.html#services-msk-consumer-group-id).
         */
        consumerGroupId?: pulumi.Input<string>;
    }
    /**
     * A configuration object that specifies the destination of an event after Lambda processes it.
     */
    interface EventSourceMappingDestinationConfigArgs {
        /**
         * The destination configuration for failed invocations.
         */
        onFailure?: pulumi.Input<inputs.lambda.EventSourceMappingOnFailureArgs>;
    }
    /**
     * Specific configuration settings for a DocumentDB event source.
     */
    interface EventSourceMappingDocumentDbEventSourceConfigArgs {
        /**
         * The name of the collection to consume within the database. If you do not specify a collection, Lambda consumes all collections.
         */
        collectionName?: pulumi.Input<string>;
        /**
         * The name of the database to consume within the DocumentDB cluster.
         */
        databaseName?: pulumi.Input<string>;
        /**
         * Determines what DocumentDB sends to your event stream during document update operations. If set to UpdateLookup, DocumentDB sends a delta describing the changes, along with a copy of the entire document. Otherwise, DocumentDB sends only a partial document that contains the changes.
         */
        fullDocument?: pulumi.Input<enums.lambda.EventSourceMappingDocumentDbEventSourceConfigFullDocument>;
    }
    /**
     * The list of bootstrap servers for your Kafka brokers in the following format: ``"KafkaBootstrapServers": ["abc.xyz.com:xxxx","abc2.xyz.com:xxxx"]``.
     */
    interface EventSourceMappingEndpointsArgs {
        /**
         * The list of bootstrap servers for your Kafka brokers in the following format: ``"KafkaBootstrapServers": ["abc.xyz.com:xxxx","abc2.xyz.com:xxxx"]``.
         */
        kafkaBootstrapServers?: pulumi.Input<pulumi.Input<string>[]>;
    }
    /**
     * A structure within a ``FilterCriteria`` object that defines an event filtering pattern.
     */
    interface EventSourceMappingFilterArgs {
        /**
         * A filter pattern. For more information on the syntax of a filter pattern, see [Filter rule syntax](https://docs.aws.amazon.com/lambda/latest/dg/invocation-eventfiltering.html#filtering-syntax).
         */
        pattern?: pulumi.Input<string>;
    }
    /**
     * An object that contains the filters for an event source.
     */
    interface EventSourceMappingFilterCriteriaArgs {
        /**
         * A list of filters.
         */
        filters?: pulumi.Input<pulumi.Input<inputs.lambda.EventSourceMappingFilterArgs>[]>;
    }
    /**
     * The metrics configuration for your event source. Use this configuration object to define which metrics you want your event source mapping to produce.
     */
    interface EventSourceMappingMetricsConfigArgs {
        /**
         * The metrics you want your event source mapping to produce. Include ``EventCount`` to receive event source mapping metrics related to the number of events processed by your event source mapping. For more information about these metrics, see [Event source mapping metrics](https://docs.aws.amazon.com/lambda/latest/dg/monitoring-metrics-types.html#event-source-mapping-metrics).
         */
        metrics?: pulumi.Input<pulumi.Input<enums.lambda.EventSourceMappingMetricsConfigMetricsItem>[]>;
    }
    /**
     * A destination for events that failed processing.
     */
    interface EventSourceMappingOnFailureArgs {
        /**
         * The Amazon Resource Name (ARN) of the destination resource.
         *  To retain records of unsuccessful [asynchronous invocations](https://docs.aws.amazon.com/lambda/latest/dg/invocation-async.html#invocation-async-destinations), you can configure an Amazon SNS topic, Amazon SQS queue, Amazon S3 bucket, Lambda function, or Amazon EventBridge event bus as the destination.
         *  To retain records of failed invocations from [Kinesis](https://docs.aws.amazon.com/lambda/latest/dg/with-kinesis.html), [DynamoDB](https://docs.aws.amazon.com/lambda/latest/dg/with-ddb.html), [self-managed Kafka](https://docs.aws.amazon.com/lambda/latest/dg/with-kafka.html#services-smaa-onfailure-destination) or [Amazon MSK](https://docs.aws.amazon.com/lambda/latest/dg/with-msk.html#services-msk-onfailure-destination), you can configure an Amazon SNS topic, Amazon SQS queue, or Amazon S3 bucket as the destination.
         */
        destination?: pulumi.Input<string>;
    }
    /**
     * The [provisioned mode](https://docs.aws.amazon.com/lambda/latest/dg/invocation-eventsourcemapping.html#invocation-eventsourcemapping-provisioned-mode) configuration for the event source. Use provisioned mode to customize the minimum and maximum number of event pollers for your event source.
     */
    interface EventSourceMappingProvisionedPollerConfigArgs {
        /**
         * The maximum number of event pollers this event source can scale up to.
         */
        maximumPollers?: pulumi.Input<number>;
        /**
         * The minimum number of event pollers this event source can scale down to.
         */
        minimumPollers?: pulumi.Input<number>;
    }
    /**
     * (Amazon SQS only) The scaling configuration for the event source. To remove the configuration, pass an empty value.
     */
    interface EventSourceMappingScalingConfigArgs {
        /**
         * Limits the number of concurrent instances that the SQS event source can invoke.
         */
        maximumConcurrency?: pulumi.Input<number>;
    }
    /**
     * The self-managed Apache Kafka cluster for your event source.
     */
    interface EventSourceMappingSelfManagedEventSourceArgs {
        /**
         * The list of bootstrap servers for your Kafka brokers in the following format: ``"KafkaBootstrapServers": ["abc.xyz.com:xxxx","abc2.xyz.com:xxxx"]``.
         */
        endpoints?: pulumi.Input<inputs.lambda.EventSourceMappingEndpointsArgs>;
    }
    /**
     * Specific configuration settings for a self-managed Apache Kafka event source.
     */
    interface EventSourceMappingSelfManagedKafkaEventSourceConfigArgs {
        /**
         * The identifier for the Kafka consumer group to join. The consumer group ID must be unique among all your Kafka event sources. After creating a Kafka event source mapping with the consumer group ID specified, you cannot update this value. For more information, see [Customizable consumer group ID](https://docs.aws.amazon.com/lambda/latest/dg/with-msk.html#services-msk-consumer-group-id).
         */
        consumerGroupId?: pulumi.Input<string>;
    }
    /**
     * An array of the authentication protocol, VPC components, or virtual host to secure and define your event source.
     */
    interface EventSourceMappingSourceAccessConfigurationArgs {
        /**
         * The type of authentication protocol, VPC components, or virtual host for your event source. For example: ``"Type":"SASL_SCRAM_512_AUTH"``.
         *   +   ``BASIC_AUTH`` – (Amazon MQ) The ASMlong secret that stores your broker credentials.
         *   +   ``BASIC_AUTH`` – (Self-managed Apache Kafka) The Secrets Manager ARN of your secret key used for SASL/PLAIN authentication of your Apache Kafka brokers.
         *   +   ``VPC_SUBNET`` – (Self-managed Apache Kafka) The subnets associated with your VPC. Lambda connects to these subnets to fetch data from your self-managed Apache Kafka cluster.
         *   +   ``VPC_SECURITY_GROUP`` – (Self-managed Apache Kafka) The VPC security group used to manage access to your self-managed Apache Kafka brokers.
         *   +   ``SASL_SCRAM_256_AUTH`` – (Self-managed Apache Kafka) The Secrets Manager ARN of your secret key used for SASL SCRAM-256 authentication of your self-managed Apache Kafka brokers.
         *   +   ``SASL_SCRAM_512_AUTH`` – (Amazon MSK, Self-managed Apache Kafka) The Secrets Manager ARN of your secret key used for SASL SCRAM-512 authentication of your self-managed Apache Kafka brokers.
         *   +   ``VIRTUAL_HOST`` –- (RabbitMQ) The name of the virtual host in your RabbitMQ broker. Lambda uses this RabbitMQ host as the event source. This property cannot be specified in an UpdateEventSourceMapping API call.
         *   +   ``CLIENT_CERTIFICATE_TLS_AUTH`` – (Amazon MSK, self-managed Apache Kafka) The Secrets Manager ARN of your secret key containing the certificate chain (X.509 PEM), private key (PKCS#8 PEM), and private key password (optional) used for mutual TLS authentication of your MSK/Apache Kafka brokers.
         *   +   ``SERVER_ROOT_CA_CERTIFICATE`` – (Self-managed Apache Kafka) The Secrets Manager ARN of your secret key containing the root CA certificate (X.509 PEM) used for TLS encryption of your Apache Kafka brokers.
         */
        type?: pulumi.Input<enums.lambda.EventSourceMappingSourceAccessConfigurationType>;
        /**
         * The value for your chosen configuration in ``Type``. For example: ``"URI": "arn:aws:secretsmanager:us-east-1:01234567890:secret:MyBrokerSecretName"``.
         */
        uri?: pulumi.Input<string>;
    }
    /**
     * The [deployment package](https://docs.aws.amazon.com/lambda/latest/dg/gettingstarted-package.html) for a Lambda function. To deploy a function defined as a container image, you specify the location of a container image in the Amazon ECR registry. For a .zip file deployment package, you can specify the location of an object in Amazon S3. For Node.js and Python functions, you can specify the function code inline in the template.
     *   When you specify source code inline for a Node.js function, the ``index`` file that CFN creates uses the extension ``.js``. This means that LAM treats the file as a CommonJS module. ES modules aren't supported for inline functions.
     *   Changes to a deployment package in Amazon S3 or a container image in ECR are not detected automatically during stack updates. To update the function code, change the object key or version in the template.
     */
    interface FunctionCodeArgs {
        /**
         * URI of a [container image](https://docs.aws.amazon.com/lambda/latest/dg/lambda-images.html) in the Amazon ECR registry.
         */
        imageUri?: pulumi.Input<string>;
        /**
         * An Amazon S3 bucket in the same AWS-Region as your function. The bucket can be in a different AWS-account.
         */
        s3Bucket?: pulumi.Input<string>;
        /**
         * The Amazon S3 key of the deployment package.
         */
        s3Key?: pulumi.Input<string>;
        /**
         * For versioned objects, the version of the deployment package object to use.
         */
        s3ObjectVersion?: pulumi.Input<string>;
        /**
         * The ARN of the KMSlong (KMS) customer managed key that's used to encrypt your function's .zip deployment package. If you don't provide a customer managed key, Lambda uses an [owned key](https://docs.aws.amazon.com/kms/latest/developerguide/concepts.html#aws-owned-cmk).
         */
        sourceKmsKeyArn?: pulumi.Input<string>;
        /**
         * (Node.js and Python) The source code of your Lambda function. If you include your function source inline with this parameter, CFN places it in a file named ``index`` and zips it to create a [deployment package](https://docs.aws.amazon.com/lambda/latest/dg/gettingstarted-package.html). This zip file cannot exceed 4MB. For the ``Handler`` property, the first part of the handler identifier must be ``index``. For example, ``index.handler``.
         *   When you specify source code inline for a Node.js function, the ``index`` file that CFN creates uses the extension ``.js``. This means that LAM treats the file as a CommonJS module. ES modules aren't supported for inline functions.
         *    For JSON, you must escape quotes and special characters such as newline (``\n``) with a backslash.
         *  If you specify a function that interacts with an AWS CloudFormation custom resource, you don't have to write your own functions to send responses to the custom resource that invoked the function. AWS CloudFormation provides a response module ([cfn-response](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/cfn-lambda-function-code-cfnresponsemodule.html)) that simplifies sending responses. See [Using Lambda with CloudFormation](https://docs.aws.amazon.com/lambda/latest/dg/services-cloudformation.html) for details.
         */
        zipFile?: pulumi.Input<string>;
    }
    /**
     * The [dead-letter queue](https://docs.aws.amazon.com/lambda/latest/dg/invocation-async.html#dlq) for failed asynchronous invocations.
     */
    interface FunctionDeadLetterConfigArgs {
        /**
         * The Amazon Resource Name (ARN) of an Amazon SQS queue or Amazon SNS topic.
         */
        targetArn?: pulumi.Input<string>;
    }
    /**
     * A function's environment variable settings. You can use environment variables to adjust your function's behavior without updating code. An environment variable is a pair of strings that are stored in a function's version-specific configuration.
     */
    interface FunctionEnvironmentArgs {
        /**
         * Environment variable key-value pairs. For more information, see [Using Lambda environment variables](https://docs.aws.amazon.com/lambda/latest/dg/configuration-envvars.html).
         *  If the value of the environment variable is a time or a duration, enclose the value in quotes.
         */
        variables?: pulumi.Input<{
            [key: string]: pulumi.Input<string>;
        }>;
    }
    /**
     * The size of the function's ``/tmp`` directory in MB. The default value is 512, but it can be any whole number between 512 and 10,240 MB.
     */
    interface FunctionEphemeralStorageArgs {
        /**
         * The size of the function's ``/tmp`` directory.
         */
        size: pulumi.Input<number>;
    }
    /**
     * Details about the connection between a Lambda function and an [Amazon EFS file system](https://docs.aws.amazon.com/lambda/latest/dg/configuration-filesystem.html).
     */
    interface FunctionFileSystemConfigArgs {
        /**
         * The Amazon Resource Name (ARN) of the Amazon EFS access point that provides access to the file system.
         */
        arn: pulumi.Input<string>;
        /**
         * The path where the function can access the file system, starting with ``/mnt/``.
         */
        localMountPath: pulumi.Input<string>;
    }
    /**
     * Configuration values that override the container image Dockerfile settings. For more information, see [Container image settings](https://docs.aws.amazon.com/lambda/latest/dg/images-create.html#images-parms).
     */
    interface FunctionImageConfigArgs {
        /**
         * Specifies parameters that you want to pass in with ENTRYPOINT. You can specify a maximum of 1,500 parameters in the list.
         */
        command?: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * Specifies the entry point to their application, which is typically the location of the runtime executable. You can specify a maximum of 1,500 string entries in the list.
         */
        entryPoint?: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * Specifies the working directory. The length of the directory string cannot exceed 1,000 characters.
         */
        workingDirectory?: pulumi.Input<string>;
    }
    /**
     * The function's Amazon CloudWatch Logs configuration settings.
     */
    interface FunctionLoggingConfigArgs {
        /**
         * Set this property to filter the application logs for your function that Lambda sends to CloudWatch. Lambda only sends application logs at the selected level of detail and lower, where ``TRACE`` is the highest level and ``FATAL`` is the lowest.
         */
        applicationLogLevel?: pulumi.Input<enums.lambda.FunctionLoggingConfigApplicationLogLevel>;
        /**
         * The format in which Lambda sends your function's application and system logs to CloudWatch. Select between plain text and structured JSON.
         */
        logFormat?: pulumi.Input<enums.lambda.FunctionLoggingConfigLogFormat>;
        /**
         * The name of the Amazon CloudWatch log group the function sends logs to. By default, Lambda functions send logs to a default log group named ``/aws/lambda/<function name>``. To use a different log group, enter an existing log group or enter a new log group name.
         */
        logGroup?: pulumi.Input<string>;
        /**
         * Set this property to filter the system logs for your function that Lambda sends to CloudWatch. Lambda only sends system logs at the selected level of detail and lower, where ``DEBUG`` is the highest level and ``WARN`` is the lowest.
         */
        systemLogLevel?: pulumi.Input<enums.lambda.FunctionLoggingConfigSystemLogLevel>;
    }
    /**
     * Sets the runtime management configuration for a function's version. For more information, see [Runtime updates](https://docs.aws.amazon.com/lambda/latest/dg/runtimes-update.html).
     */
    interface FunctionRuntimeManagementConfigArgs {
        /**
         * The ARN of the runtime version you want the function to use.
         *   This is only required if you're using the *Manual* runtime update mode.
         */
        runtimeVersionArn?: pulumi.Input<string>;
        /**
         * Specify the runtime update mode.
         *   +   *Auto (default)* - Automatically update to the most recent and secure runtime version using a [Two-phase runtime version rollout](https://docs.aws.amazon.com/lambda/latest/dg/runtimes-update.html#runtime-management-two-phase). This is the best choice for most customers to ensure they always benefit from runtime updates.
         *   +   *FunctionUpdate* - LAM updates the runtime of you function to the most recent and secure runtime version when you update your function. This approach synchronizes runtime updates with function deployments, giving you control over when runtime updates are applied and allowing you to detect and mitigate rare runtime update incompatibilities early. When using this setting, you need to regularly update your functions to keep their runtime up-to-date.
         *   +   *Manual* - You specify a runtime version in your function configuration. The function will use this runtime version indefinitely. In the rare case where a new runtime version is incompatible with an existing function, this allows you to roll back your function to an earlier runtime version. For more information, see [Roll back a runtime version](https://docs.aws.amazon.com/lambda/latest/dg/runtimes-update.html#runtime-management-rollback).
         *
         *   *Valid Values*: ``Auto`` | ``FunctionUpdate`` | ``Manual``
         */
        updateRuntimeOn: pulumi.Input<enums.lambda.FunctionRuntimeManagementConfigUpdateRuntimeOn>;
    }
    /**
     * The function's [SnapStart](https://docs.aws.amazon.com/lambda/latest/dg/snapstart.html) setting.
     */
    interface FunctionSnapStartArgs {
        /**
         * Set ``ApplyOn`` to ``PublishedVersions`` to create a snapshot of the initialized execution environment when you publish a function version.
         */
        applyOn: pulumi.Input<enums.lambda.FunctionSnapStartApplyOn>;
    }
    /**
     * The function's [](https://docs.aws.amazon.com/lambda/latest/dg/services-xray.html) tracing configuration. To sample and record incoming requests, set ``Mode`` to ``Active``.
     */
    interface FunctionTracingConfigArgs {
        /**
         * The tracing mode.
         */
        mode?: pulumi.Input<enums.lambda.FunctionTracingConfigMode>;
    }
    /**
     * The VPC security groups and subnets that are attached to a Lambda function. When you connect a function to a VPC, Lambda creates an elastic network interface for each combination of security group and subnet in the function's VPC configuration. The function can only access resources and the internet through that VPC. For more information, see [VPC Settings](https://docs.aws.amazon.com/lambda/latest/dg/configuration-vpc.html).
     *   When you delete a function, CFN monitors the state of its network interfaces and waits for Lambda to delete them before proceeding. If the VPC is defined in the same stack, the network interfaces need to be deleted by Lambda before CFN can delete the VPC's resources.
     *  To monitor network interfaces, CFN needs the ``ec2:DescribeNetworkInterfaces`` permission. It obtains this from the user or role that modifies the stack. If you don't provide this permission, CFN does not wait for network interfaces to be deleted.
     */
    interface FunctionVpcConfigArgs {
        /**
         * Allows outbound IPv6 traffic on VPC functions that are connected to dual-stack subnets.
         */
        ipv6AllowedForDualStack?: pulumi.Input<boolean>;
        /**
         * A list of VPC security group IDs.
         */
        securityGroupIds?: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * A list of VPC subnet IDs.
         */
        subnetIds?: pulumi.Input<pulumi.Input<string>[]>;
    }
    interface LayerVersionContentArgs {
        /**
         * The Amazon S3 bucket of the layer archive.
         */
        s3Bucket: pulumi.Input<string>;
        /**
         * The Amazon S3 key of the layer archive.
         */
        s3Key: pulumi.Input<string>;
        /**
         * For versioned objects, the version of the layer archive object to use.
         */
        s3ObjectVersion?: pulumi.Input<string>;
    }
    interface UrlCorsArgs {
        /**
         * Specifies whether credentials are included in the CORS request.
         */
        allowCredentials?: pulumi.Input<boolean>;
        /**
         * Represents a collection of allowed headers.
         */
        allowHeaders?: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * Represents a collection of allowed HTTP methods.
         */
        allowMethods?: pulumi.Input<pulumi.Input<enums.lambda.UrlAllowMethodsItem>[]>;
        /**
         * Represents a collection of allowed origins.
         */
        allowOrigins?: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * Represents a collection of exposed headers.
         */
        exposeHeaders?: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * The maximum amount of time, in seconds, that browsers can cache results of a preflight request. By default, this is set to `0` , which means the browser will not cache results.
         */
        maxAge?: pulumi.Input<number>;
    }
    /**
     * A provisioned concurrency configuration for a function's version.
     */
    interface VersionProvisionedConcurrencyConfigurationArgs {
        /**
         * The amount of provisioned concurrency to allocate for the version.
         */
        provisionedConcurrentExecutions: pulumi.Input<number>;
    }
    /**
     * Runtime Management Config of a function.
     */
    interface VersionRuntimePolicyArgs {
        /**
         * The ARN of the runtime the function is configured to use. If the runtime update mode is manual, the ARN is returned, otherwise null is returned.
         */
        runtimeVersionArn?: pulumi.Input<string>;
        /**
         * The runtime update mode.
         */
        updateRuntimeOn: pulumi.Input<string>;
    }
}
export declare namespace launchwizard {
}
export declare namespace lex {
    interface BotAdvancedRecognitionSettingArgs {
        /**
         * Enables using the slot values as a custom vocabulary for recognizing user utterances.
         */
        audioRecognitionStrategy?: pulumi.Input<enums.lex.BotAudioRecognitionStrategy>;
    }
    /**
     * The location of audio log files collected when conversation logging is enabled for a bot.
     */
    interface BotAliasAudioLogDestinationArgs {
        s3Bucket: pulumi.Input<inputs.lex.BotAliasS3BucketLogDestinationArgs>;
    }
    /**
     * Settings for logging audio of conversations between Amazon Lex and a user. You specify whether to log audio and the Amazon S3 bucket where the audio file is stored.
     */
    interface BotAliasAudioLogSettingArgs {
        destination: pulumi.Input<inputs.lex.BotAliasAudioLogDestinationArgs>;
        enabled: pulumi.Input<boolean>;
    }
    interface BotAliasCloudWatchLogGroupLogDestinationArgs {
        /**
         * A string used to identify the groupArn for the Cloudwatch Log Group
         */
        cloudWatchLogGroupArn: pulumi.Input<string>;
        /**
         * A string containing the value for the Log Prefix
         */
        logPrefix: pulumi.Input<string>;
    }
    /**
     * Contains information about code hooks that Amazon Lex calls during a conversation.
     */
    interface BotAliasCodeHookSpecificationArgs {
        lambdaCodeHook: pulumi.Input<inputs.lex.BotAliasLambdaCodeHookArgs>;
    }
    /**
     * Contains information about code hooks that Amazon Lex calls during a conversation.
     */
    interface BotAliasConversationLogSettingsArgs {
        /**
         * The Amazon S3 settings for logging audio to an S3 bucket.
         */
        audioLogSettings?: pulumi.Input<pulumi.Input<inputs.lex.BotAliasAudioLogSettingArgs>[]>;
        /**
         * The Amazon CloudWatch Logs settings for logging text and metadata.
         */
        textLogSettings?: pulumi.Input<pulumi.Input<inputs.lex.BotAliasTextLogSettingArgs>[]>;
    }
    /**
     * Contains information about code hooks that Amazon Lex calls during a conversation.
     */
    interface BotAliasLambdaCodeHookArgs {
        /**
         * The version of the request-response that you want Amazon Lex to use to invoke your Lambda function.
         */
        codeHookInterfaceVersion: pulumi.Input<string>;
        /**
         * The Amazon Resource Name (ARN) of the Lambda function.
         */
        lambdaArn: pulumi.Input<string>;
    }
    /**
     * You can use this parameter to specify a specific Lambda function to run different functions in different locales.
     */
    interface BotAliasLocaleSettingsArgs {
        codeHookSpecification?: pulumi.Input<inputs.lex.BotAliasCodeHookSpecificationArgs>;
        /**
         * Whether the Lambda code hook is enabled
         */
        enabled: pulumi.Input<boolean>;
    }
    /**
     * A locale setting in alias
     */
    interface BotAliasLocaleSettingsItemArgs {
        botAliasLocaleSetting: pulumi.Input<inputs.lex.BotAliasLocaleSettingsArgs>;
        /**
         * A string used to identify the locale
         */
        localeId: pulumi.Input<string>;
    }
    /**
     * Specifies an Amazon S3 bucket for logging audio conversations
     */
    interface BotAliasS3BucketLogDestinationArgs {
        /**
         * The Amazon Resource Name (ARN) of an AWS Key Management Service (KMS) key for encrypting audio log files stored in an S3 bucket.
         */
        kmsKeyArn?: pulumi.Input<string>;
        /**
         * The Amazon S3 key of the deployment package.
         */
        logPrefix: pulumi.Input<string>;
        /**
         * The Amazon Resource Name (ARN) of an Amazon S3 bucket where audio log files are stored.
         */
        s3BucketArn: pulumi.Input<string>;
    }
    /**
     * A label for tagging Lex resources
     */
    interface BotAliasTagArgs {
        /**
         * A string used to identify this tag
         */
        key: pulumi.Input<string>;
        /**
         * A string containing the value for the tag
         */
        value: pulumi.Input<string>;
    }
    /**
     * Defines the Amazon CloudWatch Logs destination log group for conversation text logs.
     */
    interface BotAliasTextLogDestinationArgs {
        cloudWatch: pulumi.Input<inputs.lex.BotAliasCloudWatchLogGroupLogDestinationArgs>;
    }
    /**
     * Contains information about code hooks that Amazon Lex calls during a conversation.
     */
    interface BotAliasTextLogSettingArgs {
        destination: pulumi.Input<inputs.lex.BotAliasTextLogDestinationArgs>;
        enabled: pulumi.Input<boolean>;
    }
    interface BotAllowedInputTypesArgs {
        allowAudioInput: pulumi.Input<boolean>;
        allowDtmfInput: pulumi.Input<boolean>;
    }
    interface BotAudioAndDtmfInputSpecificationArgs {
        audioSpecification?: pulumi.Input<inputs.lex.BotAudioSpecificationArgs>;
        dtmfSpecification?: pulumi.Input<inputs.lex.BotDtmfSpecificationArgs>;
        startTimeoutMs: pulumi.Input<number>;
    }
    interface BotAudioLogDestinationArgs {
        s3Bucket: pulumi.Input<inputs.lex.BotS3BucketLogDestinationArgs>;
    }
    interface BotAudioLogSettingArgs {
        destination: pulumi.Input<inputs.lex.BotAudioLogDestinationArgs>;
        enabled: pulumi.Input<boolean>;
    }
    interface BotAudioSpecificationArgs {
        endTimeoutMs: pulumi.Input<number>;
        maxLengthMs: pulumi.Input<number>;
    }
    interface BotBedrockAgentIntentConfigurationArgs {
        bedrockAgentConfiguration?: pulumi.Input<inputs.lex.BotBedrockAgentIntentConfigurationBedrockAgentConfigurationPropertiesArgs>;
        bedrockAgentIntentKnowledgeBaseConfiguration?: pulumi.Input<inputs.lex.BotBedrockAgentIntentConfigurationBedrockAgentIntentKnowledgeBaseConfigurationPropertiesArgs>;
    }
    interface BotBedrockAgentIntentConfigurationBedrockAgentConfigurationPropertiesArgs {
        bedrockAgentAliasId?: pulumi.Input<string>;
        bedrockAgentId?: pulumi.Input<string>;
    }
    interface BotBedrockAgentIntentConfigurationBedrockAgentIntentKnowledgeBaseConfigurationPropertiesArgs {
        bedrockKnowledgeBaseArn: pulumi.Input<string>;
        bedrockModelConfiguration: pulumi.Input<inputs.lex.BotBedrockModelSpecificationArgs>;
    }
    interface BotBedrockModelSpecificationArgs {
        bedrockGuardrailConfiguration?: pulumi.Input<inputs.lex.BotBedrockModelSpecificationBedrockGuardrailConfigurationPropertiesArgs>;
        bedrockModelCustomPrompt?: pulumi.Input<string>;
        bedrockTraceStatus?: pulumi.Input<enums.lex.BotBedrockModelSpecificationBedrockTraceStatus>;
        /**
         * The ARN of the foundation model used in descriptive bot building.
         */
        modelArn: pulumi.Input<string>;
    }
    interface BotBedrockModelSpecificationBedrockGuardrailConfigurationPropertiesArgs {
        bedrockGuardrailIdentifier?: pulumi.Input<string>;
        bedrockGuardrailVersion?: pulumi.Input<string>;
    }
    interface BotButtonArgs {
        text: pulumi.Input<string>;
        value: pulumi.Input<string>;
    }
    interface BotCloudWatchLogGroupLogDestinationArgs {
        cloudWatchLogGroupArn: pulumi.Input<string>;
        logPrefix: pulumi.Input<string>;
    }
    interface BotCompositeSlotTypeSettingArgs {
        /**
         * Subslots in the composite slot.
         */
        subSlots?: pulumi.Input<pulumi.Input<inputs.lex.BotSubSlotTypeCompositionArgs>[]>;
    }
    interface BotConditionArgs {
        expressionString: pulumi.Input<string>;
    }
    interface BotConditionalBranchArgs {
        condition: pulumi.Input<inputs.lex.BotConditionArgs>;
        name: pulumi.Input<string>;
        nextStep: pulumi.Input<inputs.lex.BotDialogStateArgs>;
        response?: pulumi.Input<inputs.lex.BotResponseSpecificationArgs>;
    }
    interface BotConditionalSpecificationArgs {
        /**
         * A list of conditional branches. A conditional branch is made up of a condition, a response and a next step. The response and next step are executed when the condition is true.
         */
        conditionalBranches: pulumi.Input<pulumi.Input<inputs.lex.BotConditionalBranchArgs>[]>;
        /**
         * The conditional branch that should be followed when the conditions for other branches are not satisfied. A conditional branch is made up of a condition, a response and a next step.
         */
        defaultBranch: pulumi.Input<inputs.lex.BotDefaultConditionalBranchArgs>;
        /**
         * Determines whether a conditional branch is active. When `IsActive` is false, the conditions are not evaluated.
         */
        isActive: pulumi.Input<boolean>;
    }
    interface BotConversationLogSettingsArgs {
        /**
         * The Amazon S3 settings for logging audio to an S3 bucket.
         */
        audioLogSettings?: pulumi.Input<pulumi.Input<inputs.lex.BotAudioLogSettingArgs>[]>;
        /**
         * The Amazon CloudWatch Logs settings for logging text and metadata.
         */
        textLogSettings?: pulumi.Input<pulumi.Input<inputs.lex.BotTextLogSettingArgs>[]>;
    }
    interface BotCustomPayloadArgs {
        value: pulumi.Input<string>;
    }
    interface BotCustomVocabularyArgs {
        /**
         * Specifies a list of words that you expect to be used during a conversation with your bot.
         */
        customVocabularyItems: pulumi.Input<pulumi.Input<inputs.lex.BotCustomVocabularyItemArgs>[]>;
    }
    interface BotCustomVocabularyItemArgs {
        displayAs?: pulumi.Input<string>;
        phrase: pulumi.Input<string>;
        weight?: pulumi.Input<number>;
    }
    interface BotDefaultConditionalBranchArgs {
        /**
         * The next step in the conversation.
         */
        nextStep?: pulumi.Input<inputs.lex.BotDialogStateArgs>;
        /**
         * Specifies a list of message groups that Amazon Lex uses to respond the user input.
         */
        response?: pulumi.Input<inputs.lex.BotResponseSpecificationArgs>;
    }
    interface BotDialogActionArgs {
        /**
         * If the dialog action is `ElicitSlot` , defines the slot to elicit from the user.
         */
        slotToElicit?: pulumi.Input<string>;
        /**
         * When true the next message for the intent is not used.
         */
        suppressNextMessage?: pulumi.Input<boolean>;
        /**
         * The action that the bot should execute.
         */
        type: pulumi.Input<enums.lex.BotDialogActionType>;
    }
    interface BotDialogCodeHookInvocationSettingArgs {
        /**
         * Indicates whether a Lambda function should be invoked for the dialog.
         */
        enableCodeHookInvocation: pulumi.Input<boolean>;
        /**
         * A label that indicates the dialog step from which the dialog code hook is happening.
         */
        invocationLabel?: pulumi.Input<string>;
        /**
         * Determines whether a dialog code hook is used when the intent is activated.
         */
        isActive: pulumi.Input<boolean>;
        /**
         * Contains the responses and actions that Amazon Lex takes after the Lambda function is complete.
         */
        postCodeHookSpecification: pulumi.Input<inputs.lex.BotPostDialogCodeHookInvocationSpecificationArgs>;
    }
    interface BotDialogCodeHookSettingArgs {
        /**
         * Enables the dialog code hook so that it processes user requests.
         */
        enabled: pulumi.Input<boolean>;
    }
    interface BotDialogStateArgs {
        /**
         * Defines the action that the bot executes at runtime when the conversation reaches this step.
         */
        dialogAction?: pulumi.Input<inputs.lex.BotDialogActionArgs>;
        /**
         * Override settings to configure the intent state.
         */
        intent?: pulumi.Input<inputs.lex.BotIntentOverrideArgs>;
        /**
         * Map of key/value pairs representing session-specific context information. It contains application information passed between Amazon Lex and a client application.
         */
        sessionAttributes?: pulumi.Input<pulumi.Input<inputs.lex.BotSessionAttributeArgs>[]>;
    }
    interface BotDtmfSpecificationArgs {
        deletionCharacter: pulumi.Input<string>;
        endCharacter: pulumi.Input<string>;
        endTimeoutMs: pulumi.Input<number>;
        maxLength: pulumi.Input<number>;
    }
    interface BotElicitationCodeHookInvocationSettingArgs {
        /**
         * Indicates whether a Lambda function should be invoked for the dialog.
         */
        enableCodeHookInvocation: pulumi.Input<boolean>;
        /**
         * A label that indicates the dialog step from which the dialog code hook is happening.
         */
        invocationLabel?: pulumi.Input<string>;
    }
    interface BotExternalSourceSettingArgs {
        /**
         * Settings required for a slot type based on a grammar that you provide.
         */
        grammarSlotTypeSetting?: pulumi.Input<inputs.lex.BotGrammarSlotTypeSettingArgs>;
    }
    interface BotFulfillmentCodeHookSettingArgs {
        /**
         * Indicates whether a Lambda function should be invoked to fulfill a specific intent.
         */
        enabled: pulumi.Input<boolean>;
        /**
         * Provides settings for update messages sent to the user for long-running Lambda fulfillment functions. Fulfillment updates can be used only with streaming conversations.
         */
        fulfillmentUpdatesSpecification?: pulumi.Input<inputs.lex.BotFulfillmentUpdatesSpecificationArgs>;
        /**
         * Determines whether the fulfillment code hook is used. When `active` is false, the code hook doesn't run.
         */
        isActive?: pulumi.Input<boolean>;
        /**
         * Provides settings for messages sent to the user for after the Lambda fulfillment function completes. Post-fulfillment messages can be sent for both streaming and non-streaming conversations.
         */
        postFulfillmentStatusSpecification?: pulumi.Input<inputs.lex.BotPostFulfillmentStatusSpecificationArgs>;
    }
    interface BotFulfillmentStartResponseSpecificationArgs {
        /**
         * Determines whether the user can interrupt the start message while it is playing.
         */
        allowInterrupt?: pulumi.Input<boolean>;
        /**
         * The delay between when the Lambda fulfillment function starts running and the start message is played. If the Lambda function returns before the delay is over, the start message isn't played.
         */
        delayInSeconds: pulumi.Input<number>;
        /**
         * 1 - 5 message groups that contain start messages. Amazon Lex chooses one of the messages to play to the user.
         */
        messageGroups: pulumi.Input<pulumi.Input<inputs.lex.BotMessageGroupArgs>[]>;
    }
    interface BotFulfillmentUpdateResponseSpecificationArgs {
        /**
         * Determines whether the user can interrupt an update message while it is playing.
         */
        allowInterrupt?: pulumi.Input<boolean>;
        /**
         * The frequency that a message is sent to the user. When the period ends, Amazon Lex chooses a message from the message groups and plays it to the user. If the fulfillment Lambda returns before the first period ends, an update message is not played to the user.
         */
        frequencyInSeconds: pulumi.Input<number>;
        /**
         * 1 - 5 message groups that contain update messages. Amazon Lex chooses one of the messages to play to the user.
         */
        messageGroups: pulumi.Input<pulumi.Input<inputs.lex.BotMessageGroupArgs>[]>;
    }
    interface BotFulfillmentUpdatesSpecificationArgs {
        /**
         * Determines whether fulfillment updates are sent to the user. When this field is true, updates are sent.
         *
         * If the `active` field is set to true, the `startResponse` , `updateResponse` , and `timeoutInSeconds` fields are required.
         */
        active: pulumi.Input<boolean>;
        /**
         * Provides configuration information for the message sent to users when the fulfillment Lambda functions starts running.
         */
        startResponse?: pulumi.Input<inputs.lex.BotFulfillmentStartResponseSpecificationArgs>;
        /**
         * The length of time that the fulfillment Lambda function should run before it times out.
         */
        timeoutInSeconds?: pulumi.Input<number>;
        /**
         * Provides configuration information for messages sent periodically to the user while the fulfillment Lambda function is running.
         */
        updateResponse?: pulumi.Input<inputs.lex.BotFulfillmentUpdateResponseSpecificationArgs>;
    }
    interface BotGrammarSlotTypeSettingArgs {
        /**
         * The source of the grammar used to create the slot type.
         */
        source?: pulumi.Input<inputs.lex.BotGrammarSlotTypeSourceArgs>;
    }
    interface BotGrammarSlotTypeSourceArgs {
        /**
         * The AWS KMS key required to decrypt the contents of the grammar, if any.
         */
        kmsKeyArn?: pulumi.Input<string>;
        /**
         * The name of the Amazon S3 bucket that contains the grammar source.
         */
        s3BucketName: pulumi.Input<string>;
        /**
         * The path to the grammar in the Amazon S3 bucket.
         */
        s3ObjectKey: pulumi.Input<string>;
    }
    interface BotImageResponseCardArgs {
        buttons?: pulumi.Input<pulumi.Input<inputs.lex.BotButtonArgs>[]>;
        imageUrl?: pulumi.Input<string>;
        subtitle?: pulumi.Input<string>;
        title: pulumi.Input<string>;
    }
    interface BotInitialResponseSettingArgs {
        /**
         * Settings that specify the dialog code hook that is called by Amazon Lex at a step of the conversation.
         */
        codeHook?: pulumi.Input<inputs.lex.BotDialogCodeHookInvocationSettingArgs>;
        /**
         * Provides a list of conditional branches. Branches are evaluated in the order that they are entered in the list. The first branch with a condition that evaluates to true is executed. The last branch in the list is the default branch. The default branch should not have any condition expression. The default branch is executed if no other branch has a matching condition.
         */
        conditional?: pulumi.Input<inputs.lex.BotConditionalSpecificationArgs>;
        /**
         * Specifies a list of message groups that Amazon Lex uses to respond the user input.
         */
        initialResponse?: pulumi.Input<inputs.lex.BotResponseSpecificationArgs>;
        /**
         * The next step in the conversation.
         */
        nextStep?: pulumi.Input<inputs.lex.BotDialogStateArgs>;
    }
    interface BotInputContextArgs {
        name: pulumi.Input<string>;
    }
    interface BotIntentArgs {
        bedrockAgentIntentConfiguration?: pulumi.Input<inputs.lex.BotBedrockAgentIntentConfigurationArgs>;
        /**
         * Description of thr intent.
         */
        description?: pulumi.Input<string>;
        /**
         * Specifies that Amazon Lex invokes the alias Lambda function for each user input. You can invoke this Lambda function to personalize user interaction.
         */
        dialogCodeHook?: pulumi.Input<inputs.lex.BotDialogCodeHookSettingArgs>;
        /**
         * Specifies that Amazon Lex invokes the alias Lambda function when the intent is ready for fulfillment. You can invoke this function to complete the bot's transaction with the user.
         */
        fulfillmentCodeHook?: pulumi.Input<inputs.lex.BotFulfillmentCodeHookSettingArgs>;
        /**
         * Configuration setting for a response sent to the user before Amazon Lex starts eliciting slots.
         */
        initialResponseSetting?: pulumi.Input<inputs.lex.BotInitialResponseSettingArgs>;
        /**
         * A list of contexts that must be active for this intent to be considered by Amazon Lex .
         */
        inputContexts?: pulumi.Input<pulumi.Input<inputs.lex.BotInputContextArgs>[]>;
        /**
         * Sets the response that Amazon Lex sends to the user when the intent is closed.
         */
        intentClosingSetting?: pulumi.Input<inputs.lex.BotIntentClosingSettingArgs>;
        /**
         * Provides prompts that Amazon Lex sends to the user to confirm the completion of an intent. If the user answers "no," the settings contain a statement that is sent to the user to end the intent.
         */
        intentConfirmationSetting?: pulumi.Input<inputs.lex.BotIntentConfirmationSettingArgs>;
        /**
         * Provides configuration information for the `AMAZON.KendraSearchIntent` intent. When you use this intent, Amazon Lex searches the specified Amazon Kendra index and returns documents from the index that match the user's utterance.
         */
        kendraConfiguration?: pulumi.Input<inputs.lex.BotKendraConfigurationArgs>;
        /**
         * The name of the intent. Intent names must be unique within the locale that contains the intent and can't match the name of any built-in intent.
         */
        name: pulumi.Input<string>;
        /**
         * A list of contexts that the intent activates when it is fulfilled.
         */
        outputContexts?: pulumi.Input<pulumi.Input<inputs.lex.BotOutputContextArgs>[]>;
        /**
         * A unique identifier for the built-in intent to base this intent on.
         */
        parentIntentSignature?: pulumi.Input<string>;
        qInConnectIntentConfiguration?: pulumi.Input<inputs.lex.BotQInConnectIntentConfigurationArgs>;
        qnAIntentConfiguration?: pulumi.Input<inputs.lex.BotQnAIntentConfigurationArgs>;
        /**
         * A list of utterances that a user might say to signal the intent.
         */
        sampleUtterances?: pulumi.Input<pulumi.Input<inputs.lex.BotSampleUtteranceArgs>[]>;
        /**
         * Indicates the priority for slots. Amazon Lex prompts the user for slot values in priority order.
         */
        slotPriorities?: pulumi.Input<pulumi.Input<inputs.lex.BotSlotPriorityArgs>[]>;
        /**
         * A list of slots that the intent requires for fulfillment.
         */
        slots?: pulumi.Input<pulumi.Input<inputs.lex.BotSlotArgs>[]>;
    }
    interface BotIntentClosingSettingArgs {
        /**
         * The response that Amazon Lex sends to the user when the intent is complete.
         */
        closingResponse?: pulumi.Input<inputs.lex.BotResponseSpecificationArgs>;
        /**
         * A list of conditional branches associated with the intent's closing response. These branches are executed when the `nextStep` attribute is set to `EvalutateConditional` .
         */
        conditional?: pulumi.Input<inputs.lex.BotConditionalSpecificationArgs>;
        /**
         * Specifies whether an intent's closing response is used. When this field is false, the closing response isn't sent to the user. If the `IsActive` field isn't specified, the default is true.
         */
        isActive?: pulumi.Input<boolean>;
        /**
         * Specifies the next step that the bot executes after playing the intent's closing response.
         */
        nextStep?: pulumi.Input<inputs.lex.BotDialogStateArgs>;
    }
    interface BotIntentConfirmationSettingArgs {
        /**
         * The `DialogCodeHookInvocationSetting` object associated with intent's confirmation step. The dialog code hook is triggered based on these invocation settings when the confirmation next step or declination next step or failure next step is `InvokeDialogCodeHook` .
         */
        codeHook?: pulumi.Input<inputs.lex.BotDialogCodeHookInvocationSettingArgs>;
        /**
         * A list of conditional branches to evaluate after the intent is closed.
         */
        confirmationConditional?: pulumi.Input<inputs.lex.BotConditionalSpecificationArgs>;
        /**
         * Specifies the next step that the bot executes when the customer confirms the intent.
         */
        confirmationNextStep?: pulumi.Input<inputs.lex.BotDialogStateArgs>;
        /**
         * Specifies a list of message groups that Amazon Lex uses to respond the user input.
         */
        confirmationResponse?: pulumi.Input<inputs.lex.BotResponseSpecificationArgs>;
        /**
         * A list of conditional branches to evaluate after the intent is declined.
         */
        declinationConditional?: pulumi.Input<inputs.lex.BotConditionalSpecificationArgs>;
        /**
         * Specifies the next step that the bot executes when the customer declines the intent.
         */
        declinationNextStep?: pulumi.Input<inputs.lex.BotDialogStateArgs>;
        /**
         * When the user answers "no" to the question defined in `promptSpecification` , Amazon Lex responds with this response to acknowledge that the intent was canceled.
         */
        declinationResponse?: pulumi.Input<inputs.lex.BotResponseSpecificationArgs>;
        /**
         * The `DialogCodeHookInvocationSetting` used when the code hook is invoked during confirmation prompt retries.
         */
        elicitationCodeHook?: pulumi.Input<inputs.lex.BotElicitationCodeHookInvocationSettingArgs>;
        /**
         * Provides a list of conditional branches. Branches are evaluated in the order that they are entered in the list. The first branch with a condition that evaluates to true is executed. The last branch in the list is the default branch. The default branch should not have any condition expression. The default branch is executed if no other branch has a matching condition.
         */
        failureConditional?: pulumi.Input<inputs.lex.BotConditionalSpecificationArgs>;
        /**
         * The next step to take in the conversation if the confirmation step fails.
         */
        failureNextStep?: pulumi.Input<inputs.lex.BotDialogStateArgs>;
        /**
         * Specifies a list of message groups that Amazon Lex uses to respond the user input when the intent confirmation fails.
         */
        failureResponse?: pulumi.Input<inputs.lex.BotResponseSpecificationArgs>;
        /**
         * Specifies whether the intent's confirmation is sent to the user. When this field is false, confirmation and declination responses aren't sent. If the `IsActive` field isn't specified, the default is true.
         */
        isActive?: pulumi.Input<boolean>;
        /**
         * Prompts the user to confirm the intent. This question should have a yes or no answer.
         *
         * Amazon Lex uses this prompt to ensure that the user acknowledges that the intent is ready for fulfillment. For example, with the `OrderPizza` intent, you might want to confirm that the order is correct before placing it. For other intents, such as intents that simply respond to user questions, you might not need to ask the user for confirmation before providing the information.
         */
        promptSpecification: pulumi.Input<inputs.lex.BotPromptSpecificationArgs>;
    }
    interface BotIntentOverrideArgs {
        /**
         * The name of the intent. Only required when you're switching intents.
         */
        name?: pulumi.Input<string>;
        /**
         * A map of all of the slot value overrides for the intent. The name of the slot maps to the value of the slot. Slots that are not included in the map aren't overridden.
         */
        slots?: pulumi.Input<pulumi.Input<inputs.lex.BotSlotValueOverrideMapArgs>[]>;
    }
    interface BotKendraConfigurationArgs {
        /**
         * The Amazon Resource Name (ARN) of the Amazon Kendra index that you want the `AMAZON.KendraSearchIntent` intent to search. The index must be in the same account and Region as the Amazon Lex bot.
         */
        kendraIndex: pulumi.Input<string>;
        /**
         * A query filter that Amazon Lex sends to Amazon Kendra to filter the response from a query. The filter is in the format defined by Amazon Kendra. For more information, see [Filtering queries](https://docs.aws.amazon.com/kendra/latest/dg/filtering.html) .
         */
        queryFilterString?: pulumi.Input<string>;
        /**
         * Determines whether the `AMAZON.KendraSearchIntent` intent uses a custom query string to query the Amazon Kendra index.
         */
        queryFilterStringEnabled?: pulumi.Input<boolean>;
    }
    interface BotLocaleArgs {
        /**
         * Specifies a custom vocabulary to use with a specific locale.
         */
        customVocabulary?: pulumi.Input<inputs.lex.BotCustomVocabularyArgs>;
        /**
         * A description of the bot locale. Use this to help identify the bot locale in lists.
         */
        description?: pulumi.Input<string>;
        /**
         * One or more intents defined for the locale.
         */
        intents?: pulumi.Input<pulumi.Input<inputs.lex.BotIntentArgs>[]>;
        /**
         * The identifier of the language and locale that the bot will be used in. The string must match one of the supported locales.
         */
        localeId: pulumi.Input<string>;
        /**
         * Determines the threshold where Amazon Lex will insert the `AMAZON.FallbackIntent` , `AMAZON.KendraSearchIntent` , or both when returning alternative intents. You must configure an `AMAZON.FallbackIntent` . `AMAZON.KendraSearchIntent` is only inserted if it is configured for the bot.
         */
        nluConfidenceThreshold: pulumi.Input<number>;
        /**
         * One or more slot types defined for the locale.
         */
        slotTypes?: pulumi.Input<pulumi.Input<inputs.lex.BotSlotTypeArgs>[]>;
        /**
         * Defines settings for using an Amazon Polly voice to communicate with a user.
         *
         * Valid values include:
         *
         * - `standard`
         * - `neural`
         * - `long-form`
         * - `generative`
         */
        voiceSettings?: pulumi.Input<inputs.lex.BotVoiceSettingsArgs>;
    }
    interface BotMessageArgs {
        customPayload?: pulumi.Input<inputs.lex.BotCustomPayloadArgs>;
        imageResponseCard?: pulumi.Input<inputs.lex.BotImageResponseCardArgs>;
        plainTextMessage?: pulumi.Input<inputs.lex.BotPlainTextMessageArgs>;
        ssmlMessage?: pulumi.Input<inputs.lex.BotSsmlMessageArgs>;
    }
    interface BotMessageGroupArgs {
        message: pulumi.Input<inputs.lex.BotMessageArgs>;
        variations?: pulumi.Input<pulumi.Input<inputs.lex.BotMessageArgs>[]>;
    }
    interface BotMultipleValuesSettingArgs {
        /**
         * Indicates whether a slot can return multiple values. When `true` , the slot may return more than one value in a response. When `false` , the slot returns only a single value.
         *
         * Multi-value slots are only available in the en-US locale. If you set this value to `true` in any other locale, Amazon Lex throws a `ValidationException` .
         *
         * If the `allowMutlipleValues` is not set, the default value is `false` .
         */
        allowMultipleValues?: pulumi.Input<boolean>;
    }
    interface BotObfuscationSettingArgs {
        /**
         * Value that determines whether Amazon Lex obscures slot values in conversation logs. The default is to obscure the values.
         */
        obfuscationSettingType: pulumi.Input<enums.lex.BotObfuscationSettingObfuscationSettingType>;
    }
    interface BotOutputContextArgs {
        name: pulumi.Input<string>;
        timeToLiveInSeconds: pulumi.Input<number>;
        turnsToLive: pulumi.Input<number>;
    }
    interface BotPlainTextMessageArgs {
        value: pulumi.Input<string>;
    }
    interface BotPostDialogCodeHookInvocationSpecificationArgs {
        /**
         * A list of conditional branches to evaluate after the dialog code hook throws an exception or returns with the `State` field of the `Intent` object set to `Failed` .
         */
        failureConditional?: pulumi.Input<inputs.lex.BotConditionalSpecificationArgs>;
        /**
         * Specifies the next step the bot runs after the dialog code hook throws an exception or returns with the `State` field of the `Intent` object set to `Failed` .
         */
        failureNextStep?: pulumi.Input<inputs.lex.BotDialogStateArgs>;
        /**
         * Specifies a list of message groups that Amazon Lex uses to respond the user input when the code hook fails.
         */
        failureResponse?: pulumi.Input<inputs.lex.BotResponseSpecificationArgs>;
        /**
         * A list of conditional branches to evaluate after the dialog code hook finishes successfully.
         */
        successConditional?: pulumi.Input<inputs.lex.BotConditionalSpecificationArgs>;
        /**
         * Specifics the next step the bot runs after the dialog code hook finishes successfully.
         */
        successNextStep?: pulumi.Input<inputs.lex.BotDialogStateArgs>;
        /**
         * Specifies a list of message groups that Amazon Lex uses to respond when the code hook succeeds.
         */
        successResponse?: pulumi.Input<inputs.lex.BotResponseSpecificationArgs>;
        /**
         * A list of conditional branches to evaluate if the code hook times out.
         */
        timeoutConditional?: pulumi.Input<inputs.lex.BotConditionalSpecificationArgs>;
        /**
         * Specifies the next step that the bot runs when the code hook times out.
         */
        timeoutNextStep?: pulumi.Input<inputs.lex.BotDialogStateArgs>;
        /**
         * Specifies a list of message groups that Amazon Lex uses to respond to the user input when the code hook times out.
         */
        timeoutResponse?: pulumi.Input<inputs.lex.BotResponseSpecificationArgs>;
    }
    interface BotPostFulfillmentStatusSpecificationArgs {
        /**
         * A list of conditional branches to evaluate after the fulfillment code hook throws an exception or returns with the `State` field of the `Intent` object set to `Failed` .
         */
        failureConditional?: pulumi.Input<inputs.lex.BotConditionalSpecificationArgs>;
        /**
         * Specifies the next step the bot runs after the fulfillment code hook throws an exception or returns with the `State` field of the `Intent` object set to `Failed` .
         */
        failureNextStep?: pulumi.Input<inputs.lex.BotDialogStateArgs>;
        /**
         * Specifies a list of message groups that Amazon Lex uses to respond when fulfillment isn't successful.
         */
        failureResponse?: pulumi.Input<inputs.lex.BotResponseSpecificationArgs>;
        /**
         * A list of conditional branches to evaluate after the fulfillment code hook finishes successfully.
         */
        successConditional?: pulumi.Input<inputs.lex.BotConditionalSpecificationArgs>;
        /**
         * Specifies the next step in the conversation that Amazon Lex invokes when the fulfillment code hook completes successfully.
         */
        successNextStep?: pulumi.Input<inputs.lex.BotDialogStateArgs>;
        /**
         * Specifies a list of message groups that Amazon Lex uses to respond when the fulfillment is successful.
         */
        successResponse?: pulumi.Input<inputs.lex.BotResponseSpecificationArgs>;
        /**
         * A list of conditional branches to evaluate if the fulfillment code hook times out.
         */
        timeoutConditional?: pulumi.Input<inputs.lex.BotConditionalSpecificationArgs>;
        /**
         * Specifies the next step that the bot runs when the fulfillment code hook times out.
         */
        timeoutNextStep?: pulumi.Input<inputs.lex.BotDialogStateArgs>;
        /**
         * Specifies a list of message groups that Amazon Lex uses to respond when fulfillment isn't completed within the timeout period.
         */
        timeoutResponse?: pulumi.Input<inputs.lex.BotResponseSpecificationArgs>;
    }
    interface BotPromptAttemptSpecificationArgs {
        allowInterrupt?: pulumi.Input<boolean>;
        allowedInputTypes: pulumi.Input<inputs.lex.BotAllowedInputTypesArgs>;
        audioAndDtmfInputSpecification?: pulumi.Input<inputs.lex.BotAudioAndDtmfInputSpecificationArgs>;
        textInputSpecification?: pulumi.Input<inputs.lex.BotTextInputSpecificationArgs>;
    }
    interface BotPromptSpecificationArgs {
        /**
         * Indicates whether the user can interrupt a speech prompt from the bot.
         */
        allowInterrupt?: pulumi.Input<boolean>;
        /**
         * The maximum number of times the bot tries to elicit a response from the user using this prompt.
         */
        maxRetries: pulumi.Input<number>;
        /**
         * A collection of messages that Amazon Lex can send to the user. Amazon Lex chooses the actual message to send at runtime.
         */
        messageGroupsList: pulumi.Input<pulumi.Input<inputs.lex.BotMessageGroupArgs>[]>;
        /**
         * Indicates how a message is selected from a message group among retries.
         */
        messageSelectionStrategy?: pulumi.Input<enums.lex.BotMessageSelectionStrategy>;
        /**
         * Specifies the advanced settings on each attempt of the prompt.
         */
        promptAttemptsSpecification?: pulumi.Input<{
            [key: string]: pulumi.Input<inputs.lex.BotPromptAttemptSpecificationArgs>;
        }>;
    }
    interface BotQInConnectIntentConfigurationArgs {
        qInConnectAssistantConfiguration?: pulumi.Input<inputs.lex.BotQInConnectIntentConfigurationQInConnectAssistantConfigurationPropertiesArgs>;
    }
    interface BotQInConnectIntentConfigurationQInConnectAssistantConfigurationPropertiesArgs {
        assistantArn: pulumi.Input<string>;
    }
    interface BotQnAIntentConfigurationArgs {
        bedrockModelConfiguration: pulumi.Input<inputs.lex.BotBedrockModelSpecificationArgs>;
        /**
         * Contains details about the configuration of the data source used for the `AMAZON.QnAIntent` .
         */
        dataSourceConfiguration: pulumi.Input<inputs.lex.BotQnAIntentConfigurationDataSourceConfigurationPropertiesArgs>;
    }
    /**
     * Contains details about the configuration of the data source used for the `AMAZON.QnAIntent` .
     */
    interface BotQnAIntentConfigurationDataSourceConfigurationPropertiesArgs {
        bedrockKnowledgeStoreConfiguration?: pulumi.Input<inputs.lex.BotQnAIntentConfigurationDataSourceConfigurationPropertiesBedrockKnowledgeStoreConfigurationPropertiesArgs>;
        kendraConfiguration?: pulumi.Input<inputs.lex.BotQnAKendraConfigurationArgs>;
        opensearchConfiguration?: pulumi.Input<inputs.lex.BotQnAIntentConfigurationDataSourceConfigurationPropertiesOpensearchConfigurationPropertiesArgs>;
    }
    interface BotQnAIntentConfigurationDataSourceConfigurationPropertiesBedrockKnowledgeStoreConfigurationPropertiesArgs {
        bedrockKnowledgeBaseArn?: pulumi.Input<string>;
        bkbExactResponseFields?: pulumi.Input<inputs.lex.BotQnAIntentConfigurationDataSourceConfigurationPropertiesBedrockKnowledgeStoreConfigurationPropertiesBkbExactResponseFieldsPropertiesArgs>;
        exactResponse?: pulumi.Input<boolean>;
    }
    interface BotQnAIntentConfigurationDataSourceConfigurationPropertiesBedrockKnowledgeStoreConfigurationPropertiesBkbExactResponseFieldsPropertiesArgs {
        answerField?: pulumi.Input<string>;
    }
    interface BotQnAIntentConfigurationDataSourceConfigurationPropertiesOpensearchConfigurationPropertiesArgs {
        domainEndpoint?: pulumi.Input<string>;
        exactResponse?: pulumi.Input<boolean>;
        exactResponseFields?: pulumi.Input<inputs.lex.BotQnAIntentConfigurationDataSourceConfigurationPropertiesOpensearchConfigurationPropertiesExactResponseFieldsPropertiesArgs>;
        includeFields?: pulumi.Input<pulumi.Input<string>[]>;
        indexName?: pulumi.Input<string>;
    }
    interface BotQnAIntentConfigurationDataSourceConfigurationPropertiesOpensearchConfigurationPropertiesExactResponseFieldsPropertiesArgs {
        answerField?: pulumi.Input<string>;
        questionField?: pulumi.Input<string>;
    }
    interface BotQnAKendraConfigurationArgs {
        /**
         * Specifies whether to return an exact response from the Amazon Kendra index or to let the Amazon Bedrock model you select generate a response based on the results. To use this feature, you must first add FAQ questions to your index by following the steps at [Adding frequently asked questions (FAQs) to an index](https://docs.aws.amazon.com/kendra/latest/dg/in-creating-faq.html) .
         */
        exactResponse: pulumi.Input<boolean>;
        /**
         * The ARN of the Amazon Kendra index to use.
         */
        kendraIndex: pulumi.Input<string>;
        /**
         * Contains the Amazon Kendra filter string to use if enabled. For more information on the Amazon Kendra search filter JSON format, see [Using document attributes to filter search results](https://docs.aws.amazon.com/kendra/latest/dg/filtering.html#search-filtering) .
         */
        queryFilterString?: pulumi.Input<string>;
        /**
         * Specifies whether to enable an Amazon Kendra filter string or not.
         */
        queryFilterStringEnabled: pulumi.Input<boolean>;
    }
    interface BotReplicationArgs {
        replicaRegions: pulumi.Input<pulumi.Input<string>[]>;
    }
    interface BotResponseSpecificationArgs {
        /**
         * Indicates whether the user can interrupt a speech response from Amazon Lex.
         */
        allowInterrupt?: pulumi.Input<boolean>;
        /**
         * A collection of responses that Amazon Lex can send to the user. Amazon Lex chooses the actual response to send at runtime.
         */
        messageGroupsList: pulumi.Input<pulumi.Input<inputs.lex.BotMessageGroupArgs>[]>;
    }
    interface BotS3BucketLogDestinationArgs {
        kmsKeyArn?: pulumi.Input<string>;
        logPrefix: pulumi.Input<string>;
        s3BucketArn: pulumi.Input<string>;
    }
    interface BotS3LocationArgs {
        /**
         * The S3 bucket name.
         */
        s3Bucket: pulumi.Input<string>;
        /**
         * The path and file name to the object in the S3 bucket.
         */
        s3ObjectKey: pulumi.Input<string>;
        /**
         * The version of the object in the S3 bucket.
         */
        s3ObjectVersion?: pulumi.Input<string>;
    }
    interface BotSampleUtteranceArgs {
        utterance: pulumi.Input<string>;
    }
    interface BotSampleValueArgs {
        value: pulumi.Input<string>;
    }
    interface BotSessionAttributeArgs {
        /**
         * The name of the session attribute.
         */
        key: pulumi.Input<string>;
        /**
         * The session-specific context information for the session attribute.
         */
        value?: pulumi.Input<string>;
    }
    interface BotSlotArgs {
        /**
         * The description of the slot.
         */
        description?: pulumi.Input<string>;
        /**
         * Indicates whether a slot can return multiple values.
         */
        multipleValuesSetting?: pulumi.Input<inputs.lex.BotMultipleValuesSettingArgs>;
        /**
         * The name given to the slot.
         */
        name: pulumi.Input<string>;
        /**
         * Determines whether the contents of the slot are obfuscated in Amazon CloudWatch Logs logs. Use obfuscated slots to protect information such as personally identifiable information (PII) in logs.
         */
        obfuscationSetting?: pulumi.Input<inputs.lex.BotObfuscationSettingArgs>;
        /**
         * The name of the slot type that this slot is based on. The slot type defines the acceptable values for the slot.
         */
        slotTypeName: pulumi.Input<string>;
        /**
         * Determines the slot resolution strategy that Amazon Lex uses to return slot type values. The field can be set to one of the following values:
         *
         * - ORIGINAL_VALUE - Returns the value entered by the user, if the user value is similar to a slot value.
         * - TOP_RESOLUTION - If there is a resolution list for the slot, return the first value in the resolution list as the slot type value. If there is no resolution list, null is returned.
         *
         * If you don't specify the `valueSelectionStrategy` , the default is `ORIGINAL_VALUE` .
         */
        valueElicitationSetting: pulumi.Input<inputs.lex.BotSlotValueElicitationSettingArgs>;
    }
    interface BotSlotCaptureSettingArgs {
        /**
         * A list of conditional branches to evaluate after the slot value is captured.
         */
        captureConditional?: pulumi.Input<inputs.lex.BotConditionalSpecificationArgs>;
        /**
         * Specifies the next step that the bot runs when the slot value is captured before the code hook times out.
         */
        captureNextStep?: pulumi.Input<inputs.lex.BotDialogStateArgs>;
        /**
         * Specifies a list of message groups that Amazon Lex uses to respond the user input.
         */
        captureResponse?: pulumi.Input<inputs.lex.BotResponseSpecificationArgs>;
        /**
         * Code hook called after Amazon Lex successfully captures a slot value.
         */
        codeHook?: pulumi.Input<inputs.lex.BotDialogCodeHookInvocationSettingArgs>;
        /**
         * Code hook called when Amazon Lex doesn't capture a slot value.
         */
        elicitationCodeHook?: pulumi.Input<inputs.lex.BotElicitationCodeHookInvocationSettingArgs>;
        /**
         * A list of conditional branches to evaluate when the slot value isn't captured.
         */
        failureConditional?: pulumi.Input<inputs.lex.BotConditionalSpecificationArgs>;
        /**
         * Specifies the next step that the bot runs when the slot value code is not recognized.
         */
        failureNextStep?: pulumi.Input<inputs.lex.BotDialogStateArgs>;
        /**
         * Specifies a list of message groups that Amazon Lex uses to respond the user input when the slot fails to be captured.
         */
        failureResponse?: pulumi.Input<inputs.lex.BotResponseSpecificationArgs>;
    }
    interface BotSlotDefaultValueArgs {
        /**
         * The default value to use when a user doesn't provide a value for a slot.
         */
        defaultValue: pulumi.Input<string>;
    }
    interface BotSlotDefaultValueSpecificationArgs {
        /**
         * A list of default values. Amazon Lex chooses the default value to use in the order that they are presented in the list.
         */
        defaultValueList: pulumi.Input<pulumi.Input<inputs.lex.BotSlotDefaultValueArgs>[]>;
    }
    interface BotSlotPriorityArgs {
        priority: pulumi.Input<number>;
        slotName: pulumi.Input<string>;
    }
    interface BotSlotTypeArgs {
        compositeSlotTypeSetting?: pulumi.Input<inputs.lex.BotCompositeSlotTypeSettingArgs>;
        /**
         * A description of the slot type. Use the description to help identify the slot type in lists.
         */
        description?: pulumi.Input<string>;
        /**
         * Sets the type of external information used to create the slot type.
         */
        externalSourceSetting?: pulumi.Input<inputs.lex.BotExternalSourceSettingArgs>;
        /**
         * The name of the slot type. A slot type name must be unique withing the account.
         */
        name: pulumi.Input<string>;
        /**
         * The built-in slot type used as a parent of this slot type. When you define a parent slot type, the new slot type has the configuration of the parent lot type.
         *
         * Only `AMAZON.AlphaNumeric` is supported.
         */
        parentSlotTypeSignature?: pulumi.Input<string>;
        /**
         * A list of SlotTypeValue objects that defines the values that the slot type can take. Each value can have a list of synonyms, additional values that help train the machine learning model about the values that it resolves for the slot.
         */
        slotTypeValues?: pulumi.Input<pulumi.Input<inputs.lex.BotSlotTypeValueArgs>[]>;
        /**
         * Determines the slot resolution strategy that Amazon Lex uses to return slot type values. The field can be set to one of the following values:
         *
         * - `ORIGINAL_VALUE` - Returns the value entered by the user, if the user value is similar to the slot value.
         * - `TOP_RESOLUTION` - If there is a resolution list for the slot, return the first value in the resolution list as the slot type value. If there is no resolution list, null is returned.
         *
         * If you don't specify the `valueSelectionStrategy` , the default is `ORIGINAL_VALUE` .
         */
        valueSelectionSetting?: pulumi.Input<inputs.lex.BotSlotValueSelectionSettingArgs>;
    }
    interface BotSlotTypeValueArgs {
        sampleValue: pulumi.Input<inputs.lex.BotSampleValueArgs>;
        synonyms?: pulumi.Input<pulumi.Input<inputs.lex.BotSampleValueArgs>[]>;
    }
    interface BotSlotValueArgs {
        /**
         * The value that Amazon Lex determines for the slot. The actual value depends on the setting of the value selection strategy for the bot. You can choose to use the value entered by the user, or you can have Amazon Lex choose the first value in the `resolvedValues` list.
         */
        interpretedValue?: pulumi.Input<string>;
    }
    interface BotSlotValueElicitationSettingArgs {
        /**
         * A list of default values for a slot. Default values are used when Amazon Lex hasn't determined a value for a slot. You can specify default values from context variables, session attributes, and defined values.
         */
        defaultValueSpecification?: pulumi.Input<inputs.lex.BotSlotDefaultValueSpecificationArgs>;
        /**
         * The prompt that Amazon Lex uses to elicit the slot value from the user.
         */
        promptSpecification?: pulumi.Input<inputs.lex.BotPromptSpecificationArgs>;
        /**
         * If you know a specific pattern that users might respond to an Amazon Lex request for a slot value, you can provide those utterances to improve accuracy. This is optional. In most cases, Amazon Lex is capable of understanding user utterances.
         */
        sampleUtterances?: pulumi.Input<pulumi.Input<inputs.lex.BotSampleUtteranceArgs>[]>;
        /**
         * Specifies the settings that Amazon Lex uses when a slot value is successfully entered by a user.
         */
        slotCaptureSetting?: pulumi.Input<inputs.lex.BotSlotCaptureSettingArgs>;
        /**
         * Specifies whether the slot is required or optional.
         */
        slotConstraint: pulumi.Input<enums.lex.BotSlotConstraint>;
        /**
         * Specifies the prompts that Amazon Lex uses while a bot is waiting for customer input.
         */
        waitAndContinueSpecification?: pulumi.Input<inputs.lex.BotWaitAndContinueSpecificationArgs>;
    }
    interface BotSlotValueOverrideArgs {
        /**
         * When the shape value is `List` , it indicates that the `values` field contains a list of slot values. When the value is `Scalar` , it indicates that the `value` field contains a single value.
         */
        shape?: pulumi.Input<enums.lex.BotSlotShape>;
        /**
         * The current value of the slot.
         */
        value?: pulumi.Input<inputs.lex.BotSlotValueArgs>;
        /**
         * A list of one or more values that the user provided for the slot. For example, for a slot that elicits pizza toppings, the values might be "pepperoni" and "pineapple."
         */
        values?: pulumi.Input<pulumi.Input<inputs.lex.BotSlotValueOverrideArgs>[]>;
    }
    interface BotSlotValueOverrideMapArgs {
        /**
         * The name of the slot.
         */
        slotName?: pulumi.Input<string>;
        /**
         * The SlotValueOverride object to which the slot name will be mapped.
         */
        slotValueOverride?: pulumi.Input<inputs.lex.BotSlotValueOverrideArgs>;
    }
    interface BotSlotValueRegexFilterArgs {
        /**
         * A regular expression used to validate the value of a slot.
         *
         * Use a standard regular expression. Amazon Lex supports the following characters in the regular expression:
         *
         * - A-Z, a-z
         * - 0-9
         * - Unicode characters ("\⁠u<Unicode>")
         *
         * Represent Unicode characters with four digits, for example "\⁠u0041" or "\⁠u005A".
         *
         * The following regular expression operators are not supported:
         *
         * - Infinite repeaters: *, +, or {x,} with no upper bound.
         * - Wild card (.)
         */
        pattern: pulumi.Input<string>;
    }
    interface BotSlotValueSelectionSettingArgs {
        /**
         * Provides settings that enable advanced recognition settings for slot values. You can use this to enable using slot values as a custom vocabulary for recognizing user utterances.
         */
        advancedRecognitionSetting?: pulumi.Input<inputs.lex.BotAdvancedRecognitionSettingArgs>;
        /**
         * A regular expression used to validate the value of a slot.
         */
        regexFilter?: pulumi.Input<inputs.lex.BotSlotValueRegexFilterArgs>;
        /**
         * Determines the slot resolution strategy that Amazon Lex uses to return slot type values. The field can be set to one of the following values:
         *
         * - `ORIGINAL_VALUE` - Returns the value entered by the user, if the user value is similar to the slot value.
         * - `TOP_RESOLUTION` - If there is a resolution list for the slot, return the first value in the resolution list as the slot type value. If there is no resolution list, null is returned.
         *
         * If you don't specify the `valueSelectionStrategy` , the default is `ORIGINAL_VALUE` .
         */
        resolutionStrategy: pulumi.Input<enums.lex.BotSlotValueResolutionStrategy>;
    }
    interface BotSsmlMessageArgs {
        value: pulumi.Input<string>;
    }
    interface BotStillWaitingResponseSpecificationArgs {
        /**
         * Indicates that the user can interrupt the response by speaking while the message is being played.
         */
        allowInterrupt?: pulumi.Input<boolean>;
        /**
         * How often a message should be sent to the user. Minimum of 1 second, maximum of 5 minutes.
         */
        frequencyInSeconds: pulumi.Input<number>;
        /**
         * One or more message groups, each containing one or more messages, that define the prompts that Amazon Lex sends to the user.
         */
        messageGroupsList: pulumi.Input<pulumi.Input<inputs.lex.BotMessageGroupArgs>[]>;
        /**
         * If Amazon Lex waits longer than this length of time for a response, it will stop sending messages.
         */
        timeoutInSeconds: pulumi.Input<number>;
    }
    interface BotSubSlotTypeCompositionArgs {
        /**
         * Name of a constituent sub slot inside a composite slot.
         */
        name: pulumi.Input<string>;
        /**
         * The unique identifier assigned to a slot type. This refers to either a built-in slot type or the unique slotTypeId of a custom slot type.
         */
        slotTypeId: pulumi.Input<string>;
    }
    interface BotTagArgs {
        key: pulumi.Input<string>;
        value: pulumi.Input<string>;
    }
    interface BotTestBotAliasSettingsArgs {
        /**
         * Specifies settings that are unique to a locale. For example, you can use a different Lambda function depending on the bot's locale.
         */
        botAliasLocaleSettings?: pulumi.Input<pulumi.Input<inputs.lex.BotAliasLocaleSettingsItemArgs>[]>;
        /**
         * Specifies settings for conversation logs that save audio, text, and metadata information for conversations with your users.
         */
        conversationLogSettings?: pulumi.Input<inputs.lex.BotConversationLogSettingsArgs>;
        /**
         * Specifies a description for the test bot alias.
         */
        description?: pulumi.Input<string>;
        /**
         * Specifies whether Amazon Lex will use Amazon Comprehend to detect the sentiment of user utterances.
         */
        sentimentAnalysisSettings?: pulumi.Input<inputs.lex.BotTestBotAliasSettingsSentimentAnalysisSettingsPropertiesArgs>;
    }
    /**
     * Specifies whether Amazon Lex will use Amazon Comprehend to detect the sentiment of user utterances.
     */
    interface BotTestBotAliasSettingsSentimentAnalysisSettingsPropertiesArgs {
        detectSentiment: pulumi.Input<boolean>;
    }
    interface BotTextInputSpecificationArgs {
        startTimeoutMs: pulumi.Input<number>;
    }
    interface BotTextLogDestinationArgs {
        cloudWatch: pulumi.Input<inputs.lex.BotCloudWatchLogGroupLogDestinationArgs>;
    }
    interface BotTextLogSettingArgs {
        destination: pulumi.Input<inputs.lex.BotTextLogDestinationArgs>;
        enabled: pulumi.Input<boolean>;
    }
    /**
     * The version of a bot used for a bot locale.
     */
    interface BotVersionLocaleDetailsArgs {
        sourceBotVersion: pulumi.Input<string>;
    }
    interface BotVersionLocaleSpecificationArgs {
        botVersionLocaleDetails: pulumi.Input<inputs.lex.BotVersionLocaleDetailsArgs>;
        localeId: pulumi.Input<string>;
    }
    interface BotVoiceSettingsArgs {
        /**
         * Indicates the type of Amazon Polly voice that Amazon Lex should use for voice interaction with the user. For more information, see the [`engine` parameter of the `SynthesizeSpeech` operation](https://docs.aws.amazon.com/polly/latest/dg/API_SynthesizeSpeech.html#polly-SynthesizeSpeech-request-Engine) in the *Amazon Polly developer guide* .
         *
         * If you do not specify a value, the default is `standard` .
         */
        engine?: pulumi.Input<enums.lex.BotVoiceSettingsEngine>;
        /**
         * The identifier of the Amazon Polly voice to use.
         */
        voiceId: pulumi.Input<string>;
    }
    interface BotWaitAndContinueSpecificationArgs {
        /**
         * The response that Amazon Lex sends to indicate that the bot is ready to continue the conversation.
         */
        continueResponse: pulumi.Input<inputs.lex.BotResponseSpecificationArgs>;
        /**
         * Specifies whether the bot will wait for a user to respond. When this field is false, wait and continue responses for a slot aren't used. If the `IsActive` field isn't specified, the default is true.
         */
        isActive?: pulumi.Input<boolean>;
        /**
         * A response that Amazon Lex sends periodically to the user to indicate that the bot is still waiting for input from the user.
         */
        stillWaitingResponse?: pulumi.Input<inputs.lex.BotStillWaitingResponseSpecificationArgs>;
        /**
         * The response that Amazon Lex sends to indicate that the bot is waiting for the conversation to continue.
         */
        waitingResponse: pulumi.Input<inputs.lex.BotResponseSpecificationArgs>;
    }
    /**
     * By default, data stored by Amazon Lex is encrypted. The `DataPrivacy` structure provides settings that determine how Amazon Lex handles special cases of securing the data for your bot.
     */
    interface DataPrivacyPropertiesArgs {
        /**
         * For each Amazon Lex bot created with the Amazon Lex Model Building Service, you must specify whether your use of Amazon Lex is related to a website, program, or other application that is directed or targeted, in whole or in part, to children under age 13 and subject to the Children's Online Privacy Protection Act (COPPA) by specifying `true` or `false` in the `childDirected` field. By specifying `true` in the `childDirected` field, you confirm that your use of Amazon Lex *is* related to a website, program, or other application that is directed or targeted, in whole or in part, to children under age 13 and subject to COPPA. By specifying `false` in the `childDirected` field, you confirm that your use of Amazon Lex *is not* related to a website, program, or other application that is directed or targeted, in whole or in part, to children under age 13 and subject to COPPA. You may not specify a default value for the `childDirected` field that does not accurately reflect whether your use of Amazon Lex is related to a website, program, or other application that is directed or targeted, in whole or in part, to children under age 13 and subject to COPPA. If your use of Amazon Lex relates to a website, program, or other application that is directed in whole or in part, to children under age 13, you must obtain any required verifiable parental consent under COPPA. For information regarding the use of Amazon Lex in connection with websites, programs, or other applications that are directed or targeted, in whole or in part, to children under age 13, see the [Amazon Lex FAQ](https://docs.aws.amazon.com/lex/faqs#data-security) .
         */
        childDirected: pulumi.Input<boolean>;
    }
    /**
     * A resource policy to add to the resource. The policy is a JSON structure following the IAM syntax that contains one or more statements that define the policy.
     */
    interface ResourcePolicyPolicyArgs {
    }
    /**
     * Determines whether Amazon Lex will use Amazon Comprehend to detect the sentiment of user utterances.
     */
    interface SentimentAnalysisSettingsPropertiesArgs {
        /**
         * Enable to call Amazon Comprehend for Sentiment natively within Lex
         */
        detectSentiment: pulumi.Input<boolean>;
    }
}
export declare namespace licensemanager {
    interface LicenseBorrowConfigurationArgs {
        /**
         * Indicates whether early check-ins are allowed.
         */
        allowEarlyCheckIn: pulumi.Input<boolean>;
        /**
         * Maximum time for the borrow configuration, in minutes.
         */
        maxTimeToLiveInMinutes: pulumi.Input<number>;
    }
    interface LicenseConsumptionConfigurationArgs {
        /**
         * Details about a borrow configuration.
         */
        borrowConfiguration?: pulumi.Input<inputs.licensemanager.LicenseBorrowConfigurationArgs>;
        /**
         * Details about a provisional configuration.
         */
        provisionalConfiguration?: pulumi.Input<inputs.licensemanager.LicenseProvisionalConfigurationArgs>;
        /**
         * Renewal frequency.
         */
        renewType?: pulumi.Input<string>;
    }
    interface LicenseEntitlementArgs {
        /**
         * Indicates whether check-ins are allowed.
         */
        allowCheckIn?: pulumi.Input<boolean>;
        /**
         * Maximum entitlement count. Use if the unit is not None.
         */
        maxCount?: pulumi.Input<number>;
        /**
         * Entitlement name.
         */
        name: pulumi.Input<string>;
        /**
         * Indicates whether overages are allowed.
         */
        overage?: pulumi.Input<boolean>;
        /**
         * Entitlement unit.
         */
        unit: pulumi.Input<string>;
        /**
         * Entitlement resource. Use only if the unit is None.
         */
        value?: pulumi.Input<string>;
    }
    interface LicenseIssuerDataArgs {
        /**
         * Issuer name.
         */
        name: pulumi.Input<string>;
        /**
         * Asymmetric KMS key from AWS Key Management Service . The KMS key must have a key usage of sign and verify, and support the RSASSA-PSS SHA-256 signing algorithm.
         */
        signKey?: pulumi.Input<string>;
    }
    interface LicenseMetadataArgs {
        /**
         * The key name.
         */
        name: pulumi.Input<string>;
        /**
         * The value.
         */
        value: pulumi.Input<string>;
    }
    interface LicenseProvisionalConfigurationArgs {
        /**
         * Maximum time for the provisional configuration, in minutes.
         */
        maxTimeToLiveInMinutes: pulumi.Input<number>;
    }
    interface LicenseValidityDateFormatArgs {
        /**
         * Validity begin date for the license.
         */
        begin: pulumi.Input<string>;
        /**
         * Validity begin date for the license.
         */
        end: pulumi.Input<string>;
    }
}
export declare namespace lightsail {
    /**
     * An object that sets the public accessibility of objects in the specified bucket.
     */
    interface BucketAccessRulesArgs {
        /**
         * A Boolean value that indicates whether the access control list (ACL) permissions that are applied to individual objects override the getObject option that is currently specified.
         */
        allowPublicOverrides?: pulumi.Input<boolean>;
        /**
         * Specifies the anonymous access to all objects in a bucket.
         */
        getObject?: pulumi.Input<string>;
    }
    /**
     * Describes the settings of a container that will be launched, or that is launched, to an Amazon Lightsail container service.
     */
    interface ContainerArgs {
        /**
         * The launch command for the container.
         */
        command?: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * The name of the container.
         */
        containerName?: pulumi.Input<string>;
        /**
         * The environment variables of the container.
         */
        environment?: pulumi.Input<pulumi.Input<inputs.lightsail.ContainerEnvironmentVariableArgs>[]>;
        /**
         * The name of the image used for the container.
         */
        image?: pulumi.Input<string>;
        /**
         * The open firewall ports of the container.
         */
        ports?: pulumi.Input<pulumi.Input<inputs.lightsail.ContainerPortInfoArgs>[]>;
    }
    interface ContainerEnvironmentVariableArgs {
        /**
         * The environment variable value.
         */
        value?: pulumi.Input<string>;
        /**
         * The environment variable key.
         */
        variable?: pulumi.Input<string>;
    }
    /**
     * Describes the health check configuration of an Amazon Lightsail container service.
     */
    interface ContainerHealthCheckConfigArgs {
        /**
         * The number of consecutive health checks successes required before moving the container to the Healthy state. The default value is 2.
         */
        healthyThreshold?: pulumi.Input<number>;
        /**
         * The approximate interval, in seconds, between health checks of an individual container. You can specify between 5 and 300 seconds. The default value is 5.
         */
        intervalSeconds?: pulumi.Input<number>;
        /**
         * The path on the container on which to perform the health check. The default value is /.
         */
        path?: pulumi.Input<string>;
        /**
         * The HTTP codes to use when checking for a successful response from a container. You can specify values between 200 and 499. You can specify multiple values (for example, 200,202) or a range of values (for example, 200-299).
         */
        successCodes?: pulumi.Input<string>;
        /**
         * The amount of time, in seconds, during which no response means a failed health check. You can specify between 2 and 60 seconds. The default value is 2.
         */
        timeoutSeconds?: pulumi.Input<number>;
        /**
         * The number of consecutive health check failures required before moving the container to the Unhealthy state. The default value is 2.
         */
        unhealthyThreshold?: pulumi.Input<number>;
    }
    interface ContainerPortInfoArgs {
        /**
         * The open firewall ports of the container.
         */
        port?: pulumi.Input<string>;
        /**
         * The protocol name for the open ports.
         *
         * *Allowed values* : `HTTP` | `HTTPS` | `TCP` | `UDP`
         */
        protocol?: pulumi.Input<string>;
    }
    /**
     * An object to describe the configuration for the container service to access private container image repositories, such as Amazon Elastic Container Registry (Amazon ECR) private repositories.
     */
    interface ContainerPrivateRegistryAccessArgs {
        /**
         * An object to describe a request to activate or deactivate the role that you can use to grant an Amazon Lightsail container service access to Amazon Elastic Container Registry (Amazon ECR) private repositories.
         */
        ecrImagePullerRole?: pulumi.Input<inputs.lightsail.ContainerPrivateRegistryAccessEcrImagePullerRolePropertiesArgs>;
    }
    /**
     * An object to describe a request to activate or deactivate the role that you can use to grant an Amazon Lightsail container service access to Amazon Elastic Container Registry (Amazon ECR) private repositories.
     */
    interface ContainerPrivateRegistryAccessEcrImagePullerRolePropertiesArgs {
        /**
         * A Boolean value that indicates whether to activate the role.
         */
        isActive?: pulumi.Input<boolean>;
        /**
         * The Amazon Resource Name (ARN) of the role, if it is activated.
         */
        principalArn?: pulumi.Input<string>;
    }
    /**
     * The public domain name to use with the container service, such as example.com and www.example.com.
     */
    interface ContainerPublicDomainNameArgs {
        /**
         * The name of the certificate for the public domains.
         */
        certificateName?: pulumi.Input<string>;
        /**
         * An object that describes the configuration for the containers of the deployment.
         */
        domainNames?: pulumi.Input<pulumi.Input<string>[]>;
    }
    /**
     * Describes the settings of a public endpoint for an Amazon Lightsail container service.
     */
    interface ContainerPublicEndpointArgs {
        /**
         * The name of the container for the endpoint.
         */
        containerName?: pulumi.Input<string>;
        /**
         * The port of the container to which traffic is forwarded to.
         */
        containerPort?: pulumi.Input<number>;
        /**
         * An object that describes the health check configuration of the container.
         */
        healthCheckConfig?: pulumi.Input<inputs.lightsail.ContainerHealthCheckConfigArgs>;
    }
    /**
     * Describes a container deployment configuration of an Amazon Lightsail container service.
     */
    interface ContainerServiceDeploymentArgs {
        /**
         * An object that describes the configuration for the containers of the deployment.
         */
        containers?: pulumi.Input<pulumi.Input<inputs.lightsail.ContainerArgs>[]>;
        /**
         * An object that describes the endpoint of the deployment.
         */
        publicEndpoint?: pulumi.Input<inputs.lightsail.ContainerPublicEndpointArgs>;
    }
    /**
     * Describes the parameters of the database.
     */
    interface DatabaseRelationalDatabaseParameterArgs {
        /**
         * Specifies the valid range of values for the parameter.
         */
        allowedValues?: pulumi.Input<string>;
        /**
         * Indicates when parameter updates are applied. Can be immediate or pending-reboot.
         */
        applyMethod?: pulumi.Input<string>;
        /**
         * Specifies the engine-specific parameter type.
         */
        applyType?: pulumi.Input<string>;
        /**
         * Specifies the valid data type for the parameter.
         */
        dataType?: pulumi.Input<string>;
        /**
         * Provides a description of the parameter.
         */
        description?: pulumi.Input<string>;
        /**
         * A Boolean value indicating whether the parameter can be modified.
         */
        isModifiable?: pulumi.Input<boolean>;
        /**
         * Specifies the name of the parameter.
         */
        parameterName?: pulumi.Input<string>;
        /**
         * Specifies the value of the parameter.
         */
        parameterValue?: pulumi.Input<string>;
    }
    /**
     * A addon associate with a resource.
     */
    interface DiskAddOnArgs {
        /**
         * The add-on type
         */
        addOnType: pulumi.Input<string>;
        /**
         * The parameters for the automatic snapshot add-on, such as the daily time when an automatic snapshot will be created.
         */
        autoSnapshotAddOnRequest?: pulumi.Input<inputs.lightsail.DiskAutoSnapshotAddOnArgs>;
        /**
         * Status of the Addon
         */
        status?: pulumi.Input<enums.lightsail.DiskAddOnStatus>;
    }
    /**
     * An object that represents additional parameters when enabling or modifying the automatic snapshot add-on
     */
    interface DiskAutoSnapshotAddOnArgs {
        /**
         * The daily time when an automatic snapshot will be created.
         */
        snapshotTimeOfDay?: pulumi.Input<string>;
    }
    /**
     * Location of a resource.
     */
    interface DiskLocationArgs {
        /**
         * The Availability Zone in which to create your disk. Use the following format: us-east-2a (case sensitive). Be sure to add the include Availability Zones parameter to your request.
         */
        availabilityZone?: pulumi.Input<string>;
        /**
         * The Region Name in which to create your disk.
         */
        regionName?: pulumi.Input<string>;
    }
    /**
     * A addon associate with a resource.
     */
    interface InstanceAddOnArgs {
        /**
         * The add-on type
         */
        addOnType: pulumi.Input<string>;
        /**
         * The parameters for the automatic snapshot add-on, such as the daily time when an automatic snapshot will be created.
         */
        autoSnapshotAddOnRequest?: pulumi.Input<inputs.lightsail.InstanceAutoSnapshotAddOnArgs>;
        /**
         * Status of the Addon
         */
        status?: pulumi.Input<enums.lightsail.InstanceAddOnStatus>;
    }
    /**
     * An object that represents additional parameters when enabling or modifying the automatic snapshot add-on
     */
    interface InstanceAutoSnapshotAddOnArgs {
        /**
         * The daily time when an automatic snapshot will be created.
         */
        snapshotTimeOfDay?: pulumi.Input<string>;
    }
    /**
     * Disk associated with the Instance.
     */
    interface InstanceDiskArgs {
        /**
         * Instance attached to the disk.
         */
        attachedTo?: pulumi.Input<string>;
        /**
         * Attachment state of the disk.
         */
        attachmentState?: pulumi.Input<string>;
        /**
         * The names to use for your new Lightsail disk.
         */
        diskName: pulumi.Input<string>;
        /**
         * IOPS of disk.
         */
        iops?: pulumi.Input<number>;
        /**
         * Is the Attached disk is the system disk of the Instance.
         */
        isSystemDisk?: pulumi.Input<boolean>;
        /**
         * Path of the disk attached to the instance.
         */
        path: pulumi.Input<string>;
        /**
         * Size of the disk attached to the Instance.
         */
        sizeInGb?: pulumi.Input<string>;
    }
    /**
     * Hardware of the Instance.
     */
    interface InstanceHardwareArgs {
        /**
         * CPU count of the Instance.
         */
        cpuCount?: pulumi.Input<number>;
        /**
         * Disks attached to the Instance.
         */
        disks?: pulumi.Input<pulumi.Input<inputs.lightsail.InstanceDiskArgs>[]>;
        /**
         * RAM Size of the Instance.
         */
        ramSizeInGb?: pulumi.Input<number>;
    }
    /**
     * Location of a resource.
     */
    interface InstanceLocationArgs {
        /**
         * The Availability Zone in which to create your instance. Use the following format: us-east-2a (case sensitive). Be sure to add the include Availability Zones parameter to your request.
         */
        availabilityZone?: pulumi.Input<string>;
        /**
         * The Region Name in which to create your instance.
         */
        regionName?: pulumi.Input<string>;
    }
    /**
     * Monthly Transfer of the Instance.
     */
    interface InstanceMonthlyTransferArgs {
        /**
         * GbPerMonthAllocated of the Instance.
         */
        gbPerMonthAllocated?: pulumi.Input<string>;
    }
    /**
     * Networking of the Instance.
     */
    interface InstanceNetworkingArgs {
        /**
         * The monthly amount of data transfer, in GB, allocated for the instance
         */
        monthlyTransfer?: pulumi.Input<inputs.lightsail.InstanceMonthlyTransferArgs>;
        /**
         * Ports to the Instance.
         */
        ports: pulumi.Input<pulumi.Input<inputs.lightsail.InstancePortArgs>[]>;
    }
    /**
     * Port of the Instance.
     */
    interface InstancePortArgs {
        /**
         * Access Direction for Protocol of the Instance(inbound/outbound).
         */
        accessDirection?: pulumi.Input<string>;
        /**
         * Access From Protocol of the Instance.
         */
        accessFrom?: pulumi.Input<string>;
        /**
         * Access Type Protocol of the Instance.
         */
        accessType?: pulumi.Input<string>;
        /**
         * An alias that defines access for a preconfigured range of IP addresses.
         *
         * The only alias currently supported is `lightsail-connect` , which allows IP addresses of the browser-based RDP/SSH client in the Lightsail console to connect to your instance.
         */
        cidrListAliases?: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * The IPv4 address, or range of IPv4 addresses (in CIDR notation) that are allowed to connect to an instance through the ports, and the protocol.
         *
         * > The `ipv6Cidrs` parameter lists the IPv6 addresses that are allowed to connect to an instance.
         *
         * Examples:
         *
         * - To allow the IP address `192.0.2.44` , specify `192.0.2.44` or `192.0.2.44/32` .
         * - To allow the IP addresses `192.0.2.0` to `192.0.2.255` , specify `192.0.2.0/24` .
         */
        cidrs?: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * CommonName for Protocol of the Instance.
         */
        commonName?: pulumi.Input<string>;
        /**
         * From Port of the Instance.
         */
        fromPort?: pulumi.Input<number>;
        /**
         * The IPv6 address, or range of IPv6 addresses (in CIDR notation) that are allowed to connect to an instance through the ports, and the protocol. Only devices with an IPv6 address can connect to an instance through IPv6; otherwise, IPv4 should be used.
         *
         * > The `cidrs` parameter lists the IPv4 addresses that are allowed to connect to an instance.
         */
        ipv6Cidrs?: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * Port Protocol of the Instance.
         */
        protocol?: pulumi.Input<string>;
        /**
         * To Port of the Instance.
         */
        toPort?: pulumi.Input<number>;
    }
    /**
     * Current State of the Instance.
     */
    interface InstanceStateArgs {
        /**
         * Status code of the Instance.
         */
        code?: pulumi.Input<number>;
        /**
         * Status code of the Instance.
         */
        name?: pulumi.Input<string>;
    }
}
export declare namespace location {
    interface ApiKeyRestrictionsArgs {
        /**
         * A list of allowed actions that an API key resource grants permissions to perform. You must have at least one action for each type of resource. For example, if you have a place resource, you must include at least one place action.
         *
         * The following are valid values for the actions.
         *
         * - *Map actions*
         *
         * - `geo:GetMap*` - Allows all actions needed for map rendering.
         * - *Enhanced Maps actions*
         *
         * - `geo-maps:GetTile` - Allows getting map tiles for rendering.
         * - `geo-maps:GetStaticMap` - Allows getting static map images.
         * - *Place actions*
         *
         * - `geo:SearchPlaceIndexForText` - Allows finding geo coordinates of a known place.
         * - `geo:SearchPlaceIndexForPosition` - Allows getting nearest address to geo coordinates.
         * - `geo:SearchPlaceIndexForSuggestions` - Allows suggestions based on an incomplete or misspelled query.
         * - `geo:GetPlace` - Allows getting details of a place.
         * - *Enhanced Places actions*
         *
         * - `geo-places:Autcomplete` - Allows auto-completion of search text.
         * - `geo-places:Geocode` - Allows finding geo coordinates of a known place.
         * - `geo-places:GetPlace` - Allows getting details of a place.
         * - `geo-places:ReverseGeocode` - Allows getting nearest address to geo coordinates.
         * - `geo-places:SearchNearby` - Allows category based places search around geo coordinates.
         * - `geo-places:SearchText` - Allows place or address search based on free-form text.
         * - `geo-places:Suggest` - Allows suggestions based on an incomplete or misspelled query.
         * - *Route actions*
         *
         * - `geo:CalculateRoute` - Allows point to point routing.
         * - `geo:CalculateRouteMatrix` - Allows matrix routing.
         * - *Enhanced Routes actions*
         *
         * - `geo-routes:CalculateIsolines` - Allows isoline calculation.
         * - `geo-routes:CalculateRoutes` - Allows point to point routing.
         * - `geo-routes:CalculateRouteMatrix` - Allows matrix routing.
         * - `geo-routes:OptimizeWaypoints` - Allows computing the best sequence of waypoints.
         * - `geo-routes:SnapToRoads` - Allows snapping GPS points to a likely route.
         *
         * > You must use these strings exactly. For example, to provide access to map rendering, the only valid action is `geo:GetMap*` as an input to the list. `["geo:GetMap*"]` is valid but `["geo:GetTile"]` is not. Similarly, you cannot use `["geo:SearchPlaceIndexFor*"]` - you must list each of the Place actions separately.
         */
        allowActions: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * An optional list of allowed HTTP referers for which requests must originate from. Requests using this API key from other domains will not be allowed.
         *
         * Requirements:
         *
         * - Contain only alphanumeric characters (A–Z, a–z, 0–9) or any symbols in this list `$\-._+!*`(),;/?:@=&`
         * - May contain a percent (%) if followed by 2 hexadecimal digits (A-F, a-f, 0-9); this is used for URL encoding purposes.
         * - May contain wildcard characters question mark (?) and asterisk (*).
         *
         * Question mark (?) will replace any single character (including hexadecimal digits).
         *
         * Asterisk (*) will replace any multiple characters (including multiple hexadecimal digits).
         * - No spaces allowed. For example, `https://example.com` .
         */
        allowReferers?: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * A list of allowed resource ARNs that a API key bearer can perform actions on.
         *
         * - The ARN must be the correct ARN for a map, place, or route ARN. You may include wildcards in the resource-id to match multiple resources of the same type.
         * - The resources must be in the same `partition` , `region` , and `account-id` as the key that is being created.
         * - Other than wildcards, you must include the full ARN, including the `arn` , `partition` , `service` , `region` , `account-id` and `resource-id` delimited by colons (:).
         * - No spaces allowed, even with wildcards. For example, `arn:aws:geo:region: *account-id* :map/ExampleMap*` .
         *
         * For more information about ARN format, see [Amazon Resource Names (ARNs)](https://docs.aws.amazon.com/general/latest/gr/aws-arns-and-namespaces.html) .
         */
        allowResources: pulumi.Input<pulumi.Input<string>[]>;
    }
    interface MapConfigurationArgs {
        /**
         * Specifies the custom layers for the style. Leave unset to not enable any custom layer, or, for styles that support custom layers, you can enable layer(s), such as the `POI` layer for the VectorEsriNavigation style.
         *
         * > Currenlty only `VectorEsriNavigation` supports CustomLayers. For more information, see [Custom Layers](https://docs.aws.amazon.com//location/latest/developerguide/map-concepts.html#map-custom-layers) .
         */
        customLayers?: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * Specifies the map political view selected from an available data provider.
         */
        politicalView?: pulumi.Input<string>;
        /**
         * Specifies the map style selected from an available data provider.
         *
         * Valid [Esri map styles](https://docs.aws.amazon.com/location/previous/developerguide/esri.html) :
         *
         * - `VectorEsriDarkGrayCanvas` – The Esri Dark Gray Canvas map style. A vector basemap with a dark gray, neutral background with minimal colors, labels, and features that's designed to draw attention to your thematic content.
         * - `RasterEsriImagery` – The Esri Imagery map style. A raster basemap that provides one meter or better satellite and aerial imagery in many parts of the world and lower resolution satellite imagery worldwide.
         * - `VectorEsriLightGrayCanvas` – The Esri Light Gray Canvas map style, which provides a detailed vector basemap with a light gray, neutral background style with minimal colors, labels, and features that's designed to draw attention to your thematic content.
         * - `VectorEsriTopographic` – The Esri Light map style, which provides a detailed vector basemap with a classic Esri map style.
         * - `VectorEsriStreets` – The Esri Street Map style, which provides a detailed vector basemap for the world symbolized with a classic Esri street map style. The vector tile layer is similar in content and style to the World Street Map raster map.
         * - `VectorEsriNavigation` – The Esri Navigation map style, which provides a detailed basemap for the world symbolized with a custom navigation map style that's designed for use during the day in mobile devices.
         *
         * Valid [HERE Technologies map styles](https://docs.aws.amazon.com/location/previous/developerguide/HERE.html) :
         *
         * - `VectorHereContrast` – The HERE Contrast (Berlin) map style is a high contrast detailed base map of the world that blends 3D and 2D rendering.
         *
         * > The `VectorHereContrast` style has been renamed from `VectorHereBerlin` . `VectorHereBerlin` has been deprecated, but will continue to work in applications that use it.
         * - `VectorHereExplore` – A default HERE map style containing a neutral, global map and its features including roads, buildings, landmarks, and water features. It also now includes a fully designed map of Japan.
         * - `VectorHereExploreTruck` – A global map containing truck restrictions and attributes (e.g. width / height / HAZMAT) symbolized with highlighted segments and icons on top of HERE Explore to support use cases within transport and logistics.
         * - `RasterHereExploreSatellite` – A global map containing high resolution satellite imagery.
         * - `HybridHereExploreSatellite` – A global map displaying the road network, street names, and city labels over satellite imagery. This style will automatically retrieve both raster and vector tiles, and your charges will be based on total tiles retrieved.
         *
         * > Hybrid styles use both vector and raster tiles when rendering the map that you see. This means that more tiles are retrieved than when using either vector or raster tiles alone. Your charges will include all tiles retrieved.
         *
         * Valid [GrabMaps map styles](https://docs.aws.amazon.com/location/previous/developerguide/grab.html) :
         *
         * - `VectorGrabStandardLight` – The Grab Standard Light map style provides a basemap with detailed land use coloring, area names, roads, landmarks, and points of interest covering Southeast Asia.
         * - `VectorGrabStandardDark` – The Grab Standard Dark map style provides a dark variation of the standard basemap covering Southeast Asia.
         *
         * > Grab provides maps only for countries in Southeast Asia, and is only available in the Asia Pacific (Singapore) Region ( `ap-southeast-1` ). For more information, see [GrabMaps countries and area covered](https://docs.aws.amazon.com/location/previous/developerguide/grab.html#grab-coverage-area) .
         *
         * Valid [Open Data map styles](https://docs.aws.amazon.com/location/previous/developerguide/open-data.html) :
         *
         * - `VectorOpenDataStandardLight` – The Open Data Standard Light map style provides a detailed basemap for the world suitable for website and mobile application use. The map includes highways major roads, minor roads, railways, water features, cities, parks, landmarks, building footprints, and administrative boundaries.
         * - `VectorOpenDataStandardDark` – Open Data Standard Dark is a dark-themed map style that provides a detailed basemap for the world suitable for website and mobile application use. The map includes highways major roads, minor roads, railways, water features, cities, parks, landmarks, building footprints, and administrative boundaries.
         * - `VectorOpenDataVisualizationLight` – The Open Data Visualization Light map style is a light-themed style with muted colors and fewer features that aids in understanding overlaid data.
         * - `VectorOpenDataVisualizationDark` – The Open Data Visualization Dark map style is a dark-themed style with muted colors and fewer features that aids in understanding overlaid data.
         */
        style: pulumi.Input<string>;
    }
    interface PlaceIndexDataSourceConfigurationArgs {
        /**
         * Specifies how the results of an operation will be stored by the caller.
         *
         * Valid values include:
         *
         * - `SingleUse` specifies that the results won't be stored.
         * - `Storage` specifies that the result can be cached or stored in a database.
         *
         * Default value: `SingleUse`
         */
        intendedUse?: pulumi.Input<enums.location.PlaceIndexIntendedUse>;
    }
}
export declare namespace logs {
    interface DeliveryDestinationDestinationPolicyArgs {
        /**
         * The name of the delivery destination to assign this policy to
         */
        deliveryDestinationName: pulumi.Input<string>;
        /**
         * The contents of the policy attached to the delivery destination
         */
        deliveryDestinationPolicy: pulumi.Input<string>;
    }
    interface IntegrationOpenSearchResourceConfigArgs {
        /**
         * If you want to use an existing OpenSearch Service application for your integration with OpenSearch Service, specify it here. If you omit this, a new application will be created.
         */
        applicationArn?: pulumi.Input<string>;
        /**
         * Specify the ARNs of IAM roles and IAM users who you want to grant permission to for viewing the dashboards.
         *
         * > In addition to specifying these users here, you must also grant them the *CloudWatchOpenSearchDashboardAccess* IAM policy. For more information, see [IAM policies for users](https://docs.aws.amazon.com/AmazonCloudWatch/latest/logs/OpenSearch-Dashboards-UserRoles.html) .
         */
        dashboardViewerPrincipals: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * Specify the ARN of an IAM role that CloudWatch Logs will use to create the integration. This role must have the permissions necessary to access the OpenSearch Service collection to be able to create the dashboards. For more information about the permissions needed, see [Permissions that the integration needs](https://docs.aws.amazon.com/AmazonCloudWatch/latest/logs/OpenSearch-Dashboards-CreateRole.html) in the CloudWatch Logs User Guide.
         */
        dataSourceRoleArn: pulumi.Input<string>;
        /**
         * To have the vended dashboard data encrypted with AWS KMS instead of the CloudWatch Logs default encryption method, specify the ARN of the AWS KMS key that you want to use.
         */
        kmsKeyArn?: pulumi.Input<string>;
        /**
         * Specify how many days that you want the data derived by OpenSearch Service to be retained in the index that the dashboard refers to. This also sets the maximum time period that you can choose when viewing data in the dashboard. Choosing a longer time frame will incur additional costs.
         */
        retentionDays?: pulumi.Input<number>;
    }
    /**
     * Specifies the CW metric dimensions to publish with this metric.
     *   Because dimensions are part of the unique identifier for a metric, whenever a unique dimension name/value pair is extracted from your logs, you are creating a new variation of that metric.
     *  For more information about publishing dimensions with metrics created by metric filters, see [Publishing dimensions with metrics from values in JSON or space-delimited log events](https://docs.aws.amazon.com/AmazonCloudWatch/latest/logs/FilterAndPatternSyntax.html#logs-metric-filters-dimensions).
     *   Metrics extracted from log events are charged as custom metrics. To prevent unexpected high charges, do not specify high-cardinality fields such as ``IPAddress`` or ``requestID`` as dimensions. Each different value found for a dimension is treated as a separate metric and accrues charges as a separate custom metric.
     *  To help prevent accidental high charges, Amazon disables a metric filter if it generates 1000 different name/value pairs for the dimensions that you have specified within a certain amount of time.
     *  You can also set up a billing alarm to alert you if your charges are higher than expected. For more information, see [Creating a Billing Alarm to Monitor Your Estimated Charges](https://docs.aws.amazon.com/AmazonCloudWatch/latest/monitoring/monitor_estimated_charges_with_cloudwatch.html).
     */
    interface MetricFilterDimensionArgs {
        /**
         * The name for the CW metric dimension that the metric filter creates.
         *  Dimension names must contain only ASCII characters, must include at least one non-whitespace character, and cannot start with a colon (:).
         */
        key: pulumi.Input<string>;
        /**
         * The log event field that will contain the value for this dimension. This dimension will only be published for a metric if the value is found in the log event. For example, ``$.eventType`` for JSON log events, or ``$server`` for space-delimited log events.
         */
        value: pulumi.Input<string>;
    }
    /**
     * ``MetricTransformation`` is a property of the ``AWS::Logs::MetricFilter`` resource that describes how to transform log streams into a CloudWatch metric.
     */
    interface MetricFilterMetricTransformationArgs {
        /**
         * (Optional) The value to emit when a filter pattern does not match a log event. This value can be null.
         */
        defaultValue?: pulumi.Input<number>;
        /**
         * The fields to use as dimensions for the metric. One metric filter can include as many as three dimensions.
         *   Metrics extracted from log events are charged as custom metrics. To prevent unexpected high charges, do not specify high-cardinality fields such as ``IPAddress`` or ``requestID`` as dimensions. Each different value found for a dimension is treated as a separate metric and accrues charges as a separate custom metric.
         *  CloudWatch Logs disables a metric filter if it generates 1000 different name/value pairs for your specified dimensions within a certain amount of time. This helps to prevent accidental high charges.
         *  You can also set up a billing alarm to alert you if your charges are higher than expected. For more information, see [Creating a Billing Alarm to Monitor Your Estimated Charges](https://docs.aws.amazon.com/AmazonCloudWatch/latest/monitoring/monitor_estimated_charges_with_cloudwatch.html).
         */
        dimensions?: pulumi.Input<pulumi.Input<inputs.logs.MetricFilterDimensionArgs>[]>;
        /**
         * The name of the CloudWatch metric.
         */
        metricName: pulumi.Input<string>;
        /**
         * A custom namespace to contain your metric in CloudWatch. Use namespaces to group together metrics that are similar. For more information, see [Namespaces](https://docs.aws.amazon.com/AmazonCloudWatch/latest/monitoring/cloudwatch_concepts.html#Namespace).
         */
        metricNamespace: pulumi.Input<string>;
        /**
         * The value that is published to the CloudWatch metric. For example, if you're counting the occurrences of a particular term like ``Error``, specify 1 for the metric value. If you're counting the number of bytes transferred, reference the value that is in the log event by using $. followed by the name of the field that you specified in the filter pattern, such as ``$.size``.
         */
        metricValue: pulumi.Input<string>;
        /**
         * The unit to assign to the metric. If you omit this, the unit is set as ``None``.
         */
        unit?: pulumi.Input<enums.logs.MetricFilterMetricTransformationUnit>;
    }
    /**
     * OpenSearchResourceConfig for the given Integration
     */
    interface ResourceConfigPropertiesArgs {
        /**
         * This structure contains configuration details about an integration between CloudWatch Logs and OpenSearch Service.
         */
        openSearchResourceConfig?: pulumi.Input<inputs.logs.IntegrationOpenSearchResourceConfigArgs>;
    }
    interface TransformerAddKeyEntryArgs {
        /**
         * The key of the new entry to be added to the log event
         */
        key: pulumi.Input<string>;
        /**
         * Specifies whether to overwrite the value if the key already exists in the log event. If you omit this, the default is `false` .
         */
        overwriteIfExists?: pulumi.Input<boolean>;
        /**
         * The value of the new entry to be added to the log event
         */
        value: pulumi.Input<string>;
    }
    interface TransformerCopyValueEntryArgs {
        overwriteIfExists?: pulumi.Input<boolean>;
        source: pulumi.Input<string>;
        target: pulumi.Input<string>;
    }
    interface TransformerMoveKeyEntryArgs {
        overwriteIfExists?: pulumi.Input<boolean>;
        source: pulumi.Input<string>;
        target: pulumi.Input<string>;
    }
    interface TransformerParseCloudfrontArgs {
        /**
         * Omit this parameter and the whole log message will be processed by this processor. No other value than `@message` is allowed for `source` .
         */
        source?: pulumi.Input<string>;
    }
    interface TransformerParsePostgresArgs {
        /**
         * Omit this parameter and the whole log message will be processed by this processor. No other value than `@message` is allowed for `source` .
         */
        source?: pulumi.Input<string>;
    }
    interface TransformerParseRoute53Args {
        /**
         * Omit this parameter and the whole log message will be processed by this processor. No other value than `@message` is allowed for `source` .
         */
        source?: pulumi.Input<string>;
    }
    interface TransformerParseVpcArgs {
        /**
         * Omit this parameter and the whole log message will be processed by this processor. No other value than `@message` is allowed for `source` .
         */
        source?: pulumi.Input<string>;
    }
    interface TransformerParseWafArgs {
        /**
         * Omit this parameter and the whole log message will be processed by this processor. No other value than `@message` is allowed for `source` .
         */
        source?: pulumi.Input<string>;
    }
    /**
     * Individual processor configuration
     */
    interface TransformerProcessorArgs {
        /**
         * Use this parameter to include the [addKeys](https://docs.aws.amazon.com/AmazonCloudWatch/latest/logs/CloudWatch-Logs-Transformation.html#CloudWatch-Logs-Transformation-addKeys) processor in your transformer.
         */
        addKeys?: pulumi.Input<inputs.logs.TransformerProcessorAddKeysPropertiesArgs>;
        /**
         * Use this parameter to include the [copyValue](https://docs.aws.amazon.com/AmazonCloudWatch/latest/logs/CloudWatch-Logs-Transformation-Processors.html#CloudWatch-Logs-Transformation-copyValue) processor in your transformer.
         */
        copyValue?: pulumi.Input<inputs.logs.TransformerProcessorCopyValuePropertiesArgs>;
        /**
         * Use this parameter to include the [CSV](https://docs.aws.amazon.com/AmazonCloudWatch/latest/logs/CloudWatch-Logs-Transformation.html#CloudWatch-Logs-Transformation-CSV) processor in your transformer.
         */
        csv?: pulumi.Input<inputs.logs.TransformerProcessorCsvPropertiesArgs>;
        /**
         * Use this parameter to include the [datetimeConverter](https://docs.aws.amazon.com/AmazonCloudWatch/latest/logs/CloudWatch-Logs-Transformation-Processors.html#CloudWatch-Logs-Transformation-datetimeConverter) processor in your transformer.
         */
        dateTimeConverter?: pulumi.Input<inputs.logs.TransformerProcessorDateTimeConverterPropertiesArgs>;
        /**
         * Use this parameter to include the [deleteKeys](https://docs.aws.amazon.com/AmazonCloudWatch/latest/logs/CloudWatch-Logs-Transformation.html#CloudWatch-Logs-Transformation-deleteKeys) processor in your transformer.
         */
        deleteKeys?: pulumi.Input<inputs.logs.TransformerProcessorDeleteKeysPropertiesArgs>;
        /**
         * Use this parameter to include the [grok](https://docs.aws.amazon.com/AmazonCloudWatch/latest/logs/CloudWatch-Logs-Transformation-Processors.html#CloudWatch-Logs-Transformation-grok) processor in your transformer.
         */
        grok?: pulumi.Input<inputs.logs.TransformerProcessorGrokPropertiesArgs>;
        /**
         * Use this parameter to include the [listToMap](https://docs.aws.amazon.com/AmazonCloudWatch/latest/logs/CloudWatch-Logs-Transformation.html#CloudWatch-Logs-Transformation-listToMap) processor in your transformer.
         */
        listToMap?: pulumi.Input<inputs.logs.TransformerProcessorListToMapPropertiesArgs>;
        /**
         * Use this parameter to include the [lowerCaseString](https://docs.aws.amazon.com/AmazonCloudWatch/latest/logs/CloudWatch-Logs-Transformation-Processors.html#CloudWatch-Logs-Transformation-lowerCaseString) processor in your transformer.
         */
        lowerCaseString?: pulumi.Input<inputs.logs.TransformerProcessorLowerCaseStringPropertiesArgs>;
        /**
         * Use this parameter to include the [moveKeys](https://docs.aws.amazon.com/AmazonCloudWatch/latest/logs/CloudWatch-Logs-Transformation-Processors.html#CloudWatch-Logs-Transformation-moveKeys) processor in your transformer.
         */
        moveKeys?: pulumi.Input<inputs.logs.TransformerProcessorMoveKeysPropertiesArgs>;
        /**
         * Use this parameter to include the [parseCloudfront](https://docs.aws.amazon.com/AmazonCloudWatch/latest/logs/CloudWatch-Logs-Transformation-Processors.html#CloudWatch-Logs-Transformation-parseCloudfront) processor in your transformer.
         *
         * If you use this processor, it must be the first processor in your transformer.
         */
        parseCloudfront?: pulumi.Input<inputs.logs.TransformerParseCloudfrontArgs>;
        /**
         * Use this parameter to include the [parseJSON](https://docs.aws.amazon.com/AmazonCloudWatch/latest/logs/CloudWatch-Logs-Transformation-Processors.html#CloudWatch-Logs-Transformation-parseJSON) processor in your transformer.
         */
        parseJson?: pulumi.Input<inputs.logs.TransformerProcessorParseJsonPropertiesArgs>;
        /**
         * Use this parameter to include the [parseKeyValue](https://docs.aws.amazon.com/AmazonCloudWatch/latest/logs/CloudWatch-Logs-Transformation-Processors.html#CloudWatch-Logs-Transformation-parseKeyValue) processor in your transformer.
         */
        parseKeyValue?: pulumi.Input<inputs.logs.TransformerProcessorParseKeyValuePropertiesArgs>;
        /**
         * Use this parameter to include the [parsePostGres](https://docs.aws.amazon.com/AmazonCloudWatch/latest/logs/CloudWatch-Logs-Transformation.html#CloudWatch-Logs-Transformation-parsePostGres) processor in your transformer.
         *
         * If you use this processor, it must be the first processor in your transformer.
         */
        parsePostgres?: pulumi.Input<inputs.logs.TransformerParsePostgresArgs>;
        /**
         * Use this parameter to include the [parseRoute53](https://docs.aws.amazon.com/AmazonCloudWatch/latest/logs/CloudWatch-Logs-Transformation-Processors.html#CloudWatch-Logs-Transformation-parseRoute53) processor in your transformer.
         *
         * If you use this processor, it must be the first processor in your transformer.
         */
        parseRoute53?: pulumi.Input<inputs.logs.TransformerParseRoute53Args>;
        /**
         * Use this parameter to include the [parseVPC](https://docs.aws.amazon.com/AmazonCloudWatch/latest/logs/CloudWatch-Logs-Transformation-Processors.html#CloudWatch-Logs-Transformation-parseVPC) processor in your transformer.
         *
         * If you use this processor, it must be the first processor in your transformer.
         */
        parseVpc?: pulumi.Input<inputs.logs.TransformerParseVpcArgs>;
        /**
         * Use this parameter to include the [parseWAF](https://docs.aws.amazon.com/AmazonCloudWatch/latest/logs/CloudWatch-Logs-Transformation.html#CloudWatch-Logs-Transformation-parseWAF) processor in your transformer.
         *
         * If you use this processor, it must be the first processor in your transformer.
         */
        parseWaf?: pulumi.Input<inputs.logs.TransformerParseWafArgs>;
        /**
         * Use this parameter to include the [renameKeys](https://docs.aws.amazon.com/AmazonCloudWatch/latest/logs/CloudWatch-Logs-Transformation.html#CloudWatch-Logs-Transformation-renameKeys) processor in your transformer.
         */
        renameKeys?: pulumi.Input<inputs.logs.TransformerProcessorRenameKeysPropertiesArgs>;
        /**
         * Use this parameter to include the [splitString](https://docs.aws.amazon.com/AmazonCloudWatch/latest/logs/CloudWatch-Logs-Transformation-Processors.html#CloudWatch-Logs-Transformation-splitString) processor in your transformer.
         */
        splitString?: pulumi.Input<inputs.logs.TransformerProcessorSplitStringPropertiesArgs>;
        /**
         * Use this parameter to include the [substituteString](https://docs.aws.amazon.com/AmazonCloudWatch/latest/logs/CloudWatch-Logs-Transformation-Processors.html#CloudWatch-Logs-Transformation-substituteString) processor in your transformer.
         */
        substituteString?: pulumi.Input<inputs.logs.TransformerProcessorSubstituteStringPropertiesArgs>;
        /**
         * Use this parameter to include the [trimString](https://docs.aws.amazon.com/AmazonCloudWatch/latest/logs/CloudWatch-Logs-Transformation-Processors.html#CloudWatch-Logs-Transformation-trimString) processor in your transformer.
         */
        trimString?: pulumi.Input<inputs.logs.TransformerProcessorTrimStringPropertiesArgs>;
        /**
         * Use this parameter to include the [typeConverter](https://docs.aws.amazon.com/AmazonCloudWatch/latest/logs/CloudWatch-Logs-Transformation-Processors.html#CloudWatch-Logs-Transformation-typeConverter) processor in your transformer.
         */
        typeConverter?: pulumi.Input<inputs.logs.TransformerProcessorTypeConverterPropertiesArgs>;
        /**
         * Use this parameter to include the [upperCaseString](https://docs.aws.amazon.com/AmazonCloudWatch/latest/logs/CloudWatch-Logs-Transformation-Processors.html#CloudWatch-Logs-Transformation-upperCaseString) processor in your transformer.
         */
        upperCaseString?: pulumi.Input<inputs.logs.TransformerProcessorUpperCaseStringPropertiesArgs>;
    }
    /**
     * Use this parameter to include the [addKeys](https://docs.aws.amazon.com/AmazonCloudWatch/latest/logs/CloudWatch-Logs-Transformation.html#CloudWatch-Logs-Transformation-addKeys) processor in your transformer.
     */
    interface TransformerProcessorAddKeysPropertiesArgs {
        entries: pulumi.Input<pulumi.Input<inputs.logs.TransformerAddKeyEntryArgs>[]>;
    }
    /**
     * Use this parameter to include the [copyValue](https://docs.aws.amazon.com/AmazonCloudWatch/latest/logs/CloudWatch-Logs-Transformation-Processors.html#CloudWatch-Logs-Transformation-copyValue) processor in your transformer.
     */
    interface TransformerProcessorCopyValuePropertiesArgs {
        entries: pulumi.Input<pulumi.Input<inputs.logs.TransformerCopyValueEntryArgs>[]>;
    }
    /**
     * Use this parameter to include the [CSV](https://docs.aws.amazon.com/AmazonCloudWatch/latest/logs/CloudWatch-Logs-Transformation.html#CloudWatch-Logs-Transformation-CSV) processor in your transformer.
     */
    interface TransformerProcessorCsvPropertiesArgs {
        columns?: pulumi.Input<pulumi.Input<string>[]>;
        delimiter?: pulumi.Input<string>;
        quoteCharacter?: pulumi.Input<string>;
        source?: pulumi.Input<string>;
    }
    /**
     * Use this parameter to include the [datetimeConverter](https://docs.aws.amazon.com/AmazonCloudWatch/latest/logs/CloudWatch-Logs-Transformation-Processors.html#CloudWatch-Logs-Transformation-datetimeConverter) processor in your transformer.
     */
    interface TransformerProcessorDateTimeConverterPropertiesArgs {
        locale?: pulumi.Input<string>;
        matchPatterns: pulumi.Input<pulumi.Input<string>[]>;
        source: pulumi.Input<string>;
        sourceTimezone?: pulumi.Input<string>;
        target: pulumi.Input<string>;
        targetFormat?: pulumi.Input<string>;
        targetTimezone?: pulumi.Input<string>;
    }
    /**
     * Use this parameter to include the [deleteKeys](https://docs.aws.amazon.com/AmazonCloudWatch/latest/logs/CloudWatch-Logs-Transformation.html#CloudWatch-Logs-Transformation-deleteKeys) processor in your transformer.
     */
    interface TransformerProcessorDeleteKeysPropertiesArgs {
        withKeys: pulumi.Input<pulumi.Input<string>[]>;
    }
    /**
     * Use this parameter to include the [grok](https://docs.aws.amazon.com/AmazonCloudWatch/latest/logs/CloudWatch-Logs-Transformation-Processors.html#CloudWatch-Logs-Transformation-grok) processor in your transformer.
     */
    interface TransformerProcessorGrokPropertiesArgs {
        match: pulumi.Input<string>;
        source?: pulumi.Input<string>;
    }
    /**
     * Use this parameter to include the [listToMap](https://docs.aws.amazon.com/AmazonCloudWatch/latest/logs/CloudWatch-Logs-Transformation.html#CloudWatch-Logs-Transformation-listToMap) processor in your transformer.
     */
    interface TransformerProcessorListToMapPropertiesArgs {
        flatten?: pulumi.Input<boolean>;
        flattenedElement?: pulumi.Input<enums.logs.TransformerProcessorListToMapPropertiesFlattenedElement>;
        key: pulumi.Input<string>;
        source: pulumi.Input<string>;
        target?: pulumi.Input<string>;
        valueKey?: pulumi.Input<string>;
    }
    /**
     * Use this parameter to include the [lowerCaseString](https://docs.aws.amazon.com/AmazonCloudWatch/latest/logs/CloudWatch-Logs-Transformation-Processors.html#CloudWatch-Logs-Transformation-lowerCaseString) processor in your transformer.
     */
    interface TransformerProcessorLowerCaseStringPropertiesArgs {
        withKeys: pulumi.Input<pulumi.Input<string>[]>;
    }
    /**
     * Use this parameter to include the [moveKeys](https://docs.aws.amazon.com/AmazonCloudWatch/latest/logs/CloudWatch-Logs-Transformation-Processors.html#CloudWatch-Logs-Transformation-moveKeys) processor in your transformer.
     */
    interface TransformerProcessorMoveKeysPropertiesArgs {
        entries: pulumi.Input<pulumi.Input<inputs.logs.TransformerMoveKeyEntryArgs>[]>;
    }
    /**
     * Use this parameter to include the [parseJSON](https://docs.aws.amazon.com/AmazonCloudWatch/latest/logs/CloudWatch-Logs-Transformation-Processors.html#CloudWatch-Logs-Transformation-parseJSON) processor in your transformer.
     */
    interface TransformerProcessorParseJsonPropertiesArgs {
        destination?: pulumi.Input<string>;
        source?: pulumi.Input<string>;
    }
    /**
     * Use this parameter to include the [parseKeyValue](https://docs.aws.amazon.com/AmazonCloudWatch/latest/logs/CloudWatch-Logs-Transformation-Processors.html#CloudWatch-Logs-Transformation-parseKeyValue) processor in your transformer.
     */
    interface TransformerProcessorParseKeyValuePropertiesArgs {
        destination?: pulumi.Input<string>;
        fieldDelimiter?: pulumi.Input<string>;
        keyPrefix?: pulumi.Input<string>;
        keyValueDelimiter?: pulumi.Input<string>;
        nonMatchValue?: pulumi.Input<string>;
        overwriteIfExists?: pulumi.Input<boolean>;
        source?: pulumi.Input<string>;
    }
    /**
     * Use this parameter to include the [renameKeys](https://docs.aws.amazon.com/AmazonCloudWatch/latest/logs/CloudWatch-Logs-Transformation.html#CloudWatch-Logs-Transformation-renameKeys) processor in your transformer.
     */
    interface TransformerProcessorRenameKeysPropertiesArgs {
        entries: pulumi.Input<pulumi.Input<inputs.logs.TransformerRenameKeyEntryArgs>[]>;
    }
    /**
     * Use this parameter to include the [splitString](https://docs.aws.amazon.com/AmazonCloudWatch/latest/logs/CloudWatch-Logs-Transformation-Processors.html#CloudWatch-Logs-Transformation-splitString) processor in your transformer.
     */
    interface TransformerProcessorSplitStringPropertiesArgs {
        entries: pulumi.Input<pulumi.Input<inputs.logs.TransformerSplitStringEntryArgs>[]>;
    }
    /**
     * Use this parameter to include the [substituteString](https://docs.aws.amazon.com/AmazonCloudWatch/latest/logs/CloudWatch-Logs-Transformation-Processors.html#CloudWatch-Logs-Transformation-substituteString) processor in your transformer.
     */
    interface TransformerProcessorSubstituteStringPropertiesArgs {
        entries: pulumi.Input<pulumi.Input<inputs.logs.TransformerSubstituteStringEntryArgs>[]>;
    }
    /**
     * Use this parameter to include the [trimString](https://docs.aws.amazon.com/AmazonCloudWatch/latest/logs/CloudWatch-Logs-Transformation-Processors.html#CloudWatch-Logs-Transformation-trimString) processor in your transformer.
     */
    interface TransformerProcessorTrimStringPropertiesArgs {
        withKeys: pulumi.Input<pulumi.Input<string>[]>;
    }
    /**
     * Use this parameter to include the [typeConverter](https://docs.aws.amazon.com/AmazonCloudWatch/latest/logs/CloudWatch-Logs-Transformation-Processors.html#CloudWatch-Logs-Transformation-typeConverter) processor in your transformer.
     */
    interface TransformerProcessorTypeConverterPropertiesArgs {
        entries: pulumi.Input<pulumi.Input<inputs.logs.TransformerTypeConverterEntryArgs>[]>;
    }
    /**
     * Use this parameter to include the [upperCaseString](https://docs.aws.amazon.com/AmazonCloudWatch/latest/logs/CloudWatch-Logs-Transformation-Processors.html#CloudWatch-Logs-Transformation-upperCaseString) processor in your transformer.
     */
    interface TransformerProcessorUpperCaseStringPropertiesArgs {
        withKeys: pulumi.Input<pulumi.Input<string>[]>;
    }
    interface TransformerRenameKeyEntryArgs {
        key: pulumi.Input<string>;
        overwriteIfExists?: pulumi.Input<boolean>;
        renameTo: pulumi.Input<string>;
    }
    interface TransformerSplitStringEntryArgs {
        delimiter: pulumi.Input<string>;
        source: pulumi.Input<string>;
    }
    interface TransformerSubstituteStringEntryArgs {
        from: pulumi.Input<string>;
        source: pulumi.Input<string>;
        to: pulumi.Input<string>;
    }
    interface TransformerTypeConverterEntryArgs {
        key: pulumi.Input<string>;
        type: pulumi.Input<enums.logs.TransformerTypeConverterEntryType>;
    }
}
export declare namespace lookoutmetrics {
    interface AlertActionArgs {
        /**
         * A configuration for an AWS Lambda channel.
         */
        lambdaConfiguration?: pulumi.Input<inputs.lookoutmetrics.AlertLambdaConfigurationArgs>;
        /**
         * A configuration for an Amazon SNS channel.
         */
        snsConfiguration?: pulumi.Input<inputs.lookoutmetrics.AlertSnsConfigurationArgs>;
    }
    /**
     * Configuration options for a Lambda alert action.
     */
    interface AlertLambdaConfigurationArgs {
        /**
         * ARN of a Lambda to send alert notifications to.
         */
        lambdaArn: pulumi.Input<string>;
        /**
         * ARN of an IAM role that LookoutMetrics should assume to access the Lambda function.
         */
        roleArn: pulumi.Input<string>;
    }
    /**
     * Configuration options for an SNS alert action.
     */
    interface AlertSnsConfigurationArgs {
        /**
         * ARN of an IAM role that LookoutMetrics should assume to access the SNS topic.
         */
        roleArn: pulumi.Input<string>;
        /**
         * ARN of an SNS topic to send alert notifications to.
         */
        snsTopicArn: pulumi.Input<string>;
    }
    interface AnomalyDetectorAppFlowConfigArgs {
        /**
         * name of the flow.
         */
        flowName: pulumi.Input<string>;
        /**
         * An IAM role that gives Amazon Lookout for Metrics permission to access the flow.
         */
        roleArn: pulumi.Input<string>;
    }
    interface AnomalyDetectorCloudwatchConfigArgs {
        /**
         * An IAM role that gives Amazon Lookout for Metrics permission to access data in Amazon CloudWatch.
         */
        roleArn: pulumi.Input<string>;
    }
    interface AnomalyDetectorConfigArgs {
        /**
         * Frequency of anomaly detection
         */
        anomalyDetectorFrequency: pulumi.Input<enums.lookoutmetrics.AnomalyDetectorFrequency>;
    }
    interface AnomalyDetectorCsvFormatDescriptorArgs {
        /**
         * The character set in which the source CSV file is written.
         */
        charset?: pulumi.Input<string>;
        /**
         * Whether or not the source CSV file contains a header.
         */
        containsHeader?: pulumi.Input<boolean>;
        /**
         * The character used to delimit the source CSV file.
         */
        delimiter?: pulumi.Input<string>;
        /**
         * The level of compression of the source CSV file.
         */
        fileCompression?: pulumi.Input<enums.lookoutmetrics.AnomalyDetectorCsvFormatDescriptorFileCompression>;
        /**
         * A list of the source CSV file's headers, if any.
         */
        headerList?: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * The character used as a quote character.
         */
        quoteSymbol?: pulumi.Input<string>;
    }
    interface AnomalyDetectorFileFormatDescriptorArgs {
        /**
         * Contains information about how a source CSV data file should be analyzed.
         */
        csvFormatDescriptor?: pulumi.Input<inputs.lookoutmetrics.AnomalyDetectorCsvFormatDescriptorArgs>;
        /**
         * Contains information about how a source JSON data file should be analyzed.
         */
        jsonFormatDescriptor?: pulumi.Input<inputs.lookoutmetrics.AnomalyDetectorJsonFormatDescriptorArgs>;
    }
    interface AnomalyDetectorJsonFormatDescriptorArgs {
        /**
         * The character set in which the source JSON file is written.
         */
        charset?: pulumi.Input<string>;
        /**
         * The level of compression of the source CSV file.
         */
        fileCompression?: pulumi.Input<enums.lookoutmetrics.AnomalyDetectorJsonFormatDescriptorFileCompression>;
    }
    interface AnomalyDetectorMetricArgs {
        /**
         * Operator used to aggregate metric values
         */
        aggregationFunction: pulumi.Input<enums.lookoutmetrics.AnomalyDetectorMetricAggregationFunction>;
        /**
         * The name of the metric.
         */
        metricName: pulumi.Input<string>;
        /**
         * The namespace for the metric.
         */
        namespace?: pulumi.Input<string>;
    }
    interface AnomalyDetectorMetricSetArgs {
        /**
         * Dimensions for this MetricSet.
         */
        dimensionList?: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * Metrics captured by this MetricSet.
         */
        metricList: pulumi.Input<pulumi.Input<inputs.lookoutmetrics.AnomalyDetectorMetricArgs>[]>;
        /**
         * A description for the MetricSet.
         */
        metricSetDescription?: pulumi.Input<string>;
        /**
         * A frequency period to aggregate the data
         */
        metricSetFrequency?: pulumi.Input<enums.lookoutmetrics.AnomalyDetectorMetricSetMetricSetFrequency>;
        /**
         * The name of the MetricSet.
         */
        metricSetName: pulumi.Input<string>;
        /**
         * Contains information about how the source data should be interpreted.
         */
        metricSource: pulumi.Input<inputs.lookoutmetrics.AnomalyDetectorMetricSourceArgs>;
        /**
         * Offset, in seconds, between the frequency interval and the time at which the metrics are available.
         */
        offset?: pulumi.Input<number>;
        /**
         * Contains information about the column used for tracking time in your source data.
         */
        timestampColumn?: pulumi.Input<inputs.lookoutmetrics.AnomalyDetectorTimestampColumnArgs>;
        /**
         * The time zone in which your source data was recorded.
         */
        timezone?: pulumi.Input<string>;
    }
    interface AnomalyDetectorMetricSourceArgs {
        /**
         * Details about an AppFlow datasource.
         */
        appFlowConfig?: pulumi.Input<inputs.lookoutmetrics.AnomalyDetectorAppFlowConfigArgs>;
        /**
         * Details about an Amazon CloudWatch monitoring datasource.
         */
        cloudwatchConfig?: pulumi.Input<inputs.lookoutmetrics.AnomalyDetectorCloudwatchConfigArgs>;
        /**
         * Details about an Amazon Relational Database Service (RDS) datasource.
         */
        rdsSourceConfig?: pulumi.Input<inputs.lookoutmetrics.AnomalyDetectorRdsSourceConfigArgs>;
        /**
         * Details about an Amazon Redshift database datasource.
         */
        redshiftSourceConfig?: pulumi.Input<inputs.lookoutmetrics.AnomalyDetectorRedshiftSourceConfigArgs>;
        /**
         * Contains information about the configuration of the S3 bucket that contains source files.
         */
        s3SourceConfig?: pulumi.Input<inputs.lookoutmetrics.AnomalyDetectorS3SourceConfigArgs>;
    }
    interface AnomalyDetectorRdsSourceConfigArgs {
        /**
         * The host name of the database.
         */
        databaseHost: pulumi.Input<string>;
        /**
         * The name of the RDS database.
         */
        databaseName: pulumi.Input<string>;
        /**
         * The port number where the database can be accessed.
         */
        databasePort: pulumi.Input<number>;
        /**
         * A string identifying the database instance.
         */
        dbInstanceIdentifier: pulumi.Input<string>;
        /**
         * The Amazon Resource Name (ARN) of the role.
         */
        roleArn: pulumi.Input<string>;
        /**
         * The Amazon Resource Name (ARN) of the AWS Secrets Manager role.
         */
        secretManagerArn: pulumi.Input<string>;
        /**
         * The name of the table in the database.
         */
        tableName: pulumi.Input<string>;
        /**
         * An object containing information about the Amazon Virtual Private Cloud (VPC) configuration.
         */
        vpcConfiguration: pulumi.Input<inputs.lookoutmetrics.AnomalyDetectorVpcConfigurationArgs>;
    }
    interface AnomalyDetectorRedshiftSourceConfigArgs {
        /**
         * A string identifying the Redshift cluster.
         */
        clusterIdentifier: pulumi.Input<string>;
        /**
         * The name of the database host.
         */
        databaseHost: pulumi.Input<string>;
        /**
         * The Redshift database name.
         */
        databaseName: pulumi.Input<string>;
        /**
         * The port number where the database can be accessed.
         */
        databasePort: pulumi.Input<number>;
        /**
         * The Amazon Resource Name (ARN) of the role providing access to the database.
         */
        roleArn: pulumi.Input<string>;
        /**
         * The Amazon Resource Name (ARN) of the AWS Secrets Manager role.
         */
        secretManagerArn: pulumi.Input<string>;
        /**
         * The table name of the Redshift database.
         */
        tableName: pulumi.Input<string>;
        /**
         * Contains information about the Amazon Virtual Private Cloud (VPC) configuration.
         */
        vpcConfiguration: pulumi.Input<inputs.lookoutmetrics.AnomalyDetectorVpcConfigurationArgs>;
    }
    interface AnomalyDetectorS3SourceConfigArgs {
        /**
         * Contains information about a source file's formatting.
         */
        fileFormatDescriptor: pulumi.Input<inputs.lookoutmetrics.AnomalyDetectorFileFormatDescriptorArgs>;
        /**
         * A list of paths to the historical data files.
         */
        historicalDataPathList?: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * The ARN of an IAM role that has read and write access permissions to the source S3 bucket.
         */
        roleArn: pulumi.Input<string>;
        /**
         * A list of templated paths to the source files.
         */
        templatedPathList?: pulumi.Input<pulumi.Input<string>[]>;
    }
    interface AnomalyDetectorTimestampColumnArgs {
        /**
         * A timestamp format for the timestamps in the dataset
         */
        columnFormat?: pulumi.Input<string>;
        /**
         * The name of the timestamp column.
         */
        columnName?: pulumi.Input<string>;
    }
    interface AnomalyDetectorVpcConfigurationArgs {
        /**
         * An array of strings containing the list of security groups.
         */
        securityGroupIdList: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * An array of strings containing the Amazon VPC subnet IDs (e.g., `subnet-0bb1c79de3EXAMPLE` .
         */
        subnetIdList: pulumi.Input<pulumi.Input<string>[]>;
    }
}
export declare namespace m2 {
    interface ApplicationDefinition0PropertiesArgs {
        s3Location: pulumi.Input<string>;
    }
    interface ApplicationDefinition1PropertiesArgs {
        content: pulumi.Input<string>;
    }
    /**
     * Defines the details of a high availability configuration.
     */
    interface EnvironmentHighAvailabilityConfigArgs {
        /**
         * The number of instances in a high availability configuration. The minimum possible value is 1 and the maximum is 100.
         */
        desiredCapacity: pulumi.Input<number>;
    }
    /**
     * Defines the storage configuration for an environment.
     */
    interface EnvironmentStorageConfigurationArgs {
    }
}
export declare namespace macie {
    /**
     * The regex or s3 object to use for the AllowList.
     */
    interface AllowListCriteriaArgs {
    }
    interface FindingsFilterCriterionAdditionalPropertiesArgs {
        /**
         * The value for the specified property matches (equals) the specified value. If you specify multiple values, Amazon Macie uses OR logic to join the values.
         */
        eq?: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * The value for the specified property is greater than the specified value.
         */
        gt?: pulumi.Input<number>;
        /**
         * The value for the specified property is greater than or equal to the specified value.
         */
        gte?: pulumi.Input<number>;
        /**
         * The value for the specified property is less than the specified value.
         */
        lt?: pulumi.Input<number>;
        /**
         * The value for the specified property is less than or equal to the specified value.
         */
        lte?: pulumi.Input<number>;
        /**
         * The value for the specified property doesn't match (doesn't equal) the specified value. If you specify multiple values, Amazon Macie uses OR logic to join the values.
         */
        neq?: pulumi.Input<pulumi.Input<string>[]>;
    }
    interface FindingsFilterFindingCriteriaArgs {
        /**
         * Specifies a condition that defines the property, operator, and one or more values to use to filter the results.
         */
        criterion?: pulumi.Input<{
            [key: string]: pulumi.Input<inputs.macie.FindingsFilterCriterionAdditionalPropertiesArgs>;
        }>;
    }
}
export declare namespace mediaconnect {
    interface BridgeEgressGatewayBridgeArgs {
        /**
         * The maximum expected bitrate of the egress bridge.
         */
        maxBitrate: pulumi.Input<number>;
    }
    /**
     * The settings for source failover.
     */
    interface BridgeFailoverConfigArgs {
        /**
         * The type of failover you choose for this flow. FAILOVER allows switching between different streams.
         */
        failoverMode: pulumi.Input<enums.mediaconnect.BridgeFailoverModeEnum>;
        /**
         * The priority you want to assign to a source. You can have a primary stream and a backup stream or two equally prioritized streams.
         */
        sourcePriority?: pulumi.Input<inputs.mediaconnect.BridgeSourcePriorityArgs>;
        /**
         * The state of source failover on the flow. If the state is inactive, the flow can have only one source. If the state is active, the flow can have one or two sources.
         */
        state?: pulumi.Input<enums.mediaconnect.BridgeFailoverConfigStateEnum>;
    }
    /**
     * The source of the bridge. A flow source originates in MediaConnect as an existing cloud flow.
     */
    interface BridgeFlowSourceArgs {
        /**
         * The ARN of the cloud flow used as a source of this bridge.
         */
        flowArn: pulumi.Input<string>;
        /**
         * The name of the VPC interface attachment to use for this source.
         */
        flowVpcInterfaceAttachment?: pulumi.Input<inputs.mediaconnect.BridgeVpcInterfaceAttachmentArgs>;
        /**
         * The name of the flow source.
         */
        name: pulumi.Input<string>;
    }
    interface BridgeIngressGatewayBridgeArgs {
        /**
         * The maximum expected bitrate of the ingress bridge.
         */
        maxBitrate: pulumi.Input<number>;
        /**
         * The maximum number of outputs on the ingress bridge.
         */
        maxOutputs: pulumi.Input<number>;
    }
    /**
     * The settings related to the multicast source.
     */
    interface BridgeMulticastSourceSettingsArgs {
        /**
         * The IP address of the source for source-specific multicast (SSM).
         */
        multicastSourceIp?: pulumi.Input<string>;
    }
    /**
     * The output of the bridge. A network output is delivered to your premises.
     */
    interface BridgeNetworkOutputArgs {
        /**
         * The network output IP Address.
         */
        ipAddress: pulumi.Input<string>;
        /**
         * The network output name.
         */
        name: pulumi.Input<string>;
        /**
         * The network output's gateway network name.
         */
        networkName: pulumi.Input<string>;
        /**
         * The network output port.
         */
        port: pulumi.Input<number>;
        /**
         * The network output protocol.
         */
        protocol: pulumi.Input<enums.mediaconnect.BridgeProtocolEnum>;
        /**
         * The network output TTL.
         */
        ttl: pulumi.Input<number>;
    }
    /**
     * The source of the bridge. A network source originates at your premises.
     */
    interface BridgeNetworkSourceArgs {
        /**
         * The network source multicast IP.
         */
        multicastIp: pulumi.Input<string>;
        /**
         * The settings related to the multicast source.
         */
        multicastSourceSettings?: pulumi.Input<inputs.mediaconnect.BridgeMulticastSourceSettingsArgs>;
        /**
         * The name of the network source.
         */
        name: pulumi.Input<string>;
        /**
         * The network source's gateway network name.
         */
        networkName: pulumi.Input<string>;
        /**
         * The network source port.
         */
        port: pulumi.Input<number>;
        /**
         * The network source protocol.
         */
        protocol: pulumi.Input<enums.mediaconnect.BridgeProtocolEnum>;
    }
    /**
     * The output of the bridge.
     */
    interface BridgeOutputArgs {
        /**
         * The output of the bridge. A network output is delivered to your premises.
         */
        networkOutput?: pulumi.Input<inputs.mediaconnect.BridgeNetworkOutputArgs>;
    }
    /**
     * The output of the bridge. A network output is delivered to your premises.
     */
    interface BridgeOutputResourceBridgeNetworkOutputArgs {
        /**
         * The network output IP Address.
         */
        ipAddress: pulumi.Input<string>;
        /**
         * The network output's gateway network name.
         */
        networkName: pulumi.Input<string>;
        /**
         * The network output port.
         */
        port: pulumi.Input<number>;
        /**
         * The network output protocol.
         */
        protocol: pulumi.Input<enums.mediaconnect.BridgeOutputResourceBridgeNetworkOutputProtocol>;
        /**
         * The network output TTL.
         */
        ttl: pulumi.Input<number>;
    }
    /**
     * The bridge's source.
     */
    interface BridgeSourceArgs {
        /**
         * The source of the bridge. A flow source originates in MediaConnect as an existing cloud flow.
         */
        flowSource?: pulumi.Input<inputs.mediaconnect.BridgeFlowSourceArgs>;
        /**
         * The source of the bridge. A network source originates at your premises.
         */
        networkSource?: pulumi.Input<inputs.mediaconnect.BridgeNetworkSourceArgs>;
    }
    /**
     * The source of the bridge. A flow source originates in MediaConnect as an existing cloud flow.
     */
    interface BridgeSourceBridgeFlowSourceArgs {
        /**
         * The ARN of the cloud flow used as a source of this bridge.
         */
        flowArn: pulumi.Input<string>;
        /**
         * The name of the VPC interface attachment to use for this source.
         */
        flowVpcInterfaceAttachment?: pulumi.Input<inputs.mediaconnect.BridgeSourceVpcInterfaceAttachmentArgs>;
    }
    /**
     * The source of the bridge. A network source originates at your premises.
     */
    interface BridgeSourceBridgeNetworkSourceArgs {
        /**
         * The network source multicast IP.
         */
        multicastIp: pulumi.Input<string>;
        /**
         * The settings related to the multicast source.
         */
        multicastSourceSettings?: pulumi.Input<inputs.mediaconnect.BridgeSourceMulticastSourceSettingsArgs>;
        /**
         * The network source's gateway network name.
         */
        networkName: pulumi.Input<string>;
        /**
         * The network source port.
         */
        port: pulumi.Input<number>;
        /**
         * The network source protocol.
         */
        protocol: pulumi.Input<enums.mediaconnect.BridgeSourceProtocolEnum>;
    }
    /**
     * The settings related to the multicast source.
     */
    interface BridgeSourceMulticastSourceSettingsArgs {
        /**
         * The IP address of the source for source-specific multicast (SSM).
         */
        multicastSourceIp?: pulumi.Input<string>;
    }
    /**
     * The priority you want to assign to a source. You can have a primary stream and a backup stream or two equally prioritized streams.
     */
    interface BridgeSourcePriorityArgs {
        /**
         * The name of the source you choose as the primary source for this flow.
         */
        primarySource?: pulumi.Input<string>;
    }
    /**
     * The settings for attaching a VPC interface to an resource.
     */
    interface BridgeSourceVpcInterfaceAttachmentArgs {
        /**
         * The name of the VPC interface to use for this resource.
         */
        vpcInterfaceName?: pulumi.Input<string>;
    }
    /**
     * The settings for attaching a VPC interface to an resource.
     */
    interface BridgeVpcInterfaceAttachmentArgs {
        /**
         * The name of the VPC interface to use for this resource.
         */
        vpcInterfaceName?: pulumi.Input<string>;
    }
    /**
     * Specifies the configuration for audio stream metrics monitoring.
     */
    interface FlowAudioMonitoringSettingArgs {
        /**
         * Detects periods of silence.
         */
        silentAudio?: pulumi.Input<inputs.mediaconnect.FlowSilentAudioArgs>;
    }
    /**
     * Configures settings for the BlackFrames metric.
     */
    interface FlowBlackFramesArgs {
        /**
         * Indicates whether the BlackFrames metric is enabled or disabled.
         */
        state?: pulumi.Input<enums.mediaconnect.FlowBlackFramesState>;
        /**
         * Specifies the number of consecutive seconds of black frames that triggers an event or alert.
         */
        thresholdSeconds?: pulumi.Input<number>;
    }
    /**
     * Information about the encryption of the flow.
     */
    interface FlowEncryptionArgs {
        /**
         * The type of algorithm that is used for the encryption (such as aes128, aes192, or aes256).
         */
        algorithm?: pulumi.Input<enums.mediaconnect.FlowEncryptionAlgorithm>;
        /**
         * A 128-bit, 16-byte hex value represented by a 32-character string, to be used with the key for encrypting content. This parameter is not valid for static key encryption.
         */
        constantInitializationVector?: pulumi.Input<string>;
        /**
         * The value of one of the devices that you configured with your digital rights management (DRM) platform key provider. This parameter is required for SPEKE encryption and is not valid for static key encryption.
         */
        deviceId?: pulumi.Input<string>;
        /**
         * The type of key that is used for the encryption. If no keyType is provided, the service will use the default setting (static-key).
         */
        keyType?: pulumi.Input<enums.mediaconnect.FlowEncryptionKeyType>;
        /**
         * The AWS Region that the API Gateway proxy endpoint was created in. This parameter is required for SPEKE encryption and is not valid for static key encryption.
         */
        region?: pulumi.Input<string>;
        /**
         * An identifier for the content. The service sends this value to the key server to identify the current endpoint. The resource ID is also known as the content ID. This parameter is required for SPEKE encryption and is not valid for static key encryption.
         */
        resourceId?: pulumi.Input<string>;
        /**
         * The ARN of the role that you created during setup (when you set up AWS Elemental MediaConnect as a trusted entity).
         */
        roleArn: pulumi.Input<string>;
        /**
         *  The ARN of the secret that you created in AWS Secrets Manager to store the encryption key. This parameter is required for static key encryption and is not valid for SPEKE encryption.
         */
        secretArn?: pulumi.Input<string>;
        /**
         * The URL from the API Gateway proxy that you set up to talk to your key server. This parameter is required for SPEKE encryption and is not valid for static key encryption.
         */
        url?: pulumi.Input<string>;
    }
    /**
     * Information about the encryption of the flow.
     */
    interface FlowEntitlementEncryptionArgs {
        /**
         * The type of algorithm that is used for the encryption (such as aes128, aes192, or aes256).
         */
        algorithm: pulumi.Input<enums.mediaconnect.FlowEntitlementEncryptionAlgorithm>;
        /**
         * A 128-bit, 16-byte hex value represented by a 32-character string, to be used with the key for encrypting content. This parameter is not valid for static key encryption.
         */
        constantInitializationVector?: pulumi.Input<string>;
        /**
         * The value of one of the devices that you configured with your digital rights management (DRM) platform key provider. This parameter is required for SPEKE encryption and is not valid for static key encryption.
         */
        deviceId?: pulumi.Input<string>;
        /**
         * The type of key that is used for the encryption. If no keyType is provided, the service will use the default setting (static-key).
         */
        keyType?: pulumi.Input<enums.mediaconnect.FlowEntitlementEncryptionKeyType>;
        /**
         * The AWS Region that the API Gateway proxy endpoint was created in. This parameter is required for SPEKE encryption and is not valid for static key encryption.
         */
        region?: pulumi.Input<string>;
        /**
         * An identifier for the content. The service sends this value to the key server to identify the current endpoint. The resource ID is also known as the content ID. This parameter is required for SPEKE encryption and is not valid for static key encryption.
         */
        resourceId?: pulumi.Input<string>;
        /**
         * The ARN of the role that you created during setup (when you set up AWS Elemental MediaConnect as a trusted entity).
         */
        roleArn: pulumi.Input<string>;
        /**
         *  The ARN of the secret that you created in AWS Secrets Manager to store the encryption key. This parameter is required for static key encryption and is not valid for SPEKE encryption.
         */
        secretArn?: pulumi.Input<string>;
        /**
         * The URL from the API Gateway proxy that you set up to talk to your key server. This parameter is required for SPEKE encryption and is not valid for static key encryption.
         */
        url?: pulumi.Input<string>;
    }
    /**
     * The settings for source failover
     */
    interface FlowFailoverConfigArgs {
        /**
         * The type of failover you choose for this flow. MERGE combines the source streams into a single stream, allowing graceful recovery from any single-source loss. FAILOVER allows switching between different streams.
         */
        failoverMode?: pulumi.Input<enums.mediaconnect.FlowFailoverConfigFailoverMode>;
        /**
         * Search window time to look for dash-7 packets
         */
        recoveryWindow?: pulumi.Input<number>;
        /**
         * The priority you want to assign to a source. You can have a primary stream and a backup stream or two equally prioritized streams.
         */
        sourcePriority?: pulumi.Input<inputs.mediaconnect.FlowFailoverConfigSourcePriorityPropertiesArgs>;
        /**
         * The state of source failover on the flow. If the state is inactive, the flow can have only one source. If the state is active, the flow can have one or two sources.
         */
        state?: pulumi.Input<enums.mediaconnect.FlowFailoverConfigState>;
    }
    /**
     * The priority you want to assign to a source. You can have a primary stream and a backup stream or two equally prioritized streams.
     */
    interface FlowFailoverConfigSourcePriorityPropertiesArgs {
        /**
         * The name of the source you choose as the primary source for this flow.
         */
        primarySource: pulumi.Input<string>;
    }
    /**
     * A set of parameters that define the media stream.
     */
    interface FlowFmtpArgs {
        /**
         * The format of the audio channel.
         */
        channelOrder?: pulumi.Input<string>;
        /**
         * The format used for the representation of color.
         */
        colorimetry?: pulumi.Input<enums.mediaconnect.FlowFmtpColorimetry>;
        /**
         * The frame rate for the video stream, in frames/second. For example: 60000/1001.
         */
        exactFramerate?: pulumi.Input<string>;
        /**
         * The pixel aspect ratio (PAR) of the video.
         */
        par?: pulumi.Input<string>;
        /**
         * The encoding range of the video.
         */
        range?: pulumi.Input<enums.mediaconnect.FlowFmtpRange>;
        /**
         * The type of compression that was used to smooth the video's appearance.
         */
        scanMode?: pulumi.Input<enums.mediaconnect.FlowFmtpScanMode>;
        /**
         * The transfer characteristic system (TCS) that is used in the video.
         */
        tcs?: pulumi.Input<enums.mediaconnect.FlowFmtpTcs>;
    }
    /**
     * Configures settings for the FrozenFrames metric.
     */
    interface FlowFrozenFramesArgs {
        /**
         * Indicates whether the FrozenFrames metric is enabled or disabled.
         */
        state?: pulumi.Input<enums.mediaconnect.FlowFrozenFramesState>;
        /**
         * Specifies the number of consecutive seconds of a static image that triggers an event or alert.
         */
        thresholdSeconds?: pulumi.Input<number>;
    }
    /**
     * The source configuration for cloud flows receiving a stream from a bridge.
     */
    interface FlowGatewayBridgeSourceArgs {
        /**
         * The ARN of the bridge feeding this flow.
         */
        bridgeArn: pulumi.Input<string>;
        /**
         * The name of the VPC interface attachment to use for this bridge source.
         */
        vpcInterfaceAttachment?: pulumi.Input<inputs.mediaconnect.FlowVpcInterfaceAttachmentArgs>;
    }
    /**
     * The transport parameters associated with an incoming media stream.
     */
    interface FlowInputConfigurationArgs {
        /**
         * The port that the flow listens on for an incoming media stream.
         */
        inputPort: pulumi.Input<number>;
        /**
         * The VPC interface where the media stream comes in from.
         */
        interface: pulumi.Input<inputs.mediaconnect.FlowInterfaceArgs>;
    }
    /**
     * The VPC interface that you want to use for the media stream associated with the output.
     */
    interface FlowInterfaceArgs {
        /**
         * The name of the VPC interface that you want to use for the media stream associated with the output.
         */
        name: pulumi.Input<string>;
    }
    /**
     * The maintenance setting of a flow.
     */
    interface FlowMaintenanceArgs {
        /**
         * A day of a week when the maintenance will happen. Use Monday/Tuesday/Wednesday/Thursday/Friday/Saturday/Sunday.
         */
        maintenanceDay: pulumi.Input<enums.mediaconnect.FlowMaintenanceMaintenanceDay>;
        /**
         * UTC time when the maintenance will happen. Use 24-hour HH:MM format. Minutes must be 00. Example: 13:00. The default value is 02:00.
         */
        maintenanceStartHour: pulumi.Input<string>;
    }
    /**
     * A single track or stream of media that contains video, audio, or ancillary data. After you add a media stream to a flow, you can associate it with sources and outputs on that flow, as long as they use the CDI protocol or the ST 2110 JPEG XS protocol. Each source or output can consist of one or many media streams.
     */
    interface FlowMediaStreamArgs {
        /**
         * Attributes that are related to the media stream.
         */
        attributes?: pulumi.Input<inputs.mediaconnect.FlowMediaStreamAttributesArgs>;
        /**
         * The sample rate for the stream. This value in measured in kHz.
         */
        clockRate?: pulumi.Input<number>;
        /**
         * A description that can help you quickly identify what your media stream is used for.
         */
        description?: pulumi.Input<string>;
        /**
         * The format type number (sometimes referred to as RTP payload type) of the media stream. MediaConnect assigns this value to the media stream. For ST 2110 JPEG XS outputs, you need to provide this value to the receiver.
         */
        fmt?: pulumi.Input<number>;
        /**
         * A unique identifier for the media stream.
         */
        mediaStreamId: pulumi.Input<number>;
        /**
         * A name that helps you distinguish one media stream from another.
         */
        mediaStreamName: pulumi.Input<string>;
        /**
         * The type of media stream.
         */
        mediaStreamType: pulumi.Input<enums.mediaconnect.FlowMediaStreamMediaStreamType>;
        /**
         * The resolution of the video.
         */
        videoFormat?: pulumi.Input<enums.mediaconnect.FlowMediaStreamVideoFormat>;
    }
    /**
     * Attributes that are related to the media stream.
     */
    interface FlowMediaStreamAttributesArgs {
        /**
         * A set of parameters that define the media stream.
         */
        fmtp?: pulumi.Input<inputs.mediaconnect.FlowFmtpArgs>;
        /**
         * The audio language, in a format that is recognized by the receiver.
         */
        lang?: pulumi.Input<string>;
    }
    /**
     * The media stream that is associated with the source, and the parameters for that association.
     */
    interface FlowMediaStreamSourceConfigurationArgs {
        /**
         * The format that was used to encode the data. For ancillary data streams, set the encoding name to smpte291. For audio streams, set the encoding name to pcm. For video, 2110 streams, set the encoding name to raw. For video, JPEG XS streams, set the encoding name to jxsv.
         */
        encodingName: pulumi.Input<enums.mediaconnect.FlowMediaStreamSourceConfigurationEncodingName>;
        /**
         * The media streams that you want to associate with the source.
         */
        inputConfigurations?: pulumi.Input<pulumi.Input<inputs.mediaconnect.FlowInputConfigurationArgs>[]>;
        /**
         * A name that helps you distinguish one media stream from another.
         */
        mediaStreamName: pulumi.Input<string>;
    }
    /**
     * Specifies the configuration settings for NDI outputs. Required when the flow includes NDI outputs.
     */
    interface FlowNdiConfigArgs {
        /**
         * A prefix for the names of the NDI sources that the flow creates. If a custom name isn't specified, MediaConnect generates a unique 12-character ID as the prefix.
         */
        machineName?: pulumi.Input<string>;
        /**
         * A list of up to three NDI discovery server configurations. While not required by the API, this configuration is necessary for NDI functionality to work properly.
         */
        ndiDiscoveryServers?: pulumi.Input<pulumi.Input<inputs.mediaconnect.FlowNdiDiscoveryServerConfigArgs>[]>;
        /**
         * A setting that controls whether NDI outputs can be used in the flow. Must be ENABLED to add NDI outputs. Default is DISABLED.
         */
        ndiState?: pulumi.Input<enums.mediaconnect.FlowNdiConfigNdiState>;
    }
    /**
     * Specifies the configuration settings for individual NDI discovery servers. A maximum of 3 servers is allowed.
     */
    interface FlowNdiDiscoveryServerConfigArgs {
        /**
         * The unique network address of the NDI discovery server.
         */
        discoveryServerAddress: pulumi.Input<string>;
        /**
         * The port for the NDI discovery server. Defaults to 5959 if a custom port isn't specified.
         */
        discoveryServerPort?: pulumi.Input<number>;
        /**
         * The identifier for the Virtual Private Cloud (VPC) network interface used by the flow.
         */
        vpcInterfaceAdapter: pulumi.Input<string>;
    }
    /**
     * The definition of a media stream that is associated with the output.
     */
    interface FlowOutputDestinationConfigurationArgs {
        /**
         * The IP address where contents of the media stream will be sent.
         */
        destinationIp: pulumi.Input<string>;
        /**
         * The port to use when the content of the media stream is distributed to the output.
         */
        destinationPort: pulumi.Input<number>;
        /**
         * The VPC interface that is used for the media stream associated with the output.
         */
        interface: pulumi.Input<inputs.mediaconnect.FlowOutputInterfaceArgs>;
    }
    /**
     * A collection of parameters that determine how MediaConnect will convert the content. These fields only apply to outputs on flows that have a CDI source.
     */
    interface FlowOutputEncodingParametersArgs {
        /**
         * A value that is used to calculate compression for an output. The bitrate of the output is calculated as follows: Output bitrate = (1 / compressionFactor) * (source bitrate) This property only applies to outputs that use the ST 2110 JPEG XS protocol, with a flow source that uses the CDI protocol. Valid values are in the range of 3.0 to 10.0, inclusive.
         */
        compressionFactor: pulumi.Input<number>;
        /**
         * A setting on the encoder that drives compression settings. This property only applies to video media streams associated with outputs that use the ST 2110 JPEG XS protocol, with a flow source that uses the CDI protocol.
         */
        encoderProfile?: pulumi.Input<enums.mediaconnect.FlowOutputEncodingParametersEncoderProfile>;
    }
    /**
     * Information about the encryption of the flow.
     */
    interface FlowOutputEncryptionArgs {
        /**
         * The type of algorithm that is used for the encryption (such as aes128, aes192, or aes256).
         */
        algorithm?: pulumi.Input<enums.mediaconnect.FlowOutputEncryptionAlgorithm>;
        /**
         * The type of key that is used for the encryption. If no keyType is provided, the service will use the default setting (static-key).
         */
        keyType?: pulumi.Input<enums.mediaconnect.FlowOutputEncryptionKeyType>;
        /**
         * The ARN of the role that you created during setup (when you set up AWS Elemental MediaConnect as a trusted entity).
         */
        roleArn: pulumi.Input<string>;
        /**
         *  The ARN of the secret that you created in AWS Secrets Manager to store the encryption key. This parameter is required for static key encryption and is not valid for SPEKE encryption.
         */
        secretArn: pulumi.Input<string>;
    }
    /**
     * The VPC interface that you want to use for the media stream associated with the output.
     */
    interface FlowOutputInterfaceArgs {
        /**
         * The name of the VPC interface that you want to use for the media stream associated with the output.
         */
        name: pulumi.Input<string>;
    }
    /**
     * The media stream that is associated with the output, and the parameters for that association.
     */
    interface FlowOutputMediaStreamOutputConfigurationArgs {
        /**
         * The media streams that you want to associate with the output.
         */
        destinationConfigurations?: pulumi.Input<pulumi.Input<inputs.mediaconnect.FlowOutputDestinationConfigurationArgs>[]>;
        /**
         * The format that will be used to encode the data. For ancillary data streams, set the encoding name to smpte291. For audio streams, set the encoding name to pcm. For video streams on sources or outputs that use the CDI protocol, set the encoding name to raw. For video streams on sources or outputs that use the ST 2110 JPEG XS protocol, set the encoding name to jxsv.
         */
        encodingName: pulumi.Input<enums.mediaconnect.FlowOutputMediaStreamOutputConfigurationEncodingName>;
        /**
         * A collection of parameters that determine how MediaConnect will convert the content. These fields only apply to outputs on flows that have a CDI source.
         */
        encodingParameters?: pulumi.Input<inputs.mediaconnect.FlowOutputEncodingParametersArgs>;
        /**
         * A name that helps you distinguish one media stream from another.
         */
        mediaStreamName: pulumi.Input<string>;
    }
    /**
     * The settings for attaching a VPC interface to an output.
     */
    interface FlowOutputVpcInterfaceAttachmentArgs {
        /**
         * The name of the VPC interface to use for this output.
         */
        vpcInterfaceName?: pulumi.Input<string>;
    }
    /**
     * Configures settings for the SilentAudio metric.
     */
    interface FlowSilentAudioArgs {
        /**
         * Indicates whether the SilentAudio metric is enabled or disabled.
         */
        state?: pulumi.Input<enums.mediaconnect.FlowSilentAudioState>;
        /**
         * Specifies the number of consecutive seconds of silence that triggers an event or alert.
         */
        thresholdSeconds?: pulumi.Input<number>;
    }
    /**
     * The settings for the source of the flow.
     */
    interface FlowSourceArgs {
        /**
         * The type of decryption that is used on the content ingested from this source.
         */
        decryption?: pulumi.Input<inputs.mediaconnect.FlowEncryptionArgs>;
        /**
         * A description for the source. This value is not used or seen outside of the current AWS Elemental MediaConnect account.
         */
        description?: pulumi.Input<string>;
        /**
         * The ARN of the entitlement that allows you to subscribe to content that comes from another AWS account. The entitlement is set by the content originator and the ARN is generated as part of the originator's flow.
         */
        entitlementArn?: pulumi.Input<string>;
        /**
         * The source configuration for cloud flows receiving a stream from a bridge.
         */
        gatewayBridgeSource?: pulumi.Input<inputs.mediaconnect.FlowGatewayBridgeSourceArgs>;
        /**
         * The IP address that the flow will be listening on for incoming content.
         */
        ingestIp?: pulumi.Input<string>;
        /**
         * The port that the flow will be listening on for incoming content.
         */
        ingestPort?: pulumi.Input<number>;
        /**
         * The smoothing max bitrate for RIST, RTP, and RTP-FEC streams.
         */
        maxBitrate?: pulumi.Input<number>;
        /**
         * The maximum latency in milliseconds. This parameter applies only to RIST-based and Zixi-based streams.
         */
        maxLatency?: pulumi.Input<number>;
        /**
         * The size of the buffer (in milliseconds) to use to sync incoming source data.
         */
        maxSyncBuffer?: pulumi.Input<number>;
        /**
         * The media stream that is associated with the source, and the parameters for that association.
         */
        mediaStreamSourceConfigurations?: pulumi.Input<pulumi.Input<inputs.mediaconnect.FlowMediaStreamSourceConfigurationArgs>[]>;
        /**
         * The minimum latency in milliseconds.
         */
        minLatency?: pulumi.Input<number>;
        /**
         * The name of the source.
         */
        name?: pulumi.Input<string>;
        /**
         * The protocol that is used by the source.
         */
        protocol?: pulumi.Input<enums.mediaconnect.FlowSourceProtocol>;
        /**
         * The port that the flow uses to send outbound requests to initiate connection with the sender for fujitsu-qos protocol.
         */
        senderControlPort?: pulumi.Input<number>;
        /**
         * The IP address that the flow communicates with to initiate connection with the sender for fujitsu-qos protocol.
         */
        senderIpAddress?: pulumi.Input<string>;
        /**
         * The ARN of the source.
         */
        sourceArn?: pulumi.Input<string>;
        /**
         * The port that the flow will be listening on for incoming content.(ReadOnly)
         */
        sourceIngestPort?: pulumi.Input<string>;
        /**
         * Source IP or domain name for SRT-caller protocol.
         */
        sourceListenerAddress?: pulumi.Input<string>;
        /**
         * Source port for SRT-caller protocol.
         */
        sourceListenerPort?: pulumi.Input<number>;
        /**
         * The stream ID that you want to use for this transport. This parameter applies only to Zixi-based streams.
         */
        streamId?: pulumi.Input<string>;
        /**
         * The name of the VPC Interface this Source is configured with.
         */
        vpcInterfaceName?: pulumi.Input<string>;
        /**
         * The range of IP addresses that should be allowed to contribute content to your source. These IP addresses should be in the form of a Classless Inter-Domain Routing (CIDR) block; for example, 10.0.0.0/16.
         */
        whitelistCidr?: pulumi.Input<string>;
    }
    /**
     * Information about the encryption of the flow.
     */
    interface FlowSourceEncryptionArgs {
        /**
         * The type of algorithm that is used for the encryption (such as aes128, aes192, or aes256).
         */
        algorithm?: pulumi.Input<enums.mediaconnect.FlowSourceEncryptionAlgorithm>;
        /**
         * A 128-bit, 16-byte hex value represented by a 32-character string, to be used with the key for encrypting content. This parameter is not valid for static key encryption.
         */
        constantInitializationVector?: pulumi.Input<string>;
        /**
         * The value of one of the devices that you configured with your digital rights management (DRM) platform key provider. This parameter is required for SPEKE encryption and is not valid for static key encryption.
         */
        deviceId?: pulumi.Input<string>;
        /**
         * The type of key that is used for the encryption. If no keyType is provided, the service will use the default setting (static-key).
         */
        keyType?: pulumi.Input<enums.mediaconnect.FlowSourceEncryptionKeyType>;
        /**
         * The AWS Region that the API Gateway proxy endpoint was created in. This parameter is required for SPEKE encryption and is not valid for static key encryption.
         */
        region?: pulumi.Input<string>;
        /**
         * An identifier for the content. The service sends this value to the key server to identify the current endpoint. The resource ID is also known as the content ID. This parameter is required for SPEKE encryption and is not valid for static key encryption.
         */
        resourceId?: pulumi.Input<string>;
        /**
         * The ARN of the role that you created during setup (when you set up AWS Elemental MediaConnect as a trusted entity).
         */
        roleArn: pulumi.Input<string>;
        /**
         *  The ARN of the secret that you created in AWS Secrets Manager to store the encryption key. This parameter is required for static key encryption and is not valid for SPEKE encryption.
         */
        secretArn?: pulumi.Input<string>;
        /**
         * The URL from the API Gateway proxy that you set up to talk to your key server. This parameter is required for SPEKE encryption and is not valid for static key encryption.
         */
        url?: pulumi.Input<string>;
    }
    /**
     * The source configuration for cloud flows receiving a stream from a bridge.
     */
    interface FlowSourceGatewayBridgeSourceArgs {
        /**
         * The ARN of the bridge feeding this flow.
         */
        bridgeArn: pulumi.Input<string>;
        /**
         * The name of the VPC interface attachment to use for this bridge source.
         */
        vpcInterfaceAttachment?: pulumi.Input<inputs.mediaconnect.FlowSourceVpcInterfaceAttachmentArgs>;
    }
    /**
     * The settings for source monitoring.
     */
    interface FlowSourceMonitoringConfigArgs {
        /**
         * Contains the settings for audio stream metrics monitoring.
         */
        audioMonitoringSettings?: pulumi.Input<pulumi.Input<inputs.mediaconnect.FlowAudioMonitoringSettingArgs>[]>;
        /**
         * Indicates whether content quality analysis is enabled or disabled.
         */
        contentQualityAnalysisState?: pulumi.Input<enums.mediaconnect.FlowSourceMonitoringConfigContentQualityAnalysisState>;
        /**
         * The state of thumbnail monitoring.
         */
        thumbnailState?: pulumi.Input<enums.mediaconnect.FlowSourceMonitoringConfigThumbnailState>;
        /**
         * Contains the settings for video stream metrics monitoring.
         */
        videoMonitoringSettings?: pulumi.Input<pulumi.Input<inputs.mediaconnect.FlowVideoMonitoringSettingArgs>[]>;
    }
    /**
     * The settings for attaching a VPC interface to an resource.
     */
    interface FlowSourceVpcInterfaceAttachmentArgs {
        /**
         * The name of the VPC interface to use for this resource.
         */
        vpcInterfaceName?: pulumi.Input<string>;
    }
    /**
     * Specifies the configuration for video stream metrics monitoring.
     */
    interface FlowVideoMonitoringSettingArgs {
        /**
         * Detects video frames that are black.
         */
        blackFrames?: pulumi.Input<inputs.mediaconnect.FlowBlackFramesArgs>;
        /**
         * Detects video frames that have not changed.
         */
        frozenFrames?: pulumi.Input<inputs.mediaconnect.FlowFrozenFramesArgs>;
    }
    /**
     * The details of a VPC interface.
     */
    interface FlowVpcInterfaceArgs {
        /**
         * Immutable and has to be a unique against other VpcInterfaces in this Flow.
         */
        name: pulumi.Input<string>;
        /**
         * IDs of the network interfaces created in customer's account by MediaConnect.
         */
        networkInterfaceIds?: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * The type of network adapter that you want MediaConnect to use on this interface. If you don't set this value, it defaults to ENA.
         */
        networkInterfaceType?: pulumi.Input<enums.mediaconnect.FlowVpcInterfaceNetworkInterfaceType>;
        /**
         * Role Arn MediaConnect can assume to create ENIs in customer's account.
         */
        roleArn: pulumi.Input<string>;
        /**
         * Security Group IDs to be used on ENI.
         */
        securityGroupIds: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * Subnet must be in the AZ of the Flow
         */
        subnetId: pulumi.Input<string>;
    }
    /**
     * The settings for attaching a VPC interface to an resource.
     */
    interface FlowVpcInterfaceAttachmentArgs {
        /**
         * The name of the VPC interface to use for this resource.
         */
        vpcInterfaceName?: pulumi.Input<string>;
    }
    /**
     * The network settings for a gateway.
     */
    interface GatewayNetworkArgs {
        /**
         * A unique IP address range to use for this network. These IP addresses should be in the form of a Classless Inter-Domain Routing (CIDR) block; for example, 10.0.0.0/16.
         */
        cidrBlock: pulumi.Input<string>;
        /**
         * The name of the network. This name is used to reference the network and must be unique among networks in this gateway.
         */
        name: pulumi.Input<string>;
    }
}
export declare namespace medialive {
    /**
     * Network mappings for the cluster
     */
    interface ClusterInterfaceMappingArgs {
        /**
         * logical interface name, unique in the list
         */
        logicalInterfaceName?: pulumi.Input<string>;
        /**
         * Network Id to be associated with the logical interface name, can be duplicated in list
         */
        networkId?: pulumi.Input<string>;
    }
    /**
     * On premises settings which will have the interface network mappings and default Output logical interface
     */
    interface ClusterNetworkSettingsArgs {
        /**
         * Default value if the customer does not define it in channel Output API
         */
        defaultRoute?: pulumi.Input<string>;
        /**
         * Network mappings for the cluster
         */
        interfaceMappings?: pulumi.Input<pulumi.Input<inputs.medialive.ClusterInterfaceMappingArgs>[]>;
    }
    /**
     * The target to which to send matching events.
     */
    interface EventBridgeRuleTemplateTargetArgs {
        /**
         * Target ARNs must be either an SNS topic or CloudWatch log group.
         */
        arn: pulumi.Input<string>;
    }
    /**
     * Multiplex MediaConnect output destination settings.
     */
    interface MultiplexOutputDestinationArgs {
        /**
         * Multiplex MediaConnect output destination settings.
         */
        multiplexMediaConnectOutputDestinationSettings?: pulumi.Input<inputs.medialive.MultiplexOutputDestinationMultiplexMediaConnectOutputDestinationSettingsPropertiesArgs>;
    }
    /**
     * Multiplex MediaConnect output destination settings.
     */
    interface MultiplexOutputDestinationMultiplexMediaConnectOutputDestinationSettingsPropertiesArgs {
        /**
         * The MediaConnect entitlement ARN available as a Flow source.
         */
        entitlementArn?: pulumi.Input<string>;
    }
    /**
     * A key-value pair to associate with a resource.
     */
    interface MultiplexSettingsArgs {
        /**
         * Maximum video buffer delay in milliseconds.
         */
        maximumVideoBufferDelayMilliseconds?: pulumi.Input<number>;
        /**
         * Transport stream bit rate.
         */
        transportStreamBitrate: pulumi.Input<number>;
        /**
         * Transport stream ID.
         */
        transportStreamId: pulumi.Input<number>;
        /**
         * Transport stream reserved bit rate.
         */
        transportStreamReservedBitrate?: pulumi.Input<number>;
    }
    /**
     * Packet identifiers map for a given Multiplex program.
     */
    interface MultiplexprogramMultiplexProgramPacketIdentifiersMapArgs {
        audioPids?: pulumi.Input<pulumi.Input<number>[]>;
        dvbSubPids?: pulumi.Input<pulumi.Input<number>[]>;
        dvbTeletextPid?: pulumi.Input<number>;
        etvPlatformPid?: pulumi.Input<number>;
        etvSignalPid?: pulumi.Input<number>;
        klvDataPids?: pulumi.Input<pulumi.Input<number>[]>;
        pcrPid?: pulumi.Input<number>;
        pmtPid?: pulumi.Input<number>;
        privateMetadataPid?: pulumi.Input<number>;
        scte27Pids?: pulumi.Input<pulumi.Input<number>[]>;
        scte35Pid?: pulumi.Input<number>;
        timedMetadataPid?: pulumi.Input<number>;
        videoPid?: pulumi.Input<number>;
    }
    /**
     * The current source for one of the pipelines in the multiplex.
     */
    interface MultiplexprogramMultiplexProgramPipelineDetailArgs {
        /**
         * Identifies the channel pipeline that is currently active for the pipeline (identified by PipelineId) in the multiplex.
         */
        activeChannelPipeline?: pulumi.Input<string>;
        /**
         * Identifies a specific pipeline in the multiplex.
         */
        pipelineId?: pulumi.Input<string>;
    }
    /**
     * Transport stream service descriptor configuration for the Multiplex program.
     */
    interface MultiplexprogramMultiplexProgramServiceDescriptorArgs {
        /**
         * Name of the provider.
         */
        providerName: pulumi.Input<string>;
        /**
         * Name of the service.
         */
        serviceName: pulumi.Input<string>;
    }
    /**
     * Multiplex Program settings configuration.
     */
    interface MultiplexprogramMultiplexProgramSettingsArgs {
        /**
         * Indicates which pipeline is preferred by the multiplex for program ingest.
         */
        preferredChannelPipeline?: pulumi.Input<enums.medialive.MultiplexprogramPreferredChannelPipeline>;
        /**
         * Unique program number.
         */
        programNumber: pulumi.Input<number>;
        /**
         * Transport stream service descriptor configuration for the Multiplex program.
         */
        serviceDescriptor?: pulumi.Input<inputs.medialive.MultiplexprogramMultiplexProgramServiceDescriptorArgs>;
        /**
         * Program video settings configuration.
         */
        videoSettings?: pulumi.Input<inputs.medialive.MultiplexprogramMultiplexVideoSettingsArgs>;
    }
    /**
     * The video configuration for each program in a multiplex.
     */
    interface MultiplexprogramMultiplexVideoSettingsArgs {
    }
    /**
     * IP address cidr pool
     */
    interface NetworkIpPoolArgs {
        /**
         * IP address cidr pool
         */
        cidr?: pulumi.Input<string>;
    }
    interface NetworkRouteArgs {
        /**
         * Ip address cidr
         */
        cidr?: pulumi.Input<string>;
        /**
         * IP address for the route packet paths
         */
        gateway?: pulumi.Input<string>;
    }
}
export declare namespace mediapackage {
    /**
     * The endpoint URL used to access an Asset using one PackagingConfiguration.
     */
    interface AssetEgressEndpointArgs {
        /**
         * The ID of the PackagingConfiguration being applied to the Asset.
         */
        packagingConfigurationId: pulumi.Input<string>;
        /**
         * The URL of the parent manifest for the repackaged Asset.
         */
        url: pulumi.Input<string>;
    }
    /**
     * An HTTP Live Streaming (HLS) ingest resource configuration.
     */
    interface ChannelHlsIngestArgs {
        /**
         * A list of endpoints to which the source stream should be sent.
         */
        ingestEndpoints?: pulumi.Input<pulumi.Input<inputs.mediapackage.ChannelIngestEndpointArgs>[]>;
    }
    /**
     * An endpoint for ingesting source content for a Channel.
     */
    interface ChannelIngestEndpointArgs {
        /**
         * The system generated unique identifier for the IngestEndpoint
         */
        id: pulumi.Input<string>;
        /**
         * The system generated password for ingest authentication.
         */
        password: pulumi.Input<string>;
        /**
         * The ingest URL to which the source stream should be sent.
         */
        url: pulumi.Input<string>;
        /**
         * The system generated username for ingest authentication.
         */
        username: pulumi.Input<string>;
    }
    interface ChannelLogConfigurationArgs {
        /**
         * Sets a custom AWS CloudWatch log group name for access logs. If a log group name isn't specified, the defaults are used: /aws/MediaPackage/EgressAccessLogs for egress access logs and /aws/MediaPackage/IngressAccessLogs for ingress access logs.
         */
        logGroupName?: pulumi.Input<string>;
    }
    /**
     * CDN Authorization credentials
     */
    interface OriginEndpointAuthorizationArgs {
        /**
         * The Amazon Resource Name (ARN) for the secret in Secrets Manager that your Content Distribution Network (CDN) uses for authorization to access your endpoint.
         */
        cdnIdentifierSecret: pulumi.Input<string>;
        /**
         * The Amazon Resource Name (ARN) for the IAM role that allows MediaPackage to communicate with AWS Secrets Manager.
         */
        secretsRoleArn: pulumi.Input<string>;
    }
    /**
     * A Common Media Application Format (CMAF) encryption configuration.
     */
    interface OriginEndpointCmafEncryptionArgs {
        /**
         * An optional 128-bit, 16-byte hex value represented by a 32-character string, used in conjunction with the key for encrypting blocks. If you don't specify a value, then MediaPackage creates the constant initialization vector (IV).
         */
        constantInitializationVector?: pulumi.Input<string>;
        /**
         * The encryption method used
         */
        encryptionMethod?: pulumi.Input<enums.mediapackage.OriginEndpointCmafEncryptionEncryptionMethod>;
        /**
         * Time (in seconds) between each encryption key rotation.
         */
        keyRotationIntervalSeconds?: pulumi.Input<number>;
        /**
         * Parameters for the SPEKE key provider.
         */
        spekeKeyProvider: pulumi.Input<inputs.mediapackage.OriginEndpointSpekeKeyProviderArgs>;
    }
    /**
     * A Common Media Application Format (CMAF) packaging configuration.
     */
    interface OriginEndpointCmafPackageArgs {
        /**
         * Parameters for encrypting content.
         */
        encryption?: pulumi.Input<inputs.mediapackage.OriginEndpointCmafEncryptionArgs>;
        /**
         * A list of HLS manifest configurations
         */
        hlsManifests?: pulumi.Input<pulumi.Input<inputs.mediapackage.OriginEndpointHlsManifestArgs>[]>;
        /**
         * Duration (in seconds) of each segment. Actual segments will be rounded to the nearest multiple of the source segment duration.
         */
        segmentDurationSeconds?: pulumi.Input<number>;
        /**
         * An optional custom string that is prepended to the name of each segment. If not specified, it defaults to the ChannelId.
         */
        segmentPrefix?: pulumi.Input<string>;
        /**
         * Limitations for outputs from the endpoint, based on the video bitrate.
         */
        streamSelection?: pulumi.Input<inputs.mediapackage.OriginEndpointStreamSelectionArgs>;
    }
    /**
     * A Dynamic Adaptive Streaming over HTTP (DASH) encryption configuration.
     */
    interface OriginEndpointDashEncryptionArgs {
        /**
         * Time (in seconds) between each encryption key rotation.
         */
        keyRotationIntervalSeconds?: pulumi.Input<number>;
        /**
         * Parameters for the SPEKE key provider.
         */
        spekeKeyProvider: pulumi.Input<inputs.mediapackage.OriginEndpointSpekeKeyProviderArgs>;
    }
    /**
     * A Dynamic Adaptive Streaming over HTTP (DASH) packaging configuration.
     */
    interface OriginEndpointDashPackageArgs {
        /**
         * A list of SCTE-35 message types that are treated as ad markers in the output.  If empty, no ad markers are output.  Specify multiple items to create ad markers for all of the included message types.
         */
        adTriggers?: pulumi.Input<pulumi.Input<enums.mediapackage.OriginEndpointDashPackageAdTriggersItem>[]>;
        /**
         * The flags on SCTE-35 segmentation descriptors that have to be present for AWS Elemental MediaPackage to insert ad markers in the output manifest. For information about SCTE-35 in AWS Elemental MediaPackage , see [SCTE-35 Message Options in AWS Elemental MediaPackage](https://docs.aws.amazon.com/mediapackage/latest/ug/scte.html) .
         */
        adsOnDeliveryRestrictions?: pulumi.Input<enums.mediapackage.OriginEndpointAdsOnDeliveryRestrictions>;
        /**
         * Parameters for encrypting content.
         */
        encryption?: pulumi.Input<inputs.mediapackage.OriginEndpointDashEncryptionArgs>;
        /**
         * When enabled, an I-Frame only stream will be included in the output.
         */
        includeIframeOnlyStream?: pulumi.Input<boolean>;
        /**
         * Determines the position of some tags in the Media Presentation Description (MPD).  When set to FULL, elements like SegmentTemplate and ContentProtection are included in each Representation.  When set to COMPACT, duplicate elements are combined and presented at the AdaptationSet level.
         */
        manifestLayout?: pulumi.Input<enums.mediapackage.OriginEndpointDashPackageManifestLayout>;
        /**
         * Time window (in seconds) contained in each manifest.
         */
        manifestWindowSeconds?: pulumi.Input<number>;
        /**
         * Minimum duration (in seconds) that a player will buffer media before starting the presentation.
         */
        minBufferTimeSeconds?: pulumi.Input<number>;
        /**
         * Minimum duration (in seconds) between potential changes to the Dynamic Adaptive Streaming over HTTP (DASH) Media Presentation Description (MPD).
         */
        minUpdatePeriodSeconds?: pulumi.Input<number>;
        /**
         * A list of triggers that controls when the outgoing Dynamic Adaptive Streaming over HTTP (DASH) Media Presentation Description (MPD) will be partitioned into multiple periods. If empty, the content will not be partitioned into more than one period. If the list contains "ADS", new periods will be created where the Channel source contains SCTE-35 ad markers.
         */
        periodTriggers?: pulumi.Input<pulumi.Input<enums.mediapackage.OriginEndpointDashPackagePeriodTriggersItem>[]>;
        /**
         * The Dynamic Adaptive Streaming over HTTP (DASH) profile type.  When set to "HBBTV_1_5", HbbTV 1.5 compliant output is enabled.
         */
        profile?: pulumi.Input<enums.mediapackage.OriginEndpointDashPackageProfile>;
        /**
         * Duration (in seconds) of each segment. Actual segments will be rounded to the nearest multiple of the source segment duration.
         */
        segmentDurationSeconds?: pulumi.Input<number>;
        /**
         * Determines the type of SegmentTemplate included in the Media Presentation Description (MPD).  When set to NUMBER_WITH_TIMELINE, a full timeline is presented in each SegmentTemplate, with $Number$ media URLs.  When set to TIME_WITH_TIMELINE, a full timeline is presented in each SegmentTemplate, with $Time$ media URLs. When set to NUMBER_WITH_DURATION, only a duration is included in each SegmentTemplate, with $Number$ media URLs.
         */
        segmentTemplateFormat?: pulumi.Input<enums.mediapackage.OriginEndpointDashPackageSegmentTemplateFormat>;
        /**
         * Limitations for outputs from the endpoint, based on the video bitrate.
         */
        streamSelection?: pulumi.Input<inputs.mediapackage.OriginEndpointStreamSelectionArgs>;
        /**
         * Duration (in seconds) to delay live content before presentation.
         */
        suggestedPresentationDelaySeconds?: pulumi.Input<number>;
        /**
         * Determines the type of UTCTiming included in the Media Presentation Description (MPD)
         */
        utcTiming?: pulumi.Input<enums.mediapackage.OriginEndpointDashPackageUtcTiming>;
        /**
         * Specifies the value attribute of the UTCTiming field when utcTiming is set to HTTP-ISO, HTTP-HEAD or HTTP-XSDATE
         */
        utcTimingUri?: pulumi.Input<string>;
    }
    /**
     * The configuration to use for encrypting one or more content tracks separately for endpoints that use SPEKE 2.0.
     */
    interface OriginEndpointEncryptionContractConfigurationArgs {
        /**
         * A collection of audio encryption presets.
         */
        presetSpeke20Audio: pulumi.Input<enums.mediapackage.OriginEndpointEncryptionContractConfigurationPresetSpeke20Audio>;
        /**
         * A collection of video encryption presets.
         */
        presetSpeke20Video: pulumi.Input<enums.mediapackage.OriginEndpointEncryptionContractConfigurationPresetSpeke20Video>;
    }
    /**
     * An HTTP Live Streaming (HLS) encryption configuration.
     */
    interface OriginEndpointHlsEncryptionArgs {
        /**
         * A constant initialization vector for encryption (optional). When not specified the initialization vector will be periodically rotated.
         */
        constantInitializationVector?: pulumi.Input<string>;
        /**
         * The encryption method to use.
         */
        encryptionMethod?: pulumi.Input<enums.mediapackage.OriginEndpointHlsEncryptionEncryptionMethod>;
        /**
         * Interval (in seconds) between each encryption key rotation.
         */
        keyRotationIntervalSeconds?: pulumi.Input<number>;
        /**
         * When enabled, the EXT-X-KEY tag will be repeated in output manifests.
         */
        repeatExtXKey?: pulumi.Input<boolean>;
        /**
         * Parameters for the SPEKE key provider.
         */
        spekeKeyProvider: pulumi.Input<inputs.mediapackage.OriginEndpointSpekeKeyProviderArgs>;
    }
    /**
     * A HTTP Live Streaming (HLS) manifest configuration.
     */
    interface OriginEndpointHlsManifestArgs {
        /**
         * This setting controls how ad markers are included in the packaged OriginEndpoint. "NONE" will omit all SCTE-35 ad markers from the output. "PASSTHROUGH" causes the manifest to contain a copy of the SCTE-35 ad markers (comments) taken directly from the input HTTP Live Streaming (HLS) manifest. "SCTE35_ENHANCED" generates ad markers and blackout tags based on SCTE-35 messages in the input source. "DATERANGE" inserts EXT-X-DATERANGE tags to signal ad and program transition events in HLS and CMAF manifests. For this option, you must set a programDateTimeIntervalSeconds value that is greater than 0.
         */
        adMarkers?: pulumi.Input<enums.mediapackage.OriginEndpointHlsManifestAdMarkers>;
        /**
         * A list of SCTE-35 message types that are treated as ad markers in the output.  If empty, no ad markers are output.  Specify multiple items to create ad markers for all of the included message types.
         */
        adTriggers?: pulumi.Input<pulumi.Input<enums.mediapackage.OriginEndpointHlsManifestAdTriggersItem>[]>;
        /**
         * The flags on SCTE-35 segmentation descriptors that have to be present for AWS Elemental MediaPackage to insert ad markers in the output manifest. For information about SCTE-35 in AWS Elemental MediaPackage , see [SCTE-35 Message Options in AWS Elemental MediaPackage](https://docs.aws.amazon.com/mediapackage/latest/ug/scte.html) .
         */
        adsOnDeliveryRestrictions?: pulumi.Input<enums.mediapackage.OriginEndpointAdsOnDeliveryRestrictions>;
        /**
         * The ID of the manifest. The ID must be unique within the OriginEndpoint and it cannot be changed after it is created.
         */
        id: pulumi.Input<string>;
        /**
         * When enabled, an I-Frame only stream will be included in the output.
         */
        includeIframeOnlyStream?: pulumi.Input<boolean>;
        /**
         * An optional short string appended to the end of the OriginEndpoint URL. If not specified, defaults to the manifestName for the OriginEndpoint.
         */
        manifestName?: pulumi.Input<string>;
        /**
         * The HTTP Live Streaming (HLS) playlist type. When either "EVENT" or "VOD" is specified, a corresponding EXT-X-PLAYLIST-TYPE entry will be included in the media playlist.
         */
        playlistType?: pulumi.Input<enums.mediapackage.OriginEndpointHlsManifestPlaylistType>;
        /**
         * Time window (in seconds) contained in each parent manifest.
         */
        playlistWindowSeconds?: pulumi.Input<number>;
        /**
         * The interval (in seconds) between each EXT-X-PROGRAM-DATE-TIME tag inserted into manifests. Additionally, when an interval is specified ID3Timed Metadata messages will be generated every 5 seconds using the ingest time of the content. If the interval is not specified, or set to 0, then no EXT-X-PROGRAM-DATE-TIME tags will be inserted into manifests and no ID3Timed Metadata messages will be generated. Note that irrespective of this parameter, if any ID3 Timed Metadata is found in HTTP Live Streaming (HLS) input, it will be passed through to HLS output.
         */
        programDateTimeIntervalSeconds?: pulumi.Input<number>;
        /**
         * The URL of the packaged OriginEndpoint for consumption.
         */
        url?: pulumi.Input<string>;
    }
    /**
     * An HTTP Live Streaming (HLS) packaging configuration.
     */
    interface OriginEndpointHlsPackageArgs {
        /**
         * This setting controls how ad markers are included in the packaged OriginEndpoint. "NONE" will omit all SCTE-35 ad markers from the output. "PASSTHROUGH" causes the manifest to contain a copy of the SCTE-35 ad markers (comments) taken directly from the input HTTP Live Streaming (HLS) manifest. "SCTE35_ENHANCED" generates ad markers and blackout tags based on SCTE-35 messages in the input source. "DATERANGE" inserts EXT-X-DATERANGE tags to signal ad and program transition events in HLS and CMAF manifests. For this option, you must set a programDateTimeIntervalSeconds value that is greater than 0.
         */
        adMarkers?: pulumi.Input<enums.mediapackage.OriginEndpointHlsPackageAdMarkers>;
        /**
         * A list of SCTE-35 message types that are treated as ad markers in the output.  If empty, no ad markers are output.  Specify multiple items to create ad markers for all of the included message types.
         */
        adTriggers?: pulumi.Input<pulumi.Input<enums.mediapackage.OriginEndpointHlsPackageAdTriggersItem>[]>;
        /**
         * The flags on SCTE-35 segmentation descriptors that have to be present for AWS Elemental MediaPackage to insert ad markers in the output manifest. For information about SCTE-35 in AWS Elemental MediaPackage , see [SCTE-35 Message Options in AWS Elemental MediaPackage](https://docs.aws.amazon.com/mediapackage/latest/ug/scte.html) .
         */
        adsOnDeliveryRestrictions?: pulumi.Input<enums.mediapackage.OriginEndpointAdsOnDeliveryRestrictions>;
        /**
         * Parameters for encrypting content.
         */
        encryption?: pulumi.Input<inputs.mediapackage.OriginEndpointHlsEncryptionArgs>;
        /**
         * When enabled, MediaPackage passes through digital video broadcasting (DVB) subtitles into the output.
         */
        includeDvbSubtitles?: pulumi.Input<boolean>;
        /**
         * When enabled, an I-Frame only stream will be included in the output.
         */
        includeIframeOnlyStream?: pulumi.Input<boolean>;
        /**
         * The HTTP Live Streaming (HLS) playlist type. When either "EVENT" or "VOD" is specified, a corresponding EXT-X-PLAYLIST-TYPE entry will be included in the media playlist.
         */
        playlistType?: pulumi.Input<enums.mediapackage.OriginEndpointHlsPackagePlaylistType>;
        /**
         * Time window (in seconds) contained in each parent manifest.
         */
        playlistWindowSeconds?: pulumi.Input<number>;
        /**
         * The interval (in seconds) between each EXT-X-PROGRAM-DATE-TIME tag inserted into manifests. Additionally, when an interval is specified ID3Timed Metadata messages will be generated every 5 seconds using the ingest time of the content. If the interval is not specified, or set to 0, then no EXT-X-PROGRAM-DATE-TIME tags will be inserted into manifests and no ID3Timed Metadata messages will be generated. Note that irrespective of this parameter, if any ID3 Timed Metadata is found in HTTP Live Streaming (HLS) input, it will be passed through to HLS output.
         */
        programDateTimeIntervalSeconds?: pulumi.Input<number>;
        /**
         * Duration (in seconds) of each fragment. Actual fragments will be rounded to the nearest multiple of the source fragment duration.
         */
        segmentDurationSeconds?: pulumi.Input<number>;
        /**
         * Limitations for outputs from the endpoint, based on the video bitrate.
         */
        streamSelection?: pulumi.Input<inputs.mediapackage.OriginEndpointStreamSelectionArgs>;
        /**
         * When enabled, audio streams will be placed in rendition groups in the output.
         */
        useAudioRenditionGroup?: pulumi.Input<boolean>;
    }
    /**
     * A Microsoft Smooth Streaming (MSS) encryption configuration.
     */
    interface OriginEndpointMssEncryptionArgs {
        /**
         * Parameters for the SPEKE key provider.
         */
        spekeKeyProvider: pulumi.Input<inputs.mediapackage.OriginEndpointSpekeKeyProviderArgs>;
    }
    /**
     * A Microsoft Smooth Streaming (MSS) packaging configuration.
     */
    interface OriginEndpointMssPackageArgs {
        /**
         * Parameters for encrypting content.
         */
        encryption?: pulumi.Input<inputs.mediapackage.OriginEndpointMssEncryptionArgs>;
        /**
         * The time window (in seconds) contained in each manifest.
         */
        manifestWindowSeconds?: pulumi.Input<number>;
        /**
         * The duration (in seconds) of each segment.
         */
        segmentDurationSeconds?: pulumi.Input<number>;
        /**
         * Limitations for outputs from the endpoint, based on the video bitrate.
         */
        streamSelection?: pulumi.Input<inputs.mediapackage.OriginEndpointStreamSelectionArgs>;
    }
    /**
     * A configuration for accessing an external Secure Packager and Encoder Key Exchange (SPEKE) service that will provide encryption keys.
     */
    interface OriginEndpointSpekeKeyProviderArgs {
        /**
         * An Amazon Resource Name (ARN) of a Certificate Manager certificate that MediaPackage will use for enforcing secure end-to-end data transfer with the key provider service.
         */
        certificateArn?: pulumi.Input<string>;
        /**
         * Use `encryptionContractConfiguration` to configure one or more content encryption keys for your endpoints that use SPEKE Version 2.0. The encryption contract defines which content keys are used to encrypt the audio and video tracks in your stream. To configure the encryption contract, specify which audio and video encryption presets to use.
         */
        encryptionContractConfiguration?: pulumi.Input<inputs.mediapackage.OriginEndpointEncryptionContractConfigurationArgs>;
        /**
         * The resource ID to include in key requests.
         */
        resourceId: pulumi.Input<string>;
        /**
         * An Amazon Resource Name (ARN) of an IAM role that AWS Elemental MediaPackage will assume when accessing the key provider service.
         */
        roleArn: pulumi.Input<string>;
        /**
         * The system IDs to include in key requests.
         */
        systemIds: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * The URL of the external key provider service.
         */
        url: pulumi.Input<string>;
    }
    /**
     * A StreamSelection configuration.
     */
    interface OriginEndpointStreamSelectionArgs {
        /**
         * The maximum video bitrate (bps) to include in output.
         */
        maxVideoBitsPerSecond?: pulumi.Input<number>;
        /**
         * The minimum video bitrate (bps) to include in output.
         */
        minVideoBitsPerSecond?: pulumi.Input<number>;
        /**
         * A directive that determines the order of streams in the output.
         */
        streamOrder?: pulumi.Input<enums.mediapackage.OriginEndpointStreamSelectionStreamOrder>;
    }
    /**
     * A CMAF encryption configuration.
     */
    interface PackagingConfigurationCmafEncryptionArgs {
        /**
         * Parameters for the SPEKE key provider.
         */
        spekeKeyProvider: pulumi.Input<inputs.mediapackage.PackagingConfigurationSpekeKeyProviderArgs>;
    }
    /**
     * A CMAF packaging configuration.
     */
    interface PackagingConfigurationCmafPackageArgs {
        /**
         * Parameters for encrypting content.
         */
        encryption?: pulumi.Input<inputs.mediapackage.PackagingConfigurationCmafEncryptionArgs>;
        /**
         * A list of HLS manifest configurations.
         */
        hlsManifests: pulumi.Input<pulumi.Input<inputs.mediapackage.PackagingConfigurationHlsManifestArgs>[]>;
        /**
         * When includeEncoderConfigurationInSegments is set to true, MediaPackage places your encoder's Sequence Parameter Set (SPS), Picture Parameter Set (PPS), and Video Parameter Set (VPS) metadata in every video segment instead of in the init fragment. This lets you use different SPS/PPS/VPS settings for your assets during content playback.
         */
        includeEncoderConfigurationInSegments?: pulumi.Input<boolean>;
        /**
         * Duration (in seconds) of each segment. Actual segments are rounded to the nearest multiple of the source fragment duration.
         */
        segmentDurationSeconds?: pulumi.Input<number>;
    }
    /**
     * A Dynamic Adaptive Streaming over HTTP (DASH) encryption configuration.
     */
    interface PackagingConfigurationDashEncryptionArgs {
        /**
         * Parameters for the SPEKE key provider.
         */
        spekeKeyProvider: pulumi.Input<inputs.mediapackage.PackagingConfigurationSpekeKeyProviderArgs>;
    }
    /**
     * A DASH manifest configuration.
     */
    interface PackagingConfigurationDashManifestArgs {
        /**
         * Determines the position of some tags in the Media Presentation Description (MPD). When set to FULL, elements like SegmentTemplate and ContentProtection are included in each Representation. When set to COMPACT, duplicate elements are combined and presented at the AdaptationSet level.
         */
        manifestLayout?: pulumi.Input<enums.mediapackage.PackagingConfigurationDashManifestManifestLayout>;
        /**
         * A short string that's appended to the end of the endpoint URL to create a unique path to this packaging configuration.
         */
        manifestName?: pulumi.Input<string>;
        /**
         * Minimum duration (in seconds) that a player will buffer media before starting the presentation.
         */
        minBufferTimeSeconds?: pulumi.Input<number>;
        /**
         * The Dynamic Adaptive Streaming over HTTP (DASH) profile type. When set to "HBBTV_1_5", HbbTV 1.5 compliant output is enabled.
         */
        profile?: pulumi.Input<enums.mediapackage.PackagingConfigurationDashManifestProfile>;
        /**
         * The source of scte markers used. When set to SEGMENTS, the scte markers are sourced from the segments of the ingested content. When set to MANIFEST, the scte markers are sourced from the manifest of the ingested content.
         */
        scteMarkersSource?: pulumi.Input<enums.mediapackage.PackagingConfigurationDashManifestScteMarkersSource>;
        /**
         * Limitations for outputs from the endpoint, based on the video bitrate.
         */
        streamSelection?: pulumi.Input<inputs.mediapackage.PackagingConfigurationStreamSelectionArgs>;
    }
    /**
     * A Dynamic Adaptive Streaming over HTTP (DASH) packaging configuration.
     */
    interface PackagingConfigurationDashPackageArgs {
        /**
         * A list of DASH manifest configurations.
         */
        dashManifests: pulumi.Input<pulumi.Input<inputs.mediapackage.PackagingConfigurationDashManifestArgs>[]>;
        /**
         * Parameters for encrypting content.
         */
        encryption?: pulumi.Input<inputs.mediapackage.PackagingConfigurationDashEncryptionArgs>;
        /**
         * When includeEncoderConfigurationInSegments is set to true, MediaPackage places your encoder's Sequence Parameter Set (SPS), Picture Parameter Set (PPS), and Video Parameter Set (VPS) metadata in every video segment instead of in the init fragment. This lets you use different SPS/PPS/VPS settings for your assets during content playback.
         */
        includeEncoderConfigurationInSegments?: pulumi.Input<boolean>;
        /**
         * When enabled, an I-Frame only stream will be included in the output.
         */
        includeIframeOnlyStream?: pulumi.Input<boolean>;
        /**
         * A list of triggers that controls when the outgoing Dynamic Adaptive Streaming over HTTP (DASH) Media Presentation Description (MPD) will be partitioned into multiple periods. If empty, the content will not be partitioned into more than one period. If the list contains "ADS", new periods will be created where the Asset contains SCTE-35 ad markers.
         */
        periodTriggers?: pulumi.Input<pulumi.Input<enums.mediapackage.PackagingConfigurationDashPackagePeriodTriggersItem>[]>;
        /**
         * Duration (in seconds) of each fragment. Actual fragments are rounded to the nearest multiple of the source segment duration.
         */
        segmentDurationSeconds?: pulumi.Input<number>;
        /**
         * Determines the type of SegmentTemplate included in the Media Presentation Description (MPD). When set to NUMBER_WITH_TIMELINE, a full timeline is presented in each SegmentTemplate, with $Number$ media URLs. When set to TIME_WITH_TIMELINE, a full timeline is presented in each SegmentTemplate, with $Time$ media URLs. When set to NUMBER_WITH_DURATION, only a duration is included in each SegmentTemplate, with $Number$ media URLs.
         */
        segmentTemplateFormat?: pulumi.Input<enums.mediapackage.PackagingConfigurationDashPackageSegmentTemplateFormat>;
    }
    /**
     * The configuration to use for encrypting one or more content tracks separately for endpoints that use SPEKE 2.0.
     */
    interface PackagingConfigurationEncryptionContractConfigurationArgs {
        /**
         * A collection of audio encryption presets.
         */
        presetSpeke20Audio: pulumi.Input<enums.mediapackage.PackagingConfigurationEncryptionContractConfigurationPresetSpeke20Audio>;
        /**
         * A collection of video encryption presets.
         */
        presetSpeke20Video: pulumi.Input<enums.mediapackage.PackagingConfigurationEncryptionContractConfigurationPresetSpeke20Video>;
    }
    /**
     * An HTTP Live Streaming (HLS) encryption configuration.
     */
    interface PackagingConfigurationHlsEncryptionArgs {
        /**
         * An HTTP Live Streaming (HLS) encryption configuration.
         */
        constantInitializationVector?: pulumi.Input<string>;
        /**
         * The encryption method to use.
         */
        encryptionMethod?: pulumi.Input<enums.mediapackage.PackagingConfigurationHlsEncryptionEncryptionMethod>;
        /**
         * Parameters for the SPEKE key provider.
         */
        spekeKeyProvider: pulumi.Input<inputs.mediapackage.PackagingConfigurationSpekeKeyProviderArgs>;
    }
    /**
     * An HTTP Live Streaming (HLS) manifest configuration.
     */
    interface PackagingConfigurationHlsManifestArgs {
        /**
         * This setting controls how ad markers are included in the packaged OriginEndpoint. "NONE" will omit all SCTE-35 ad markers from the output. "PASSTHROUGH" causes the manifest to contain a copy of the SCTE-35 ad markers (comments) taken directly from the input HTTP Live Streaming (HLS) manifest. "SCTE35_ENHANCED" generates ad markers and blackout tags based on SCTE-35 messages in the input source.
         */
        adMarkers?: pulumi.Input<enums.mediapackage.PackagingConfigurationHlsManifestAdMarkers>;
        /**
         * When enabled, an I-Frame only stream will be included in the output.
         */
        includeIframeOnlyStream?: pulumi.Input<boolean>;
        /**
         * A short string that's appended to the end of the endpoint URL to create a unique path to this packaging configuration.
         */
        manifestName?: pulumi.Input<string>;
        /**
         * The interval (in seconds) between each EXT-X-PROGRAM-DATE-TIME tag inserted into manifests. Additionally, when an interval is specified ID3Timed Metadata messages will be generated every 5 seconds using the ingest time of the content. If the interval is not specified, or set to 0, then no EXT-X-PROGRAM-DATE-TIME tags will be inserted into manifests and no ID3Timed Metadata messages will be generated. Note that irrespective of this parameter, if any ID3 Timed Metadata is found in HTTP Live Streaming (HLS) input, it will be passed through to HLS output.
         */
        programDateTimeIntervalSeconds?: pulumi.Input<number>;
        /**
         * When enabled, the EXT-X-KEY tag will be repeated in output manifests.
         */
        repeatExtXKey?: pulumi.Input<boolean>;
        /**
         * Video bitrate limitations for outputs from this packaging configuration.
         */
        streamSelection?: pulumi.Input<inputs.mediapackage.PackagingConfigurationStreamSelectionArgs>;
    }
    /**
     * An HTTP Live Streaming (HLS) packaging configuration.
     */
    interface PackagingConfigurationHlsPackageArgs {
        /**
         * Parameters for encrypting content.
         */
        encryption?: pulumi.Input<inputs.mediapackage.PackagingConfigurationHlsEncryptionArgs>;
        /**
         * A list of HLS manifest configurations.
         */
        hlsManifests: pulumi.Input<pulumi.Input<inputs.mediapackage.PackagingConfigurationHlsManifestArgs>[]>;
        /**
         * When enabled, MediaPackage passes through digital video broadcasting (DVB) subtitles into the output.
         */
        includeDvbSubtitles?: pulumi.Input<boolean>;
        /**
         * Duration (in seconds) of each fragment. Actual fragments are rounded to the nearest multiple of the source fragment duration.
         */
        segmentDurationSeconds?: pulumi.Input<number>;
        /**
         * When enabled, audio streams will be placed in rendition groups in the output.
         */
        useAudioRenditionGroup?: pulumi.Input<boolean>;
    }
    /**
     * A CMAF encryption configuration.
     */
    interface PackagingConfigurationMssEncryptionArgs {
        /**
         * Parameters for the SPEKE key provider.
         */
        spekeKeyProvider: pulumi.Input<inputs.mediapackage.PackagingConfigurationSpekeKeyProviderArgs>;
    }
    /**
     * A Microsoft Smooth Streaming (MSS) manifest configuration.
     */
    interface PackagingConfigurationMssManifestArgs {
        /**
         * A short string that's appended to the end of the endpoint URL to create a unique path to this packaging configuration.
         */
        manifestName?: pulumi.Input<string>;
        /**
         * Video bitrate limitations for outputs from this packaging configuration.
         */
        streamSelection?: pulumi.Input<inputs.mediapackage.PackagingConfigurationStreamSelectionArgs>;
    }
    /**
     * A Microsoft Smooth Streaming (MSS) PackagingConfiguration.
     */
    interface PackagingConfigurationMssPackageArgs {
        /**
         * Parameters for encrypting content.
         */
        encryption?: pulumi.Input<inputs.mediapackage.PackagingConfigurationMssEncryptionArgs>;
        /**
         * A list of MSS manifest configurations.
         */
        mssManifests: pulumi.Input<pulumi.Input<inputs.mediapackage.PackagingConfigurationMssManifestArgs>[]>;
        /**
         * Duration (in seconds) of each fragment. Actual fragments are rounded to the nearest multiple of the source fragment duration.
         */
        segmentDurationSeconds?: pulumi.Input<number>;
    }
    /**
     * A configuration for accessing an external Secure Packager and Encoder Key Exchange (SPEKE) service that will provide encryption keys.
     */
    interface PackagingConfigurationSpekeKeyProviderArgs {
        /**
         * Use `encryptionContractConfiguration` to configure one or more content encryption keys for your endpoints that use SPEKE Version 2.0. The encryption contract defines which content keys are used to encrypt the audio and video tracks in your stream. To configure the encryption contract, specify which audio and video encryption presets to use.
         */
        encryptionContractConfiguration?: pulumi.Input<inputs.mediapackage.PackagingConfigurationEncryptionContractConfigurationArgs>;
        /**
         * The ARN for the IAM role that's granted by the key provider to provide access to the key provider API. Valid format: arn:aws:iam::{accountID}:role/{name}
         */
        roleArn: pulumi.Input<string>;
        /**
         * The system IDs to include in key requests.
         */
        systemIds: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * The URL of the external key provider service.
         */
        url: pulumi.Input<string>;
    }
    /**
     * A StreamSelection configuration.
     */
    interface PackagingConfigurationStreamSelectionArgs {
        /**
         * The maximum video bitrate (bps) to include in output.
         */
        maxVideoBitsPerSecond?: pulumi.Input<number>;
        /**
         * The minimum video bitrate (bps) to include in output.
         */
        minVideoBitsPerSecond?: pulumi.Input<number>;
        /**
         * A directive that determines the order of streams in the output.
         */
        streamOrder?: pulumi.Input<enums.mediapackage.PackagingConfigurationStreamSelectionStreamOrder>;
    }
    interface PackagingGroupAuthorizationArgs {
        /**
         * The Amazon Resource Name (ARN) for the secret in AWS Secrets Manager that is used for CDN authorization.
         */
        cdnIdentifierSecret: pulumi.Input<string>;
        /**
         * The Amazon Resource Name (ARN) for the IAM role that allows MediaPackage to communicate with AWS Secrets Manager.
         */
        secretsRoleArn: pulumi.Input<string>;
    }
    interface PackagingGroupLogConfigurationArgs {
        /**
         * Sets a custom AWS CloudWatch log group name for egress logs. If a log group name isn't specified, the default name is used: /aws/MediaPackage/VodEgressAccessLogs.
         */
        logGroupName?: pulumi.Input<string>;
    }
}
export declare namespace mediapackagev2 {
    /**
     * <p>The configuration for input switching based on the media quality confidence score (MQCS) as provided from AWS Elemental MediaLive.</p>
     */
    interface ChannelInputSwitchConfigurationArgs {
        /**
         * <p>When true, AWS Elemental MediaPackage performs input switching based on the MQCS. Default is true. This setting is valid only when <code>InputType</code> is <code>CMAF</code>.</p>
         */
        mqcsInputSwitching?: pulumi.Input<boolean>;
    }
    /**
     * <p>The settings for what common media server data (CMSD) headers AWS Elemental MediaPackage includes in responses to the CDN.</p>
     */
    interface ChannelOutputHeaderConfigurationArgs {
        /**
         * <p>When true, AWS Elemental MediaPackage includes the MQCS in responses to the CDN. This setting is valid only when <code>InputType</code> is <code>CMAF</code>.</p>
         */
        publishMqcs?: pulumi.Input<boolean>;
    }
    /**
     * <p>Retrieve the DASH manifest configuration.</p>
     */
    interface OriginEndpointDashManifestConfigurationArgs {
        drmSignaling?: pulumi.Input<enums.mediapackagev2.OriginEndpointDashDrmSignaling>;
        filterConfiguration?: pulumi.Input<inputs.mediapackagev2.OriginEndpointFilterConfigurationArgs>;
        /**
         * <p>A short string that's appended to the endpoint URL. The manifest name creates a unique path to this endpoint. If you don't enter a value, MediaPackage uses the default manifest name, index. </p>
         */
        manifestName: pulumi.Input<string>;
        /**
         * <p>The total duration (in seconds) of the manifest's content.</p>
         */
        manifestWindowSeconds?: pulumi.Input<number>;
        /**
         * <p>Minimum amount of content (in seconds) that a player must keep available in the buffer.</p>
         */
        minBufferTimeSeconds?: pulumi.Input<number>;
        /**
         * <p>Minimum amount of time (in seconds) that the player should wait before requesting updates to the manifest.</p>
         */
        minUpdatePeriodSeconds?: pulumi.Input<number>;
        /**
         * <p>A list of triggers that controls when AWS Elemental MediaPackage separates the MPEG-DASH manifest into multiple periods. Leave this value empty to indicate that the manifest is contained all in one period.
         *          For more information about periods in the DASH manifest, see <a href="https://docs.aws.amazon.com/mediapackage/latest/userguide/multi-period.html">Multi-period DASH in AWS Elemental MediaPackage</a>.</p>
         */
        periodTriggers?: pulumi.Input<pulumi.Input<enums.mediapackagev2.OriginEndpointDashPeriodTrigger>[]>;
        scteDash?: pulumi.Input<inputs.mediapackagev2.OriginEndpointScteDashArgs>;
        segmentTemplateFormat?: pulumi.Input<enums.mediapackagev2.OriginEndpointDashSegmentTemplateFormat>;
        /**
         * <p>The amount of time (in seconds) that the player should be from the end of the manifest.</p>
         */
        suggestedPresentationDelaySeconds?: pulumi.Input<number>;
        utcTiming?: pulumi.Input<inputs.mediapackagev2.OriginEndpointDashUtcTimingArgs>;
    }
    /**
     * <p>Determines the type of UTC timing included in the DASH Media Presentation Description (MPD).</p>
     */
    interface OriginEndpointDashUtcTimingArgs {
        /**
         * The UTC timing mode.
         */
        timingMode?: pulumi.Input<enums.mediapackagev2.OriginEndpointDashUtcTimingMode>;
        /**
         * <p>The the method that the player uses to synchronize to coordinated universal time (UTC) wall clock time.</p>
         */
        timingSource?: pulumi.Input<string>;
    }
    /**
     * <p>The parameters for encrypting content.</p>
     */
    interface OriginEndpointEncryptionArgs {
        /**
         * <p>A 128-bit, 16-byte hex value represented by a 32-character string, used in conjunction with the key for encrypting content. If you don't specify a value, then MediaPackage creates the constant initialization vector (IV).</p>
         */
        constantInitializationVector?: pulumi.Input<string>;
        /**
         * The encryption method to use.
         */
        encryptionMethod: pulumi.Input<inputs.mediapackagev2.OriginEndpointEncryptionMethodArgs>;
        /**
         * <p>The frequency (in seconds) of key changes for live workflows, in which content is streamed real time. The service retrieves content keys before the live content begins streaming, and then retrieves them as needed over the lifetime of the workflow. By default, key rotation is set to 300 seconds (5 minutes), the minimum rotation interval, which is equivalent to setting it to 300. If you don't enter an interval, content keys aren't rotated.</p>
         *          <p>The following example setting causes the service to rotate keys every thirty minutes: <code>1800</code>
         *          </p>
         */
        keyRotationIntervalSeconds?: pulumi.Input<number>;
        /**
         * The SPEKE key provider to use for encryption.
         */
        spekeKeyProvider: pulumi.Input<inputs.mediapackagev2.OriginEndpointSpekeKeyProviderArgs>;
    }
    /**
     * <p>Configure one or more content encryption keys for your endpoints that use SPEKE Version 2.0. The encryption contract defines which content keys are used to encrypt the audio and video tracks in your stream. To configure the encryption contract, specify which audio and video encryption presets to use.</p>
     */
    interface OriginEndpointEncryptionContractConfigurationArgs {
        /**
         * A collection of audio encryption presets.
         *
         * Value description:
         *
         * - `PRESET-AUDIO-1` - Use one content key to encrypt all of the audio tracks in your stream.
         * - `PRESET-AUDIO-2` - Use one content key to encrypt all of the stereo audio tracks and one content key to encrypt all of the multichannel audio tracks.
         * - `PRESET-AUDIO-3` - Use one content key to encrypt all of the stereo audio tracks, one content key to encrypt all of the multichannel audio tracks with 3 to 6 channels, and one content key to encrypt all of the multichannel audio tracks with more than 6 channels.
         * - `SHARED` - Use the same content key for all of the audio and video tracks in your stream.
         * - `UNENCRYPTED` - Don't encrypt any of the audio tracks in your stream.
         */
        presetSpeke20Audio: pulumi.Input<enums.mediapackagev2.OriginEndpointPresetSpeke20Audio>;
        /**
         * The SPEKE Version 2.0 preset video associated with the encryption contract configuration of the origin endpoint.
         *
         * A collection of video encryption presets.
         *
         * Value description:
         *
         * - `PRESET-VIDEO-1` - Use one content key to encrypt all of the video tracks in your stream.
         * - `PRESET-VIDEO-2` - Use one content key to encrypt all of the SD video tracks and one content key for all HD and higher resolutions video tracks.
         * - `PRESET-VIDEO-3` - Use one content key to encrypt all of the SD video tracks, one content key for HD video tracks and one content key for all UHD video tracks.
         * - `PRESET-VIDEO-4` - Use one content key to encrypt all of the SD video tracks, one content key for HD video tracks, one content key for all UHD1 video tracks and one content key for all UHD2 video tracks.
         * - `PRESET-VIDEO-5` - Use one content key to encrypt all of the SD video tracks, one content key for HD1 video tracks, one content key for HD2 video tracks, one content key for all UHD1 video tracks and one content key for all UHD2 video tracks.
         * - `PRESET-VIDEO-6` - Use one content key to encrypt all of the SD video tracks, one content key for HD1 video tracks, one content key for HD2 video tracks and one content key for all UHD video tracks.
         * - `PRESET-VIDEO-7` - Use one content key to encrypt all of the SD+HD1 video tracks, one content key for HD2 video tracks and one content key for all UHD video tracks.
         * - `PRESET-VIDEO-8` - Use one content key to encrypt all of the SD+HD1 video tracks, one content key for HD2 video tracks, one content key for all UHD1 video tracks and one content key for all UHD2 video tracks.
         * - `SHARED` - Use the same content key for all of the video and audio tracks in your stream.
         * - `UNENCRYPTED` - Don't encrypt any of the video tracks in your stream.
         */
        presetSpeke20Video: pulumi.Input<enums.mediapackagev2.OriginEndpointPresetSpeke20Video>;
    }
    /**
     * <p>The encryption type.</p>
     */
    interface OriginEndpointEncryptionMethodArgs {
        /**
         * The encryption method to use.
         */
        cmafEncryptionMethod?: pulumi.Input<enums.mediapackagev2.OriginEndpointCmafEncryptionMethod>;
        /**
         * The encryption method to use.
         */
        tsEncryptionMethod?: pulumi.Input<enums.mediapackagev2.OriginEndpointTsEncryptionMethod>;
    }
    /**
     * <p>Filter configuration includes settings for manifest filtering, start and end times, and time delay that apply to all of your egress requests for this manifest. </p>
     */
    interface OriginEndpointFilterConfigurationArgs {
        /**
         * <p>Optionally specify the clip start time for all of your manifest egress requests. When you include clip start time, note that you cannot use clip start time query parameters for this manifest's endpoint URL.</p>
         */
        clipStartTime?: pulumi.Input<string>;
        /**
         * <p>Optionally specify the end time for all of your manifest egress requests. When you include end time, note that you cannot use end time query parameters for this manifest's endpoint URL.</p>
         */
        end?: pulumi.Input<string>;
        /**
         * <p>Optionally specify one or more manifest filters for all of your manifest egress requests. When you include a manifest filter, note that you cannot use an identical manifest filter query parameter for this manifest's endpoint URL.</p>
         */
        manifestFilter?: pulumi.Input<string>;
        /**
         * <p>Optionally specify the start time for all of your manifest egress requests. When you include start time, note that you cannot use start time query parameters for this manifest's endpoint URL.</p>
         */
        start?: pulumi.Input<string>;
        /**
         * <p>Optionally specify the time delay for all of your manifest egress requests. Enter a value that is smaller than your endpoint's startover window. When you include time delay, note that you cannot use time delay query parameters for this manifest's endpoint URL.</p>
         */
        timeDelaySeconds?: pulumi.Input<number>;
    }
    /**
     * <p>The failover settings for the endpoint.</p>
     */
    interface OriginEndpointForceEndpointErrorConfigurationArgs {
        /**
         * <p>The failover settings for the endpoint. The options are:</p>
         *          <ul>
         *             <li>
         *                <p>
         *                   <code>STALE_MANIFEST</code> - The manifest stalled and there a no new segments or parts.</p>
         *             </li>
         *             <li>
         *                <p>
         *                   <code>INCOMPLETE_MANIFEST</code> - There is a gap in the manifest.</p>
         *             </li>
         *             <li>
         *                <p>
         *                   <code>MISSING_DRM_KEY</code> - Key rotation is enabled but we're unable to fetch the key for the current key period.</p>
         *             </li>
         *          </ul>
         */
        endpointErrorConditions?: pulumi.Input<pulumi.Input<enums.mediapackagev2.OriginEndpointEndpointErrorCondition>[]>;
    }
    /**
     * <p>Retrieve the HTTP live streaming (HLS) manifest configuration.</p>
     */
    interface OriginEndpointHlsManifestConfigurationArgs {
        /**
         * <p>A short string that's appended to the endpoint URL. The child manifest name creates a unique path to this endpoint. If you don't enter a value, MediaPackage uses the default child manifest name, index_1. The manifestName on the HLSManifest object overrides the manifestName you provided on the originEndpoint object.</p>
         */
        childManifestName?: pulumi.Input<string>;
        filterConfiguration?: pulumi.Input<inputs.mediapackagev2.OriginEndpointFilterConfigurationArgs>;
        /**
         * <p>A short short string that's appended to the endpoint URL. The manifest name creates a unique path to this endpoint. If you don't enter a value, MediaPackage uses the default manifest name, index. MediaPackage automatically inserts the format extension, such as .m3u8. You can't use the same manifest name if you use HLS manifest and low-latency HLS manifest. The manifestName on the HLSManifest object overrides the manifestName you provided on the originEndpoint object.</p>
         */
        manifestName: pulumi.Input<string>;
        /**
         * <p>The total duration (in seconds) of the manifest's content.</p>
         */
        manifestWindowSeconds?: pulumi.Input<number>;
        /**
         * <p>Inserts EXT-X-PROGRAM-DATE-TIME tags in the output manifest at the interval that you specify. If you don't enter an interval,
         *          EXT-X-PROGRAM-DATE-TIME tags aren't included in the manifest.
         *          The tags sync the stream to the wall clock so that viewers can seek to a specific time in the playback timeline on the player.
         *          ID3Timed metadata messages generate every 5 seconds whenever the content is ingested.</p>
         *          <p>Irrespective of this parameter, if any ID3Timed metadata is in the HLS input, it is passed through to the HLS output.</p>
         */
        programDateTimeIntervalSeconds?: pulumi.Input<number>;
        /**
         * THE SCTE-35 HLS configuration associated with the HLS manifest configuration.
         */
        scteHls?: pulumi.Input<inputs.mediapackagev2.OriginEndpointScteHlsArgs>;
        startTag?: pulumi.Input<inputs.mediapackagev2.OriginEndpointStartTagArgs>;
        /**
         * <p>The egress domain URL for stream delivery from MediaPackage.</p>
         */
        url?: pulumi.Input<string>;
    }
    /**
     * <p>Retrieve the low-latency HTTP live streaming (HLS) manifest configuration.</p>
     */
    interface OriginEndpointLowLatencyHlsManifestConfigurationArgs {
        /**
         * <p>A short string that's appended to the endpoint URL. The child manifest name creates a unique path to this endpoint. If you don't enter a value, MediaPackage uses the default child manifest name, index_1. The manifestName on the HLSManifest object overrides the manifestName you provided on the originEndpoint object.</p>
         */
        childManifestName?: pulumi.Input<string>;
        filterConfiguration?: pulumi.Input<inputs.mediapackagev2.OriginEndpointFilterConfigurationArgs>;
        /**
         * <p>A short short string that's appended to the endpoint URL. The manifest name creates a unique path to this endpoint. If you don't enter a value, MediaPackage uses the default manifest name, index. MediaPackage automatically inserts the format extension, such as .m3u8. You can't use the same manifest name if you use HLS manifest and low-latency HLS manifest. The manifestName on the HLSManifest object overrides the manifestName you provided on the originEndpoint object.</p>
         */
        manifestName: pulumi.Input<string>;
        /**
         * <p>The total duration (in seconds) of the manifest's content.</p>
         */
        manifestWindowSeconds?: pulumi.Input<number>;
        /**
         * <p>Inserts EXT-X-PROGRAM-DATE-TIME tags in the output manifest at the interval that you specify. If you don't enter an interval,
         *          EXT-X-PROGRAM-DATE-TIME tags aren't included in the manifest.
         *          The tags sync the stream to the wall clock so that viewers can seek to a specific time in the playback timeline on the player.
         *          ID3Timed metadata messages generate every 5 seconds whenever the content is ingested.</p>
         *          <p>Irrespective of this parameter, if any ID3Timed metadata is in the HLS input, it is passed through to the HLS output.</p>
         */
        programDateTimeIntervalSeconds?: pulumi.Input<number>;
        /**
         * The SCTE-35 HLS configuration associated with the low-latency HLS (LL-HLS) manifest configuration of the origin endpoint.
         */
        scteHls?: pulumi.Input<inputs.mediapackagev2.OriginEndpointScteHlsArgs>;
        startTag?: pulumi.Input<inputs.mediapackagev2.OriginEndpointStartTagArgs>;
        /**
         * <p>The egress domain URL for stream delivery from MediaPackage.</p>
         */
        url?: pulumi.Input<string>;
    }
    /**
     * <p>The SCTE configuration.</p>
     */
    interface OriginEndpointScteArgs {
        /**
         * <p>The SCTE-35 message types that you want to be treated as ad markers in the output.</p>
         */
        scteFilter?: pulumi.Input<pulumi.Input<enums.mediapackagev2.OriginEndpointScteFilter>[]>;
    }
    /**
     * <p>The SCTE configuration.</p>
     */
    interface OriginEndpointScteDashArgs {
        /**
         * Choose how ad markers are included in the packaged content. If you include ad markers in the content stream in your upstream encoders, then you need to inform MediaPackage what to do with the ad markers in the output.
         *
         * Value description:
         *
         * - `Binary` - The SCTE-35 marker is expressed as a hex-string (Base64 string) rather than full XML.
         * - `XML` - The SCTE marker is expressed fully in XML.
         */
        adMarkerDash?: pulumi.Input<enums.mediapackagev2.OriginEndpointAdMarkerDash>;
    }
    /**
     * <p>The SCTE configuration.</p>
     */
    interface OriginEndpointScteHlsArgs {
        /**
         * The SCTE-35 HLS ad-marker configuration.
         */
        adMarkerHls?: pulumi.Input<enums.mediapackagev2.OriginEndpointAdMarkerHls>;
    }
    /**
     * <p>The segment configuration, including the segment name, duration, and other configuration values.</p>
     */
    interface OriginEndpointSegmentArgs {
        /**
         * Whether to use encryption for the segment.
         */
        encryption?: pulumi.Input<inputs.mediapackagev2.OriginEndpointEncryptionArgs>;
        /**
         * <p>When selected, the stream set includes an additional I-frame only stream, along with the other tracks. If false, this extra stream is not included. MediaPackage generates an I-frame only stream from the first rendition in the manifest. The service inserts EXT-I-FRAMES-ONLY tags in the output manifest, and then generates and includes an I-frames only playlist in the stream. This playlist permits player functionality like fast forward and rewind.</p>
         */
        includeIframeOnlyStreams?: pulumi.Input<boolean>;
        /**
         * The SCTE-35 configuration associated with the segment.
         */
        scte?: pulumi.Input<inputs.mediapackagev2.OriginEndpointScteArgs>;
        /**
         * <p>The duration (in seconds) of each segment. Enter a value equal to, or a multiple of, the input segment duration. If the value that you enter is different from the input segment duration, MediaPackage rounds segments to the nearest multiple of the input segment duration.</p>
         */
        segmentDurationSeconds?: pulumi.Input<number>;
        /**
         * <p>The name that describes the segment. The name is the base name of the segment used in all content manifests inside of the endpoint. You can't use spaces in the name.</p>
         */
        segmentName?: pulumi.Input<string>;
        /**
         * <p>By default, MediaPackage excludes all digital video broadcasting (DVB) subtitles from the output. When selected, MediaPackage passes through DVB subtitles into the output.</p>
         */
        tsIncludeDvbSubtitles?: pulumi.Input<boolean>;
        /**
         * <p>When selected, MediaPackage bundles all audio tracks in a rendition group. All other tracks in the stream can be used with any audio rendition from the group.</p>
         */
        tsUseAudioRenditionGroup?: pulumi.Input<boolean>;
    }
    /**
     * <p>The parameters for the SPEKE key provider.</p>
     */
    interface OriginEndpointSpekeKeyProviderArgs {
        /**
         * <p>The DRM solution provider you're using to protect your content during distribution.</p>
         */
        drmSystems: pulumi.Input<pulumi.Input<enums.mediapackagev2.OriginEndpointDrmSystem>[]>;
        /**
         * The encryption contract configuration associated with the SPEKE key provider.
         */
        encryptionContractConfiguration: pulumi.Input<inputs.mediapackagev2.OriginEndpointEncryptionContractConfigurationArgs>;
        /**
         * <p>The unique identifier for the content. The service sends this to the key server to identify the current endpoint. How unique you make this depends on how fine-grained you want access controls to be. The service does not permit you to use the same ID for two simultaneous encryption processes. The resource ID is also known as the content ID.</p>
         *          <p>The following example shows a resource ID: <code>MovieNight20171126093045</code>
         *          </p>
         */
        resourceId: pulumi.Input<string>;
        /**
         * <p>The ARN for the IAM role granted by the key provider that provides access to the key provider API. This role must have a trust policy that allows MediaPackage to assume the role, and it must have a sufficient permissions policy to allow access to the specific key retrieval URL. Get this from your DRM solution provider.</p>
         *          <p>Valid format: <code>arn:aws:iam::{accountID}:role/{name}</code>. The following example shows a role ARN: <code>arn:aws:iam::444455556666:role/SpekeAccess</code>
         *          </p>
         */
        roleArn: pulumi.Input<string>;
        /**
         * <p>The URL of the API Gateway proxy that you set up to talk to your key server. The API Gateway proxy must reside in the same AWS Region as MediaPackage and must start with https://.</p>
         *          <p>The following example shows a URL: <code>https://1wm2dx1f33.execute-api.us-west-2.amazonaws.com/SpekeSample/copyProtection</code>
         *          </p>
         */
        url: pulumi.Input<string>;
    }
    /**
     * <p>To insert an EXT-X-START tag in your HLS playlist, specify a StartTag configuration object with a valid TimeOffset. When you do, you can also optionally specify whether to include a PRECISE value in the EXT-X-START tag.</p>
     */
    interface OriginEndpointStartTagArgs {
        /**
         * <p>Specify the value for PRECISE within your EXT-X-START tag. Leave blank, or choose false, to use the default value NO. Choose yes to use the value YES.</p>
         */
        precise?: pulumi.Input<boolean>;
        /**
         * <p>Specify the value for TIME-OFFSET within your EXT-X-START tag. Enter a signed floating point value which, if positive, must be less than the configured manifest duration minus three times the configured segment target duration. If negative, the absolute value must be larger than three times the configured segment target duration, and the absolute value must be smaller than the configured manifest duration.</p>
         */
        timeOffset: pulumi.Input<number>;
    }
}
export declare namespace mediatailor {
    /**
     * <p>Dash manifest configuration parameters.</p>
     */
    interface ChannelDashPlaylistSettingsArgs {
        /**
         * <p>The total duration (in seconds) of each manifest. Minimum value: <code>30</code> seconds. Maximum value: <code>3600</code> seconds.</p>
         */
        manifestWindowSeconds?: pulumi.Input<number>;
        /**
         * <p>Minimum amount of content (measured in seconds) that a player must keep available in the buffer. Minimum value: <code>2</code> seconds. Maximum value: <code>60</code> seconds.</p>
         */
        minBufferTimeSeconds?: pulumi.Input<number>;
        /**
         * <p>Minimum amount of time (in seconds) that the player should wait before requesting updates to the manifest. Minimum value: <code>2</code> seconds. Maximum value: <code>60</code> seconds.</p>
         */
        minUpdatePeriodSeconds?: pulumi.Input<number>;
        /**
         * <p>Amount of time (in seconds) that the player should be from the live point at the end of the manifest. Minimum value: <code>2</code> seconds. Maximum value: <code>60</code> seconds.</p>
         */
        suggestedPresentationDelaySeconds?: pulumi.Input<number>;
    }
    /**
     * <p>HLS playlist configuration parameters.</p>
     */
    interface ChannelHlsPlaylistSettingsArgs {
        /**
         * <p>Determines the type of SCTE 35 tags to use in ad markup. Specify <code>DATERANGE</code> to use <code>DATERANGE</code> tags (for live or VOD content). Specify <code>SCTE35_ENHANCED</code> to use <code>EXT-X-CUE-OUT</code> and <code>EXT-X-CUE-IN</code> tags (for VOD content only).</p>
         */
        adMarkupType?: pulumi.Input<pulumi.Input<enums.mediatailor.ChannelAdMarkupType>[]>;
        /**
         * <p>The total duration (in seconds) of each manifest. Minimum value: <code>30</code> seconds. Maximum value: <code>3600</code> seconds.</p>
         */
        manifestWindowSeconds?: pulumi.Input<number>;
    }
    /**
     * <p>The log configuration for the channel.</p>
     */
    interface ChannelLogConfigurationForChannelArgs {
        /**
         * <p>The log types.</p>
         */
        logTypes?: pulumi.Input<pulumi.Input<enums.mediatailor.ChannelLogType>[]>;
    }
    /**
     * <p>The output configuration for this channel.</p>
     */
    interface ChannelRequestOutputItemArgs {
        /**
         * DASH manifest configuration parameters.
         */
        dashPlaylistSettings?: pulumi.Input<inputs.mediatailor.ChannelDashPlaylistSettingsArgs>;
        /**
         * HLS playlist configuration parameters.
         */
        hlsPlaylistSettings?: pulumi.Input<inputs.mediatailor.ChannelHlsPlaylistSettingsArgs>;
        /**
         * <p>The name of the manifest for the channel. The name appears in the <code>PlaybackUrl</code>.</p>
         */
        manifestName: pulumi.Input<string>;
        /**
         * <p>A string used to match which <code>HttpPackageConfiguration</code> is used for each <code>VodSource</code>.</p>
         */
        sourceGroup: pulumi.Input<string>;
    }
    /**
     * <p>Slate VOD source configuration.</p>
     */
    interface ChannelSlateSourceArgs {
        /**
         * <p>The name of the source location where the slate VOD source is stored.</p>
         */
        sourceLocationName?: pulumi.Input<string>;
        /**
         * <p>The slate VOD source name. The VOD source must already exist in a source location before it can be used for slate.</p>
         */
        vodSourceName?: pulumi.Input<string>;
    }
    /**
     * <p>The configuration for time-shifted viewing.</p>
     */
    interface ChannelTimeShiftConfigurationArgs {
        /**
         * <p>The maximum time delay for time-shifted viewing. The minimum allowed maximum time delay is 0 seconds, and the maximum allowed maximum time delay is 21600 seconds (6 hours).</p>
         */
        maxTimeDelaySeconds: pulumi.Input<number>;
    }
    /**
     * <p>The HTTP package configuration properties for the requested VOD source.</p>
     */
    interface LiveSourceHttpPackageConfigurationArgs {
        /**
         * <p>The relative path to the URL for this VOD source. This is combined with <code>SourceLocation::HttpConfiguration::BaseUrl</code> to form a valid URL.</p>
         */
        path: pulumi.Input<string>;
        /**
         * <p>The name of the source group. This has to match one of the <code>Channel::Outputs::SourceGroup</code>.</p>
         */
        sourceGroup: pulumi.Input<string>;
        /**
         * The streaming protocol for this package configuration. Supported values are `HLS` and `DASH` .
         */
        type: pulumi.Input<enums.mediatailor.LiveSourceType>;
    }
    /**
     * For HLS, when set to true, MediaTailor passes through EXT-X-CUE-IN, EXT-X-CUE-OUT, and EXT-X-SPLICEPOINT-SCTE35 ad markers from the origin manifest to the MediaTailor personalized manifest. No logic is applied to these ad markers. For example, if EXT-X-CUE-OUT has a value of 60, but no ads are filled for that ad break, MediaTailor will not set the value to 0.
     */
    interface PlaybackConfigurationAdMarkerPassthroughArgs {
        /**
         * Enables ad marker passthrough for your configuration.
         */
        enabled?: pulumi.Input<boolean>;
    }
    /**
     * The configuration for avail suppression, also known as ad suppression. For more information about ad suppression, see Ad Suppression (https://docs.aws.amazon.com/mediatailor/latest/ug/ad-behavior.html).
     */
    interface PlaybackConfigurationAvailSuppressionArgs {
        /**
         * Defines the policy to apply to the avail suppression mode. BEHIND_LIVE_EDGE will always use the full avail suppression policy. AFTER_LIVE_EDGE mode can be used to invoke partial ad break fills when a session starts mid-break. Valid values are FULL_AVAIL_ONLY and PARTIAL_AVAIL
         */
        fillPolicy?: pulumi.Input<enums.mediatailor.PlaybackConfigurationAvailSuppressionFillPolicy>;
        /**
         * Sets the ad suppression mode. By default, ad suppression is off and all ad breaks are filled with ads or slate. When Mode is set to BEHIND_LIVE_EDGE, ad suppression is active and MediaTailor won't fill ad breaks on or behind the ad suppression Value time in the manifest lookback window. When Mode is set to AFTER_LIVE_EDGE, ad suppression is active and MediaTailor won't fill ad breaks that are within the live edge plus the avail suppression value.
         */
        mode?: pulumi.Input<enums.mediatailor.PlaybackConfigurationAvailSuppressionMode>;
        /**
         * A live edge offset time in HH:MM:SS. MediaTailor won't fill ad breaks on or behind this time in the manifest lookback window. If Value is set to 00:00:00, it is in sync with the live edge, and MediaTailor won't fill any ad breaks on or behind the live edge. If you set a Value time, MediaTailor won't fill any ad breaks on or behind this time in the manifest lookback window. For example, if you set 00:45:00, then MediaTailor will fill ad breaks that occur within 45 minutes behind the live edge, but won't fill ad breaks on or behind 45 minutes behind the live edge.
         */
        value?: pulumi.Input<string>;
    }
    /**
     * The configuration for bumpers. Bumpers are short audio or video clips that play at the start or before the end of an ad break. To learn more about bumpers, see Bumpers (https://docs.aws.amazon.com/mediatailor/latest/ug/bumpers.html).
     */
    interface PlaybackConfigurationBumperArgs {
        /**
         * The URL for the end bumper asset.
         */
        endUrl?: pulumi.Input<string>;
        /**
         * The URL for the start bumper asset.
         */
        startUrl?: pulumi.Input<string>;
    }
    /**
     * The configuration for using a content delivery network (CDN), like Amazon CloudFront, for content and ad segment management.
     */
    interface PlaybackConfigurationCdnConfigurationArgs {
        /**
         * A non-default content delivery network (CDN) to serve ad segments. By default, AWS Elemental MediaTailor uses Amazon CloudFront with default cache settings as its CDN for ad segments. To set up an alternate CDN, create a rule in your CDN for the origin ads.mediatailor.&lt;region>.amazonaws.com. Then specify the rule's name in this AdSegmentUrlPrefix. When AWS Elemental MediaTailor serves a manifest, it reports your CDN as the source for ad segments.
         */
        adSegmentUrlPrefix?: pulumi.Input<string>;
        /**
         * A content delivery network (CDN) to cache content segments, so that content requests don't always have to go to the origin server. First, create a rule in your CDN for the content segment origin server. Then specify the rule's name in this ContentSegmentUrlPrefix. When AWS Elemental MediaTailor serves a manifest, it reports your CDN as the source for content segments.
         */
        contentSegmentUrlPrefix?: pulumi.Input<string>;
    }
    /**
     * The configuration for DASH PUT operations.
     */
    interface PlaybackConfigurationDashConfigurationArgs {
        /**
         * The URL generated by MediaTailor to initiate a DASH playback session. The session uses server-side reporting.
         */
        manifestEndpointPrefix?: pulumi.Input<string>;
        /**
         * The setting that controls whether MediaTailor includes the Location tag in DASH manifests. MediaTailor populates the Location tag with the URL for manifest update requests, to be used by players that don't support sticky redirects. Disable this if you have CDN routing rules set up for accessing MediaTailor manifests, and you are either using client-side reporting or your players support sticky HTTP redirects. Valid values are DISABLED and EMT_DEFAULT. The EMT_DEFAULT setting enables the inclusion of the tag and is the default value.
         */
        mpdLocation?: pulumi.Input<string>;
        /**
         * The setting that controls whether MediaTailor handles manifests from the origin server as multi-period manifests or single-period manifests. If your origin server produces single-period manifests, set this to SINGLE_PERIOD. The default setting is MULTI_PERIOD. For multi-period manifests, omit this setting or set it to MULTI_PERIOD.
         */
        originManifestType?: pulumi.Input<enums.mediatailor.PlaybackConfigurationDashConfigurationOriginManifestType>;
    }
    interface PlaybackConfigurationHlsConfigurationArgs {
        /**
         * The URL that is used to initiate a playback session for devices that support Apple HLS. The session uses server-side reporting.
         */
        manifestEndpointPrefix?: pulumi.Input<string>;
    }
    /**
     * The configuration for pre-roll ad insertion.
     */
    interface PlaybackConfigurationLivePreRollConfigurationArgs {
        /**
         * The URL for the ad decision server (ADS) for pre-roll ads. This includes the specification of static parameters and placeholders for dynamic parameters. AWS Elemental MediaTailor substitutes player-specific and session-specific parameters as needed when calling the ADS. Alternately, for testing, you can provide a static VAST URL. The maximum length is 25,000 characters.
         */
        adDecisionServerUrl?: pulumi.Input<string>;
        /**
         * The maximum allowed duration for the pre-roll ad avail. AWS Elemental MediaTailor won't play pre-roll ads to exceed this duration, regardless of the total duration of ads that the ADS returns.
         */
        maxDurationSeconds?: pulumi.Input<number>;
    }
    /**
     * The configuration for manifest processing rules. Manifest processing rules enable customization of the personalized manifests created by MediaTailor.
     */
    interface PlaybackConfigurationManifestProcessingRulesArgs {
        /**
         * For HLS, when set to true, MediaTailor passes through EXT-X-CUE-IN, EXT-X-CUE-OUT, and EXT-X-SPLICEPOINT-SCTE35 ad markers from the origin manifest to the MediaTailor personalized manifest. No logic is applied to these ad markers. For example, if EXT-X-CUE-OUT has a value of 60, but no ads are filled for that ad break, MediaTailor will not set the value to 0.
         */
        adMarkerPassthrough?: pulumi.Input<inputs.mediatailor.PlaybackConfigurationAdMarkerPassthroughArgs>;
    }
    /**
     * <p>Access configuration parameters.</p>
     */
    interface SourceLocationAccessConfigurationArgs {
        /**
         * The type of authentication used to access content from `HttpConfiguration::BaseUrl` on your source location. Accepted value: `S3_SIGV4` .
         *
         * `S3_SIGV4` - AWS Signature Version 4 authentication for Amazon S3 hosted virtual-style access. If your source location base URL is an Amazon S3 bucket, MediaTailor can use AWS Signature Version 4 (SigV4) authentication to access the bucket where your source content is stored. Your MediaTailor source location baseURL must follow the S3 virtual hosted-style request URL format. For example, https://bucket-name.s3.Region.amazonaws.com/key-name.
         *
         * Before you can use `S3_SIGV4` , you must meet these requirements:
         *
         * • You must allow MediaTailor to access your S3 bucket by granting mediatailor.amazonaws.com principal access in IAM. For information about configuring access in IAM, see Access management in the IAM User Guide.
         *
         * • The mediatailor.amazonaws.com service principal must have permissions to read all top level manifests referenced by the VodSource packaging configurations.
         *
         * • The caller of the API must have s3:GetObject IAM permissions to read all top level manifests referenced by your MediaTailor VodSource packaging configurations.
         */
        accessType?: pulumi.Input<enums.mediatailor.SourceLocationAccessType>;
        /**
         * AWS Secrets Manager access token configuration parameters.
         */
        secretsManagerAccessTokenConfiguration?: pulumi.Input<inputs.mediatailor.SourceLocationSecretsManagerAccessTokenConfigurationArgs>;
    }
    /**
     * <p>The optional configuration for a server that serves segments. Use this if you want the segment delivery server to be different from the source location server. For example, you can configure your source location server to be an origination server, such as MediaPackage, and the segment delivery server to be a content delivery network (CDN), such as CloudFront. If you don't specify a segment delivery server, then the source location server is used.</p>
     */
    interface SourceLocationDefaultSegmentDeliveryConfigurationArgs {
        /**
         * <p>The hostname of the server that will be used to serve segments. This string must include the protocol, such as <b>https://</b>.</p>
         */
        baseUrl?: pulumi.Input<string>;
    }
    /**
     * <p>The HTTP configuration for the source location.</p>
     */
    interface SourceLocationHttpConfigurationArgs {
        /**
         * <p>The base URL for the source location host server. This string must include the protocol, such as <b>https://</b>.</p>
         */
        baseUrl: pulumi.Input<string>;
    }
    /**
     * <p>AWS Secrets Manager access token configuration parameters. For information about Secrets Manager access token authentication, see <a href="https://docs.aws.amazon.com/mediatailor/latest/ug/channel-assembly-access-configuration-access-token.html">Working with AWS Secrets Manager access token authentication</a>.</p>
     */
    interface SourceLocationSecretsManagerAccessTokenConfigurationArgs {
        /**
         * <p>The name of the HTTP header used to supply the access token in requests to the source location.</p>
         */
        headerName?: pulumi.Input<string>;
        /**
         * <p>The Amazon Resource Name (ARN) of the AWS Secrets Manager secret that contains the access token.</p>
         */
        secretArn?: pulumi.Input<string>;
        /**
         * <p>The AWS Secrets Manager <a href="https://docs.aws.amazon.com/secretsmanager/latest/apireference/API_CreateSecret.html#SecretsManager-CreateSecret-request-SecretString.html">SecretString</a> key associated with the access token. MediaTailor uses the key to look up SecretString key and value pair containing the access token.</p>
         */
        secretStringKey?: pulumi.Input<string>;
    }
    /**
     * <p>The segment delivery configuration settings.</p>
     */
    interface SourceLocationSegmentDeliveryConfigurationArgs {
        /**
         * <p>The base URL of the host or path of the segment delivery server that you're using to serve segments. This is typically a content delivery network (CDN). The URL can be absolute or relative. To use an absolute URL include the protocol, such as <code>https://example.com/some/path</code>. To use a relative URL specify the relative path, such as <code>/some/path*</code>.</p>
         */
        baseUrl?: pulumi.Input<string>;
        /**
         * <p>A unique identifier used to distinguish between multiple segment delivery configurations in a source location.</p>
         */
        name?: pulumi.Input<string>;
    }
    /**
     * <p>The HTTP package configuration properties for the requested VOD source.</p>
     */
    interface VodSourceHttpPackageConfigurationArgs {
        /**
         * <p>The relative path to the URL for this VOD source. This is combined with <code>SourceLocation::HttpConfiguration::BaseUrl</code> to form a valid URL.</p>
         */
        path: pulumi.Input<string>;
        /**
         * <p>The name of the source group. This has to match one of the <code>Channel::Outputs::SourceGroup</code>.</p>
         */
        sourceGroup: pulumi.Input<string>;
        /**
         * The streaming protocol for this package configuration. Supported values are `HLS` and `DASH` .
         */
        type: pulumi.Input<enums.mediatailor.VodSourceType>;
    }
}
export declare namespace memorydb {
    /**
     * Denotes whether the user requires a password to authenticate.
     *
     * *Example:*
     *
     * `mynewdbuser: Type: AWS::MemoryDB::User Properties: AccessString: on ~* &* +@all AuthenticationMode: Passwords: '1234567890123456' Type: password UserName: mynewdbuser AuthenticationMode: { "Passwords": ["1234567890123456"], "Type": "Password" }`
     */
    interface AuthenticationModePropertiesArgs {
        /**
         * Passwords used for this user account. You can create up to two passwords for each user.
         */
        passwords?: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * Type of authentication strategy for this user.
         */
        type?: pulumi.Input<enums.memorydb.UserAuthenticationModePropertiesType>;
    }
    interface ClusterEndpointArgs {
        /**
         * The DNS address of the primary read-write node.
         */
        address?: pulumi.Input<string>;
        /**
         * The port number that the engine is listening on.
         */
        port?: pulumi.Input<number>;
    }
}
export declare namespace msk {
    interface ClusterBrokerLogsArgs {
        cloudWatchLogs?: pulumi.Input<inputs.msk.ClusterCloudWatchLogsArgs>;
        /**
         * Details of the Kinesis Data Firehose delivery stream that is the destination for broker logs.
         */
        firehose?: pulumi.Input<inputs.msk.ClusterFirehoseArgs>;
        /**
         * Details of the Amazon S3 destination for broker logs.
         */
        s3?: pulumi.Input<inputs.msk.ClusterS3Args>;
    }
    interface ClusterBrokerNodeGroupInfoArgs {
        /**
         * This parameter is currently not in use.
         */
        brokerAzDistribution?: pulumi.Input<string>;
        /**
         * The list of subnets to connect to in the client virtual private cloud (VPC). Amazon creates elastic network interfaces (ENIs) inside these subnets. Client applications use ENIs to produce and consume data.
         *
         * If you use the US West (N. California) Region, specify exactly two subnets. For other Regions where Amazon MSK is available, you can specify either two or three subnets. The subnets that you specify must be in distinct Availability Zones. When you create a cluster, Amazon MSK distributes the broker nodes evenly across the subnets that you specify.
         *
         * Client subnets can't occupy the Availability Zone with ID `use1-az3` .
         */
        clientSubnets: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * Information about the cluster's connectivity setting.
         */
        connectivityInfo?: pulumi.Input<inputs.msk.ClusterConnectivityInfoArgs>;
        /**
         * The type of Amazon EC2 instances to use for brokers. The following instance types are allowed: kafka.m5.large, kafka.m5.xlarge, kafka.m5.2xlarge, kafka.m5.4xlarge, kafka.m5.8xlarge, kafka.m5.12xlarge, kafka.m5.16xlarge, kafka.m5.24xlarge, and kafka.t3.small.
         */
        instanceType: pulumi.Input<string>;
        /**
         * The security groups to associate with the ENIs in order to specify who can connect to and communicate with the Amazon MSK cluster. If you don't specify a security group, Amazon MSK uses the default security group associated with the VPC. If you specify security groups that were shared with you, you must ensure that you have permissions to them. Specifically, you need the `ec2:DescribeSecurityGroups` permission.
         */
        securityGroups?: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * Contains information about storage volumes attached to Amazon MSK broker nodes.
         */
        storageInfo?: pulumi.Input<inputs.msk.ClusterStorageInfoArgs>;
    }
    interface ClusterClientAuthenticationArgs {
        /**
         * Details for client authentication using SASL. To turn on SASL, you must also turn on `EncryptionInTransit` by setting `inCluster` to true. You must set `clientBroker` to either `TLS` or `TLS_PLAINTEXT` . If you choose `TLS_PLAINTEXT` , then you must also set `unauthenticated` to true.
         */
        sasl?: pulumi.Input<inputs.msk.ClusterSaslArgs>;
        /**
         * Details for ClientAuthentication using TLS. To turn on TLS access control, you must also turn on `EncryptionInTransit` by setting `inCluster` to true and `clientBroker` to `TLS` .
         */
        tls?: pulumi.Input<inputs.msk.ClusterTlsArgs>;
        /**
         * Details for ClientAuthentication using no authentication.
         */
        unauthenticated?: pulumi.Input<inputs.msk.ClusterUnauthenticatedArgs>;
    }
    interface ClusterCloudWatchLogsArgs {
        /**
         * Specifies whether broker logs get sent to the specified CloudWatch Logs destination.
         */
        enabled: pulumi.Input<boolean>;
        /**
         * The CloudWatch log group that is the destination for broker logs.
         */
        logGroup?: pulumi.Input<string>;
    }
    interface ClusterConfigurationInfoArgs {
        /**
         * ARN of the configuration to use.
         */
        arn: pulumi.Input<string>;
        /**
         * The revision of the configuration to use.
         */
        revision: pulumi.Input<number>;
    }
    interface ClusterConnectivityInfoArgs {
        /**
         * Access control settings for the cluster's brokers.
         */
        publicAccess?: pulumi.Input<inputs.msk.ClusterPublicAccessArgs>;
        /**
         * VPC connection control settings for brokers.
         */
        vpcConnectivity?: pulumi.Input<inputs.msk.ClusterVpcConnectivityArgs>;
    }
    interface ClusterEbsStorageInfoArgs {
        /**
         * EBS volume provisioned throughput information.
         */
        provisionedThroughput?: pulumi.Input<inputs.msk.ClusterProvisionedThroughputArgs>;
        /**
         * The size in GiB of the EBS volume for the data drive on each broker node.
         */
        volumeSize?: pulumi.Input<number>;
    }
    interface ClusterEncryptionAtRestArgs {
        /**
         * The ARN of the Amazon KMS key for encrypting data at rest. If you don't specify a KMS key, MSK creates one for you and uses it.
         */
        dataVolumeKmsKeyId: pulumi.Input<string>;
    }
    interface ClusterEncryptionInTransitArgs {
        /**
         * Indicates the encryption setting for data in transit between clients and brokers. You must set it to one of the following values.
         *
         * - `TLS` : Indicates that client-broker communication is enabled with TLS only.
         * - `TLS_PLAINTEXT` : Indicates that client-broker communication is enabled for both TLS-encrypted, as well as plaintext data.
         * - `PLAINTEXT` : Indicates that client-broker communication is enabled in plaintext only.
         *
         * The default value is `TLS` .
         */
        clientBroker?: pulumi.Input<enums.msk.ClusterEncryptionInTransitClientBroker>;
        /**
         * When set to true, it indicates that data communication among the broker nodes of the cluster is encrypted. When set to false, the communication happens in plaintext.
         *
         * The default value is true.
         */
        inCluster?: pulumi.Input<boolean>;
    }
    interface ClusterEncryptionInfoArgs {
        /**
         * The data-volume encryption details.
         */
        encryptionAtRest?: pulumi.Input<inputs.msk.ClusterEncryptionAtRestArgs>;
        /**
         * The details for encryption in transit.
         */
        encryptionInTransit?: pulumi.Input<inputs.msk.ClusterEncryptionInTransitArgs>;
    }
    interface ClusterFirehoseArgs {
        /**
         * The Kinesis Data Firehose delivery stream that is the destination for broker logs.
         */
        deliveryStream?: pulumi.Input<string>;
        /**
         * Specifies whether broker logs get send to the specified Kinesis Data Firehose delivery stream.
         */
        enabled: pulumi.Input<boolean>;
    }
    interface ClusterIamArgs {
        /**
         * SASL/IAM authentication is enabled or not.
         */
        enabled: pulumi.Input<boolean>;
    }
    interface ClusterJmxExporterArgs {
        /**
         * Indicates whether you want to enable or disable the JMX Exporter.
         */
        enabledInBroker: pulumi.Input<boolean>;
    }
    interface ClusterLoggingInfoArgs {
        /**
         * You can configure your MSK cluster to send broker logs to different destination types. This configuration specifies the details of these destinations.
         */
        brokerLogs: pulumi.Input<inputs.msk.ClusterBrokerLogsArgs>;
    }
    interface ClusterNodeExporterArgs {
        /**
         * Indicates whether you want to enable or disable the Node Exporter.
         */
        enabledInBroker: pulumi.Input<boolean>;
    }
    interface ClusterOpenMonitoringArgs {
        /**
         * Prometheus exporter settings.
         */
        prometheus: pulumi.Input<inputs.msk.ClusterPrometheusArgs>;
    }
    interface ClusterPrometheusArgs {
        /**
         * Indicates whether you want to enable or disable the JMX Exporter.
         */
        jmxExporter?: pulumi.Input<inputs.msk.ClusterJmxExporterArgs>;
        /**
         * Indicates whether you want to enable or disable the Node Exporter.
         */
        nodeExporter?: pulumi.Input<inputs.msk.ClusterNodeExporterArgs>;
    }
    interface ClusterProvisionedThroughputArgs {
        /**
         * Provisioned throughput is on or off.
         */
        enabled?: pulumi.Input<boolean>;
        /**
         * Throughput value of the EBS volumes for the data drive on each kafka broker node in MiB per second.
         */
        volumeThroughput?: pulumi.Input<number>;
    }
    interface ClusterPublicAccessArgs {
        /**
         * DISABLED means that public access is turned off. SERVICE_PROVIDED_EIPS means that public access is turned on.
         */
        type?: pulumi.Input<string>;
    }
    interface ClusterS3Args {
        /**
         * The name of the S3 bucket that is the destination for broker logs.
         */
        bucket?: pulumi.Input<string>;
        /**
         * Specifies whether broker logs get sent to the specified Amazon S3 destination.
         */
        enabled: pulumi.Input<boolean>;
        /**
         * The S3 prefix that is the destination for broker logs.
         */
        prefix?: pulumi.Input<string>;
    }
    interface ClusterSaslArgs {
        /**
         * Details for ClientAuthentication using IAM.
         */
        iam?: pulumi.Input<inputs.msk.ClusterIamArgs>;
        /**
         * Details for SASL/SCRAM client authentication.
         */
        scram?: pulumi.Input<inputs.msk.ClusterScramArgs>;
    }
    interface ClusterScramArgs {
        /**
         * SASL/SCRAM authentication is enabled or not.
         */
        enabled: pulumi.Input<boolean>;
    }
    interface ClusterStorageInfoArgs {
        /**
         * EBS volume information.
         */
        ebsStorageInfo?: pulumi.Input<inputs.msk.ClusterEbsStorageInfoArgs>;
    }
    interface ClusterTlsArgs {
        /**
         * List of AWS Private CA ARNs.
         */
        certificateAuthorityArnList?: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * TLS authentication is enabled or not.
         */
        enabled?: pulumi.Input<boolean>;
    }
    interface ClusterUnauthenticatedArgs {
        /**
         * Unauthenticated is enabled or not.
         */
        enabled: pulumi.Input<boolean>;
    }
    interface ClusterVpcConnectivityArgs {
        /**
         * VPC connection control settings for brokers.
         */
        clientAuthentication?: pulumi.Input<inputs.msk.ClusterVpcConnectivityClientAuthenticationArgs>;
    }
    interface ClusterVpcConnectivityClientAuthenticationArgs {
        /**
         * Details for VpcConnectivity ClientAuthentication using SASL.
         */
        sasl?: pulumi.Input<inputs.msk.ClusterVpcConnectivitySaslArgs>;
        /**
         * Details for VpcConnectivity ClientAuthentication using TLS.
         */
        tls?: pulumi.Input<inputs.msk.ClusterVpcConnectivityTlsArgs>;
    }
    interface ClusterVpcConnectivityIamArgs {
        /**
         * SASL/IAM authentication is enabled or not.
         */
        enabled: pulumi.Input<boolean>;
    }
    interface ClusterVpcConnectivitySaslArgs {
        /**
         * Details for ClientAuthentication using IAM for VpcConnectivity.
         */
        iam?: pulumi.Input<inputs.msk.ClusterVpcConnectivityIamArgs>;
        /**
         * Details for SASL/SCRAM client authentication for VpcConnectivity.
         */
        scram?: pulumi.Input<inputs.msk.ClusterVpcConnectivityScramArgs>;
    }
    interface ClusterVpcConnectivityScramArgs {
        /**
         * SASL/SCRAM authentication is enabled or not.
         */
        enabled: pulumi.Input<boolean>;
    }
    interface ClusterVpcConnectivityTlsArgs {
        /**
         * TLS authentication is enabled or not.
         */
        enabled: pulumi.Input<boolean>;
    }
    interface ConfigurationLatestRevisionArgs {
        /**
         * The time when the configuration revision was created.
         */
        creationTime?: pulumi.Input<string>;
        /**
         * The description of the configuration revision.
         */
        description?: pulumi.Input<string>;
        /**
         * The revision number.
         */
        revision?: pulumi.Input<number>;
    }
    /**
     * Details of an Amazon MSK cluster.
     */
    interface ReplicatorAmazonMskClusterArgs {
        /**
         * The ARN of an Amazon MSK cluster.
         */
        mskClusterArn: pulumi.Input<string>;
    }
    /**
     * Configuration relating to consumer group replication.
     */
    interface ReplicatorConsumerGroupReplicationArgs {
        /**
         * List of regular expression patterns indicating the consumer groups that should not be replicated.
         */
        consumerGroupsToExclude?: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * List of regular expression patterns indicating the consumer groups to copy.
         */
        consumerGroupsToReplicate: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * Whether to periodically check for new consumer groups.
         */
        detectAndCopyNewConsumerGroups?: pulumi.Input<boolean>;
        /**
         * Whether to periodically write the translated offsets to __consumer_offsets topic in target cluster.
         */
        synchroniseConsumerGroupOffsets?: pulumi.Input<boolean>;
    }
    /**
     * Details of a Kafka cluster for replication.
     */
    interface ReplicatorKafkaClusterArgs {
        /**
         * Details of an Amazon MSK cluster. Exactly one of AmazonMskCluster is required.
         */
        amazonMskCluster: pulumi.Input<inputs.msk.ReplicatorAmazonMskClusterArgs>;
        /**
         * Details of an Amazon VPC which has network connectivity to the Apache Kafka cluster.
         */
        vpcConfig: pulumi.Input<inputs.msk.ReplicatorKafkaClusterClientVpcConfigArgs>;
    }
    /**
     * Details of an Amazon VPC which has network connectivity to the Kafka cluster.
     */
    interface ReplicatorKafkaClusterClientVpcConfigArgs {
        /**
         * The AWS security groups to associate with the elastic network interfaces in order to specify what the replicator has access to. If a security group is not specified, the default security group associated with the VPC is used.
         */
        securityGroupIds?: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * The list of subnets to connect to in the virtual private cloud (VPC). AWS creates elastic network interfaces inside these subnets.
         */
        subnetIds: pulumi.Input<pulumi.Input<string>[]>;
    }
    /**
     * Specifies configuration for replication between a source and target Kafka cluster.
     */
    interface ReplicatorReplicationInfoArgs {
        /**
         * Configuration relating to consumer group replication.
         */
        consumerGroupReplication: pulumi.Input<inputs.msk.ReplicatorConsumerGroupReplicationArgs>;
        /**
         * Amazon Resource Name of the source Kafka cluster.
         */
        sourceKafkaClusterArn: pulumi.Input<string>;
        /**
         * The type of compression to use writing records to target Kafka cluster.
         */
        targetCompressionType: pulumi.Input<enums.msk.ReplicatorReplicationInfoTargetCompressionType>;
        /**
         * Amazon Resource Name of the target Kafka cluster.
         */
        targetKafkaClusterArn: pulumi.Input<string>;
        /**
         * Configuration relating to topic replication.
         */
        topicReplication: pulumi.Input<inputs.msk.ReplicatorTopicReplicationArgs>;
    }
    /**
     * Configuration for specifying the position in the topics to start replicating from.
     */
    interface ReplicatorReplicationStartingPositionArgs {
        /**
         * The type of replication starting position.
         */
        type?: pulumi.Input<enums.msk.ReplicatorReplicationStartingPositionType>;
    }
    /**
     * Configuration for specifying replicated topic names should be the same as their corresponding upstream topics or prefixed with source cluster alias.
     */
    interface ReplicatorReplicationTopicNameConfigurationArgs {
        /**
         * The type of replication topic name configuration, identical to upstream topic name or prefixed with source cluster alias.
         */
        type?: pulumi.Input<enums.msk.ReplicatorReplicationTopicNameConfigurationType>;
    }
    interface ReplicatorTopicReplicationArgs {
        /**
         * Whether to periodically configure remote topic ACLs to match their corresponding upstream topics.
         */
        copyAccessControlListsForTopics?: pulumi.Input<boolean>;
        /**
         * Whether to periodically configure remote topics to match their corresponding upstream topics.
         */
        copyTopicConfigurations?: pulumi.Input<boolean>;
        /**
         * Whether to periodically check for new topics and partitions.
         */
        detectAndCopyNewTopics?: pulumi.Input<boolean>;
        /**
         * Configuration for specifying the position in the topics to start replicating from.
         */
        startingPosition?: pulumi.Input<inputs.msk.ReplicatorReplicationStartingPositionArgs>;
        /**
         * Configuration for specifying replicated topic names should be the same as their corresponding upstream topics or prefixed with source cluster alias.
         */
        topicNameConfiguration?: pulumi.Input<inputs.msk.ReplicatorReplicationTopicNameConfigurationArgs>;
        /**
         * List of regular expression patterns indicating the topics that should not be replicated.
         */
        topicsToExclude?: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * List of regular expression patterns indicating the topics to copy.
         */
        topicsToReplicate: pulumi.Input<pulumi.Input<string>[]>;
    }
    interface ServerlessClusterClientAuthenticationArgs {
        /**
         * Details for client authentication using SASL. To turn on SASL, you must also turn on `EncryptionInTransit` by setting `inCluster` to true. You must set `clientBroker` to either `TLS` or `TLS_PLAINTEXT` . If you choose `TLS_PLAINTEXT` , then you must also set `unauthenticated` to true.
         */
        sasl: pulumi.Input<inputs.msk.ServerlessClusterSaslArgs>;
    }
    interface ServerlessClusterIamArgs {
        /**
         * SASL/IAM authentication is enabled or not.
         */
        enabled: pulumi.Input<boolean>;
    }
    interface ServerlessClusterSaslArgs {
        /**
         * Details for ClientAuthentication using IAM.
         */
        iam: pulumi.Input<inputs.msk.ServerlessClusterIamArgs>;
    }
    interface ServerlessClusterVpcConfigArgs {
        securityGroups?: pulumi.Input<pulumi.Input<string>[]>;
        subnetIds: pulumi.Input<pulumi.Input<string>[]>;
    }
}
export declare namespace mwaa {
    /**
     * Logging configuration for the environment.
     */
    interface EnvironmentLoggingConfigurationArgs {
        /**
         * Defines the processing logs sent to CloudWatch Logs and the logging level to send.
         */
        dagProcessingLogs?: pulumi.Input<inputs.mwaa.EnvironmentModuleLoggingConfigurationArgs>;
        /**
         * Defines the scheduler logs sent to CloudWatch Logs and the logging level to send.
         */
        schedulerLogs?: pulumi.Input<inputs.mwaa.EnvironmentModuleLoggingConfigurationArgs>;
        /**
         * Defines the task logs sent to CloudWatch Logs and the logging level to send.
         */
        taskLogs?: pulumi.Input<inputs.mwaa.EnvironmentModuleLoggingConfigurationArgs>;
        /**
         * Defines the web server logs sent to CloudWatch Logs and the logging level to send.
         */
        webserverLogs?: pulumi.Input<inputs.mwaa.EnvironmentModuleLoggingConfigurationArgs>;
        /**
         * Defines the worker logs sent to CloudWatch Logs and the logging level to send.
         */
        workerLogs?: pulumi.Input<inputs.mwaa.EnvironmentModuleLoggingConfigurationArgs>;
    }
    /**
     * Logging configuration for a specific airflow component.
     */
    interface EnvironmentModuleLoggingConfigurationArgs {
        /**
         * The ARN of the CloudWatch Logs log group for each type of Apache Airflow log type that you have enabled.
         *
         * > `CloudWatchLogGroupArn` is available only as a return value, accessible when specified as an attribute in the [`Fn:GetAtt`](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-mwaa-environment.html#aws-resource-mwaa-environment-return-values) intrinsic function. Any value you provide for `CloudWatchLogGroupArn` is discarded by Amazon MWAA.
         */
        cloudWatchLogGroupArn?: pulumi.Input<string>;
        /**
         * Indicates whether to enable the Apache Airflow log type (e.g. `DagProcessingLogs` ) in CloudWatch Logs.
         */
        enabled?: pulumi.Input<boolean>;
        /**
         * Defines the Apache Airflow logs to send for the log type (e.g. `DagProcessingLogs` ) to CloudWatch Logs. Valid values: `CRITICAL` , `ERROR` , `WARNING` , `INFO` .
         */
        logLevel?: pulumi.Input<enums.mwaa.EnvironmentLoggingLevel>;
    }
    /**
     * Configures the network resources of the environment.
     */
    interface EnvironmentNetworkConfigurationArgs {
        /**
         * A list of security groups to use for the environment.
         */
        securityGroupIds?: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * A list of subnets to use for the environment. These must be private subnets, in the same VPC, in two different availability zones.
         */
        subnetIds?: pulumi.Input<pulumi.Input<string>[]>;
    }
}
export declare namespace neptune {
    /**
     * Describes an AWS Identity and Access Management (IAM) role that is associated with a DB cluster.
     */
    interface DbClusterDbClusterRoleArgs {
        /**
         * The name of the feature associated with the AWS Identity and Access Management (IAM) role. For the list of supported feature names, see DBEngineVersion in the Amazon Neptune API Reference.
         */
        featureName?: pulumi.Input<string>;
        /**
         * The Amazon Resource Name (ARN) of the IAM role that is associated with the DB cluster.
         */
        roleArn: pulumi.Input<string>;
    }
    /**
     * Contains the scaling configuration of an Neptune Serverless DB cluster.
     */
    interface DbClusterServerlessScalingConfigurationArgs {
        /**
         * The maximum number of Neptune capacity units (NCUs) for a DB instance in an Neptune Serverless cluster. You can specify NCU values in half-step increments, such as 40, 40.5, 41, and so on. The smallest value you can use is 2.5, whereas the largest is 128.
         */
        maxCapacity: pulumi.Input<number>;
        /**
         * The minimum number of Neptune capacity units (NCUs) for a DB instance in an Neptune Serverless cluster. You can specify NCU values in half-step increments, such as 8, 8.5, 9, and so on. The smallest value you can use is 1, whereas the largest is 128.
         */
        minCapacity: pulumi.Input<number>;
    }
}
export declare namespace neptunegraph {
    /**
     * The vector search configuration.
     */
    interface GraphVectorSearchConfigurationArgs {
        /**
         * The vector search dimension
         */
        vectorSearchDimension: pulumi.Input<number>;
    }
}
export declare namespace networkfirewall {
    interface FirewallPolicyArgs {
        /**
         * Contains variables that you can use to override default Suricata settings in your firewall policy.
         */
        policyVariables?: pulumi.Input<inputs.networkfirewall.FirewallPolicyPolicyVariablesPropertiesArgs>;
        /**
         * The default actions to take on a packet that doesn't match any stateful rules. The stateful default action is optional, and is only valid when using the strict rule order.
         *
         * Valid values of the stateful default action:
         *
         * - aws:drop_strict
         * - aws:drop_established
         * - aws:alert_strict
         * - aws:alert_established
         *
         * For more information, see [Strict evaluation order](https://docs.aws.amazon.com/network-firewall/latest/developerguide/suricata-rule-evaluation-order.html#suricata-strict-rule-evaluation-order.html) in the *AWS Network Firewall Developer Guide* .
         */
        statefulDefaultActions?: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * Additional options governing how Network Firewall handles stateful rules. The stateful rule groups that you use in your policy must have stateful rule options settings that are compatible with these settings.
         */
        statefulEngineOptions?: pulumi.Input<inputs.networkfirewall.FirewallPolicyStatefulEngineOptionsArgs>;
        /**
         * References to the stateful rule groups that are used in the policy. These define the inspection criteria in stateful rules.
         */
        statefulRuleGroupReferences?: pulumi.Input<pulumi.Input<inputs.networkfirewall.FirewallPolicyStatefulRuleGroupReferenceArgs>[]>;
        /**
         * The custom action definitions that are available for use in the firewall policy's `StatelessDefaultActions` setting. You name each custom action that you define, and then you can use it by name in your default actions specifications.
         */
        statelessCustomActions?: pulumi.Input<pulumi.Input<inputs.networkfirewall.FirewallPolicyCustomActionArgs>[]>;
        /**
         * The actions to take on a packet if it doesn't match any of the stateless rules in the policy. If you want non-matching packets to be forwarded for stateful inspection, specify `aws:forward_to_sfe` .
         *
         * You must specify one of the standard actions: `aws:pass` , `aws:drop` , or `aws:forward_to_sfe` . In addition, you can specify custom actions that are compatible with your standard section choice.
         *
         * For example, you could specify `["aws:pass"]` or you could specify `["aws:pass", "customActionName"]` . For information about compatibility, see the custom action descriptions.
         */
        statelessDefaultActions: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * The actions to take on a fragmented packet if it doesn't match any of the stateless rules in the policy. If you want non-matching fragmented packets to be forwarded for stateful inspection, specify `aws:forward_to_sfe` .
         *
         * You must specify one of the standard actions: `aws:pass` , `aws:drop` , or `aws:forward_to_sfe` . In addition, you can specify custom actions that are compatible with your standard section choice.
         *
         * For example, you could specify `["aws:pass"]` or you could specify `["aws:pass", "customActionName"]` . For information about compatibility, see the custom action descriptions.
         */
        statelessFragmentDefaultActions: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * References to the stateless rule groups that are used in the policy. These define the matching criteria in stateless rules.
         */
        statelessRuleGroupReferences?: pulumi.Input<pulumi.Input<inputs.networkfirewall.FirewallPolicyStatelessRuleGroupReferenceArgs>[]>;
        /**
         * The Amazon Resource Name (ARN) of the TLS inspection configuration.
         */
        tlsInspectionConfigurationArn?: pulumi.Input<string>;
    }
    interface FirewallPolicyActionDefinitionArgs {
        /**
         * Stateless inspection criteria that publishes the specified metrics to Amazon CloudWatch for the matching packet. This setting defines a CloudWatch dimension value to be published.
         *
         * You can pair this custom action with any of the standard stateless rule actions. For example, you could pair this in a rule action with the standard action that forwards the packet for stateful inspection. Then, when a packet matches the rule, Network Firewall publishes metrics for the packet and forwards it.
         */
        publishMetricAction?: pulumi.Input<inputs.networkfirewall.FirewallPolicyPublishMetricActionArgs>;
    }
    interface FirewallPolicyCustomActionArgs {
        /**
         * The custom action associated with the action name.
         */
        actionDefinition: pulumi.Input<inputs.networkfirewall.FirewallPolicyActionDefinitionArgs>;
        /**
         * The descriptive name of the custom action. You can't change the name of a custom action after you create it.
         */
        actionName: pulumi.Input<string>;
    }
    interface FirewallPolicyDimensionArgs {
        /**
         * The value to use in the custom metric dimension.
         */
        value: pulumi.Input<string>;
    }
    interface FirewallPolicyIpSetArgs {
        /**
         * The list of IP addresses and address ranges, in CIDR notation.
         */
        definition?: pulumi.Input<pulumi.Input<string>[]>;
    }
    /**
     * Contains variables that you can use to override default Suricata settings in your firewall policy.
     */
    interface FirewallPolicyPolicyVariablesPropertiesArgs {
        ruleVariables?: pulumi.Input<{
            [key: string]: pulumi.Input<inputs.networkfirewall.FirewallPolicyIpSetArgs>;
        }>;
    }
    interface FirewallPolicyPublishMetricActionArgs {
        dimensions: pulumi.Input<pulumi.Input<inputs.networkfirewall.FirewallPolicyDimensionArgs>[]>;
    }
    interface FirewallPolicyStatefulEngineOptionsArgs {
        /**
         * Configures the amount of time that can pass without any traffic sent through the firewall before the firewall determines that the connection is idle.
         */
        flowTimeouts?: pulumi.Input<inputs.networkfirewall.FirewallPolicyStatefulEngineOptionsFlowTimeoutsPropertiesArgs>;
        /**
         * Indicates how to manage the order of stateful rule evaluation for the policy. `DEFAULT_ACTION_ORDER` is the default behavior. Stateful rules are provided to the rule engine as Suricata compatible strings, and Suricata evaluates them based on certain settings. For more information, see [Evaluation order for stateful rules](https://docs.aws.amazon.com/network-firewall/latest/developerguide/suricata-rule-evaluation-order.html) in the *AWS Network Firewall Developer Guide* .
         */
        ruleOrder?: pulumi.Input<enums.networkfirewall.FirewallPolicyRuleOrder>;
        /**
         * Configures how Network Firewall processes traffic when a network connection breaks midstream. Network connections can break due to disruptions in external networks or within the firewall itself.
         *
         * - `DROP` - Network Firewall fails closed and drops all subsequent traffic going to the firewall. This is the default behavior.
         * - `CONTINUE` - Network Firewall continues to apply rules to the subsequent traffic without context from traffic before the break. This impacts the behavior of rules that depend on this context. For example, if you have a stateful rule to `drop http` traffic, Network Firewall won't match the traffic for this rule because the service won't have the context from session initialization defining the application layer protocol as HTTP. However, this behavior is rule dependent—a TCP-layer rule using a `flow:stateless` rule would still match, as would the `aws:drop_strict` default action.
         * - `REJECT` - Network Firewall fails closed and drops all subsequent traffic going to the firewall. Network Firewall also sends a TCP reject packet back to your client so that the client can immediately establish a new session. Network Firewall will have context about the new session and will apply rules to the subsequent traffic.
         */
        streamExceptionPolicy?: pulumi.Input<enums.networkfirewall.FirewallPolicyStreamExceptionPolicy>;
    }
    /**
     * Configures the amount of time that can pass without any traffic sent through the firewall before the firewall determines that the connection is idle.
     */
    interface FirewallPolicyStatefulEngineOptionsFlowTimeoutsPropertiesArgs {
        tcpIdleTimeoutSeconds?: pulumi.Input<number>;
    }
    interface FirewallPolicyStatefulRuleGroupOverrideArgs {
        /**
         * The action that changes the rule group from `DROP` to `ALERT` . This only applies to managed rule groups.
         */
        action?: pulumi.Input<enums.networkfirewall.FirewallPolicyOverrideAction>;
    }
    interface FirewallPolicyStatefulRuleGroupReferenceArgs {
        /**
         * The action that allows the policy owner to override the behavior of the rule group within a policy.
         */
        override?: pulumi.Input<inputs.networkfirewall.FirewallPolicyStatefulRuleGroupOverrideArgs>;
        /**
         * An integer setting that indicates the order in which to run the stateful rule groups in a single `FirewallPolicy` . This setting only applies to firewall policies that specify the `STRICT_ORDER` rule order in the stateful engine options settings.
         *
         * Network Firewall evalutes each stateful rule group against a packet starting with the group that has the lowest priority setting. You must ensure that the priority settings are unique within each policy.
         *
         * You can change the priority settings of your rule groups at any time. To make it easier to insert rule groups later, number them so there's a wide range in between, for example use 100, 200, and so on.
         */
        priority?: pulumi.Input<number>;
        /**
         * The Amazon Resource Name (ARN) of the stateful rule group.
         */
        resourceArn: pulumi.Input<string>;
    }
    interface FirewallPolicyStatelessRuleGroupReferenceArgs {
        /**
         * An integer setting that indicates the order in which to run the stateless rule groups in a single `FirewallPolicy` . Network Firewall applies each stateless rule group to a packet starting with the group that has the lowest priority setting. You must ensure that the priority settings are unique within each policy.
         */
        priority: pulumi.Input<number>;
        /**
         * The Amazon Resource Name (ARN) of the stateless rule group.
         */
        resourceArn: pulumi.Input<string>;
    }
    interface FirewallSubnetMappingArgs {
        /**
         * A IPAddressType
         */
        ipAddressType?: pulumi.Input<string>;
        /**
         * A SubnetId.
         */
        subnetId: pulumi.Input<string>;
    }
    interface LoggingConfigurationArgs {
        /**
         * Defines the logging destinations for the logs for a firewall. Network Firewall generates logs for stateful rule groups.
         */
        logDestinationConfigs: pulumi.Input<pulumi.Input<inputs.networkfirewall.LoggingConfigurationLogDestinationConfigArgs>[]>;
    }
    interface LoggingConfigurationLogDestinationConfigArgs {
        /**
         * A key-value pair to configure the logDestinations.
         */
        logDestination: pulumi.Input<{
            [key: string]: pulumi.Input<string>;
        }>;
        /**
         * The type of storage destination to send these logs to. You can send logs to an Amazon S3 bucket, a CloudWatch log group, or a Firehose delivery stream.
         */
        logDestinationType: pulumi.Input<enums.networkfirewall.LoggingConfigurationLogDestinationConfigLogDestinationType>;
        /**
         * The type of log to record. You can record the following types of logs from your Network Firewall stateful engine.
         *
         * - `ALERT` - Logs for traffic that matches your stateful rules and that have an action that sends an alert. A stateful rule sends alerts for the rule actions DROP, ALERT, and REJECT. For more information, see the `StatefulRule` property.
         * - `FLOW` - Standard network traffic flow logs. The stateful rules engine records flow logs for all network traffic that it receives. Each flow log record captures the network flow for a specific standard stateless rule group.
         * - `TLS` - Logs for events that are related to TLS inspection. For more information, see [Inspecting SSL/TLS traffic with TLS inspection configurations](https://docs.aws.amazon.com/network-firewall/latest/developerguide/tls-inspection-configurations.html) in the *Network Firewall Developer Guide* .
         */
        logType: pulumi.Input<enums.networkfirewall.LoggingConfigurationLogDestinationConfigLogType>;
    }
    interface RuleGroupArgs {
        /**
         * The reference sets for the stateful rule group.
         */
        referenceSets?: pulumi.Input<inputs.networkfirewall.RuleGroupReferenceSetsArgs>;
        /**
         * Settings that are available for use in the rules in the rule group. You can only use these for stateful rule groups.
         */
        ruleVariables?: pulumi.Input<inputs.networkfirewall.RuleGroupRuleVariablesArgs>;
        /**
         * The stateful rules or stateless rules for the rule group.
         */
        rulesSource: pulumi.Input<inputs.networkfirewall.RuleGroupRulesSourceArgs>;
        /**
         * Additional options governing how Network Firewall handles stateful rules. The policies where you use your stateful rule group must have stateful rule options settings that are compatible with these settings. Some limitations apply; for more information, see [Strict evaluation order](https://docs.aws.amazon.com/network-firewall/latest/developerguide/suricata-limitations-caveats.html) in the *AWS Network Firewall Developer Guide* .
         */
        statefulRuleOptions?: pulumi.Input<inputs.networkfirewall.RuleGroupStatefulRuleOptionsArgs>;
    }
    interface RuleGroupActionDefinitionArgs {
        /**
         * Stateless inspection criteria that publishes the specified metrics to Amazon CloudWatch for the matching packet. This setting defines a CloudWatch dimension value to be published.
         *
         * You can pair this custom action with any of the standard stateless rule actions. For example, you could pair this in a rule action with the standard action that forwards the packet for stateful inspection. Then, when a packet matches the rule, Network Firewall publishes metrics for the packet and forwards it.
         */
        publishMetricAction?: pulumi.Input<inputs.networkfirewall.RuleGroupPublishMetricActionArgs>;
    }
    interface RuleGroupAddressArgs {
        /**
         * Specify an IP address or a block of IP addresses in Classless Inter-Domain Routing (CIDR) notation. Network Firewall supports all address ranges for IPv4 and IPv6.
         *
         * Examples:
         *
         * - To configure Network Firewall to inspect for the IP address 192.0.2.44, specify `192.0.2.44/32` .
         * - To configure Network Firewall to inspect for IP addresses from 192.0.2.0 to 192.0.2.255, specify `192.0.2.0/24` .
         * - To configure Network Firewall to inspect for the IP address 1111:0000:0000:0000:0000:0000:0000:0111, specify `1111:0000:0000:0000:0000:0000:0000:0111/128` .
         * - To configure Network Firewall to inspect for IP addresses from 1111:0000:0000:0000:0000:0000:0000:0000 to 1111:0000:0000:0000:ffff:ffff:ffff:ffff, specify `1111:0000:0000:0000:0000:0000:0000:0000/64` .
         *
         * For more information about CIDR notation, see the Wikipedia entry [Classless Inter-Domain Routing](https://docs.aws.amazon.com/https://en.wikipedia.org/wiki/Classless_Inter-Domain_Routing) .
         */
        addressDefinition: pulumi.Input<string>;
    }
    interface RuleGroupCustomActionArgs {
        /**
         * The custom action associated with the action name.
         */
        actionDefinition: pulumi.Input<inputs.networkfirewall.RuleGroupActionDefinitionArgs>;
        /**
         * The descriptive name of the custom action. You can't change the name of a custom action after you create it.
         */
        actionName: pulumi.Input<string>;
    }
    interface RuleGroupDimensionArgs {
        /**
         * The value to use in the custom metric dimension.
         */
        value: pulumi.Input<string>;
    }
    interface RuleGroupHeaderArgs {
        /**
         * The destination IP address or address range to inspect for, in CIDR notation. To match with any address, specify `ANY` .
         *
         * Specify an IP address or a block of IP addresses in Classless Inter-Domain Routing (CIDR) notation. Network Firewall supports all address ranges for IPv4 and IPv6.
         *
         * Examples:
         *
         * - To configure Network Firewall to inspect for the IP address 192.0.2.44, specify `192.0.2.44/32` .
         * - To configure Network Firewall to inspect for IP addresses from 192.0.2.0 to 192.0.2.255, specify `192.0.2.0/24` .
         * - To configure Network Firewall to inspect for the IP address 1111:0000:0000:0000:0000:0000:0000:0111, specify `1111:0000:0000:0000:0000:0000:0000:0111/128` .
         * - To configure Network Firewall to inspect for IP addresses from 1111:0000:0000:0000:0000:0000:0000:0000 to 1111:0000:0000:0000:ffff:ffff:ffff:ffff, specify `1111:0000:0000:0000:0000:0000:0000:0000/64` .
         *
         * For more information about CIDR notation, see the Wikipedia entry [Classless Inter-Domain Routing](https://docs.aws.amazon.com/https://en.wikipedia.org/wiki/Classless_Inter-Domain_Routing) .
         */
        destination: pulumi.Input<string>;
        /**
         * The destination port to inspect for. You can specify an individual port, for example `1994` and you can specify a port range, for example `1990:1994` . To match with any port, specify `ANY` .
         */
        destinationPort: pulumi.Input<string>;
        /**
         * The direction of traffic flow to inspect. If set to `ANY` , the inspection matches bidirectional traffic, both from the source to the destination and from the destination to the source. If set to `FORWARD` , the inspection only matches traffic going from the source to the destination.
         */
        direction: pulumi.Input<enums.networkfirewall.RuleGroupHeaderDirection>;
        /**
         * The protocol to inspect for. To specify all, you can use `IP` , because all traffic on AWS and on the internet is IP.
         */
        protocol: pulumi.Input<enums.networkfirewall.RuleGroupHeaderProtocol>;
        /**
         * The source IP address or address range to inspect for, in CIDR notation. To match with any address, specify `ANY` .
         *
         * Specify an IP address or a block of IP addresses in Classless Inter-Domain Routing (CIDR) notation. Network Firewall supports all address ranges for IPv4 and IPv6.
         *
         * Examples:
         *
         * - To configure Network Firewall to inspect for the IP address 192.0.2.44, specify `192.0.2.44/32` .
         * - To configure Network Firewall to inspect for IP addresses from 192.0.2.0 to 192.0.2.255, specify `192.0.2.0/24` .
         * - To configure Network Firewall to inspect for the IP address 1111:0000:0000:0000:0000:0000:0000:0111, specify `1111:0000:0000:0000:0000:0000:0000:0111/128` .
         * - To configure Network Firewall to inspect for IP addresses from 1111:0000:0000:0000:0000:0000:0000:0000 to 1111:0000:0000:0000:ffff:ffff:ffff:ffff, specify `1111:0000:0000:0000:0000:0000:0000:0000/64` .
         *
         * For more information about CIDR notation, see the Wikipedia entry [Classless Inter-Domain Routing](https://docs.aws.amazon.com/https://en.wikipedia.org/wiki/Classless_Inter-Domain_Routing) .
         */
        source: pulumi.Input<string>;
        /**
         * The source port to inspect for. You can specify an individual port, for example `1994` and you can specify a port range, for example `1990:1994` . To match with any port, specify `ANY` .
         */
        sourcePort: pulumi.Input<string>;
    }
    interface RuleGroupIpSetArgs {
        definition?: pulumi.Input<pulumi.Input<string>[]>;
    }
    interface RuleGroupIpSetReferenceArgs {
        referenceArn?: pulumi.Input<string>;
    }
    interface RuleGroupMatchAttributesArgs {
        /**
         * The destination port to inspect for. You can specify an individual port, for example `1994` and you can specify a port range, for example `1990:1994` . To match with any port, specify `ANY` .
         *
         * This setting is only used for protocols 6 (TCP) and 17 (UDP).
         */
        destinationPorts?: pulumi.Input<pulumi.Input<inputs.networkfirewall.RuleGroupPortRangeArgs>[]>;
        /**
         * The destination IP addresses and address ranges to inspect for, in CIDR notation. If not specified, this matches with any destination address.
         */
        destinations?: pulumi.Input<pulumi.Input<inputs.networkfirewall.RuleGroupAddressArgs>[]>;
        /**
         * The protocols to inspect for, specified using the assigned internet protocol number (IANA) for each protocol. If not specified, this matches with any protocol.
         */
        protocols?: pulumi.Input<pulumi.Input<number>[]>;
        /**
         * The source port to inspect for. You can specify an individual port, for example `1994` and you can specify a port range, for example `1990:1994` . To match with any port, specify `ANY` .
         *
         * If not specified, this matches with any source port.
         *
         * This setting is only used for protocols 6 (TCP) and 17 (UDP).
         */
        sourcePorts?: pulumi.Input<pulumi.Input<inputs.networkfirewall.RuleGroupPortRangeArgs>[]>;
        /**
         * The source IP addresses and address ranges to inspect for, in CIDR notation. If not specified, this matches with any source address.
         */
        sources?: pulumi.Input<pulumi.Input<inputs.networkfirewall.RuleGroupAddressArgs>[]>;
        /**
         * The TCP flags and masks to inspect for. If not specified, this matches with any settings. This setting is only used for protocol 6 (TCP).
         */
        tcpFlags?: pulumi.Input<pulumi.Input<inputs.networkfirewall.RuleGroupTcpFlagFieldArgs>[]>;
    }
    interface RuleGroupPortRangeArgs {
        /**
         * The lower limit of the port range. This must be less than or equal to the `ToPort` specification.
         */
        fromPort: pulumi.Input<number>;
        /**
         * The upper limit of the port range. This must be greater than or equal to the `FromPort` specification.
         */
        toPort: pulumi.Input<number>;
    }
    interface RuleGroupPortSetArgs {
        definition?: pulumi.Input<pulumi.Input<string>[]>;
    }
    interface RuleGroupPublishMetricActionArgs {
        dimensions: pulumi.Input<pulumi.Input<inputs.networkfirewall.RuleGroupDimensionArgs>[]>;
    }
    interface RuleGroupReferenceSetsArgs {
        /**
         * The IP set references to use in the stateful rule group.
         */
        ipSetReferences?: pulumi.Input<{
            [key: string]: pulumi.Input<inputs.networkfirewall.RuleGroupIpSetReferenceArgs>;
        }>;
    }
    interface RuleGroupRuleDefinitionArgs {
        /**
         * The actions to take on a packet that matches one of the stateless rule definition's match attributes. You must specify a standard action and you can add custom actions.
         *
         * > Network Firewall only forwards a packet for stateful rule inspection if you specify `aws:forward_to_sfe` for a rule that the packet matches, or if the packet doesn't match any stateless rule and you specify `aws:forward_to_sfe` for the `StatelessDefaultActions` setting for the `FirewallPolicy` .
         *
         * For every rule, you must specify exactly one of the following standard actions.
         *
         * - *aws:pass* - Discontinues all inspection of the packet and permits it to go to its intended destination.
         * - *aws:drop* - Discontinues all inspection of the packet and blocks it from going to its intended destination.
         * - *aws:forward_to_sfe* - Discontinues stateless inspection of the packet and forwards it to the stateful rule engine for inspection.
         *
         * Additionally, you can specify a custom action. To do this, you define a custom action by name and type, then provide the name you've assigned to the action in this `Actions` setting.
         *
         * To provide more than one action in this setting, separate the settings with a comma. For example, if you have a publish metrics custom action that you've named `MyMetricsAction` , then you could specify the standard action `aws:pass` combined with the custom action using `["aws:pass", "MyMetricsAction"]` .
         */
        actions: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * Criteria for Network Firewall to use to inspect an individual packet in stateless rule inspection. Each match attributes set can include one or more items such as IP address, CIDR range, port number, protocol, and TCP flags.
         */
        matchAttributes: pulumi.Input<inputs.networkfirewall.RuleGroupMatchAttributesArgs>;
    }
    interface RuleGroupRuleOptionArgs {
        /**
         * The Suricata rule option keywords. For Network Firewall , the keyword signature ID (sid) is required in the format `sid:112233` . The sid must be unique within the rule group. For information about Suricata rule option keywords, see [Rule options](https://docs.aws.amazon.com/https://suricata.readthedocs.io/en/suricata-6.0.9/rules/intro.html#rule-options) .
         */
        keyword: pulumi.Input<string>;
        /**
         * The Suricata rule option settings. Settings have zero or more values, and the number of possible settings and required settings depends on the keyword. The format for Settings is `number` . For information about Suricata rule option settings, see [Rule options](https://docs.aws.amazon.com/https://suricata.readthedocs.io/en/suricata-6.0.9/rules/intro.html#rule-options) .
         */
        settings?: pulumi.Input<pulumi.Input<string>[]>;
    }
    interface RuleGroupRuleVariablesArgs {
        /**
         * A list of IP addresses and address ranges, in CIDR notation.
         */
        ipSets?: pulumi.Input<{
            [key: string]: pulumi.Input<inputs.networkfirewall.RuleGroupIpSetArgs>;
        }>;
        /**
         * A list of port ranges.
         */
        portSets?: pulumi.Input<{
            [key: string]: pulumi.Input<inputs.networkfirewall.RuleGroupPortSetArgs>;
        }>;
    }
    interface RuleGroupRulesSourceArgs {
        /**
         * Stateful inspection criteria for a domain list rule group.
         */
        rulesSourceList?: pulumi.Input<inputs.networkfirewall.RuleGroupRulesSourceListArgs>;
        /**
         * Stateful inspection criteria, provided in Suricata compatible rules. Suricata is an open-source threat detection framework that includes a standard rule-based language for network traffic inspection.
         *
         * These rules contain the inspection criteria and the action to take for traffic that matches the criteria, so this type of rule group doesn't have a separate action setting.
         *
         * > You can't use the `priority` keyword if the `RuleOrder` option in `StatefulRuleOptions` is set to `STRICT_ORDER` .
         */
        rulesString?: pulumi.Input<string>;
        /**
         * An array of individual stateful rules inspection criteria to be used together in a stateful rule group. Use this option to specify simple Suricata rules with protocol, source and destination, ports, direction, and rule options. For information about the Suricata `Rules` format, see [Rules Format](https://docs.aws.amazon.com/https://suricata.readthedocs.io/en/suricata-7.0.3/rules/intro.html) .
         */
        statefulRules?: pulumi.Input<pulumi.Input<inputs.networkfirewall.RuleGroupStatefulRuleArgs>[]>;
        /**
         * Stateless inspection criteria to be used in a stateless rule group.
         */
        statelessRulesAndCustomActions?: pulumi.Input<inputs.networkfirewall.RuleGroupStatelessRulesAndCustomActionsArgs>;
    }
    interface RuleGroupRulesSourceListArgs {
        /**
         * Whether you want to allow or deny access to the domains in your target list.
         */
        generatedRulesType: pulumi.Input<enums.networkfirewall.RuleGroupGeneratedRulesType>;
        /**
         * The types of targets to inspect for. Valid values are `TLS_SNI` and `HTTP_HOST` .
         */
        targetTypes: pulumi.Input<pulumi.Input<enums.networkfirewall.RuleGroupTargetType>[]>;
        /**
         * The domains that you want to inspect for in your traffic flows. Valid domain specifications are the following:
         *
         * - Explicit names. For example, `abc.example.com` matches only the domain `abc.example.com` .
         * - Names that use a domain wildcard, which you indicate with an initial ' `.` '. For example, `.example.com` matches `example.com` and matches all subdomains of `example.com` , such as `abc.example.com` and `www.example.com` .
         */
        targets: pulumi.Input<pulumi.Input<string>[]>;
    }
    interface RuleGroupStatefulRuleArgs {
        /**
         * Defines what Network Firewall should do with the packets in a traffic flow when the flow matches the stateful rule criteria. For all actions, Network Firewall performs the specified action and discontinues stateful inspection of the traffic flow.
         *
         * The actions for a stateful rule are defined as follows:
         *
         * - *PASS* - Permits the packets to go to the intended destination.
         * - *DROP* - Blocks the packets from going to the intended destination and sends an alert log message, if alert logging is configured in the `Firewall` `LoggingConfiguration` .
         * - *REJECT* - Drops traffic that matches the conditions of the stateful rule and sends a TCP reset packet back to sender of the packet. A TCP reset packet is a packet with no payload and a `RST` bit contained in the TCP header flags. `REJECT` is available only for TCP traffic.
         * - *ALERT* - Permits the packets to go to the intended destination and sends an alert log message, if alert logging is configured in the `Firewall` `LoggingConfiguration` .
         *
         * You can use this action to test a rule that you intend to use to drop traffic. You can enable the rule with `ALERT` action, verify in the logs that the rule is filtering as you want, then change the action to `DROP` .
         * - *REJECT* - Drops TCP traffic that matches the conditions of the stateful rule, and sends a TCP reset packet back to sender of the packet. A TCP reset packet is a packet with no payload and a `RST` bit contained in the TCP header flags. Also sends an alert log mesage if alert logging is configured in the `Firewall` `LoggingConfiguration` .
         *
         * `REJECT` isn't currently available for use with IMAP and FTP protocols.
         */
        action: pulumi.Input<enums.networkfirewall.RuleGroupStatefulRuleAction>;
        /**
         * The stateful inspection criteria for this rule, used to inspect traffic flows.
         */
        header: pulumi.Input<inputs.networkfirewall.RuleGroupHeaderArgs>;
        /**
         * Additional settings for a stateful rule, provided as keywords and settings.
         */
        ruleOptions: pulumi.Input<pulumi.Input<inputs.networkfirewall.RuleGroupRuleOptionArgs>[]>;
    }
    interface RuleGroupStatefulRuleOptionsArgs {
        /**
         * Indicates how to manage the order of the rule evaluation for the rule group. `DEFAULT_ACTION_ORDER` is the default behavior. Stateful rules are provided to the rule engine as Suricata compatible strings, and Suricata evaluates them based on certain settings. For more information, see [Evaluation order for stateful rules](https://docs.aws.amazon.com/network-firewall/latest/developerguide/suricata-rule-evaluation-order.html) in the *AWS Network Firewall Developer Guide* .
         */
        ruleOrder?: pulumi.Input<enums.networkfirewall.RuleGroupRuleOrder>;
    }
    interface RuleGroupStatelessRuleArgs {
        /**
         * Indicates the order in which to run this rule relative to all of the rules that are defined for a stateless rule group. Network Firewall evaluates the rules in a rule group starting with the lowest priority setting. You must ensure that the priority settings are unique for the rule group.
         *
         * Each stateless rule group uses exactly one `StatelessRulesAndCustomActions` object, and each `StatelessRulesAndCustomActions` contains exactly one `StatelessRules` object. To ensure unique priority settings for your rule groups, set unique priorities for the stateless rules that you define inside any single `StatelessRules` object.
         *
         * You can change the priority settings of your rules at any time. To make it easier to insert rules later, number them so there's a wide range in between, for example use 100, 200, and so on.
         */
        priority: pulumi.Input<number>;
        /**
         * Defines the stateless 5-tuple packet inspection criteria and the action to take on a packet that matches the criteria.
         */
        ruleDefinition: pulumi.Input<inputs.networkfirewall.RuleGroupRuleDefinitionArgs>;
    }
    interface RuleGroupStatelessRulesAndCustomActionsArgs {
        /**
         * Defines an array of individual custom action definitions that are available for use by the stateless rules in this `StatelessRulesAndCustomActions` specification. You name each custom action that you define, and then you can use it by name in your stateless rule `RuleGroup.RuleDefinition` `Actions` specification.
         */
        customActions?: pulumi.Input<pulumi.Input<inputs.networkfirewall.RuleGroupCustomActionArgs>[]>;
        /**
         * Defines the set of stateless rules for use in a stateless rule group.
         */
        statelessRules: pulumi.Input<pulumi.Input<inputs.networkfirewall.RuleGroupStatelessRuleArgs>[]>;
    }
    interface RuleGroupTcpFlagFieldArgs {
        /**
         * Used in conjunction with the `Masks` setting to define the flags that must be set and flags that must not be set in order for the packet to match. This setting can only specify values that are also specified in the `Masks` setting.
         *
         * For the flags that are specified in the masks setting, the following must be true for the packet to match:
         *
         * - The ones that are set in this flags setting must be set in the packet.
         * - The ones that are not set in this flags setting must also not be set in the packet.
         */
        flags: pulumi.Input<pulumi.Input<enums.networkfirewall.RuleGroupTcpFlag>[]>;
        /**
         * The set of flags to consider in the inspection. To inspect all flags in the valid values list, leave this with no setting.
         */
        masks?: pulumi.Input<pulumi.Input<enums.networkfirewall.RuleGroupTcpFlag>[]>;
    }
    interface TlsInspectionConfigurationAddressArgs {
        /**
         * Specify an IP address or a block of IP addresses in Classless Inter-Domain Routing (CIDR) notation. Network Firewall supports all address ranges for IPv4 and IPv6.
         *
         * Examples:
         *
         * - To configure Network Firewall to inspect for the IP address 192.0.2.44, specify `192.0.2.44/32` .
         * - To configure Network Firewall to inspect for IP addresses from 192.0.2.0 to 192.0.2.255, specify `192.0.2.0/24` .
         * - To configure Network Firewall to inspect for the IP address 1111:0000:0000:0000:0000:0000:0000:0111, specify `1111:0000:0000:0000:0000:0000:0000:0111/128` .
         * - To configure Network Firewall to inspect for IP addresses from 1111:0000:0000:0000:0000:0000:0000:0000 to 1111:0000:0000:0000:ffff:ffff:ffff:ffff, specify `1111:0000:0000:0000:0000:0000:0000:0000/64` .
         *
         * For more information about CIDR notation, see the Wikipedia entry [Classless Inter-Domain Routing](https://docs.aws.amazon.com/https://en.wikipedia.org/wiki/Classless_Inter-Domain_Routing) .
         */
        addressDefinition: pulumi.Input<string>;
    }
    interface TlsInspectionConfigurationPortRangeArgs {
        /**
         * The lower limit of the port range. This must be less than or equal to the `ToPort` specification.
         */
        fromPort: pulumi.Input<number>;
        /**
         * The upper limit of the port range. This must be greater than or equal to the `FromPort` specification.
         */
        toPort: pulumi.Input<number>;
    }
    interface TlsInspectionConfigurationServerCertificateArgs {
        /**
         * The Amazon Resource Name (ARN) of the AWS Certificate Manager SSL/TLS server certificate that's used for inbound SSL/TLS inspection.
         */
        resourceArn?: pulumi.Input<string>;
    }
    interface TlsInspectionConfigurationServerCertificateConfigurationArgs {
        /**
         * The Amazon Resource Name (ARN) of the imported certificate authority (CA) certificate within AWS Certificate Manager (ACM) to use for outbound SSL/TLS inspection.
         *
         * The following limitations apply:
         *
         * - You can use CA certificates that you imported into ACM, but you can't generate CA certificates with ACM.
         * - You can't use certificates issued by AWS Private Certificate Authority .
         *
         * For more information about configuring certificates for outbound inspection, see [Using SSL/TLS certificates with certificates with TLS inspection configurations](https://docs.aws.amazon.com/network-firewall/latest/developerguide/tls-inspection-certificate-requirements.html) in the *AWS Network Firewall Developer Guide* .
         *
         * For information about working with certificates in ACM, see [Importing certificates](https://docs.aws.amazon.com/acm/latest/userguide/import-certificate.html) in the *AWS Certificate Manager User Guide* .
         */
        certificateAuthorityArn?: pulumi.Input<string>;
        /**
         * When enabled, Network Firewall checks if the server certificate presented by the server in the SSL/TLS connection has a revoked or unkown status. If the certificate has an unknown or revoked status, you must specify the actions that Network Firewall takes on outbound traffic. To check the certificate revocation status, you must also specify a `CertificateAuthorityArn` in [ServerCertificateConfiguration](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-networkfirewall-servercertificateconfiguration.html) .
         */
        checkCertificateRevocationStatus?: pulumi.Input<inputs.networkfirewall.TlsInspectionConfigurationServerCertificateConfigurationCheckCertificateRevocationStatusPropertiesArgs>;
        /**
         * A list of scopes.
         */
        scopes?: pulumi.Input<pulumi.Input<inputs.networkfirewall.TlsInspectionConfigurationServerCertificateScopeArgs>[]>;
        /**
         * The list of server certificates to use for inbound SSL/TLS inspection.
         */
        serverCertificates?: pulumi.Input<pulumi.Input<inputs.networkfirewall.TlsInspectionConfigurationServerCertificateArgs>[]>;
    }
    /**
     * When enabled, Network Firewall checks if the server certificate presented by the server in the SSL/TLS connection has a revoked or unkown status. If the certificate has an unknown or revoked status, you must specify the actions that Network Firewall takes on outbound traffic. To check the certificate revocation status, you must also specify a `CertificateAuthorityArn` in [ServerCertificateConfiguration](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-networkfirewall-servercertificateconfiguration.html) .
     */
    interface TlsInspectionConfigurationServerCertificateConfigurationCheckCertificateRevocationStatusPropertiesArgs {
        revokedStatusAction?: pulumi.Input<enums.networkfirewall.TlsInspectionConfigurationRevokedStatusAction>;
        unknownStatusAction?: pulumi.Input<enums.networkfirewall.TlsInspectionConfigurationUnknownStatusAction>;
    }
    interface TlsInspectionConfigurationServerCertificateScopeArgs {
        /**
         * The destination ports to decrypt for inspection, in Transmission Control Protocol (TCP) format. If not specified, this matches with any destination port.
         *
         * You can specify individual ports, for example `1994` , and you can specify port ranges, such as `1990:1994` .
         */
        destinationPorts?: pulumi.Input<pulumi.Input<inputs.networkfirewall.TlsInspectionConfigurationPortRangeArgs>[]>;
        /**
         * The destination IP addresses and address ranges to decrypt for inspection, in CIDR notation. If not specified, this
         * matches with any destination address.
         */
        destinations?: pulumi.Input<pulumi.Input<inputs.networkfirewall.TlsInspectionConfigurationAddressArgs>[]>;
        /**
         * The protocols to inspect for, specified using the assigned internet protocol number (IANA) for each protocol. If not specified, this matches with any protocol.
         *
         * Network Firewall currently supports only TCP.
         */
        protocols?: pulumi.Input<pulumi.Input<number>[]>;
        /**
         * The source ports to decrypt for inspection, in Transmission Control Protocol (TCP) format. If not specified, this matches with any source port.
         *
         * You can specify individual ports, for example `1994` , and you can specify port ranges, such as `1990:1994` .
         */
        sourcePorts?: pulumi.Input<pulumi.Input<inputs.networkfirewall.TlsInspectionConfigurationPortRangeArgs>[]>;
        /**
         * The source IP addresses and address ranges to decrypt for inspection, in CIDR notation. If not specified, this
         * matches with any source address.
         */
        sources?: pulumi.Input<pulumi.Input<inputs.networkfirewall.TlsInspectionConfigurationAddressArgs>[]>;
    }
    interface TlsInspectionConfigurationTlsInspectionConfigurationArgs {
        /**
         * Lists the server certificate configurations that are associated with the TLS configuration.
         */
        serverCertificateConfigurations?: pulumi.Input<pulumi.Input<inputs.networkfirewall.TlsInspectionConfigurationServerCertificateConfigurationArgs>[]>;
    }
}
export declare namespace networkmanager {
    /**
     * Connect attachment options for protocol
     */
    interface ConnectAttachmentOptionsArgs {
        /**
         * Tunnel protocol for connect attachment
         */
        protocol?: pulumi.Input<string>;
    }
    /**
     * The attachment to move from one network function group to another.
     */
    interface ConnectAttachmentProposedNetworkFunctionGroupChangeArgs {
        /**
         * The rule number in the policy document that applies to this change.
         */
        attachmentPolicyRuleNumber?: pulumi.Input<number>;
        /**
         * The name of the network function group to change.
         */
        networkFunctionGroupName?: pulumi.Input<string>;
        /**
         * The key-value tags that changed for the network function group.
         */
        tags?: pulumi.Input<pulumi.Input<inputs.networkmanager.ConnectAttachmentTagArgs>[]>;
    }
    /**
     * The attachment to move from one segment to another.
     */
    interface ConnectAttachmentProposedSegmentChangeArgs {
        /**
         * The rule number in the policy document that applies to this change.
         */
        attachmentPolicyRuleNumber?: pulumi.Input<number>;
        /**
         * The name of the segment to change.
         */
        segmentName?: pulumi.Input<string>;
        /**
         * The list of key-value tags that changed for the segment.
         */
        tags?: pulumi.Input<pulumi.Input<inputs.networkmanager.ConnectAttachmentTagArgs>[]>;
    }
    /**
     * A key-value pair to associate with a resource.
     */
    interface ConnectAttachmentTagArgs {
        /**
         * The key name of the tag. You can specify a value that is 1 to 128 Unicode characters in length and cannot be prefixed with aws:. You can use any of the following characters: the set of Unicode letters, digits, whitespace, _, ., /, =, +, and -.
         */
        key: pulumi.Input<string>;
        /**
         * The value for the tag. You can specify a value that is 0 to 256 Unicode characters in length and cannot be prefixed with aws:. You can use any of the following characters: the set of Unicode letters, digits, whitespace, _, ., /, =, +, and -.
         */
        value: pulumi.Input<string>;
    }
    /**
     * Bgp options
     */
    interface ConnectPeerBgpOptionsArgs {
        /**
         * The Peer ASN of the BGP.
         */
        peerAsn?: pulumi.Input<number>;
    }
    /**
     * The Amazon Web Services location of the device, if applicable.
     */
    interface DeviceAwsLocationArgs {
        /**
         * The Amazon Resource Name (ARN) of the subnet that the device is located in.
         */
        subnetArn?: pulumi.Input<string>;
        /**
         * The Zone that the device is located in. Specify the ID of an Availability Zone, Local Zone, Wavelength Zone, or an Outpost.
         */
        zone?: pulumi.Input<string>;
    }
    /**
     * The site location.
     */
    interface DeviceLocationArgs {
        /**
         * The physical address.
         */
        address?: pulumi.Input<string>;
        /**
         * The latitude.
         */
        latitude?: pulumi.Input<string>;
        /**
         * The longitude.
         */
        longitude?: pulumi.Input<string>;
    }
    /**
     * The attachment to move from one network function group to another.
     */
    interface DirectConnectGatewayAttachmentProposedNetworkFunctionGroupChangeArgs {
        /**
         * The rule number in the policy document that applies to this change.
         */
        attachmentPolicyRuleNumber?: pulumi.Input<number>;
        /**
         * The name of the network function group to change.
         */
        networkFunctionGroupName?: pulumi.Input<string>;
        /**
         * The key-value tags that changed for the network function group.
         */
        tags?: pulumi.Input<pulumi.Input<inputs.networkmanager.DirectConnectGatewayAttachmentTagArgs>[]>;
    }
    /**
     * The attachment to move from one segment to another.
     */
    interface DirectConnectGatewayAttachmentProposedSegmentChangeArgs {
        /**
         * The rule number in the policy document that applies to this change.
         */
        attachmentPolicyRuleNumber?: pulumi.Input<number>;
        /**
         * The name of the segment to change.
         */
        segmentName?: pulumi.Input<string>;
        /**
         * The key-value tags that changed for the segment.
         */
        tags?: pulumi.Input<pulumi.Input<inputs.networkmanager.DirectConnectGatewayAttachmentTagArgs>[]>;
    }
    /**
     * A key-value pair to associate with a resource.
     */
    interface DirectConnectGatewayAttachmentTagArgs {
        /**
         * The key name of the tag. You can specify a value that is 1 to 128 Unicode characters in length and cannot be prefixed with aws:. You can use any of the following characters: the set of Unicode letters, digits, whitespace, _, ., /, =, +, and -.
         */
        key: pulumi.Input<string>;
        /**
         * The value for the tag. You can specify a value that is 0 to 256 Unicode characters in length and cannot be prefixed with aws:. You can use any of the following characters: the set of Unicode letters, digits, whitespace, _, ., /, =, +, and -.
         */
        value: pulumi.Input<string>;
    }
    /**
     * The bandwidth for the link.
     */
    interface LinkBandwidthArgs {
        /**
         * Download speed in Mbps.
         */
        downloadSpeed?: pulumi.Input<number>;
        /**
         * Upload speed in Mbps.
         */
        uploadSpeed?: pulumi.Input<number>;
    }
    /**
     * The location of the site
     */
    interface SiteLocationArgs {
        /**
         * The physical address.
         */
        address?: pulumi.Input<string>;
        /**
         * The latitude.
         */
        latitude?: pulumi.Input<string>;
        /**
         * The longitude.
         */
        longitude?: pulumi.Input<string>;
    }
    /**
     * The attachment to move from one network function group to another.
     */
    interface SiteToSiteVpnAttachmentProposedNetworkFunctionGroupChangeArgs {
        /**
         * The rule number in the policy document that applies to this change.
         */
        attachmentPolicyRuleNumber?: pulumi.Input<number>;
        /**
         * The name of the network function group to change.
         */
        networkFunctionGroupName?: pulumi.Input<string>;
        /**
         * The key-value tags that changed for the network function group.
         */
        tags?: pulumi.Input<pulumi.Input<inputs.networkmanager.SiteToSiteVpnAttachmentTagArgs>[]>;
    }
    /**
     * The attachment to move from one segment to another.
     */
    interface SiteToSiteVpnAttachmentProposedSegmentChangeArgs {
        /**
         * The rule number in the policy document that applies to this change.
         */
        attachmentPolicyRuleNumber?: pulumi.Input<number>;
        /**
         * The name of the segment to change.
         */
        segmentName?: pulumi.Input<string>;
        /**
         * The key-value tags that changed for the segment.
         */
        tags?: pulumi.Input<pulumi.Input<inputs.networkmanager.SiteToSiteVpnAttachmentTagArgs>[]>;
    }
    /**
     * A key-value pair to associate with a resource.
     */
    interface SiteToSiteVpnAttachmentTagArgs {
        /**
         * The key name of the tag. You can specify a value that is 1 to 128 Unicode characters in length and cannot be prefixed with aws:. You can use any of the following characters: the set of Unicode letters, digits, whitespace, _, ., /, =, +, and -.
         */
        key: pulumi.Input<string>;
        /**
         * The value for the tag. You can specify a value that is 0 to 256 Unicode characters in length and cannot be prefixed with aws:. You can use any of the following characters: the set of Unicode letters, digits, whitespace, _, ., /, =, +, and -.
         */
        value: pulumi.Input<string>;
    }
    /**
     * The attachment to move from one network function group to another.
     */
    interface TransitGatewayRouteTableAttachmentProposedNetworkFunctionGroupChangeArgs {
        /**
         * The rule number in the policy document that applies to this change.
         */
        attachmentPolicyRuleNumber?: pulumi.Input<number>;
        /**
         * The name of the network function group to change.
         */
        networkFunctionGroupName?: pulumi.Input<string>;
        /**
         * The key-value tags that changed for the network function group.
         */
        tags?: pulumi.Input<pulumi.Input<inputs.networkmanager.TransitGatewayRouteTableAttachmentTagArgs>[]>;
    }
    /**
     * The attachment to move from one segment to another.
     */
    interface TransitGatewayRouteTableAttachmentProposedSegmentChangeArgs {
        /**
         * The rule number in the policy document that applies to this change.
         */
        attachmentPolicyRuleNumber?: pulumi.Input<number>;
        /**
         * The name of the segment to change.
         */
        segmentName?: pulumi.Input<string>;
        /**
         * The key-value tags that changed for the segment.
         */
        tags?: pulumi.Input<pulumi.Input<inputs.networkmanager.TransitGatewayRouteTableAttachmentTagArgs>[]>;
    }
    /**
     * A key-value pair to associate with a resource.
     */
    interface TransitGatewayRouteTableAttachmentTagArgs {
        /**
         * The key name of the tag. You can specify a value that is 1 to 128 Unicode characters in length and cannot be prefixed with aws:. You can use any of the following characters: the set of Unicode letters, digits, whitespace, _, ., /, =, +, and -.
         */
        key: pulumi.Input<string>;
        /**
         * The value for the tag. You can specify a value that is 0 to 256 Unicode characters in length and cannot be prefixed with aws:. You can use any of the following characters: the set of Unicode letters, digits, whitespace, _, ., /, =, +, and -.
         */
        value: pulumi.Input<string>;
    }
    /**
     * The attachment to move from one network function group to another.
     */
    interface VpcAttachmentProposedNetworkFunctionGroupChangeArgs {
        /**
         * The rule number in the policy document that applies to this change.
         */
        attachmentPolicyRuleNumber?: pulumi.Input<number>;
        /**
         * The name of the network function group to change.
         */
        networkFunctionGroupName?: pulumi.Input<string>;
        /**
         * The key-value tags that changed for the network function group.
         */
        tags?: pulumi.Input<pulumi.Input<inputs.networkmanager.VpcAttachmentTagArgs>[]>;
    }
    /**
     * The attachment to move from one segment to another.
     */
    interface VpcAttachmentProposedSegmentChangeArgs {
        /**
         * The rule number in the policy document that applies to this change.
         */
        attachmentPolicyRuleNumber?: pulumi.Input<number>;
        /**
         * The name of the segment to change.
         */
        segmentName?: pulumi.Input<string>;
        /**
         * The key-value tags that changed for the segment.
         */
        tags?: pulumi.Input<pulumi.Input<inputs.networkmanager.VpcAttachmentTagArgs>[]>;
    }
    /**
     * A key-value pair to associate with a resource.
     */
    interface VpcAttachmentTagArgs {
        /**
         * The key name of the tag. You can specify a value that is 1 to 128 Unicode characters in length and cannot be prefixed with aws:. You can use any of the following characters: the set of Unicode letters, digits, whitespace, _, ., /, =, +, and -.
         */
        key: pulumi.Input<string>;
        /**
         * The value for the tag. You can specify a value that is 0 to 256 Unicode characters in length and cannot be prefixed with aws:. You can use any of the following characters: the set of Unicode letters, digits, whitespace, _, ., /, =, +, and -.
         */
        value: pulumi.Input<string>;
    }
    /**
     * Vpc options of the attachment.
     */
    interface VpcAttachmentVpcOptionsArgs {
        /**
         * Indicates whether to enable ApplianceModeSupport Support for Vpc Attachment. Valid Values: true | false
         */
        applianceModeSupport?: pulumi.Input<boolean>;
        /**
         * Indicates whether to enable Ipv6 Support for Vpc Attachment. Valid Values: enable | disable
         */
        ipv6Support?: pulumi.Input<boolean>;
    }
}
export declare namespace nimblestudio {
    interface LaunchProfileStreamConfigurationArgs {
        /**
         * Indicates if a streaming session created from this launch profile should be terminated automatically or retained without termination after being in a `STOPPED` state.
         *
         * - When `ACTIVATED` , the streaming session is scheduled for termination after being in the `STOPPED` state for the time specified in `maxStoppedSessionLengthInMinutes` .
         * - When `DEACTIVATED` , the streaming session can remain in the `STOPPED` state indefinitely.
         *
         * This parameter is only allowed when `sessionPersistenceMode` is `ACTIVATED` . When allowed, the default value for this parameter is `DEACTIVATED` .
         */
        automaticTerminationMode?: pulumi.Input<string>;
        /**
         * Allows or deactivates the use of the system clipboard to copy and paste between the streaming session and streaming client.
         */
        clipboardMode: pulumi.Input<string>;
        /**
         * The EC2 instance types that users can select from when launching a streaming session with this launch profile.
         */
        ec2InstanceTypes: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * The length of time, in minutes, that a streaming session can be active before it is stopped or terminated. After this point, Nimble Studio automatically terminates or stops the session. The default length of time is 690 minutes, and the maximum length of time is 30 days.
         */
        maxSessionLengthInMinutes?: pulumi.Input<number>;
        /**
         * Integer that determines if you can start and stop your sessions and how long a session can stay in the `STOPPED` state. The default value is 0. The maximum value is 5760.
         *
         * This field is allowed only when `sessionPersistenceMode` is `ACTIVATED` and `automaticTerminationMode` is `ACTIVATED` .
         *
         * If the value is set to 0, your sessions can’t be `STOPPED` . If you then call `StopStreamingSession` , the session fails. If the time that a session stays in the `READY` state exceeds the `maxSessionLengthInMinutes` value, the session will automatically be terminated (instead of `STOPPED` ).
         *
         * If the value is set to a positive number, the session can be stopped. You can call `StopStreamingSession` to stop sessions in the `READY` state. If the time that a session stays in the `READY` state exceeds the `maxSessionLengthInMinutes` value, the session will automatically be stopped (instead of terminated).
         */
        maxStoppedSessionLengthInMinutes?: pulumi.Input<number>;
        /**
         * Information about the streaming session backup.
         */
        sessionBackup?: pulumi.Input<inputs.nimblestudio.LaunchProfileStreamConfigurationSessionBackupArgs>;
        /**
         * Determine if a streaming session created from this launch profile can configure persistent storage. This means that `volumeConfiguration` and `automaticTerminationMode` are configured.
         */
        sessionPersistenceMode?: pulumi.Input<string>;
        /**
         * The upload storage for a streaming session.
         */
        sessionStorage?: pulumi.Input<inputs.nimblestudio.LaunchProfileStreamConfigurationSessionStorageArgs>;
        /**
         * The streaming images that users can select from when launching a streaming session with this launch profile.
         */
        streamingImageIds: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * Custom volume configuration for the root volumes that are attached to streaming sessions.
         *
         * This parameter is only allowed when `sessionPersistenceMode` is `ACTIVATED` .
         */
        volumeConfiguration?: pulumi.Input<inputs.nimblestudio.LaunchProfileVolumeConfigurationArgs>;
    }
    interface LaunchProfileStreamConfigurationSessionBackupArgs {
        /**
         * The maximum number of backups that each streaming session created from this launch profile can have.
         */
        maxBackupsToRetain?: pulumi.Input<number>;
        /**
         * Specifies how artists sessions are backed up.
         *
         * Configures backups for streaming sessions launched with this launch profile. The default value is `DEACTIVATED` , which means that backups are deactivated. To allow backups, set this value to `AUTOMATIC` .
         */
        mode?: pulumi.Input<string>;
    }
    interface LaunchProfileStreamConfigurationSessionStorageArgs {
        /**
         * Allows artists to upload files to their workstations. The only valid option is `UPLOAD` .
         */
        mode: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * The configuration for the upload storage root of the streaming session.
         */
        root?: pulumi.Input<inputs.nimblestudio.LaunchProfileStreamingSessionStorageRootArgs>;
    }
    interface LaunchProfileStreamingSessionStorageRootArgs {
        /**
         * The folder path in Linux workstations where files are uploaded.
         */
        linux?: pulumi.Input<string>;
        /**
         * The folder path in Windows workstations where files are uploaded.
         */
        windows?: pulumi.Input<string>;
    }
    interface LaunchProfileVolumeConfigurationArgs {
        /**
         * The number of I/O operations per second for the root volume that is attached to streaming session.
         */
        iops?: pulumi.Input<number>;
        /**
         * The size of the root volume that is attached to the streaming session. The root volume size is measured in GiBs.
         */
        size?: pulumi.Input<number>;
        /**
         * The throughput to provision for the root volume that is attached to the streaming session. The throughput is measured in MiB/s.
         */
        throughput?: pulumi.Input<number>;
    }
    interface StudioComponentActiveDirectoryComputerAttributeArgs {
        /**
         * The name for the LDAP attribute.
         */
        name?: pulumi.Input<string>;
        /**
         * The value for the LDAP attribute.
         */
        value?: pulumi.Input<string>;
    }
    interface StudioComponentActiveDirectoryConfigurationArgs {
        /**
         * A collection of custom attributes for an Active Directory computer.
         */
        computerAttributes?: pulumi.Input<pulumi.Input<inputs.nimblestudio.StudioComponentActiveDirectoryComputerAttributeArgs>[]>;
        /**
         * The directory ID of the AWS Directory Service for Microsoft Active Directory to access using this studio component.
         */
        directoryId?: pulumi.Input<string>;
        /**
         * The distinguished name (DN) and organizational unit (OU) of an Active Directory computer.
         */
        organizationalUnitDistinguishedName?: pulumi.Input<string>;
    }
    interface StudioComponentComputeFarmConfigurationArgs {
        /**
         * The name of an Active Directory user that is used on ComputeFarm worker instances.
         */
        activeDirectoryUser?: pulumi.Input<string>;
        /**
         * The endpoint of the ComputeFarm that is accessed by the studio component resource.
         */
        endpoint?: pulumi.Input<string>;
    }
    interface StudioComponentConfigurationArgs {
        /**
         * The configuration for a AWS Directory Service for Microsoft Active Directory studio resource.
         */
        activeDirectoryConfiguration?: pulumi.Input<inputs.nimblestudio.StudioComponentActiveDirectoryConfigurationArgs>;
        /**
         * The configuration for a render farm that is associated with a studio resource.
         */
        computeFarmConfiguration?: pulumi.Input<inputs.nimblestudio.StudioComponentComputeFarmConfigurationArgs>;
        /**
         * The configuration for a license service that is associated with a studio resource.
         */
        licenseServiceConfiguration?: pulumi.Input<inputs.nimblestudio.StudioComponentLicenseServiceConfigurationArgs>;
        /**
         * The configuration for a shared file storage system that is associated with a studio resource.
         */
        sharedFileSystemConfiguration?: pulumi.Input<inputs.nimblestudio.StudioComponentSharedFileSystemConfigurationArgs>;
    }
    interface StudioComponentInitializationScriptArgs {
        /**
         * The version number of the protocol that is used by the launch profile. The only valid version is "2021-03-31".
         */
        launchProfileProtocolVersion?: pulumi.Input<string>;
        /**
         * The platform of the initialization script, either Windows or Linux.
         */
        platform?: pulumi.Input<string>;
        /**
         * The method to use when running the initialization script.
         */
        runContext?: pulumi.Input<string>;
        /**
         * The initialization script.
         */
        script?: pulumi.Input<string>;
    }
    interface StudioComponentLicenseServiceConfigurationArgs {
        /**
         * The endpoint of the license service that is accessed by the studio component resource.
         */
        endpoint?: pulumi.Input<string>;
    }
    interface StudioComponentScriptParameterKeyValueArgs {
        /**
         * A script parameter key.
         */
        key?: pulumi.Input<string>;
        /**
         * A script parameter value.
         */
        value?: pulumi.Input<string>;
    }
    interface StudioComponentSharedFileSystemConfigurationArgs {
        /**
         * The endpoint of the shared file system that is accessed by the studio component resource.
         */
        endpoint?: pulumi.Input<string>;
        /**
         * The unique identifier for a file system.
         */
        fileSystemId?: pulumi.Input<string>;
        /**
         * The mount location for a shared file system on a Linux virtual workstation.
         */
        linuxMountPoint?: pulumi.Input<string>;
        /**
         * The name of the file share.
         */
        shareName?: pulumi.Input<string>;
        /**
         * The mount location for a shared file system on a Windows virtual workstation.
         */
        windowsMountDrive?: pulumi.Input<string>;
    }
    interface StudioEncryptionConfigurationArgs {
        /**
         * The ARN for a KMS key that is used to encrypt studio data.
         */
        keyArn?: pulumi.Input<string>;
        /**
         * The type of KMS key that is used to encrypt studio data.
         */
        keyType: pulumi.Input<string>;
    }
}
export declare namespace oam {
    interface LinkConfigurationArgs {
        /**
         * Use this structure to filter which log groups are to send log events from the source account to the monitoring account.
         */
        logGroupConfiguration?: pulumi.Input<inputs.oam.LinkFilterArgs>;
        /**
         * Use this structure to filter which metric namespaces are to be shared from the source account to the monitoring account.
         */
        metricConfiguration?: pulumi.Input<inputs.oam.LinkFilterArgs>;
    }
    interface LinkFilterArgs {
        filter: pulumi.Input<string>;
    }
}
export declare namespace omics {
    interface AnnotationStoreReferenceItemArgs {
        /**
         * The reference's ARN.
         */
        referenceArn: pulumi.Input<string>;
    }
    interface AnnotationStoreSseConfigArgs {
        /**
         * An encryption key ARN.
         */
        keyArn?: pulumi.Input<string>;
        /**
         * The encryption type.
         */
        type: pulumi.Input<enums.omics.AnnotationStoreEncryptionType>;
    }
    interface AnnotationStoreStoreOptionsPropertiesArgs {
        tsvStoreOptions: pulumi.Input<inputs.omics.AnnotationStoreTsvStoreOptionsArgs>;
    }
    interface AnnotationStoreTsvStoreOptionsArgs {
        annotationType?: pulumi.Input<enums.omics.AnnotationStoreAnnotationType>;
        formatToHeader?: pulumi.Input<{
            [key: string]: pulumi.Input<string>;
        }>;
        schema?: pulumi.Input<pulumi.Input<{
            [key: string]: pulumi.Input<enums.omics.AnnotationStoreSchemaValueType>;
        }>[]>;
    }
    /**
     * Server-side encryption (SSE) settings for a store.
     */
    interface ReferenceStoreSseConfigArgs {
        /**
         * An encryption key ARN.
         */
        keyArn?: pulumi.Input<string>;
        /**
         * The encryption type.
         */
        type: pulumi.Input<enums.omics.ReferenceStoreEncryptionType>;
    }
    /**
     * Server-side encryption (SSE) settings for a store.
     */
    interface SequenceStoreSseConfigArgs {
        /**
         * An encryption key ARN.
         */
        keyArn?: pulumi.Input<string>;
        /**
         * The encryption type.
         */
        type: pulumi.Input<enums.omics.SequenceStoreEncryptionType>;
    }
    interface VariantStoreReferenceItemArgs {
        /**
         * The reference's ARN.
         */
        referenceArn: pulumi.Input<string>;
    }
    interface VariantStoreSseConfigArgs {
        /**
         * An encryption key ARN.
         */
        keyArn?: pulumi.Input<string>;
        /**
         * The encryption type.
         */
        type: pulumi.Input<enums.omics.VariantStoreEncryptionType>;
    }
    interface WorkflowParameterArgs {
        /**
         * The parameter's description.
         */
        description?: pulumi.Input<string>;
        /**
         * Whether the parameter is optional.
         */
        optional?: pulumi.Input<boolean>;
    }
}
export declare namespace opensearchserverless {
    interface IndexPropertyMappingArgs {
        /**
         * Dimension size for vector fields, defines the number of dimensions in the vector
         */
        dimension?: pulumi.Input<number>;
        /**
         * Whether a field should be indexed
         */
        index?: pulumi.Input<boolean>;
        /**
         * Configuration for k-NN search method
         */
        method?: pulumi.Input<inputs.opensearchserverless.IndexPropertyMappingMethodPropertiesArgs>;
        /**
         * Nested fields within an object or nested field type
         */
        properties?: pulumi.Input<{
            [key: string]: pulumi.Input<inputs.opensearchserverless.IndexPropertyMappingArgs>;
        }>;
        /**
         * The field data type. Must be a valid OpenSearch field type.
         */
        type: pulumi.Input<enums.opensearchserverless.IndexPropertyMappingType>;
        /**
         * Default value for the field when not specified in a document
         */
        value?: pulumi.Input<string>;
    }
    /**
     * Configuration for k-NN search method
     */
    interface IndexPropertyMappingMethodPropertiesArgs {
        /**
         * The k-NN search engine to use
         */
        engine: pulumi.Input<enums.opensearchserverless.IndexPropertyMappingMethodPropertiesEngine>;
        /**
         * The algorithm name for k-NN search
         */
        name: pulumi.Input<enums.opensearchserverless.IndexPropertyMappingMethodPropertiesName>;
        /**
         * Additional parameters for the k-NN algorithm
         */
        parameters?: pulumi.Input<inputs.opensearchserverless.IndexPropertyMappingMethodPropertiesParametersPropertiesArgs>;
        /**
         * The distance function used for k-NN search
         */
        spaceType?: pulumi.Input<enums.opensearchserverless.IndexPropertyMappingMethodPropertiesSpaceType>;
    }
    /**
     * Additional parameters for the k-NN algorithm
     */
    interface IndexPropertyMappingMethodPropertiesParametersPropertiesArgs {
        /**
         * The size of the dynamic list used during k-NN graph creation
         */
        efConstruction?: pulumi.Input<number>;
        /**
         * Number of neighbors to consider during k-NN search
         */
        m?: pulumi.Input<number>;
    }
    interface IndexSettingsArgs {
        /**
         * Index settings.
         */
        index?: pulumi.Input<inputs.opensearchserverless.IndexSettingsIndexPropertiesArgs>;
    }
    /**
     * Index settings.
     */
    interface IndexSettingsIndexPropertiesArgs {
        /**
         * Enable/disable k-nearest neighbor search capability
         */
        knn?: pulumi.Input<boolean>;
        /**
         * Size of the dynamic list for the nearest neighbors
         */
        knnAlgoParamEfSearch?: pulumi.Input<number>;
        /**
         * How often to perform refresh operation (e.g. '1s', '5s')
         */
        refreshInterval?: pulumi.Input<string>;
    }
    /**
     * Index Mappings
     */
    interface MappingsPropertiesArgs {
        /**
         * Defines the fields within the mapping, including their types and configurations
         */
        properties?: pulumi.Input<{
            [key: string]: pulumi.Input<inputs.opensearchserverless.IndexPropertyMappingArgs>;
        }>;
    }
    /**
     * Describes IAM Identity Center options for an OpenSearch Serverless security configuration in the form of a key-value map
     */
    interface SecurityConfigIamIdentityCenterConfigOptionsArgs {
        /**
         * The ARN of the IAM Identity Center application used to integrate with OpenSearch Serverless.
         */
        applicationArn?: pulumi.Input<string>;
        /**
         * The description of the IAM Identity Center application used to integrate with OpenSearch Serverless
         */
        applicationDescription?: pulumi.Input<string>;
        /**
         * The name of the IAM Identity Center application used to integrate with OpenSearch Serverless
         */
        applicationName?: pulumi.Input<string>;
        /**
         * The group attribute for this IAM Identity Center integration. Defaults to `GroupId` .
         */
        groupAttribute?: pulumi.Input<string>;
        /**
         * The ARN of the IAM Identity Center instance used to integrate with OpenSearch Serverless.
         */
        instanceArn: pulumi.Input<string>;
        /**
         * The user attribute for this IAM Identity Center integration. Defaults to `UserId`
         */
        userAttribute?: pulumi.Input<string>;
    }
    /**
     * Describes saml options in form of key value map
     */
    interface SecurityConfigSamlConfigOptionsArgs {
        /**
         * Group attribute for this saml integration
         */
        groupAttribute?: pulumi.Input<string>;
        /**
         * The XML saml provider metadata document that you want to use
         */
        metadata: pulumi.Input<string>;
        /**
         * Custom entity id attribute to override default entity id for this saml integration
         */
        openSearchServerlessEntityId?: pulumi.Input<string>;
        /**
         * Defines the session timeout in minutes
         */
        sessionTimeout?: pulumi.Input<number>;
        /**
         * Custom attribute for this saml integration
         */
        userAttribute?: pulumi.Input<string>;
    }
}
export declare namespace opensearchservice {
    /**
     * A key-value pair of AppConfig
     */
    interface ApplicationAppConfigArgs {
        /**
         * The configuration key
         */
        key: pulumi.Input<enums.opensearchservice.ApplicationAppConfigType>;
        /**
         * The configuration value.
         */
        value: pulumi.Input<string>;
    }
    /**
     * Datasource arn and description
     */
    interface ApplicationDataSourceArgs {
        /**
         * The ARN of the data source.
         */
        dataSourceArn: any;
        /**
         * Description of the data source.
         */
        dataSourceDescription?: pulumi.Input<string>;
    }
    interface DomainAdvancedSecurityOptionsInputArgs {
        /**
         * Date and time when the migration period will be disabled. Only necessary when [enabling fine-grained access control on an existing domain](https://docs.aws.amazon.com/opensearch-service/latest/developerguide/fgac.html#fgac-enabling-existing) .
         */
        anonymousAuthDisableDate?: pulumi.Input<string>;
        /**
         * True to enable a 30-day migration period during which administrators can create role mappings. Only necessary when [enabling fine-grained access control on an existing domain](https://docs.aws.amazon.com/opensearch-service/latest/developerguide/fgac.html#fgac-enabling-existing) .
         */
        anonymousAuthEnabled?: pulumi.Input<boolean>;
        /**
         * True to enable fine-grained access control. You must also enable encryption of data at rest and node-to-node encryption. See [Fine-grained access control in Amazon OpenSearch Service](https://docs.aws.amazon.com/opensearch-service/latest/developerguide/fgac.html) .
         */
        enabled?: pulumi.Input<boolean>;
        /**
         * True to enable the internal user database.
         */
        internalUserDatabaseEnabled?: pulumi.Input<boolean>;
        /**
         * Container for information about the JWT configuration of the Amazon OpenSearch Service.
         */
        jwtOptions?: pulumi.Input<inputs.opensearchservice.DomainJwtOptionsArgs>;
        /**
         * Specifies information about the master user.
         */
        masterUserOptions?: pulumi.Input<inputs.opensearchservice.DomainMasterUserOptionsArgs>;
        /**
         * Container for information about the SAML configuration for OpenSearch Dashboards.
         */
        samlOptions?: pulumi.Input<inputs.opensearchservice.DomainSamlOptionsArgs>;
    }
    interface DomainClusterConfigArgs {
        /**
         * Container for cold storage configuration options.
         */
        coldStorageOptions?: pulumi.Input<inputs.opensearchservice.DomainColdStorageOptionsArgs>;
        /**
         * The number of instances to use for the master node. If you specify this property, you must specify `true` for the `DedicatedMasterEnabled` property.
         */
        dedicatedMasterCount?: pulumi.Input<number>;
        /**
         * Indicates whether to use a dedicated master node for the OpenSearch Service domain. A dedicated master node is a cluster node that performs cluster management tasks, but doesn't hold data or respond to data upload requests. Dedicated master nodes offload cluster management tasks to increase the stability of your search clusters. See [Dedicated master nodes in Amazon OpenSearch Service](https://docs.aws.amazon.com/opensearch-service/latest/developerguide/managedomains-dedicatedmasternodes.html) .
         */
        dedicatedMasterEnabled?: pulumi.Input<boolean>;
        /**
         * The hardware configuration of the computer that hosts the dedicated master node, such as `m3.medium.search` . If you specify this property, you must specify `true` for the `DedicatedMasterEnabled` property. For valid values, see [Supported instance types in Amazon OpenSearch Service](https://docs.aws.amazon.com/opensearch-service/latest/developerguide/supported-instance-types.html) .
         */
        dedicatedMasterType?: pulumi.Input<string>;
        /**
         * The number of data nodes (instances) to use in the OpenSearch Service domain.
         */
        instanceCount?: pulumi.Input<number>;
        /**
         * The instance type for your data nodes, such as `m3.medium.search` . For valid values, see [Supported instance types in Amazon OpenSearch Service](https://docs.aws.amazon.com/opensearch-service/latest/developerguide/supported-instance-types.html) .
         */
        instanceType?: pulumi.Input<string>;
        /**
         * Indicates whether Multi-AZ with Standby deployment option is enabled. For more information, see [Multi-AZ with Standby](https://docs.aws.amazon.com/opensearch-service/latest/developerguide/managedomains-multiaz.html#managedomains-za-standby) .
         */
        multiAzWithStandbyEnabled?: pulumi.Input<boolean>;
        /**
         * List of node options for the domain.
         */
        nodeOptions?: pulumi.Input<pulumi.Input<inputs.opensearchservice.DomainNodeOptionArgs>[]>;
        /**
         * The number of warm nodes in the cluster.
         */
        warmCount?: pulumi.Input<number>;
        /**
         * Whether to enable UltraWarm storage for the cluster. See [UltraWarm storage for Amazon OpenSearch Service](https://docs.aws.amazon.com/opensearch-service/latest/developerguide/ultrawarm.html) .
         */
        warmEnabled?: pulumi.Input<boolean>;
        /**
         * The instance type for the cluster's warm nodes.
         */
        warmType?: pulumi.Input<string>;
        /**
         * Specifies zone awareness configuration options. Only use if `ZoneAwarenessEnabled` is `true` .
         */
        zoneAwarenessConfig?: pulumi.Input<inputs.opensearchservice.DomainZoneAwarenessConfigArgs>;
        /**
         * Indicates whether to enable zone awareness for the OpenSearch Service domain. When you enable zone awareness, OpenSearch Service allocates the nodes and replica index shards that belong to a cluster across two Availability Zones (AZs) in the same region to prevent data loss and minimize downtime in the event of node or data center failure. Don't enable zone awareness if your cluster has no replica index shards or is a single-node cluster. For more information, see [Configuring a multi-AZ domain in Amazon OpenSearch Service](https://docs.aws.amazon.com/opensearch-service/latest/developerguide/managedomains-multiaz.html) .
         */
        zoneAwarenessEnabled?: pulumi.Input<boolean>;
    }
    interface DomainCognitoOptionsArgs {
        /**
         * Whether to enable or disable Amazon Cognito authentication for OpenSearch Dashboards. See [Amazon Cognito authentication for OpenSearch Dashboards](https://docs.aws.amazon.com/opensearch-service/latest/developerguide/cognito-auth.html) .
         */
        enabled?: pulumi.Input<boolean>;
        /**
         * The Amazon Cognito identity pool ID that you want OpenSearch Service to use for OpenSearch Dashboards authentication.
         *
         * Required if you enabled Cognito Authentication for OpenSearch Dashboards.
         */
        identityPoolId?: pulumi.Input<string>;
        /**
         * The `AmazonOpenSearchServiceCognitoAccess` role that allows OpenSearch Service to configure your user pool and identity pool.
         *
         * Required if you enabled Cognito Authentication for OpenSearch Dashboards.
         */
        roleArn?: pulumi.Input<string>;
        /**
         * The Amazon Cognito user pool ID that you want OpenSearch Service to use for OpenSearch Dashboards authentication.
         *
         * Required if you enabled Cognito Authentication for OpenSearch Dashboards.
         */
        userPoolId?: pulumi.Input<string>;
    }
    interface DomainColdStorageOptionsArgs {
        /**
         * Whether to enable or disable cold storage on the domain. You must enable UltraWarm storage to enable cold storage.
         */
        enabled?: pulumi.Input<boolean>;
    }
    interface DomainEbsOptionsArgs {
        /**
         * Specifies whether Amazon EBS volumes are attached to data nodes in the OpenSearch Service domain.
         */
        ebsEnabled?: pulumi.Input<boolean>;
        /**
         * The number of I/O operations per second (IOPS) that the volume supports. This property applies only to the `gp3` and provisioned IOPS EBS volume types.
         */
        iops?: pulumi.Input<number>;
        /**
         * The throughput (in MiB/s) of the EBS volumes attached to data nodes. Applies only to the `gp3` volume type.
         */
        throughput?: pulumi.Input<number>;
        /**
         * The size (in GiB) of the EBS volume for each data node. The minimum and maximum size of an EBS volume depends on the EBS volume type and the instance type to which it is attached. For more information, see [EBS volume size limits](https://docs.aws.amazon.com/opensearch-service/latest/developerguide/limits.html#ebsresource) in the *Amazon OpenSearch Service Developer Guide* .
         */
        volumeSize?: pulumi.Input<number>;
        /**
         * The EBS volume type to use with the OpenSearch Service domain. If you choose `gp3` , you must also specify values for `Iops` and `Throughput` . For more information about each type, see [Amazon EBS volume types](https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/EBSVolumeTypes.html) in the *Amazon EC2 User Guide for Linux Instances* .
         */
        volumeType?: pulumi.Input<string>;
    }
    interface DomainEncryptionAtRestOptionsArgs {
        /**
         * Specify `true` to enable encryption at rest. Required if you enable fine-grained access control in [AdvancedSecurityOptionsInput](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-opensearchservice-domain-advancedsecurityoptionsinput.html) .
         *
         * If no encryption at rest options were initially specified in the template, updating this property by adding it causes no interruption. However, if you change this property after it's already been set within a template, the domain is deleted and recreated in order to modify the property.
         */
        enabled?: pulumi.Input<boolean>;
        /**
         * The KMS key ID. Takes the form `1a2a3a4-1a2a-3a4a-5a6a-1a2a3a4a5a6a` . Required if you enable encryption at rest.
         *
         * You can also use `keyAlias` as a value.
         *
         * If no encryption at rest options were initially specified in the template, updating this property by adding it causes no interruption. However, if you change this property after it's already been set within a template, the domain is deleted and recreated in order to modify the property.
         */
        kmsKeyId?: pulumi.Input<string>;
    }
    interface DomainEndpointOptionsArgs {
        /**
         * The fully qualified URL for your custom endpoint. Required if you enabled a custom endpoint for the domain.
         */
        customEndpoint?: pulumi.Input<string>;
        /**
         * The AWS Certificate Manager ARN for your domain's SSL/TLS certificate. Required if you enabled a custom endpoint for the domain.
         */
        customEndpointCertificateArn?: pulumi.Input<string>;
        /**
         * True to enable a custom endpoint for the domain. If enabled, you must also provide values for `CustomEndpoint` and `CustomEndpointCertificateArn` .
         */
        customEndpointEnabled?: pulumi.Input<boolean>;
        /**
         * True to require that all traffic to the domain arrive over HTTPS. Required if you enable fine-grained access control in [AdvancedSecurityOptions](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-opensearchservice-domain-advancedsecurityoptionsinput.html) .
         */
        enforceHttps?: pulumi.Input<boolean>;
        /**
         * The minimum TLS version required for traffic to the domain. The policy can be one of the following values:
         *
         * - *Policy-Min-TLS-1-0-2019-07:* TLS security policy that supports TLS version 1.0 to TLS version 1.2
         * - *Policy-Min-TLS-1-2-2019-07:* TLS security policy that supports only TLS version 1.2
         * - *Policy-Min-TLS-1-2-PFS-2023-10:* TLS security policy that supports TLS version 1.2 to TLS version 1.3 with perfect forward secrecy cipher suites
         */
        tlsSecurityPolicy?: pulumi.Input<string>;
    }
    /**
     * Options for configuring Identity Center
     */
    interface DomainIdentityCenterOptionsArgs {
        /**
         * Whether Identity Center is enabled.
         */
        enabledApiAccess?: pulumi.Input<boolean>;
        /**
         * The ARN of the Identity Center application.
         */
        identityCenterApplicationArn?: pulumi.Input<string>;
        /**
         * The ARN of the Identity Center instance.
         */
        identityCenterInstanceArn?: pulumi.Input<string>;
        /**
         * The IdentityStoreId for Identity Center options.
         */
        identityStoreId?: pulumi.Input<string>;
        /**
         * The roles key for Identity Center options.
         */
        rolesKey?: pulumi.Input<enums.opensearchservice.DomainRolesKeyIdcType>;
        /**
         * The subject key for Identity Center options.
         */
        subjectKey?: pulumi.Input<enums.opensearchservice.DomainSubjectKeyIdcType>;
    }
    interface DomainIdpArgs {
        /**
         * The unique entity ID of the application in the SAML identity provider.
         */
        entityId: pulumi.Input<string>;
        /**
         * The metadata of the SAML application, in XML format.
         */
        metadataContent: pulumi.Input<string>;
    }
    interface DomainJwtOptionsArgs {
        enabled?: pulumi.Input<boolean>;
        publicKey?: pulumi.Input<string>;
        rolesKey?: pulumi.Input<string>;
        subjectKey?: pulumi.Input<string>;
    }
    interface DomainLogPublishingOptionArgs {
        cloudWatchLogsLogGroupArn?: pulumi.Input<string>;
        enabled?: pulumi.Input<boolean>;
    }
    interface DomainMasterUserOptionsArgs {
        /**
         * Amazon Resource Name (ARN) for the master user. The ARN can point to an IAM user or role. This property is required for Amazon Cognito to work, and it must match the role configured for Cognito. Only specify if `InternalUserDatabaseEnabled` is false in [AdvancedSecurityOptionsInput](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-opensearchservice-domain-advancedsecurityoptionsinput.html) .
         */
        masterUserArn?: pulumi.Input<string>;
        /**
         * Username for the master user. Only specify if `InternalUserDatabaseEnabled` is true in [AdvancedSecurityOptionsInput](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-opensearchservice-domain-advancedsecurityoptionsinput.html) .
         *
         * If you don't want to specify this value directly within the template, you can use a [dynamic reference](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/dynamic-references.html) instead.
         */
        masterUserName?: pulumi.Input<string>;
        /**
         * Password for the master user. Only specify if `InternalUserDatabaseEnabled` is true in [AdvancedSecurityOptionsInput](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-opensearchservice-domain-advancedsecurityoptionsinput.html) .
         *
         * If you don't want to specify this value directly within the template, you can use a [dynamic reference](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/dynamic-references.html) instead.
         */
        masterUserPassword?: pulumi.Input<string>;
    }
    interface DomainNodeConfigArgs {
        /**
         * The number of nodes of a specific type within the cluster.
         */
        count?: pulumi.Input<number>;
        /**
         * A boolean value indicating whether a specific node type is active or inactive.
         */
        enabled?: pulumi.Input<boolean>;
        /**
         * The instance type of a particular node within the cluster.
         */
        type?: pulumi.Input<string>;
    }
    interface DomainNodeOptionArgs {
        /**
         * Configuration options for defining the setup of any node type.
         */
        nodeConfig?: pulumi.Input<inputs.opensearchservice.DomainNodeConfigArgs>;
        /**
         * Defines the type of node, such as coordinating nodes.
         */
        nodeType?: pulumi.Input<enums.opensearchservice.DomainNodeOptionNodeType>;
    }
    interface DomainNodeToNodeEncryptionOptionsArgs {
        /**
         * Specifies to enable or disable node-to-node encryption on the domain. Required if you enable fine-grained access control in [AdvancedSecurityOptionsInput](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-opensearchservice-domain-advancedsecurityoptionsinput.html) .
         */
        enabled?: pulumi.Input<boolean>;
    }
    interface DomainOffPeakWindowArgs {
        /**
         * The desired start time for an off-peak maintenance window.
         */
        windowStartTime?: pulumi.Input<inputs.opensearchservice.DomainWindowStartTimeArgs>;
    }
    interface DomainOffPeakWindowOptionsArgs {
        /**
         * Specifies whether off-peak window settings are enabled for the domain.
         */
        enabled?: pulumi.Input<boolean>;
        /**
         * Off-peak window settings for the domain.
         */
        offPeakWindow?: pulumi.Input<inputs.opensearchservice.DomainOffPeakWindowArgs>;
    }
    interface DomainSamlOptionsArgs {
        /**
         * True to enable SAML authentication for a domain.
         */
        enabled?: pulumi.Input<boolean>;
        /**
         * The SAML Identity Provider's information.
         */
        idp?: pulumi.Input<inputs.opensearchservice.DomainIdpArgs>;
        /**
         * The backend role that the SAML master user is mapped to.
         */
        masterBackendRole?: pulumi.Input<string>;
        /**
         * The SAML master user name, which is stored in the domain's internal user database.
         */
        masterUserName?: pulumi.Input<string>;
        /**
         * Element of the SAML assertion to use for backend roles. Default is `roles` .
         */
        rolesKey?: pulumi.Input<string>;
        /**
         * The duration, in minutes, after which a user session becomes inactive. Acceptable values are between 1 and 1440, and the default value is 60.
         */
        sessionTimeoutMinutes?: pulumi.Input<number>;
        /**
         * Element of the SAML assertion to use for the user name. Default is `NameID` .
         */
        subjectKey?: pulumi.Input<string>;
    }
    interface DomainSnapshotOptionsArgs {
        /**
         * The hour in UTC during which the service takes an automated daily snapshot of the indexes in the OpenSearch Service domain. For example, if you specify 0, OpenSearch Service takes an automated snapshot everyday between midnight and 1 am. You can specify a value between 0 and 23.
         */
        automatedSnapshotStartHour?: pulumi.Input<number>;
    }
    interface DomainSoftwareUpdateOptionsArgs {
        /**
         * Specifies whether automatic service software updates are enabled for the domain.
         */
        autoSoftwareUpdateEnabled?: pulumi.Input<boolean>;
    }
    interface DomainVpcOptionsArgs {
        /**
         * The list of security group IDs that are associated with the VPC endpoints for the domain. If you don't provide a security group ID, OpenSearch Service uses the default security group for the VPC. To learn more, see [Security groups for your VPC](https://docs.aws.amazon.com/vpc/latest/userguide/VPC_SecurityGroups.html) in the *Amazon VPC User Guide* .
         */
        securityGroupIds?: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * Provide one subnet ID for each Availability Zone that your domain uses. For example, you must specify three subnet IDs for a three-AZ domain. To learn more, see [VPCs and subnets](https://docs.aws.amazon.com/vpc/latest/userguide/VPC_Subnets.html) in the *Amazon VPC User Guide* .
         *
         * If you specify more than one subnet, you must also configure `ZoneAwarenessEnabled` and `ZoneAwarenessConfig` within [ClusterConfig](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-opensearchservice-domain-clusterconfig.html) , otherwise you'll see the error "You must specify exactly one subnet" during template creation.
         */
        subnetIds?: pulumi.Input<pulumi.Input<string>[]>;
    }
    interface DomainWindowStartTimeArgs {
        /**
         * The start hour of the window in Coordinated Universal Time (UTC), using 24-hour time. For example, 17 refers to 5:00 P.M. UTC. The minimum value is 0 and the maximum value is 23.
         */
        hours: pulumi.Input<number>;
        /**
         * The start minute of the window, in UTC. The minimum value is 0 and the maximum value is 59.
         */
        minutes: pulumi.Input<number>;
    }
    interface DomainZoneAwarenessConfigArgs {
        /**
         * If you enabled multiple Availability Zones (AZs), the number of AZs that you want the domain to use.
         *
         * Valid values are `2` and `3` . Default is 2.
         */
        availabilityZoneCount?: pulumi.Input<number>;
    }
    /**
     * Options for configuring IAM Identity Center
     */
    interface IamIdentityCenterOptionsPropertiesArgs {
        /**
         * Whether IAM Identity Center is enabled.
         */
        enabled?: pulumi.Input<boolean>;
        /**
         * The ARN of the IAM Identity Center instance.
         */
        iamIdentityCenterInstanceArn?: any;
        /**
         * The ARN of the IAM role for Identity Center application.
         */
        iamRoleForIdentityCenterApplicationArn?: pulumi.Input<string>;
    }
}
export declare namespace opsworkscm {
    interface ServerEngineAttributeArgs {
        /**
         * The name of the engine attribute.
         *
         * *Attribute name for Chef Automate servers:*
         *
         * - `CHEF_AUTOMATE_ADMIN_PASSWORD`
         *
         * *Attribute names for Puppet Enterprise servers:*
         *
         * - `PUPPET_ADMIN_PASSWORD`
         * - `PUPPET_R10K_REMOTE`
         * - `PUPPET_R10K_PRIVATE_KEY`
         */
        name?: pulumi.Input<string>;
        /**
         * The value of the engine attribute.
         *
         * *Attribute value for Chef Automate servers:*
         *
         * - `CHEF_AUTOMATE_PIVOTAL_KEY` : A base64-encoded RSA public key. The corresponding private key is required to access the Chef API. You can generate this key by running the following [OpenSSL](https://docs.aws.amazon.com/https://www.openssl.org/) command on Linux-based computers.
         *
         * `openssl genrsa -out *pivotal_key_file_name* .pem 2048`
         *
         * On Windows-based computers, you can use the PuTTYgen utility to generate a base64-encoded RSA private key. For more information, see [PuTTYgen - Key Generator for PuTTY on Windows](https://docs.aws.amazon.com/https://www.ssh.com/ssh/putty/windows/puttygen) on SSH.com.
         *
         * *Attribute values for Puppet Enterprise servers:*
         *
         * - `PUPPET_ADMIN_PASSWORD` : An administrator password that you can use to sign in to the Puppet Enterprise console webpage after the server is online. The password must use between 8 and 32 ASCII characters.
         * - `PUPPET_R10K_REMOTE` : The r10k remote is the URL of your control repository (for example, ssh://git@your.git-repo.com:user/control-repo.git). Specifying an r10k remote opens TCP port 8170.
         * - `PUPPET_R10K_PRIVATE_KEY` : If you are using a private Git repository, add `PUPPET_R10K_PRIVATE_KEY` to specify a PEM-encoded private SSH key.
         */
        value?: pulumi.Input<string>;
    }
}
export declare namespace organizations {
}
export declare namespace osis {
    /**
     * Key-value pairs to configure buffering.
     */
    interface PipelineBufferOptionsArgs {
        /**
         * Whether persistent buffering should be enabled.
         */
        persistentBufferEnabled: pulumi.Input<boolean>;
    }
    /**
     * Key-value pairs to configure encryption at rest.
     */
    interface PipelineEncryptionAtRestOptionsArgs {
        /**
         * The KMS key to use for encrypting data. By default an AWS owned key is used
         */
        kmsKeyArn: pulumi.Input<string>;
    }
    /**
     * Key-value pairs to configure log publishing.
     */
    interface PipelineLogPublishingOptionsArgs {
        /**
         * The destination for OpenSearch Ingestion Service logs sent to Amazon CloudWatch.
         */
        cloudWatchLogDestination?: pulumi.Input<inputs.osis.PipelineLogPublishingOptionsCloudWatchLogDestinationPropertiesArgs>;
        /**
         * Whether logs should be published.
         */
        isLoggingEnabled?: pulumi.Input<boolean>;
    }
    /**
     * The destination for OpenSearch Ingestion Service logs sent to Amazon CloudWatch.
     */
    interface PipelineLogPublishingOptionsCloudWatchLogDestinationPropertiesArgs {
        logGroup: pulumi.Input<string>;
    }
    /**
     * Container for the values required to configure VPC access for the pipeline. If you don't specify these values, OpenSearch Ingestion Service creates the pipeline with a public endpoint.
     */
    interface PipelineVpcOptionsArgs {
        /**
         * A list of security groups associated with the VPC endpoint.
         */
        securityGroupIds?: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * A list of subnet IDs associated with the VPC endpoint.
         */
        subnetIds: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * Options for attaching a VPC to the pipeline.
         */
        vpcAttachmentOptions?: pulumi.Input<inputs.osis.PipelineVpcOptionsVpcAttachmentOptionsPropertiesArgs>;
        /**
         * Defines whether you or Amazon OpenSearch Ingestion service create and manage the VPC endpoint configured for the pipeline.
         */
        vpcEndpointManagement?: pulumi.Input<enums.osis.PipelineVpcOptionsVpcEndpointManagement>;
    }
    /**
     * Options for attaching a VPC to the pipeline.
     */
    interface PipelineVpcOptionsVpcAttachmentOptionsPropertiesArgs {
        /**
         * Whether the pipeline should be attached to the provided VPC
         */
        attachToVpc: pulumi.Input<boolean>;
        /**
         * The CIDR block to be reserved for OpenSearch Ingestion to create elastic network interfaces (ENIs).
         */
        cidrBlock: pulumi.Input<string>;
    }
}
export declare namespace panorama {
    /**
     * Parameter overrides for an application instance. This is a JSON document that has a single key (``PayloadData``) where the value is an escaped string representation of the overrides document.
     */
    interface ApplicationInstanceManifestOverridesPayloadArgs {
        /**
         * The overrides document.
         */
        payloadData?: pulumi.Input<string>;
    }
    /**
     * A application verion's manifest file. This is a JSON document that has a single key (``PayloadData``) where the value is an escaped string representation of the application manifest (``graph.json``). This file is located in the ``graphs`` folder in your application source.
     */
    interface ApplicationInstanceManifestPayloadArgs {
        /**
         * The application manifest.
         */
        payloadData?: pulumi.Input<string>;
    }
    /**
     * A storage location.
     */
    interface PackageStorageLocationArgs {
        /**
         * The location's binary prefix.
         */
        binaryPrefixLocation?: pulumi.Input<string>;
        /**
         * The location's bucket.
         */
        bucket?: pulumi.Input<string>;
        /**
         * The location's generated prefix.
         */
        generatedPrefixLocation?: pulumi.Input<string>;
        /**
         * The location's manifest prefix.
         */
        manifestPrefixLocation?: pulumi.Input<string>;
        /**
         * The location's repo prefix.
         */
        repoPrefixLocation?: pulumi.Input<string>;
    }
}
export declare namespace paymentcryptography {
    interface KeyAttributesArgs {
        /**
         * The key algorithm to be use during creation of an AWS Payment Cryptography key.
         *
         * For symmetric keys, AWS Payment Cryptography supports `AES` and `TDES` algorithms. For asymmetric keys, AWS Payment Cryptography supports `RSA` and `ECC_NIST` algorithms.
         */
        keyAlgorithm: pulumi.Input<enums.paymentcryptography.KeyAlgorithm>;
        /**
         * The type of AWS Payment Cryptography key to create, which determines the classiﬁcation of the cryptographic method and whether AWS Payment Cryptography key contains a symmetric key or an asymmetric key pair.
         */
        keyClass: pulumi.Input<enums.paymentcryptography.KeyClass>;
        /**
         * The list of cryptographic operations that you can perform using the key.
         */
        keyModesOfUse: pulumi.Input<inputs.paymentcryptography.KeyModesOfUseArgs>;
        /**
         * The cryptographic usage of an AWS Payment Cryptography key as deﬁned in section A.5.2 of the TR-31 spec.
         */
        keyUsage: pulumi.Input<enums.paymentcryptography.KeyUsage>;
    }
    interface KeyModesOfUseArgs {
        /**
         * Speciﬁes whether an AWS Payment Cryptography key can be used to decrypt data.
         */
        decrypt?: pulumi.Input<boolean>;
        /**
         * Speciﬁes whether an AWS Payment Cryptography key can be used to derive new keys.
         */
        deriveKey?: pulumi.Input<boolean>;
        /**
         * Speciﬁes whether an AWS Payment Cryptography key can be used to encrypt data.
         */
        encrypt?: pulumi.Input<boolean>;
        /**
         * Speciﬁes whether an AWS Payment Cryptography key can be used to generate and verify other card and PIN verification keys.
         */
        generate?: pulumi.Input<boolean>;
        /**
         * Speciﬁes whether an AWS Payment Cryptography key has no special restrictions other than the restrictions implied by `KeyUsage` .
         */
        noRestrictions?: pulumi.Input<boolean>;
        /**
         * Speciﬁes whether an AWS Payment Cryptography key can be used for signing.
         */
        sign?: pulumi.Input<boolean>;
        unwrap?: pulumi.Input<boolean>;
        /**
         * Speciﬁes whether an AWS Payment Cryptography key can be used to verify signatures.
         */
        verify?: pulumi.Input<boolean>;
        /**
         * Speciﬁes whether an AWS Payment Cryptography key can be used to wrap other keys.
         */
        wrap?: pulumi.Input<boolean>;
    }
}
export declare namespace pcaconnectorad {
    interface ConnectorVpcInformationArgs {
        /**
         * The VPC IP address type.
         */
        ipAddressType?: pulumi.Input<enums.pcaconnectorad.ConnectorVpcInformationIpAddressType>;
        /**
         * The security groups used with the connector. You can use a maximum of 4 security groups with a connector.
         */
        securityGroupIds: pulumi.Input<pulumi.Input<string>[]>;
    }
    interface TemplateApplicationPoliciesArgs {
        critical?: pulumi.Input<boolean>;
        policies: pulumi.Input<pulumi.Input<inputs.pcaconnectorad.TemplateApplicationPolicy0PropertiesArgs | inputs.pcaconnectorad.TemplateApplicationPolicy1PropertiesArgs>[]>;
    }
    interface TemplateApplicationPolicy0PropertiesArgs {
        policyType: pulumi.Input<enums.pcaconnectorad.TemplateApplicationPolicyType>;
    }
    interface TemplateApplicationPolicy1PropertiesArgs {
        policyObjectIdentifier: pulumi.Input<string>;
    }
    interface TemplateCertificateValidityArgs {
        renewalPeriod: pulumi.Input<inputs.pcaconnectorad.TemplateValidityPeriodArgs>;
        validityPeriod: pulumi.Input<inputs.pcaconnectorad.TemplateValidityPeriodArgs>;
    }
    interface TemplateDefinition0PropertiesArgs {
        templateV2: pulumi.Input<inputs.pcaconnectorad.TemplateV2Args>;
    }
    interface TemplateDefinition1PropertiesArgs {
        templateV3: pulumi.Input<inputs.pcaconnectorad.TemplateV3Args>;
    }
    interface TemplateDefinition2PropertiesArgs {
        templateV4: pulumi.Input<inputs.pcaconnectorad.TemplateV4Args>;
    }
    interface TemplateEnrollmentFlagsV2Args {
        enableKeyReuseOnNtTokenKeysetStorageFull?: pulumi.Input<boolean>;
        includeSymmetricAlgorithms?: pulumi.Input<boolean>;
        noSecurityExtension?: pulumi.Input<boolean>;
        removeInvalidCertificateFromPersonalStore?: pulumi.Input<boolean>;
        userInteractionRequired?: pulumi.Input<boolean>;
    }
    interface TemplateEnrollmentFlagsV3Args {
        enableKeyReuseOnNtTokenKeysetStorageFull?: pulumi.Input<boolean>;
        includeSymmetricAlgorithms?: pulumi.Input<boolean>;
        noSecurityExtension?: pulumi.Input<boolean>;
        removeInvalidCertificateFromPersonalStore?: pulumi.Input<boolean>;
        userInteractionRequired?: pulumi.Input<boolean>;
    }
    interface TemplateEnrollmentFlagsV4Args {
        enableKeyReuseOnNtTokenKeysetStorageFull?: pulumi.Input<boolean>;
        includeSymmetricAlgorithms?: pulumi.Input<boolean>;
        noSecurityExtension?: pulumi.Input<boolean>;
        removeInvalidCertificateFromPersonalStore?: pulumi.Input<boolean>;
        userInteractionRequired?: pulumi.Input<boolean>;
    }
    interface TemplateExtensionsV2Args {
        applicationPolicies?: pulumi.Input<inputs.pcaconnectorad.TemplateApplicationPoliciesArgs>;
        keyUsage: pulumi.Input<inputs.pcaconnectorad.TemplateKeyUsageArgs>;
    }
    interface TemplateExtensionsV3Args {
        applicationPolicies?: pulumi.Input<inputs.pcaconnectorad.TemplateApplicationPoliciesArgs>;
        keyUsage: pulumi.Input<inputs.pcaconnectorad.TemplateKeyUsageArgs>;
    }
    interface TemplateExtensionsV4Args {
        applicationPolicies?: pulumi.Input<inputs.pcaconnectorad.TemplateApplicationPoliciesArgs>;
        keyUsage: pulumi.Input<inputs.pcaconnectorad.TemplateKeyUsageArgs>;
    }
    interface TemplateGeneralFlagsV2Args {
        autoEnrollment?: pulumi.Input<boolean>;
        machineType?: pulumi.Input<boolean>;
    }
    interface TemplateGeneralFlagsV3Args {
        autoEnrollment?: pulumi.Input<boolean>;
        machineType?: pulumi.Input<boolean>;
    }
    interface TemplateGeneralFlagsV4Args {
        autoEnrollment?: pulumi.Input<boolean>;
        machineType?: pulumi.Input<boolean>;
    }
    interface TemplateGroupAccessControlEntryAccessRightsArgs {
        /**
         * Allow or deny an Active Directory group from autoenrolling certificates issued against a template. The Active Directory group must be allowed to enroll to allow autoenrollment
         */
        autoEnroll?: pulumi.Input<enums.pcaconnectorad.TemplateGroupAccessControlEntryAccessRight>;
        /**
         * Allow or deny an Active Directory group from enrolling certificates issued against a template.
         */
        enroll?: pulumi.Input<enums.pcaconnectorad.TemplateGroupAccessControlEntryAccessRight>;
    }
    interface TemplateKeyUsageArgs {
        critical?: pulumi.Input<boolean>;
        usageFlags: pulumi.Input<inputs.pcaconnectorad.TemplateKeyUsageFlagsArgs>;
    }
    interface TemplateKeyUsageFlagsArgs {
        dataEncipherment?: pulumi.Input<boolean>;
        digitalSignature?: pulumi.Input<boolean>;
        keyAgreement?: pulumi.Input<boolean>;
        keyEncipherment?: pulumi.Input<boolean>;
        nonRepudiation?: pulumi.Input<boolean>;
    }
    interface TemplateKeyUsageProperty0PropertiesArgs {
        propertyType: pulumi.Input<enums.pcaconnectorad.TemplateKeyUsagePropertyType>;
    }
    interface TemplateKeyUsageProperty1PropertiesArgs {
        propertyFlags: pulumi.Input<inputs.pcaconnectorad.TemplateKeyUsagePropertyFlagsArgs>;
    }
    interface TemplateKeyUsagePropertyFlagsArgs {
        decrypt?: pulumi.Input<boolean>;
        keyAgreement?: pulumi.Input<boolean>;
        sign?: pulumi.Input<boolean>;
    }
    interface TemplatePrivateKeyAttributesV2Args {
        cryptoProviders?: pulumi.Input<pulumi.Input<string>[]>;
        keySpec: pulumi.Input<enums.pcaconnectorad.TemplateKeySpec>;
        minimalKeyLength: pulumi.Input<number>;
    }
    interface TemplatePrivateKeyAttributesV3Args {
        algorithm: pulumi.Input<enums.pcaconnectorad.TemplatePrivateKeyAlgorithm>;
        cryptoProviders?: pulumi.Input<pulumi.Input<string>[]>;
        keySpec: pulumi.Input<enums.pcaconnectorad.TemplateKeySpec>;
        keyUsageProperty: pulumi.Input<inputs.pcaconnectorad.TemplateKeyUsageProperty0PropertiesArgs | inputs.pcaconnectorad.TemplateKeyUsageProperty1PropertiesArgs>;
        minimalKeyLength: pulumi.Input<number>;
    }
    interface TemplatePrivateKeyAttributesV4Args {
        algorithm?: pulumi.Input<enums.pcaconnectorad.TemplatePrivateKeyAlgorithm>;
        cryptoProviders?: pulumi.Input<pulumi.Input<string>[]>;
        keySpec: pulumi.Input<enums.pcaconnectorad.TemplateKeySpec>;
        keyUsageProperty?: pulumi.Input<inputs.pcaconnectorad.TemplateKeyUsageProperty0PropertiesArgs | inputs.pcaconnectorad.TemplateKeyUsageProperty1PropertiesArgs>;
        minimalKeyLength: pulumi.Input<number>;
    }
    interface TemplatePrivateKeyFlagsV2Args {
        clientVersion: pulumi.Input<enums.pcaconnectorad.TemplateClientCompatibilityV2>;
        exportableKey?: pulumi.Input<boolean>;
        strongKeyProtectionRequired?: pulumi.Input<boolean>;
    }
    interface TemplatePrivateKeyFlagsV3Args {
        clientVersion: pulumi.Input<enums.pcaconnectorad.TemplateClientCompatibilityV3>;
        exportableKey?: pulumi.Input<boolean>;
        requireAlternateSignatureAlgorithm?: pulumi.Input<boolean>;
        strongKeyProtectionRequired?: pulumi.Input<boolean>;
    }
    interface TemplatePrivateKeyFlagsV4Args {
        clientVersion: pulumi.Input<enums.pcaconnectorad.TemplateClientCompatibilityV4>;
        exportableKey?: pulumi.Input<boolean>;
        requireAlternateSignatureAlgorithm?: pulumi.Input<boolean>;
        requireSameKeyRenewal?: pulumi.Input<boolean>;
        strongKeyProtectionRequired?: pulumi.Input<boolean>;
        useLegacyProvider?: pulumi.Input<boolean>;
    }
    interface TemplateSubjectNameFlagsV2Args {
        requireCommonName?: pulumi.Input<boolean>;
        requireDirectoryPath?: pulumi.Input<boolean>;
        requireDnsAsCn?: pulumi.Input<boolean>;
        requireEmail?: pulumi.Input<boolean>;
        sanRequireDirectoryGuid?: pulumi.Input<boolean>;
        sanRequireDns?: pulumi.Input<boolean>;
        sanRequireDomainDns?: pulumi.Input<boolean>;
        sanRequireEmail?: pulumi.Input<boolean>;
        sanRequireSpn?: pulumi.Input<boolean>;
        sanRequireUpn?: pulumi.Input<boolean>;
    }
    interface TemplateSubjectNameFlagsV3Args {
        requireCommonName?: pulumi.Input<boolean>;
        requireDirectoryPath?: pulumi.Input<boolean>;
        requireDnsAsCn?: pulumi.Input<boolean>;
        requireEmail?: pulumi.Input<boolean>;
        sanRequireDirectoryGuid?: pulumi.Input<boolean>;
        sanRequireDns?: pulumi.Input<boolean>;
        sanRequireDomainDns?: pulumi.Input<boolean>;
        sanRequireEmail?: pulumi.Input<boolean>;
        sanRequireSpn?: pulumi.Input<boolean>;
        sanRequireUpn?: pulumi.Input<boolean>;
    }
    interface TemplateSubjectNameFlagsV4Args {
        requireCommonName?: pulumi.Input<boolean>;
        requireDirectoryPath?: pulumi.Input<boolean>;
        requireDnsAsCn?: pulumi.Input<boolean>;
        requireEmail?: pulumi.Input<boolean>;
        sanRequireDirectoryGuid?: pulumi.Input<boolean>;
        sanRequireDns?: pulumi.Input<boolean>;
        sanRequireDomainDns?: pulumi.Input<boolean>;
        sanRequireEmail?: pulumi.Input<boolean>;
        sanRequireSpn?: pulumi.Input<boolean>;
        sanRequireUpn?: pulumi.Input<boolean>;
    }
    interface TemplateV2Args {
        certificateValidity: pulumi.Input<inputs.pcaconnectorad.TemplateCertificateValidityArgs>;
        enrollmentFlags: pulumi.Input<inputs.pcaconnectorad.TemplateEnrollmentFlagsV2Args>;
        extensions: pulumi.Input<inputs.pcaconnectorad.TemplateExtensionsV2Args>;
        generalFlags: pulumi.Input<inputs.pcaconnectorad.TemplateGeneralFlagsV2Args>;
        privateKeyAttributes: pulumi.Input<inputs.pcaconnectorad.TemplatePrivateKeyAttributesV2Args>;
        privateKeyFlags: pulumi.Input<inputs.pcaconnectorad.TemplatePrivateKeyFlagsV2Args>;
        subjectNameFlags: pulumi.Input<inputs.pcaconnectorad.TemplateSubjectNameFlagsV2Args>;
        supersededTemplates?: pulumi.Input<pulumi.Input<string>[]>;
    }
    interface TemplateV3Args {
        certificateValidity: pulumi.Input<inputs.pcaconnectorad.TemplateCertificateValidityArgs>;
        enrollmentFlags: pulumi.Input<inputs.pcaconnectorad.TemplateEnrollmentFlagsV3Args>;
        extensions: pulumi.Input<inputs.pcaconnectorad.TemplateExtensionsV3Args>;
        generalFlags: pulumi.Input<inputs.pcaconnectorad.TemplateGeneralFlagsV3Args>;
        hashAlgorithm: pulumi.Input<enums.pcaconnectorad.TemplateHashAlgorithm>;
        privateKeyAttributes: pulumi.Input<inputs.pcaconnectorad.TemplatePrivateKeyAttributesV3Args>;
        privateKeyFlags: pulumi.Input<inputs.pcaconnectorad.TemplatePrivateKeyFlagsV3Args>;
        subjectNameFlags: pulumi.Input<inputs.pcaconnectorad.TemplateSubjectNameFlagsV3Args>;
        supersededTemplates?: pulumi.Input<pulumi.Input<string>[]>;
    }
    interface TemplateV4Args {
        certificateValidity: pulumi.Input<inputs.pcaconnectorad.TemplateCertificateValidityArgs>;
        enrollmentFlags: pulumi.Input<inputs.pcaconnectorad.TemplateEnrollmentFlagsV4Args>;
        extensions: pulumi.Input<inputs.pcaconnectorad.TemplateExtensionsV4Args>;
        generalFlags: pulumi.Input<inputs.pcaconnectorad.TemplateGeneralFlagsV4Args>;
        hashAlgorithm?: pulumi.Input<enums.pcaconnectorad.TemplateHashAlgorithm>;
        privateKeyAttributes: pulumi.Input<inputs.pcaconnectorad.TemplatePrivateKeyAttributesV4Args>;
        privateKeyFlags: pulumi.Input<inputs.pcaconnectorad.TemplatePrivateKeyFlagsV4Args>;
        subjectNameFlags: pulumi.Input<inputs.pcaconnectorad.TemplateSubjectNameFlagsV4Args>;
        supersededTemplates?: pulumi.Input<pulumi.Input<string>[]>;
    }
    interface TemplateValidityPeriodArgs {
        period: pulumi.Input<number>;
        periodType: pulumi.Input<enums.pcaconnectorad.TemplateValidityPeriodType>;
    }
}
export declare namespace pcaconnectorscep {
    interface ConnectorMobileDeviceManagementArgs {
    }
}
export declare namespace pcs {
    /**
     * An EC2 instance configuration AWS PCS uses to launch compute nodes.
     */
    interface ComputeNodeGroupInstanceConfigArgs {
        /**
         * The EC2 instance type that AWS PCS can provision in the compute node group.
         */
        instanceType?: pulumi.Input<string>;
    }
    /**
     * Additional settings that directly map to Slurm settings.
     */
    interface ComputeNodeGroupSlurmCustomSettingArgs {
        /**
         * AWS PCS supports configuration of the following Slurm parameters for compute node groups: Weight and RealMemory.
         */
        parameterName: pulumi.Input<string>;
        /**
         * The value for the configured Slurm setting.
         */
        parameterValue: pulumi.Input<string>;
    }
    /**
     * An Amazon EC2 launch template AWS PCS uses to launch compute nodes.
     */
    interface CustomLaunchTemplatePropertiesArgs {
        /**
         * The ID of the EC2 launch template to use to provision instances.
         */
        templateId?: pulumi.Input<string>;
        /**
         * The version of the EC2 launch template to use to provision instances.
         */
        version: pulumi.Input<string>;
    }
    /**
     * The networking configuration for the cluster's control plane.
     */
    interface NetworkingPropertiesArgs {
        /**
         * The list of security group IDs associated with the Elastic Network Interface (ENI) created in subnets.
         */
        securityGroupIds?: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * The list of subnet IDs where AWS PCS creates an Elastic Network Interface (ENI) to enable communication between managed controllers and AWS PCS resources. The subnet must have an available IP address, cannot reside in AWS Outposts, AWS Wavelength, or an AWS Local Zone. AWS PCS currently supports only 1 subnet in this list.
         */
        subnetIds?: pulumi.Input<pulumi.Input<string>[]>;
    }
    /**
     * The compute node group configuration for a queue.
     */
    interface QueueComputeNodeGroupConfigurationArgs {
        /**
         * The compute node group ID for the compute node group configuration.
         */
        computeNodeGroupId?: pulumi.Input<string>;
    }
    /**
     * Specifies the boundaries of the compute node group auto scaling.
     */
    interface ScalingConfigurationPropertiesArgs {
        /**
         * The upper bound of the number of instances allowed in the compute fleet.
         */
        maxInstanceCount: pulumi.Input<number>;
        /**
         * The lower bound of the number of instances allowed in the compute fleet.
         */
        minInstanceCount: pulumi.Input<number>;
    }
    /**
     * The cluster management and job scheduling software associated with the cluster.
     */
    interface SchedulerPropertiesArgs {
        /**
         * The software AWS PCS uses to manage cluster scaling and job scheduling.
         */
        type: pulumi.Input<enums.pcs.ClusterSchedulerPropertiesType>;
        /**
         * The version of the specified scheduling software that AWS PCS uses to manage cluster scaling and job scheduling.
         */
        version: pulumi.Input<string>;
    }
    /**
     * Additional options related to the Slurm scheduler.
     */
    interface SlurmConfigurationPropertiesArgs {
        /**
         * Additional Slurm-specific configuration that directly maps to Slurm settings.
         */
        slurmCustomSettings?: pulumi.Input<pulumi.Input<inputs.pcs.ComputeNodeGroupSlurmCustomSettingArgs>[]>;
    }
    /**
     * Additional configuration when you specify SPOT as the purchase option.
     */
    interface SpotOptionsPropertiesArgs {
        /**
         * The Amazon EC2 allocation strategy AWS PCS uses to provision EC2 instances. AWS PCS supports lowest price, capacity optimized, and price capacity optimized. If you don't provide this option, it defaults to price capacity optimized.
         */
        allocationStrategy?: pulumi.Input<enums.pcs.ComputeNodeGroupSpotOptionsPropertiesAllocationStrategy>;
    }
}
export declare namespace personalize {
    /**
     * Initial DatasetImportJob for the created dataset
     */
    interface DatasetImportJobArgs {
        /**
         * The Amazon S3 bucket that contains the training data to import.
         */
        dataSource?: pulumi.Input<inputs.personalize.DatasetImportJobDataSourcePropertiesArgs>;
        /**
         * The ARN of the dataset that receives the imported data
         */
        datasetArn?: pulumi.Input<string>;
        /**
         * The ARN of the dataset import job
         */
        datasetImportJobArn?: pulumi.Input<string>;
        /**
         * The name for the dataset import job.
         */
        jobName?: pulumi.Input<string>;
        /**
         * The ARN of the IAM role that has permissions to read from the Amazon S3 data source.
         */
        roleArn?: pulumi.Input<string>;
    }
    /**
     * The Amazon S3 bucket that contains the training data to import.
     */
    interface DatasetImportJobDataSourcePropertiesArgs {
        /**
         * The path to the Amazon S3 bucket where the data that you want to upload to your dataset is stored.
         */
        dataLocation?: pulumi.Input<string>;
    }
    /**
     * Provides the name and values of a Categorical hyperparameter.
     */
    interface SolutionCategoricalHyperParameterRangeArgs {
        /**
         * The name of the hyperparameter.
         */
        name?: pulumi.Input<string>;
        /**
         * A list of the categories for the hyperparameter.
         */
        values?: pulumi.Input<pulumi.Input<string>[]>;
    }
    /**
     * The configuration to use with the solution. When performAutoML is set to true, Amazon Personalize only evaluates the autoMLConfig section of the solution configuration.
     */
    interface SolutionConfigArgs {
        /**
         * Lists the hyperparameter names and ranges.
         */
        algorithmHyperParameters?: pulumi.Input<{
            [key: string]: pulumi.Input<string>;
        }>;
        /**
         * The AutoMLConfig object containing a list of recipes to search when AutoML is performed.
         */
        autoMlConfig?: pulumi.Input<inputs.personalize.SolutionConfigAutoMlConfigPropertiesArgs>;
        /**
         * Only events with a value greater than or equal to this threshold are used for training a model.
         */
        eventValueThreshold?: pulumi.Input<string>;
        /**
         * Lists the feature transformation parameters.
         */
        featureTransformationParameters?: pulumi.Input<{
            [key: string]: pulumi.Input<string>;
        }>;
        /**
         * Describes the properties for hyperparameter optimization (HPO)
         */
        hpoConfig?: pulumi.Input<inputs.personalize.SolutionConfigHpoConfigPropertiesArgs>;
    }
    /**
     * The AutoMLConfig object containing a list of recipes to search when AutoML is performed.
     */
    interface SolutionConfigAutoMlConfigPropertiesArgs {
        /**
         * The metric to optimize.
         */
        metricName?: pulumi.Input<string>;
        /**
         * The list of candidate recipes.
         */
        recipeList?: pulumi.Input<pulumi.Input<string>[]>;
    }
    /**
     * Describes the properties for hyperparameter optimization (HPO)
     */
    interface SolutionConfigHpoConfigPropertiesArgs {
        /**
         * The hyperparameters and their allowable ranges
         */
        algorithmHyperParameterRanges?: pulumi.Input<inputs.personalize.SolutionConfigHpoConfigPropertiesAlgorithmHyperParameterRangesPropertiesArgs>;
        /**
         * The metric to optimize during HPO.
         */
        hpoObjective?: pulumi.Input<inputs.personalize.SolutionConfigHpoConfigPropertiesHpoObjectivePropertiesArgs>;
        /**
         * Describes the resource configuration for hyperparameter optimization (HPO).
         */
        hpoResourceConfig?: pulumi.Input<inputs.personalize.SolutionConfigHpoConfigPropertiesHpoResourceConfigPropertiesArgs>;
    }
    /**
     * The hyperparameters and their allowable ranges
     */
    interface SolutionConfigHpoConfigPropertiesAlgorithmHyperParameterRangesPropertiesArgs {
        /**
         * The categorical hyperparameters and their ranges.
         */
        categoricalHyperParameterRanges?: pulumi.Input<pulumi.Input<inputs.personalize.SolutionCategoricalHyperParameterRangeArgs>[]>;
        /**
         * The continuous hyperparameters and their ranges.
         */
        continuousHyperParameterRanges?: pulumi.Input<pulumi.Input<inputs.personalize.SolutionContinuousHyperParameterRangeArgs>[]>;
        /**
         * The integer hyperparameters and their ranges.
         */
        integerHyperParameterRanges?: pulumi.Input<pulumi.Input<inputs.personalize.SolutionIntegerHyperParameterRangeArgs>[]>;
    }
    /**
     * The metric to optimize during HPO.
     */
    interface SolutionConfigHpoConfigPropertiesHpoObjectivePropertiesArgs {
        /**
         * The name of the metric
         */
        metricName?: pulumi.Input<string>;
        /**
         * A regular expression for finding the metric in the training job logs.
         */
        metricRegex?: pulumi.Input<string>;
        /**
         * The type of the metric. Valid values are Maximize and Minimize.
         */
        type?: pulumi.Input<enums.personalize.SolutionConfigHpoConfigPropertiesHpoObjectivePropertiesType>;
    }
    /**
     * Describes the resource configuration for hyperparameter optimization (HPO).
     */
    interface SolutionConfigHpoConfigPropertiesHpoResourceConfigPropertiesArgs {
        /**
         * The maximum number of training jobs when you create a solution version. The maximum value for maxNumberOfTrainingJobs is 40.
         */
        maxNumberOfTrainingJobs?: pulumi.Input<string>;
        /**
         * The maximum number of parallel training jobs when you create a solution version. The maximum value for maxParallelTrainingJobs is 10.
         */
        maxParallelTrainingJobs?: pulumi.Input<string>;
    }
    /**
     * Provides the name and range of a continuous hyperparameter.
     */
    interface SolutionContinuousHyperParameterRangeArgs {
        /**
         * The maximum allowable value for the hyperparameter.
         */
        maxValue?: pulumi.Input<number>;
        /**
         * The minimum allowable value for the hyperparameter.
         */
        minValue?: pulumi.Input<number>;
        /**
         * The name of the hyperparameter.
         */
        name?: pulumi.Input<string>;
    }
    /**
     * Provides the name and range of an integer-valued hyperparameter.
     */
    interface SolutionIntegerHyperParameterRangeArgs {
        /**
         * The maximum allowable value for the hyperparameter.
         */
        maxValue?: pulumi.Input<number>;
        /**
         * The minimum allowable value for the hyperparameter.
         */
        minValue?: pulumi.Input<number>;
        /**
         * The name of the hyperparameter.
         */
        name?: pulumi.Input<string>;
    }
}
export declare namespace pinpoint {
    interface InAppTemplateBodyConfigArgs {
        /**
         * The text alignment of the main body text of the message. Acceptable values: `LEFT` , `CENTER` , `RIGHT` .
         */
        alignment?: pulumi.Input<enums.pinpoint.InAppTemplateAlignment>;
        /**
         * The main body text of the message.
         */
        body?: pulumi.Input<string>;
        /**
         * The color of the body text, expressed as a hex color code (such as #000000 for black).
         */
        textColor?: pulumi.Input<string>;
    }
    interface InAppTemplateButtonConfigArgs {
        /**
         * Optional button configuration to use for in-app messages sent to Android devices. This button configuration overrides the default button configuration.
         */
        android?: pulumi.Input<inputs.pinpoint.InAppTemplateOverrideButtonConfigurationArgs>;
        /**
         * Specifies the default behavior of a button that appears in an in-app message. You can optionally add button configurations that specifically apply to iOS, Android, or web browser users.
         */
        defaultConfig?: pulumi.Input<inputs.pinpoint.InAppTemplateDefaultButtonConfigurationArgs>;
        /**
         * Optional button configuration to use for in-app messages sent to iOS devices. This button configuration overrides the default button configuration.
         */
        ios?: pulumi.Input<inputs.pinpoint.InAppTemplateOverrideButtonConfigurationArgs>;
        /**
         * Optional button configuration to use for in-app messages sent to web applications. This button configuration overrides the default button configuration.
         */
        web?: pulumi.Input<inputs.pinpoint.InAppTemplateOverrideButtonConfigurationArgs>;
    }
    interface InAppTemplateDefaultButtonConfigurationArgs {
        /**
         * The background color of a button, expressed as a hex color code (such as #000000 for black).
         */
        backgroundColor?: pulumi.Input<string>;
        /**
         * The border radius of a button.
         */
        borderRadius?: pulumi.Input<number>;
        /**
         * The action that occurs when a recipient chooses a button in an in-app message. You can specify one of the following:
         *
         * - `LINK` – A link to a web destination.
         * - `DEEP_LINK` – A link to a specific page in an application.
         * - `CLOSE` – Dismisses the message.
         */
        buttonAction?: pulumi.Input<enums.pinpoint.InAppTemplateButtonAction>;
        /**
         * The destination (such as a URL) for a button.
         */
        link?: pulumi.Input<string>;
        /**
         * The text that appears on a button in an in-app message.
         */
        text?: pulumi.Input<string>;
        /**
         * The color of the body text in a button, expressed as a hex color code (such as #000000 for black).
         */
        textColor?: pulumi.Input<string>;
    }
    interface InAppTemplateHeaderConfigArgs {
        /**
         * The text alignment of the title of the message. Acceptable values: `LEFT` , `CENTER` , `RIGHT` .
         */
        alignment?: pulumi.Input<enums.pinpoint.InAppTemplateAlignment>;
        /**
         * The title text of the in-app message.
         */
        header?: pulumi.Input<string>;
        /**
         * The color of the title text, expressed as a hex color code (such as #000000 for black).
         */
        textColor?: pulumi.Input<string>;
    }
    interface InAppTemplateInAppMessageContentArgs {
        /**
         * The background color for an in-app message banner, expressed as a hex color code (such as #000000 for black).
         */
        backgroundColor?: pulumi.Input<string>;
        /**
         * An object that contains configuration information about the header or title text of the in-app message.
         */
        bodyConfig?: pulumi.Input<inputs.pinpoint.InAppTemplateBodyConfigArgs>;
        /**
         * An object that contains configuration information about the header or title text of the in-app message.
         */
        headerConfig?: pulumi.Input<inputs.pinpoint.InAppTemplateHeaderConfigArgs>;
        /**
         * The URL of the image that appears on an in-app message banner.
         */
        imageUrl?: pulumi.Input<string>;
        /**
         * An object that contains configuration information about the primary button in an in-app message.
         */
        primaryBtn?: pulumi.Input<inputs.pinpoint.InAppTemplateButtonConfigArgs>;
        /**
         * An object that contains configuration information about the secondary button in an in-app message.
         */
        secondaryBtn?: pulumi.Input<inputs.pinpoint.InAppTemplateButtonConfigArgs>;
    }
    interface InAppTemplateOverrideButtonConfigurationArgs {
        /**
         * The action that occurs when a recipient chooses a button in an in-app message. You can specify one of the following:
         *
         * - `LINK` – A link to a web destination.
         * - `DEEP_LINK` – A link to a specific page in an application.
         * - `CLOSE` – Dismisses the message.
         */
        buttonAction?: pulumi.Input<enums.pinpoint.InAppTemplateButtonAction>;
        /**
         * The destination (such as a URL) for a button.
         */
        link?: pulumi.Input<string>;
    }
}
export declare namespace pipes {
    interface PipeAwsVpcConfigurationArgs {
        /**
         * Specifies whether the task's elastic network interface receives a public IP address. You can specify `ENABLED` only when `LaunchType` in `EcsParameters` is set to `FARGATE` .
         */
        assignPublicIp?: pulumi.Input<enums.pipes.PipeAssignPublicIp>;
        /**
         * Specifies the security groups associated with the task. These security groups must all be in the same VPC. You can specify as many as five security groups. If you do not specify a security group, the default security group for the VPC is used.
         */
        securityGroups?: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * Specifies the subnets associated with the task. These subnets must all be in the same VPC. You can specify as many as 16 subnets.
         */
        subnets: pulumi.Input<pulumi.Input<string>[]>;
    }
    interface PipeBatchArrayPropertiesArgs {
        /**
         * The size of the array, if this is an array batch job.
         */
        size?: pulumi.Input<number>;
    }
    interface PipeBatchContainerOverridesArgs {
        /**
         * The command to send to the container that overrides the default command from the Docker image or the task definition.
         */
        command?: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * The environment variables to send to the container. You can add new environment variables, which are added to the container at launch, or you can override the existing environment variables from the Docker image or the task definition.
         *
         * > Environment variables cannot start with " `AWS Batch` ". This naming convention is reserved for variables that AWS Batch sets.
         */
        environment?: pulumi.Input<pulumi.Input<inputs.pipes.PipeBatchEnvironmentVariableArgs>[]>;
        /**
         * The instance type to use for a multi-node parallel job.
         *
         * > This parameter isn't applicable to single-node container jobs or jobs that run on Fargate resources, and shouldn't be provided.
         */
        instanceType?: pulumi.Input<string>;
        /**
         * The type and amount of resources to assign to a container. This overrides the settings in the job definition. The supported resources include `GPU` , `MEMORY` , and `VCPU` .
         */
        resourceRequirements?: pulumi.Input<pulumi.Input<inputs.pipes.PipeBatchResourceRequirementArgs>[]>;
    }
    interface PipeBatchEnvironmentVariableArgs {
        /**
         * The name of the key-value pair. For environment variables, this is the name of the environment variable.
         */
        name?: pulumi.Input<string>;
        /**
         * The value of the key-value pair. For environment variables, this is the value of the environment variable.
         */
        value?: pulumi.Input<string>;
    }
    interface PipeBatchJobDependencyArgs {
        /**
         * The job ID of the AWS Batch job that's associated with this dependency.
         */
        jobId?: pulumi.Input<string>;
        /**
         * The type of the job dependency.
         */
        type?: pulumi.Input<enums.pipes.PipeBatchJobDependencyType>;
    }
    interface PipeBatchResourceRequirementArgs {
        /**
         * The type of resource to assign to a container. The supported resources include `GPU` , `MEMORY` , and `VCPU` .
         */
        type: pulumi.Input<enums.pipes.PipeBatchResourceRequirementType>;
        /**
         * The quantity of the specified resource to reserve for the container. The values vary based on the `type` specified.
         *
         * - **type="GPU"** - The number of physical GPUs to reserve for the container. Make sure that the number of GPUs reserved for all containers in a job doesn't exceed the number of available GPUs on the compute resource that the job is launched on.
         *
         * > GPUs aren't available for jobs that are running on Fargate resources.
         * - **type="MEMORY"** - The memory hard limit (in MiB) present to the container. This parameter is supported for jobs that are running on EC2 resources. If your container attempts to exceed the memory specified, the container is terminated. This parameter maps to `Memory` in the [Create a container](https://docs.aws.amazon.com/https://docs.docker.com/engine/api/v1.23/#create-a-container) section of the [Docker Remote API](https://docs.aws.amazon.com/https://docs.docker.com/engine/api/v1.23/) and the `--memory` option to [docker run](https://docs.aws.amazon.com/https://docs.docker.com/engine/reference/run/) . You must specify at least 4 MiB of memory for a job. This is required but can be specified in several places for multi-node parallel (MNP) jobs. It must be specified for each node at least once. This parameter maps to `Memory` in the [Create a container](https://docs.aws.amazon.com/https://docs.docker.com/engine/api/v1.23/#create-a-container) section of the [Docker Remote API](https://docs.aws.amazon.com/https://docs.docker.com/engine/api/v1.23/) and the `--memory` option to [docker run](https://docs.aws.amazon.com/https://docs.docker.com/engine/reference/run/) .
         *
         * > If you're trying to maximize your resource utilization by providing your jobs as much memory as possible for a particular instance type, see [Memory management](https://docs.aws.amazon.com/batch/latest/userguide/memory-management.html) in the *AWS Batch User Guide* .
         *
         * For jobs that are running on Fargate resources, then `value` is the hard limit (in MiB), and must match one of the supported values and the `VCPU` values must be one of the values supported for that memory value.
         *
         * - **value = 512** - `VCPU` = 0.25
         * - **value = 1024** - `VCPU` = 0.25 or 0.5
         * - **value = 2048** - `VCPU` = 0.25, 0.5, or 1
         * - **value = 3072** - `VCPU` = 0.5, or 1
         * - **value = 4096** - `VCPU` = 0.5, 1, or 2
         * - **value = 5120, 6144, or 7168** - `VCPU` = 1 or 2
         * - **value = 8192** - `VCPU` = 1, 2, 4, or 8
         * - **value = 9216, 10240, 11264, 12288, 13312, 14336, or 15360** - `VCPU` = 2 or 4
         * - **value = 16384** - `VCPU` = 2, 4, or 8
         * - **value = 17408, 18432, 19456, 21504, 22528, 23552, 25600, 26624, 27648, 29696, or 30720** - `VCPU` = 4
         * - **value = 20480, 24576, or 28672** - `VCPU` = 4 or 8
         * - **value = 36864, 45056, 53248, or 61440** - `VCPU` = 8
         * - **value = 32768, 40960, 49152, or 57344** - `VCPU` = 8 or 16
         * - **value = 65536, 73728, 81920, 90112, 98304, 106496, 114688, or 122880** - `VCPU` = 16
         * - **type="VCPU"** - The number of vCPUs reserved for the container. This parameter maps to `CpuShares` in the [Create a container](https://docs.aws.amazon.com/https://docs.docker.com/engine/api/v1.23/#create-a-container) section of the [Docker Remote API](https://docs.aws.amazon.com/https://docs.docker.com/engine/api/v1.23/) and the `--cpu-shares` option to [docker run](https://docs.aws.amazon.com/https://docs.docker.com/engine/reference/run/) . Each vCPU is equivalent to 1,024 CPU shares. For EC2 resources, you must specify at least one vCPU. This is required but can be specified in several places; it must be specified for each node at least once.
         *
         * The default for the Fargate On-Demand vCPU resource count quota is 6 vCPUs. For more information about Fargate quotas, see [AWS Fargate quotas](https://docs.aws.amazon.com/general/latest/gr/ecs-service.html#service-quotas-fargate) in the *AWS General Reference* .
         *
         * For jobs that are running on Fargate resources, then `value` must match one of the supported values and the `MEMORY` values must be one of the values supported for that `VCPU` value. The supported values are 0.25, 0.5, 1, 2, 4, 8, and 16
         *
         * - **value = 0.25** - `MEMORY` = 512, 1024, or 2048
         * - **value = 0.5** - `MEMORY` = 1024, 2048, 3072, or 4096
         * - **value = 1** - `MEMORY` = 2048, 3072, 4096, 5120, 6144, 7168, or 8192
         * - **value = 2** - `MEMORY` = 4096, 5120, 6144, 7168, 8192, 9216, 10240, 11264, 12288, 13312, 14336, 15360, or 16384
         * - **value = 4** - `MEMORY` = 8192, 9216, 10240, 11264, 12288, 13312, 14336, 15360, 16384, 17408, 18432, 19456, 20480, 21504, 22528, 23552, 24576, 25600, 26624, 27648, 28672, 29696, or 30720
         * - **value = 8** - `MEMORY` = 16384, 20480, 24576, 28672, 32768, 36864, 40960, 45056, 49152, 53248, 57344, or 61440
         * - **value = 16** - `MEMORY` = 32768, 40960, 49152, 57344, 65536, 73728, 81920, 90112, 98304, 106496, 114688, or 122880
         */
        value: pulumi.Input<string>;
    }
    interface PipeBatchRetryStrategyArgs {
        /**
         * The number of times to move a job to the `RUNNABLE` status. If the value of `attempts` is greater than one, the job is retried on failure the same number of attempts as the value.
         */
        attempts?: pulumi.Input<number>;
    }
    interface PipeCapacityProviderStrategyItemArgs {
        /**
         * The base value designates how many tasks, at a minimum, to run on the specified capacity provider. Only one capacity provider in a capacity provider strategy can have a base defined. If no value is specified, the default value of 0 is used.
         */
        base?: pulumi.Input<number>;
        /**
         * The short name of the capacity provider.
         */
        capacityProvider: pulumi.Input<string>;
        /**
         * The weight value designates the relative percentage of the total number of tasks launched that should use the specified capacity provider. The weight value is taken into consideration after the base value, if defined, is satisfied.
         */
        weight?: pulumi.Input<number>;
    }
    interface PipeCloudwatchLogsLogDestinationArgs {
        /**
         * The AWS Resource Name (ARN) for the CloudWatch log group to which EventBridge sends the log records.
         */
        logGroupArn?: pulumi.Input<string>;
    }
    interface PipeDeadLetterConfigArgs {
        /**
         * The ARN of the specified target for the dead-letter queue.
         *
         * For Amazon Kinesis stream and Amazon DynamoDB stream sources, specify either an Amazon SNS topic or Amazon SQS queue ARN.
         */
        arn?: pulumi.Input<string>;
    }
    interface PipeDimensionMappingArgs {
        /**
         * The metadata attributes of the time series. For example, the name and Availability Zone of an Amazon EC2 instance or the name of the manufacturer of a wind turbine are dimensions.
         */
        dimensionName: pulumi.Input<string>;
        /**
         * Dynamic path to the dimension value in the source event.
         */
        dimensionValue: pulumi.Input<string>;
        /**
         * The data type of the dimension for the time-series data.
         */
        dimensionValueType: pulumi.Input<enums.pipes.PipeDimensionValueType>;
    }
    interface PipeEcsContainerOverrideArgs {
        /**
         * The command to send to the container that overrides the default command from the Docker image or the task definition. You must also specify a container name.
         */
        command?: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * The number of `cpu` units reserved for the container, instead of the default value from the task definition. You must also specify a container name.
         */
        cpu?: pulumi.Input<number>;
        /**
         * The environment variables to send to the container. You can add new environment variables, which are added to the container at launch, or you can override the existing environment variables from the Docker image or the task definition. You must also specify a container name.
         */
        environment?: pulumi.Input<pulumi.Input<inputs.pipes.PipeEcsEnvironmentVariableArgs>[]>;
        /**
         * A list of files containing the environment variables to pass to a container, instead of the value from the container definition.
         */
        environmentFiles?: pulumi.Input<pulumi.Input<inputs.pipes.PipeEcsEnvironmentFileArgs>[]>;
        /**
         * The hard limit (in MiB) of memory to present to the container, instead of the default value from the task definition. If your container attempts to exceed the memory specified here, the container is killed. You must also specify a container name.
         */
        memory?: pulumi.Input<number>;
        /**
         * The soft limit (in MiB) of memory to reserve for the container, instead of the default value from the task definition. You must also specify a container name.
         */
        memoryReservation?: pulumi.Input<number>;
        /**
         * The name of the container that receives the override. This parameter is required if any override is specified.
         */
        name?: pulumi.Input<string>;
        /**
         * The type and amount of a resource to assign to a container, instead of the default value from the task definition. The only supported resource is a GPU.
         */
        resourceRequirements?: pulumi.Input<pulumi.Input<inputs.pipes.PipeEcsResourceRequirementArgs>[]>;
    }
    interface PipeEcsEnvironmentFileArgs {
        /**
         * The file type to use. The only supported value is `s3` .
         */
        type: pulumi.Input<enums.pipes.PipeEcsEnvironmentFileType>;
        /**
         * The Amazon Resource Name (ARN) of the Amazon S3 object containing the environment variable file.
         */
        value: pulumi.Input<string>;
    }
    interface PipeEcsEnvironmentVariableArgs {
        /**
         * The name of the key-value pair. For environment variables, this is the name of the environment variable.
         */
        name?: pulumi.Input<string>;
        /**
         * The value of the key-value pair. For environment variables, this is the value of the environment variable.
         */
        value?: pulumi.Input<string>;
    }
    interface PipeEcsEphemeralStorageArgs {
        /**
         * The total amount, in GiB, of ephemeral storage to set for the task. The minimum supported value is `21` GiB and the maximum supported value is `200` GiB.
         */
        sizeInGiB: pulumi.Input<number>;
    }
    interface PipeEcsInferenceAcceleratorOverrideArgs {
        /**
         * The Elastic Inference accelerator device name to override for the task. This parameter must match a `deviceName` specified in the task definition.
         */
        deviceName?: pulumi.Input<string>;
        /**
         * The Elastic Inference accelerator type to use.
         */
        deviceType?: pulumi.Input<string>;
    }
    interface PipeEcsResourceRequirementArgs {
        /**
         * The type of resource to assign to a container. The supported values are `GPU` or `InferenceAccelerator` .
         */
        type: pulumi.Input<enums.pipes.PipeEcsResourceRequirementType>;
        /**
         * The value for the specified resource type.
         *
         * If the `GPU` type is used, the value is the number of physical `GPUs` the Amazon ECS container agent reserves for the container. The number of GPUs that's reserved for all containers in a task can't exceed the number of available GPUs on the container instance that the task is launched on.
         *
         * If the `InferenceAccelerator` type is used, the `value` matches the `deviceName` for an InferenceAccelerator specified in a task definition.
         */
        value: pulumi.Input<string>;
    }
    interface PipeEcsTaskOverrideArgs {
        /**
         * One or more container overrides that are sent to a task.
         */
        containerOverrides?: pulumi.Input<pulumi.Input<inputs.pipes.PipeEcsContainerOverrideArgs>[]>;
        /**
         * The cpu override for the task.
         */
        cpu?: pulumi.Input<string>;
        /**
         * The ephemeral storage setting override for the task.
         *
         * > This parameter is only supported for tasks hosted on Fargate that use the following platform versions:
         * >
         * > - Linux platform version `1.4.0` or later.
         * > - Windows platform version `1.0.0` or later.
         */
        ephemeralStorage?: pulumi.Input<inputs.pipes.PipeEcsEphemeralStorageArgs>;
        /**
         * The Amazon Resource Name (ARN) of the task execution IAM role override for the task. For more information, see [Amazon ECS task execution IAM role](https://docs.aws.amazon.com/AmazonECS/latest/developerguide/task_execution_IAM_role.html) in the *Amazon Elastic Container Service Developer Guide* .
         */
        executionRoleArn?: pulumi.Input<string>;
        /**
         * The Elastic Inference accelerator override for the task.
         */
        inferenceAcceleratorOverrides?: pulumi.Input<pulumi.Input<inputs.pipes.PipeEcsInferenceAcceleratorOverrideArgs>[]>;
        /**
         * The memory override for the task.
         */
        memory?: pulumi.Input<string>;
        /**
         * The Amazon Resource Name (ARN) of the IAM role that containers in this task can assume. All containers in this task are granted the permissions that are specified in this role. For more information, see [IAM Role for Tasks](https://docs.aws.amazon.com/AmazonECS/latest/developerguide/task-iam-roles.html) in the *Amazon Elastic Container Service Developer Guide* .
         */
        taskRoleArn?: pulumi.Input<string>;
    }
    interface PipeEnrichmentHttpParametersArgs {
        /**
         * The headers that need to be sent as part of request invoking the API Gateway REST API or EventBridge ApiDestination.
         */
        headerParameters?: pulumi.Input<{
            [key: string]: pulumi.Input<string>;
        }>;
        /**
         * The path parameter values to be used to populate API Gateway REST API or EventBridge ApiDestination path wildcards ("*").
         */
        pathParameterValues?: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * The query string keys/values that need to be sent as part of request invoking the API Gateway REST API or EventBridge ApiDestination.
         */
        queryStringParameters?: pulumi.Input<{
            [key: string]: pulumi.Input<string>;
        }>;
    }
    interface PipeEnrichmentParametersArgs {
        /**
         * Contains the HTTP parameters to use when the target is a API Gateway REST endpoint or EventBridge ApiDestination.
         *
         * If you specify an API Gateway REST API or EventBridge ApiDestination as a target, you can use this parameter to specify headers, path parameters, and query string keys/values as part of your target invoking request. If you're using ApiDestinations, the corresponding Connection can also have these values configured. In case of any conflicting keys, values from the Connection take precedence.
         */
        httpParameters?: pulumi.Input<inputs.pipes.PipeEnrichmentHttpParametersArgs>;
        /**
         * Valid JSON text passed to the enrichment. In this case, nothing from the event itself is passed to the enrichment. For more information, see [The JavaScript Object Notation (JSON) Data Interchange Format](https://docs.aws.amazon.com/http://www.rfc-editor.org/rfc/rfc7159.txt) .
         *
         * To remove an input template, specify an empty string.
         */
        inputTemplate?: pulumi.Input<string>;
    }
    interface PipeFilterArgs {
        /**
         * The event pattern.
         */
        pattern?: pulumi.Input<string>;
    }
    interface PipeFilterCriteriaArgs {
        /**
         * The event patterns.
         */
        filters?: pulumi.Input<pulumi.Input<inputs.pipes.PipeFilterArgs>[]>;
    }
    interface PipeFirehoseLogDestinationArgs {
        /**
         * The Amazon Resource Name (ARN) of the Firehose delivery stream to which EventBridge delivers the pipe log records.
         */
        deliveryStreamArn?: pulumi.Input<string>;
    }
    interface PipeLogConfigurationArgs {
        /**
         * The logging configuration settings for the pipe.
         */
        cloudwatchLogsLogDestination?: pulumi.Input<inputs.pipes.PipeCloudwatchLogsLogDestinationArgs>;
        /**
         * The Amazon Data Firehose logging configuration settings for the pipe.
         */
        firehoseLogDestination?: pulumi.Input<inputs.pipes.PipeFirehoseLogDestinationArgs>;
        /**
         * Whether the execution data (specifically, the `payload` , `awsRequest` , and `awsResponse` fields) is included in the log messages for this pipe.
         *
         * This applies to all log destinations for the pipe.
         *
         * For more information, see [Including execution data in logs](https://docs.aws.amazon.com/eventbridge/latest/userguide/eb-pipes-logs.html#eb-pipes-logs-execution-data) in the *Amazon EventBridge User Guide* .
         *
         * *Allowed values:* `ALL`
         */
        includeExecutionData?: pulumi.Input<pulumi.Input<enums.pipes.PipeIncludeExecutionDataOption>[]>;
        /**
         * The level of logging detail to include. This applies to all log destinations for the pipe.
         */
        level?: pulumi.Input<enums.pipes.PipeLogLevel>;
        /**
         * The Amazon S3 logging configuration settings for the pipe.
         */
        s3LogDestination?: pulumi.Input<inputs.pipes.PipeS3LogDestinationArgs>;
    }
    interface PipeMqBrokerAccessCredentialsPropertiesArgs {
        /**
         * Optional SecretManager ARN which stores the database credentials
         */
        basicAuth: pulumi.Input<string>;
    }
    interface PipeMskAccessCredentials0PropertiesArgs {
        /**
         * Optional SecretManager ARN which stores the database credentials
         */
        saslScram512Auth: pulumi.Input<string>;
    }
    interface PipeMskAccessCredentials1PropertiesArgs {
        /**
         * Optional SecretManager ARN which stores the database credentials
         */
        clientCertificateTlsAuth: pulumi.Input<string>;
    }
    interface PipeMultiMeasureAttributeMappingArgs {
        /**
         * Dynamic path to the measurement attribute in the source event.
         */
        measureValue: pulumi.Input<string>;
        /**
         * Data type of the measurement attribute in the source event.
         */
        measureValueType: pulumi.Input<enums.pipes.PipeMeasureValueType>;
        /**
         * Target measure name to be used.
         */
        multiMeasureAttributeName: pulumi.Input<string>;
    }
    interface PipeMultiMeasureMappingArgs {
        /**
         * Mappings that represent multiple source event fields mapped to measures in the same Timestream for LiveAnalytics record.
         */
        multiMeasureAttributeMappings: pulumi.Input<pulumi.Input<inputs.pipes.PipeMultiMeasureAttributeMappingArgs>[]>;
        /**
         * The name of the multiple measurements per record (multi-measure).
         */
        multiMeasureName: pulumi.Input<string>;
    }
    interface PipeNetworkConfigurationArgs {
        /**
         * Use this structure to specify the VPC subnets and security groups for the task, and whether a public IP address is to be used. This structure is relevant only for ECS tasks that use the `awsvpc` network mode.
         */
        awsvpcConfiguration?: pulumi.Input<inputs.pipes.PipeAwsVpcConfigurationArgs>;
    }
    interface PipePlacementConstraintArgs {
        /**
         * A cluster query language expression to apply to the constraint. You cannot specify an expression if the constraint type is `distinctInstance` . To learn more, see [Cluster Query Language](https://docs.aws.amazon.com/AmazonECS/latest/developerguide/cluster-query-language.html) in the Amazon Elastic Container Service Developer Guide.
         */
        expression?: pulumi.Input<string>;
        /**
         * The type of constraint. Use distinctInstance to ensure that each task in a particular group is running on a different container instance. Use memberOf to restrict the selection to a group of valid candidates.
         */
        type?: pulumi.Input<enums.pipes.PipePlacementConstraintType>;
    }
    interface PipePlacementStrategyArgs {
        /**
         * The field to apply the placement strategy against. For the spread placement strategy, valid values are instanceId (or host, which has the same effect), or any platform or custom attribute that is applied to a container instance, such as attribute:ecs.availability-zone. For the binpack placement strategy, valid values are cpu and memory. For the random placement strategy, this field is not used.
         */
        field?: pulumi.Input<string>;
        /**
         * The type of placement strategy. The random placement strategy randomly places tasks on available candidates. The spread placement strategy spreads placement across available candidates evenly based on the field parameter. The binpack strategy places tasks on available candidates that have the least available amount of the resource that is specified with the field parameter. For example, if you binpack on memory, a task is placed on the instance with the least amount of remaining memory (but still enough to run the task).
         */
        type?: pulumi.Input<enums.pipes.PipePlacementStrategyType>;
    }
    interface PipeS3LogDestinationArgs {
        /**
         * The name of the Amazon S3 bucket to which EventBridge delivers the log records for the pipe.
         */
        bucketName?: pulumi.Input<string>;
        /**
         * The AWS account that owns the Amazon S3 bucket to which EventBridge delivers the log records for the pipe.
         */
        bucketOwner?: pulumi.Input<string>;
        /**
         * The format EventBridge uses for the log records.
         *
         * EventBridge currently only supports `json` formatting.
         */
        outputFormat?: pulumi.Input<enums.pipes.PipeS3OutputFormat>;
        /**
         * The prefix text with which to begin Amazon S3 log object names.
         *
         * For more information, see [Organizing objects using prefixes](https://docs.aws.amazon.com/AmazonS3/latest/userguide/using-prefixes.html) in the *Amazon Simple Storage Service User Guide* .
         */
        prefix?: pulumi.Input<string>;
    }
    interface PipeSageMakerPipelineParameterArgs {
        /**
         * Name of parameter to start execution of a SageMaker AI Model Building Pipeline.
         */
        name: pulumi.Input<string>;
        /**
         * Value of parameter to start execution of a SageMaker AI Model Building Pipeline.
         */
        value: pulumi.Input<string>;
    }
    interface PipeSelfManagedKafkaAccessConfigurationCredentials0PropertiesArgs {
        /**
         * Optional SecretManager ARN which stores the database credentials
         */
        basicAuth: pulumi.Input<string>;
    }
    interface PipeSelfManagedKafkaAccessConfigurationCredentials1PropertiesArgs {
        /**
         * Optional SecretManager ARN which stores the database credentials
         */
        saslScram512Auth: pulumi.Input<string>;
    }
    interface PipeSelfManagedKafkaAccessConfigurationCredentials2PropertiesArgs {
        /**
         * Optional SecretManager ARN which stores the database credentials
         */
        saslScram256Auth: pulumi.Input<string>;
    }
    interface PipeSelfManagedKafkaAccessConfigurationCredentials3PropertiesArgs {
        /**
         * Optional SecretManager ARN which stores the database credentials
         */
        clientCertificateTlsAuth: pulumi.Input<string>;
    }
    interface PipeSelfManagedKafkaAccessConfigurationVpcArgs {
        /**
         * List of SecurityGroupId.
         */
        securityGroup?: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * List of SubnetId.
         */
        subnets?: pulumi.Input<pulumi.Input<string>[]>;
    }
    interface PipeSingleMeasureMappingArgs {
        /**
         * Target measure name for the measurement attribute in the Timestream table.
         */
        measureName: pulumi.Input<string>;
        /**
         * Dynamic path of the source field to map to the measure in the record.
         */
        measureValue: pulumi.Input<string>;
        /**
         * Data type of the source field.
         */
        measureValueType: pulumi.Input<enums.pipes.PipeMeasureValueType>;
    }
    interface PipeSourceActiveMqBrokerParametersArgs {
        /**
         * The maximum number of records to include in each batch.
         */
        batchSize?: pulumi.Input<number>;
        /**
         * The credentials needed to access the resource.
         */
        credentials: pulumi.Input<inputs.pipes.PipeMqBrokerAccessCredentialsPropertiesArgs>;
        /**
         * The maximum length of a time to wait for events.
         */
        maximumBatchingWindowInSeconds?: pulumi.Input<number>;
        /**
         * The name of the destination queue to consume.
         */
        queueName: pulumi.Input<string>;
    }
    interface PipeSourceDynamoDbStreamParametersArgs {
        /**
         * The maximum number of records to include in each batch.
         */
        batchSize?: pulumi.Input<number>;
        /**
         * Define the target queue to send dead-letter queue events to.
         */
        deadLetterConfig?: pulumi.Input<inputs.pipes.PipeDeadLetterConfigArgs>;
        /**
         * The maximum length of a time to wait for events.
         */
        maximumBatchingWindowInSeconds?: pulumi.Input<number>;
        /**
         * Discard records older than the specified age. The default value is -1, which sets the maximum age to infinite. When the value is set to infinite, EventBridge never discards old records.
         */
        maximumRecordAgeInSeconds?: pulumi.Input<number>;
        /**
         * Discard records after the specified number of retries. The default value is -1, which sets the maximum number of retries to infinite. When MaximumRetryAttempts is infinite, EventBridge retries failed records until the record expires in the event source.
         */
        maximumRetryAttempts?: pulumi.Input<number>;
        /**
         * Define how to handle item process failures. `AUTOMATIC_BISECT` halves each batch and retry each half until all the records are processed or there is one failed message left in the batch.
         */
        onPartialBatchItemFailure?: pulumi.Input<enums.pipes.PipeOnPartialBatchItemFailureStreams>;
        /**
         * The number of batches to process concurrently from each shard. The default value is 1.
         */
        parallelizationFactor?: pulumi.Input<number>;
        /**
         * (Streams only) The position in a stream from which to start reading.
         *
         * *Valid values* : `TRIM_HORIZON | LATEST`
         */
        startingPosition: pulumi.Input<enums.pipes.PipeDynamoDbStreamStartPosition>;
    }
    interface PipeSourceKinesisStreamParametersArgs {
        /**
         * The maximum number of records to include in each batch.
         */
        batchSize?: pulumi.Input<number>;
        /**
         * Define the target queue to send dead-letter queue events to.
         */
        deadLetterConfig?: pulumi.Input<inputs.pipes.PipeDeadLetterConfigArgs>;
        /**
         * The maximum length of a time to wait for events.
         */
        maximumBatchingWindowInSeconds?: pulumi.Input<number>;
        /**
         * Discard records older than the specified age. The default value is -1, which sets the maximum age to infinite. When the value is set to infinite, EventBridge never discards old records.
         */
        maximumRecordAgeInSeconds?: pulumi.Input<number>;
        /**
         * Discard records after the specified number of retries. The default value is -1, which sets the maximum number of retries to infinite. When MaximumRetryAttempts is infinite, EventBridge retries failed records until the record expires in the event source.
         */
        maximumRetryAttempts?: pulumi.Input<number>;
        /**
         * Define how to handle item process failures. `AUTOMATIC_BISECT` halves each batch and retry each half until all the records are processed or there is one failed message left in the batch.
         */
        onPartialBatchItemFailure?: pulumi.Input<enums.pipes.PipeOnPartialBatchItemFailureStreams>;
        /**
         * The number of batches to process concurrently from each shard. The default value is 1.
         */
        parallelizationFactor?: pulumi.Input<number>;
        /**
         * The position in a stream from which to start reading.
         */
        startingPosition: pulumi.Input<enums.pipes.PipeKinesisStreamStartPosition>;
        /**
         * With `StartingPosition` set to `AT_TIMESTAMP` , the time from which to start reading, in Unix time seconds.
         */
        startingPositionTimestamp?: pulumi.Input<string>;
    }
    interface PipeSourceManagedStreamingKafkaParametersArgs {
        /**
         * The maximum number of records to include in each batch.
         */
        batchSize?: pulumi.Input<number>;
        /**
         * The name of the destination queue to consume.
         */
        consumerGroupId?: pulumi.Input<string>;
        /**
         * The credentials needed to access the resource.
         */
        credentials?: pulumi.Input<inputs.pipes.PipeMskAccessCredentials0PropertiesArgs | inputs.pipes.PipeMskAccessCredentials1PropertiesArgs>;
        /**
         * The maximum length of a time to wait for events.
         */
        maximumBatchingWindowInSeconds?: pulumi.Input<number>;
        /**
         * The position in a stream from which to start reading.
         */
        startingPosition?: pulumi.Input<enums.pipes.PipeMskStartPosition>;
        /**
         * The name of the topic that the pipe will read from.
         */
        topicName: pulumi.Input<string>;
    }
    interface PipeSourceParametersArgs {
        /**
         * The parameters for using an Active MQ broker as a source.
         */
        activeMqBrokerParameters?: pulumi.Input<inputs.pipes.PipeSourceActiveMqBrokerParametersArgs>;
        /**
         * The parameters for using a DynamoDB stream as a source.
         */
        dynamoDbStreamParameters?: pulumi.Input<inputs.pipes.PipeSourceDynamoDbStreamParametersArgs>;
        /**
         * The collection of event patterns used to filter events.
         *
         * To remove a filter, specify a `FilterCriteria` object with an empty array of `Filter` objects.
         *
         * For more information, see [Events and Event Patterns](https://docs.aws.amazon.com/eventbridge/latest/userguide/eventbridge-and-event-patterns.html) in the *Amazon EventBridge User Guide* .
         */
        filterCriteria?: pulumi.Input<inputs.pipes.PipeFilterCriteriaArgs>;
        /**
         * The parameters for using a Kinesis stream as a source.
         */
        kinesisStreamParameters?: pulumi.Input<inputs.pipes.PipeSourceKinesisStreamParametersArgs>;
        /**
         * The parameters for using an MSK stream as a source.
         */
        managedStreamingKafkaParameters?: pulumi.Input<inputs.pipes.PipeSourceManagedStreamingKafkaParametersArgs>;
        /**
         * The parameters for using a Rabbit MQ broker as a source.
         */
        rabbitMqBrokerParameters?: pulumi.Input<inputs.pipes.PipeSourceRabbitMqBrokerParametersArgs>;
        /**
         * The parameters for using a self-managed Apache Kafka stream as a source.
         *
         * A *self managed* cluster refers to any Apache Kafka cluster not hosted by AWS . This includes both clusters you manage yourself, as well as those hosted by a third-party provider, such as [Confluent Cloud](https://docs.aws.amazon.com/https://www.confluent.io/) , [CloudKarafka](https://docs.aws.amazon.com/https://www.cloudkarafka.com/) , or [Redpanda](https://docs.aws.amazon.com/https://redpanda.com/) . For more information, see [Apache Kafka streams as a source](https://docs.aws.amazon.com/eventbridge/latest/userguide/eb-pipes-kafka.html) in the *Amazon EventBridge User Guide* .
         */
        selfManagedKafkaParameters?: pulumi.Input<inputs.pipes.PipeSourceSelfManagedKafkaParametersArgs>;
        /**
         * The parameters for using a Amazon SQS stream as a source.
         */
        sqsQueueParameters?: pulumi.Input<inputs.pipes.PipeSourceSqsQueueParametersArgs>;
    }
    interface PipeSourceRabbitMqBrokerParametersArgs {
        /**
         * The maximum number of records to include in each batch.
         */
        batchSize?: pulumi.Input<number>;
        /**
         * The credentials needed to access the resource.
         */
        credentials: pulumi.Input<inputs.pipes.PipeMqBrokerAccessCredentialsPropertiesArgs>;
        /**
         * The maximum length of a time to wait for events.
         */
        maximumBatchingWindowInSeconds?: pulumi.Input<number>;
        /**
         * The name of the destination queue to consume.
         */
        queueName: pulumi.Input<string>;
        /**
         * The name of the virtual host associated with the source broker.
         */
        virtualHost?: pulumi.Input<string>;
    }
    interface PipeSourceSelfManagedKafkaParametersArgs {
        /**
         * An array of server URLs.
         */
        additionalBootstrapServers?: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * The maximum number of records to include in each batch.
         */
        batchSize?: pulumi.Input<number>;
        /**
         * The name of the destination queue to consume.
         */
        consumerGroupId?: pulumi.Input<string>;
        /**
         * The credentials needed to access the resource.
         */
        credentials?: pulumi.Input<inputs.pipes.PipeSelfManagedKafkaAccessConfigurationCredentials0PropertiesArgs | inputs.pipes.PipeSelfManagedKafkaAccessConfigurationCredentials1PropertiesArgs | inputs.pipes.PipeSelfManagedKafkaAccessConfigurationCredentials2PropertiesArgs | inputs.pipes.PipeSelfManagedKafkaAccessConfigurationCredentials3PropertiesArgs>;
        /**
         * The maximum length of a time to wait for events.
         */
        maximumBatchingWindowInSeconds?: pulumi.Input<number>;
        /**
         * Optional SecretManager ARN which stores the database credentials
         */
        serverRootCaCertificate?: pulumi.Input<string>;
        /**
         * The position in a stream from which to start reading.
         */
        startingPosition?: pulumi.Input<enums.pipes.PipeSelfManagedKafkaStartPosition>;
        /**
         * The name of the topic that the pipe will read from.
         */
        topicName: pulumi.Input<string>;
        /**
         * This structure specifies the VPC subnets and security groups for the stream, and whether a public IP address is to be used.
         */
        vpc?: pulumi.Input<inputs.pipes.PipeSelfManagedKafkaAccessConfigurationVpcArgs>;
    }
    interface PipeSourceSqsQueueParametersArgs {
        /**
         * The maximum number of records to include in each batch.
         */
        batchSize?: pulumi.Input<number>;
        /**
         * The maximum length of a time to wait for events.
         */
        maximumBatchingWindowInSeconds?: pulumi.Input<number>;
    }
    interface PipeTagArgs {
        /**
         * The key of the key-value pair.
         */
        key: pulumi.Input<string>;
        /**
         * The value of the key-value pair.
         */
        value: pulumi.Input<string>;
    }
    interface PipeTargetBatchJobParametersArgs {
        /**
         * The array properties for the submitted job, such as the size of the array. The array size can be between 2 and 10,000. If you specify array properties for a job, it becomes an array job. This parameter is used only if the target is an AWS Batch job.
         */
        arrayProperties?: pulumi.Input<inputs.pipes.PipeBatchArrayPropertiesArgs>;
        /**
         * The overrides that are sent to a container.
         */
        containerOverrides?: pulumi.Input<inputs.pipes.PipeBatchContainerOverridesArgs>;
        /**
         * A list of dependencies for the job. A job can depend upon a maximum of 20 jobs. You can specify a `SEQUENTIAL` type dependency without specifying a job ID for array jobs so that each child array job completes sequentially, starting at index 0. You can also specify an `N_TO_N` type dependency with a job ID for array jobs. In that case, each index child of this job must wait for the corresponding index child of each dependency to complete before it can begin.
         */
        dependsOn?: pulumi.Input<pulumi.Input<inputs.pipes.PipeBatchJobDependencyArgs>[]>;
        /**
         * The job definition used by this job. This value can be one of `name` , `name:revision` , or the Amazon Resource Name (ARN) for the job definition. If name is specified without a revision then the latest active revision is used.
         */
        jobDefinition: pulumi.Input<string>;
        /**
         * The name of the job. It can be up to 128 letters long. The first character must be alphanumeric, can contain uppercase and lowercase letters, numbers, hyphens (-), and underscores (_).
         */
        jobName: pulumi.Input<string>;
        /**
         * Additional parameters passed to the job that replace parameter substitution placeholders that are set in the job definition. Parameters are specified as a key and value pair mapping. Parameters included here override any corresponding parameter defaults from the job definition.
         */
        parameters?: pulumi.Input<{
            [key: string]: pulumi.Input<string>;
        }>;
        /**
         * The retry strategy to use for failed jobs. When a retry strategy is specified here, it overrides the retry strategy defined in the job definition.
         */
        retryStrategy?: pulumi.Input<inputs.pipes.PipeBatchRetryStrategyArgs>;
    }
    interface PipeTargetCloudWatchLogsParametersArgs {
        /**
         * The name of the log stream.
         */
        logStreamName?: pulumi.Input<string>;
        /**
         * A [dynamic path parameter](https://docs.aws.amazon.com/eventbridge/latest/userguide/eb-pipes-event-target.html) to a field in the payload containing the time the event occurred, expressed as the number of milliseconds after Jan 1, 1970 00:00:00 UTC.
         *
         * The value cannot be a static timestamp as the provided timestamp would be applied to all events delivered by the Pipe, regardless of when they are actually delivered.
         *
         * If no dynamic path parameter is provided, the default value is the time the invocation is processed by the Pipe.
         */
        timestamp?: pulumi.Input<string>;
    }
    interface PipeTargetEcsTaskParametersArgs {
        /**
         * The capacity provider strategy to use for the task.
         *
         * If a `capacityProviderStrategy` is specified, the `launchType` parameter must be omitted. If no `capacityProviderStrategy` or launchType is specified, the `defaultCapacityProviderStrategy` for the cluster is used.
         */
        capacityProviderStrategy?: pulumi.Input<pulumi.Input<inputs.pipes.PipeCapacityProviderStrategyItemArgs>[]>;
        /**
         * Specifies whether to enable Amazon ECS managed tags for the task. For more information, see [Tagging Your Amazon ECS Resources](https://docs.aws.amazon.com/AmazonECS/latest/developerguide/ecs-using-tags.html) in the Amazon Elastic Container Service Developer Guide.
         */
        enableEcsManagedTags?: pulumi.Input<boolean>;
        /**
         * Whether or not to enable the execute command functionality for the containers in this task. If true, this enables execute command functionality on all containers in the task.
         */
        enableExecuteCommand?: pulumi.Input<boolean>;
        /**
         * Specifies an Amazon ECS task group for the task. The maximum length is 255 characters.
         */
        group?: pulumi.Input<string>;
        /**
         * Specifies the launch type on which your task is running. The launch type that you specify here must match one of the launch type (compatibilities) of the target task. The `FARGATE` value is supported only in the Regions where AWS Fargate with Amazon ECS is supported. For more information, see [AWS Fargate on Amazon ECS](https://docs.aws.amazon.com/AmazonECS/latest/developerguide/AWS-Fargate.html) in the *Amazon Elastic Container Service Developer Guide* .
         */
        launchType?: pulumi.Input<enums.pipes.PipeLaunchType>;
        /**
         * Use this structure if the Amazon ECS task uses the `awsvpc` network mode. This structure specifies the VPC subnets and security groups associated with the task, and whether a public IP address is to be used. This structure is required if `LaunchType` is `FARGATE` because the `awsvpc` mode is required for Fargate tasks.
         *
         * If you specify `NetworkConfiguration` when the target ECS task does not use the `awsvpc` network mode, the task fails.
         */
        networkConfiguration?: pulumi.Input<inputs.pipes.PipeNetworkConfigurationArgs>;
        /**
         * The overrides that are associated with a task.
         */
        overrides?: pulumi.Input<inputs.pipes.PipeEcsTaskOverrideArgs>;
        /**
         * An array of placement constraint objects to use for the task. You can specify up to 10 constraints per task (including constraints in the task definition and those specified at runtime).
         */
        placementConstraints?: pulumi.Input<pulumi.Input<inputs.pipes.PipePlacementConstraintArgs>[]>;
        /**
         * The placement strategy objects to use for the task. You can specify a maximum of five strategy rules per task.
         */
        placementStrategy?: pulumi.Input<pulumi.Input<inputs.pipes.PipePlacementStrategyArgs>[]>;
        /**
         * Specifies the platform version for the task. Specify only the numeric portion of the platform version, such as `1.1.0` .
         *
         * This structure is used only if `LaunchType` is `FARGATE` . For more information about valid platform versions, see [AWS Fargate Platform Versions](https://docs.aws.amazon.com/AmazonECS/latest/developerguide/platform_versions.html) in the *Amazon Elastic Container Service Developer Guide* .
         */
        platformVersion?: pulumi.Input<string>;
        /**
         * Specifies whether to propagate the tags from the task definition to the task. If no value is specified, the tags are not propagated. Tags can only be propagated to the task during task creation. To add tags to a task after task creation, use the `TagResource` API action.
         */
        propagateTags?: pulumi.Input<enums.pipes.PipePropagateTags>;
        /**
         * The reference ID to use for the task.
         */
        referenceId?: pulumi.Input<string>;
        /**
         * The metadata that you apply to the task to help you categorize and organize them. Each tag consists of a key and an optional value, both of which you define. To learn more, see [RunTask](https://docs.aws.amazon.com/AmazonECS/latest/APIReference/API_RunTask.html#ECS-RunTask-request-tags) in the Amazon ECS API Reference.
         */
        tags?: pulumi.Input<pulumi.Input<inputs.pipes.PipeTagArgs>[]>;
        /**
         * The number of tasks to create based on `TaskDefinition` . The default is 1.
         */
        taskCount?: pulumi.Input<number>;
        /**
         * The ARN of the task definition to use if the event target is an Amazon ECS task.
         */
        taskDefinitionArn: pulumi.Input<string>;
    }
    interface PipeTargetEventBridgeEventBusParametersArgs {
        /**
         * A free-form string, with a maximum of 128 characters, used to decide what fields to expect in the event detail.
         */
        detailType?: pulumi.Input<string>;
        /**
         * The URL subdomain of the endpoint. For example, if the URL for Endpoint is https://abcde.veo.endpoints.event.amazonaws.com, then the EndpointId is `abcde.veo` .
         */
        endpointId?: pulumi.Input<string>;
        /**
         * AWS resources, identified by Amazon Resource Name (ARN), which the event primarily concerns. Any number, including zero, may be present.
         */
        resources?: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * The source of the event.
         */
        source?: pulumi.Input<string>;
        /**
         * The time stamp of the event, per [RFC3339](https://docs.aws.amazon.com/https://www.rfc-editor.org/rfc/rfc3339.txt) . If no time stamp is provided, the time stamp of the [PutEvents](https://docs.aws.amazon.com/eventbridge/latest/APIReference/API_PutEvents.html) call is used.
         */
        time?: pulumi.Input<string>;
    }
    interface PipeTargetHttpParametersArgs {
        /**
         * The headers that need to be sent as part of request invoking the API Gateway REST API or EventBridge ApiDestination.
         */
        headerParameters?: pulumi.Input<{
            [key: string]: pulumi.Input<string>;
        }>;
        /**
         * The path parameter values to be used to populate API Gateway REST API or EventBridge ApiDestination path wildcards ("*").
         */
        pathParameterValues?: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * The query string keys/values that need to be sent as part of request invoking the API Gateway REST API or EventBridge ApiDestination.
         */
        queryStringParameters?: pulumi.Input<{
            [key: string]: pulumi.Input<string>;
        }>;
    }
    interface PipeTargetKinesisStreamParametersArgs {
        /**
         * Determines which shard in the stream the data record is assigned to. Partition keys are Unicode strings with a maximum length limit of 256 characters for each key. Amazon Kinesis Data Streams uses the partition key as input to a hash function that maps the partition key and associated data to a specific shard. Specifically, an MD5 hash function is used to map partition keys to 128-bit integer values and to map associated data records to shards. As a result of this hashing mechanism, all data records with the same partition key map to the same shard within the stream.
         */
        partitionKey: pulumi.Input<string>;
    }
    interface PipeTargetLambdaFunctionParametersArgs {
        /**
         * Specify whether to invoke the function synchronously or asynchronously.
         *
         * - `REQUEST_RESPONSE` (default) - Invoke synchronously. This corresponds to the `RequestResponse` option in the `InvocationType` parameter for the Lambda [Invoke](https://docs.aws.amazon.com/lambda/latest/dg/API_Invoke.html#API_Invoke_RequestSyntax) API.
         * - `FIRE_AND_FORGET` - Invoke asynchronously. This corresponds to the `Event` option in the `InvocationType` parameter for the Lambda [Invoke](https://docs.aws.amazon.com/lambda/latest/dg/API_Invoke.html#API_Invoke_RequestSyntax) API.
         *
         * For more information, see [Invocation types](https://docs.aws.amazon.com/eventbridge/latest/userguide/eb-pipes.html#pipes-invocation) in the *Amazon EventBridge User Guide* .
         */
        invocationType?: pulumi.Input<enums.pipes.PipeTargetInvocationType>;
    }
    interface PipeTargetParametersArgs {
        /**
         * The parameters for using an AWS Batch job as a target.
         */
        batchJobParameters?: pulumi.Input<inputs.pipes.PipeTargetBatchJobParametersArgs>;
        /**
         * The parameters for using an CloudWatch Logs log stream as a target.
         */
        cloudWatchLogsParameters?: pulumi.Input<inputs.pipes.PipeTargetCloudWatchLogsParametersArgs>;
        /**
         * The parameters for using an Amazon ECS task as a target.
         */
        ecsTaskParameters?: pulumi.Input<inputs.pipes.PipeTargetEcsTaskParametersArgs>;
        /**
         * The parameters for using an EventBridge event bus as a target.
         */
        eventBridgeEventBusParameters?: pulumi.Input<inputs.pipes.PipeTargetEventBridgeEventBusParametersArgs>;
        /**
         * These are custom parameter to be used when the target is an API Gateway REST APIs or EventBridge ApiDestinations.
         */
        httpParameters?: pulumi.Input<inputs.pipes.PipeTargetHttpParametersArgs>;
        /**
         * Valid JSON text passed to the target. In this case, nothing from the event itself is passed to the target. For more information, see [The JavaScript Object Notation (JSON) Data Interchange Format](https://docs.aws.amazon.com/http://www.rfc-editor.org/rfc/rfc7159.txt) .
         *
         * To remove an input template, specify an empty string.
         */
        inputTemplate?: pulumi.Input<string>;
        /**
         * The parameters for using a Kinesis stream as a target.
         */
        kinesisStreamParameters?: pulumi.Input<inputs.pipes.PipeTargetKinesisStreamParametersArgs>;
        /**
         * The parameters for using a Lambda function as a target.
         */
        lambdaFunctionParameters?: pulumi.Input<inputs.pipes.PipeTargetLambdaFunctionParametersArgs>;
        /**
         * These are custom parameters to be used when the target is a Amazon Redshift cluster to invoke the Amazon Redshift Data API BatchExecuteStatement.
         */
        redshiftDataParameters?: pulumi.Input<inputs.pipes.PipeTargetRedshiftDataParametersArgs>;
        /**
         * The parameters for using a SageMaker AI pipeline as a target.
         */
        sageMakerPipelineParameters?: pulumi.Input<inputs.pipes.PipeTargetSageMakerPipelineParametersArgs>;
        /**
         * The parameters for using a Amazon SQS stream as a target.
         */
        sqsQueueParameters?: pulumi.Input<inputs.pipes.PipeTargetSqsQueueParametersArgs>;
        /**
         * The parameters for using a Step Functions state machine as a target.
         */
        stepFunctionStateMachineParameters?: pulumi.Input<inputs.pipes.PipeTargetStateMachineParametersArgs>;
        /**
         * The parameters for using a Timestream for LiveAnalytics table as a target.
         */
        timestreamParameters?: pulumi.Input<inputs.pipes.PipeTargetTimestreamParametersArgs>;
    }
    interface PipeTargetRedshiftDataParametersArgs {
        /**
         * Redshift Database
         */
        database: pulumi.Input<string>;
        /**
         * Database user name
         */
        dbUser?: pulumi.Input<string>;
        /**
         * Optional SecretManager ARN which stores the database credentials
         */
        secretManagerArn?: pulumi.Input<string>;
        /**
         * A list of SQLs.
         */
        sqls: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * A name for Redshift DataAPI statement which can be used as filter of ListStatement.
         */
        statementName?: pulumi.Input<string>;
        /**
         * Indicates whether to send an event back to EventBridge after the SQL statement runs.
         */
        withEvent?: pulumi.Input<boolean>;
    }
    interface PipeTargetSageMakerPipelineParametersArgs {
        /**
         * List of Parameter names and values for SageMaker AI Model Building Pipeline execution.
         */
        pipelineParameterList?: pulumi.Input<pulumi.Input<inputs.pipes.PipeSageMakerPipelineParameterArgs>[]>;
    }
    interface PipeTargetSqsQueueParametersArgs {
        /**
         * This parameter applies only to FIFO (first-in-first-out) queues.
         *
         * The token used for deduplication of sent messages.
         */
        messageDeduplicationId?: pulumi.Input<string>;
        /**
         * The FIFO message group ID to use as the target.
         */
        messageGroupId?: pulumi.Input<string>;
    }
    interface PipeTargetStateMachineParametersArgs {
        /**
         * Specify whether to invoke the Step Functions state machine synchronously or asynchronously.
         *
         * - `REQUEST_RESPONSE` (default) - Invoke synchronously. For more information, see [StartSyncExecution](https://docs.aws.amazon.com/step-functions/latest/apireference/API_StartSyncExecution.html) in the *AWS Step Functions API Reference* .
         *
         * > `REQUEST_RESPONSE` is not supported for `STANDARD` state machine workflows.
         * - `FIRE_AND_FORGET` - Invoke asynchronously. For more information, see [StartExecution](https://docs.aws.amazon.com/step-functions/latest/apireference/API_StartExecution.html) in the *AWS Step Functions API Reference* .
         *
         * For more information, see [Invocation types](https://docs.aws.amazon.com/eventbridge/latest/userguide/eb-pipes.html#pipes-invocation) in the *Amazon EventBridge User Guide* .
         */
        invocationType?: pulumi.Input<enums.pipes.PipeTargetInvocationType>;
    }
    interface PipeTargetTimestreamParametersArgs {
        /**
         * Map source data to dimensions in the target Timestream for LiveAnalytics table.
         *
         * For more information, see [Amazon Timestream for LiveAnalytics concepts](https://docs.aws.amazon.com/timestream/latest/developerguide/concepts.html)
         */
        dimensionMappings: pulumi.Input<pulumi.Input<inputs.pipes.PipeDimensionMappingArgs>[]>;
        /**
         * The granularity of the time units used. Default is `MILLISECONDS` .
         *
         * Required if `TimeFieldType` is specified as `EPOCH` .
         */
        epochTimeUnit?: pulumi.Input<enums.pipes.PipeEpochTimeUnit>;
        /**
         * Maps multiple measures from the source event to the same record in the specified Timestream for LiveAnalytics table.
         */
        multiMeasureMappings?: pulumi.Input<pulumi.Input<inputs.pipes.PipeMultiMeasureMappingArgs>[]>;
        /**
         * Mappings of single source data fields to individual records in the specified Timestream for LiveAnalytics table.
         */
        singleMeasureMappings?: pulumi.Input<pulumi.Input<inputs.pipes.PipeSingleMeasureMappingArgs>[]>;
        /**
         * The type of time value used.
         *
         * The default is `EPOCH` .
         */
        timeFieldType?: pulumi.Input<enums.pipes.PipeTimeFieldType>;
        /**
         * Dynamic path to the source data field that represents the time value for your data.
         */
        timeValue: pulumi.Input<string>;
        /**
         * How to format the timestamps. For example, `yyyy-MM-dd'T'HH:mm:ss'Z'` .
         *
         * Required if `TimeFieldType` is specified as `TIMESTAMP_FORMAT` .
         */
        timestampFormat?: pulumi.Input<string>;
        /**
         * 64 bit version value or source data field that represents the version value for your data.
         *
         * Write requests with a higher version number will update the existing measure values of the record and version. In cases where the measure value is the same, the version will still be updated.
         *
         * Default value is 1.
         *
         * Timestream for LiveAnalytics does not support updating partial measure values in a record.
         *
         * Write requests for duplicate data with a higher version number will update the existing measure value and version. In cases where the measure value is the same, `Version` will still be updated. Default value is `1` .
         *
         * > `Version` must be `1` or greater, or you will receive a `ValidationException` error.
         */
        versionValue: pulumi.Input<string>;
    }
}
export declare namespace proton {
}
export declare namespace qbusiness {
    interface ApplicationAttachmentsConfigurationArgs {
        /**
         * Status information about whether file upload functionality is activated or deactivated for your end user.
         */
        attachmentsControlMode: pulumi.Input<enums.qbusiness.ApplicationAttachmentsControlMode>;
    }
    interface ApplicationAutoSubscriptionConfigurationArgs {
        /**
         * Describes whether automatic subscriptions are enabled for an Amazon Q Business application using IAM identity federation for user management.
         */
        autoSubscribe: pulumi.Input<enums.qbusiness.ApplicationAutoSubscriptionStatus>;
        /**
         * Describes the default subscription type assigned to an Amazon Q Business application using IAM identity federation for user management. If the value for `autoSubscribe` is set to `ENABLED` you must select a value for this field.
         */
        defaultSubscriptionType?: pulumi.Input<enums.qbusiness.ApplicationSubscriptionType>;
    }
    interface ApplicationEncryptionConfigurationArgs {
        /**
         * The identifier of the AWS KMS key. Amazon Q Business doesn't support asymmetric keys.
         */
        kmsKeyId?: pulumi.Input<string>;
    }
    interface ApplicationPersonalizationConfigurationArgs {
        /**
         * An option to allow Amazon Q Business to customize chat responses using user specific metadata—specifically, location and job information—in your IAM Identity Center instance.
         */
        personalizationControlMode: pulumi.Input<enums.qbusiness.ApplicationPersonalizationControlMode>;
    }
    interface ApplicationQAppsConfigurationArgs {
        /**
         * Status information about whether end users can create and use Amazon Q Apps in the web experience.
         */
        qAppsControlMode: pulumi.Input<enums.qbusiness.ApplicationQAppsControlMode>;
    }
    interface ApplicationQuickSightConfigurationArgs {
        /**
         * The Amazon QuickSight namespace that is used as the identity provider. For more information about QuickSight namespaces, see [Namespace operations](https://docs.aws.amazon.com/quicksight/latest/developerguide/namespace-operations.html) .
         */
        clientNamespace: pulumi.Input<string>;
    }
    interface DataAccessorActionConfigurationArgs {
        /**
         * The Amazon Q Business action that is allowed.
         */
        action: pulumi.Input<string>;
        /**
         * The filter configuration for the action, if any.
         */
        filterConfiguration?: pulumi.Input<inputs.qbusiness.DataAccessorActionFilterConfigurationArgs>;
    }
    interface DataAccessorActionFilterConfigurationArgs {
        /**
         * Enables filtering of responses based on document attributes or metadata fields.
         */
        documentAttributeFilter: pulumi.Input<inputs.qbusiness.DataAccessorAttributeFilterArgs>;
    }
    interface DataAccessorAttributeFilterArgs {
        /**
         * Performs a logical `AND` operation on all supplied filters.
         */
        andAllFilters?: pulumi.Input<pulumi.Input<inputs.qbusiness.DataAccessorAttributeFilterArgs>[]>;
        /**
         * Returns `true` when a document contains all the specified document attributes or metadata fields. Supported for the following [document attribute value types](https://docs.aws.amazon.com/amazonq/latest/api-reference/API_DocumentAttributeValue.html) : `stringListValue` .
         */
        containsAll?: pulumi.Input<inputs.qbusiness.DataAccessorDocumentAttributeArgs>;
        /**
         * Returns `true` when a document contains any of the specified document attributes or metadata fields. Supported for the following [document attribute value types](https://docs.aws.amazon.com/amazonq/latest/api-reference/API_DocumentAttributeValue.html) : `stringListValue` .
         */
        containsAny?: pulumi.Input<inputs.qbusiness.DataAccessorDocumentAttributeArgs>;
        /**
         * Performs an equals operation on two document attributes or metadata fields. Supported for the following [document attribute value types](https://docs.aws.amazon.com/amazonq/latest/api-reference/API_DocumentAttributeValue.html) : `dateValue` , `longValue` , `stringListValue` and `stringValue` .
         */
        equalsTo?: pulumi.Input<inputs.qbusiness.DataAccessorDocumentAttributeArgs>;
        /**
         * Performs a greater than operation on two document attributes or metadata fields. Supported for the following [document attribute value types](https://docs.aws.amazon.com/amazonq/latest/api-reference/API_DocumentAttributeValue.html) : `dateValue` and `longValue` .
         */
        greaterThan?: pulumi.Input<inputs.qbusiness.DataAccessorDocumentAttributeArgs>;
        /**
         * Performs a greater or equals than operation on two document attributes or metadata fields. Supported for the following [document attribute value types](https://docs.aws.amazon.com/amazonq/latest/api-reference/API_DocumentAttributeValue.html) : `dateValue` and `longValue` .
         */
        greaterThanOrEquals?: pulumi.Input<inputs.qbusiness.DataAccessorDocumentAttributeArgs>;
        /**
         * Performs a less than operation on two document attributes or metadata fields. Supported for the following [document attribute value types](https://docs.aws.amazon.com/amazonq/latest/api-reference/API_DocumentAttributeValue.html) : `dateValue` and `longValue` .
         */
        lessThan?: pulumi.Input<inputs.qbusiness.DataAccessorDocumentAttributeArgs>;
        /**
         * Performs a less than or equals operation on two document attributes or metadata fields.Supported for the following [document attribute value type](https://docs.aws.amazon.com/amazonq/latest/api-reference/API_DocumentAttributeValue.html) : `dateValue` and `longValue` .
         */
        lessThanOrEquals?: pulumi.Input<inputs.qbusiness.DataAccessorDocumentAttributeArgs>;
        /**
         * Performs a logical `NOT` operation on all supplied filters.
         */
        notFilter?: pulumi.Input<inputs.qbusiness.DataAccessorAttributeFilterArgs>;
        /**
         * Performs a logical `OR` operation on all supplied filters.
         */
        orAllFilters?: pulumi.Input<pulumi.Input<inputs.qbusiness.DataAccessorAttributeFilterArgs>[]>;
    }
    interface DataAccessorDocumentAttributeArgs {
        /**
         * The identifier for the attribute.
         */
        name: pulumi.Input<string>;
        /**
         * The value of the attribute.
         */
        value: pulumi.Input<inputs.qbusiness.DataAccessorDocumentAttributeValue0PropertiesArgs | inputs.qbusiness.DataAccessorDocumentAttributeValue1PropertiesArgs | inputs.qbusiness.DataAccessorDocumentAttributeValue2PropertiesArgs | inputs.qbusiness.DataAccessorDocumentAttributeValue3PropertiesArgs>;
    }
    interface DataAccessorDocumentAttributeValue0PropertiesArgs {
        stringValue: pulumi.Input<string>;
    }
    interface DataAccessorDocumentAttributeValue1PropertiesArgs {
        stringListValue: pulumi.Input<pulumi.Input<string>[]>;
    }
    interface DataAccessorDocumentAttributeValue2PropertiesArgs {
        longValue: pulumi.Input<number>;
    }
    interface DataAccessorDocumentAttributeValue3PropertiesArgs {
        dateValue: pulumi.Input<string>;
    }
    interface DataSourceAudioExtractionConfigurationArgs {
        /**
         * The status of audio extraction (ENABLED or DISABLED) for processing audio content from files.
         */
        audioExtractionStatus: pulumi.Input<enums.qbusiness.DataSourceAudioExtractionStatus>;
    }
    interface DataSourceDocumentAttributeConditionArgs {
        /**
         * The identifier of the document attribute used for the condition.
         *
         * For example, 'Source_URI' could be an identifier for the attribute or metadata field that contains source URIs associated with the documents.
         *
         * Amazon Q Business currently doesn't support `_document_body` as an attribute key used for the condition.
         */
        key: pulumi.Input<string>;
        /**
         * The identifier of the document attribute used for the condition.
         *
         * For example, 'Source_URI' could be an identifier for the attribute or metadata field that contains source URIs associated with the documents.
         *
         * Amazon Q Business currently does not support `_document_body` as an attribute key used for the condition.
         */
        operator: pulumi.Input<enums.qbusiness.DataSourceDocumentEnrichmentConditionOperator>;
        /**
         * The value of a document attribute. You can only provide one value for a document attribute.
         */
        value?: pulumi.Input<inputs.qbusiness.DataSourceDocumentAttributeValue0PropertiesArgs | inputs.qbusiness.DataSourceDocumentAttributeValue1PropertiesArgs | inputs.qbusiness.DataSourceDocumentAttributeValue2PropertiesArgs | inputs.qbusiness.DataSourceDocumentAttributeValue3PropertiesArgs>;
    }
    interface DataSourceDocumentAttributeTargetArgs {
        /**
         * `TRUE` to delete the existing target value for your specified target attribute key. You cannot create a target value and set this to `TRUE` .
         */
        attributeValueOperator?: pulumi.Input<enums.qbusiness.DataSourceAttributeValueOperator>;
        /**
         * The identifier of the target document attribute or metadata field. For example, 'Department' could be an identifier for the target attribute or metadata field that includes the department names associated with the documents.
         */
        key: pulumi.Input<string>;
        /**
         * The value of a document attribute. You can only provide one value for a document attribute.
         */
        value?: pulumi.Input<inputs.qbusiness.DataSourceDocumentAttributeValue0PropertiesArgs | inputs.qbusiness.DataSourceDocumentAttributeValue1PropertiesArgs | inputs.qbusiness.DataSourceDocumentAttributeValue2PropertiesArgs | inputs.qbusiness.DataSourceDocumentAttributeValue3PropertiesArgs>;
    }
    interface DataSourceDocumentAttributeValue0PropertiesArgs {
        stringValue: pulumi.Input<string>;
    }
    interface DataSourceDocumentAttributeValue1PropertiesArgs {
        stringListValue: pulumi.Input<pulumi.Input<string>[]>;
    }
    interface DataSourceDocumentAttributeValue2PropertiesArgs {
        longValue: pulumi.Input<number>;
    }
    interface DataSourceDocumentAttributeValue3PropertiesArgs {
        dateValue: pulumi.Input<string>;
    }
    interface DataSourceDocumentEnrichmentConfigurationArgs {
        /**
         * Configuration information to alter document attributes or metadata fields and content when ingesting documents into Amazon Q Business.
         */
        inlineConfigurations?: pulumi.Input<pulumi.Input<inputs.qbusiness.DataSourceInlineDocumentEnrichmentConfigurationArgs>[]>;
        /**
         * Configuration information for invoking a Lambda function in AWS Lambda on the structured documents with their metadata and text extracted. You can use a Lambda function to apply advanced logic for creating, modifying, or deleting document metadata and content. For more information, see [Using Lambda functions](https://docs.aws.amazon.com/amazonq/latest/business-use-dg/cde-lambda-operations.html) .
         */
        postExtractionHookConfiguration?: pulumi.Input<inputs.qbusiness.DataSourceHookConfigurationArgs>;
        /**
         * Configuration information for invoking a Lambda function in AWS Lambda on the original or raw documents before extracting their metadata and text. You can use a Lambda function to apply advanced logic for creating, modifying, or deleting document metadata and content. For more information, see [Using Lambda functions](https://docs.aws.amazon.com/amazonq/latest/business-use-dg/cde-lambda-operations.html) .
         */
        preExtractionHookConfiguration?: pulumi.Input<inputs.qbusiness.DataSourceHookConfigurationArgs>;
    }
    interface DataSourceHookConfigurationArgs {
        /**
         * The condition used for when a Lambda function should be invoked.
         *
         * For example, you can specify a condition that if there are empty date-time values, then Amazon Q Business should invoke a function that inserts the current date-time.
         */
        invocationCondition?: pulumi.Input<inputs.qbusiness.DataSourceDocumentAttributeConditionArgs>;
        /**
         * The Amazon Resource Name (ARN) of the Lambda function sduring ingestion. For more information, see [Using Lambda functions for Amazon Q Business document enrichment](https://docs.aws.amazon.com/amazonq/latest/qbusiness-ug/cde-lambda-operations.html) .
         */
        lambdaArn?: pulumi.Input<string>;
        /**
         * The Amazon Resource Name (ARN) of a role with permission to run `PreExtractionHookConfiguration` and `PostExtractionHookConfiguration` for altering document metadata and content during the document ingestion process.
         */
        roleArn?: pulumi.Input<string>;
        /**
         * Stores the original, raw documents or the structured, parsed documents before and after altering them. For more information, see [Data contracts for Lambda functions](https://docs.aws.amazon.com/amazonq/latest/business-use-dg/cde-lambda-operations.html#cde-lambda-operations-data-contracts) .
         */
        s3BucketName?: pulumi.Input<string>;
    }
    interface DataSourceImageExtractionConfigurationArgs {
        /**
         * Specify whether to extract semantic meaning from images and visuals from documents.
         */
        imageExtractionStatus: pulumi.Input<enums.qbusiness.DataSourceImageExtractionStatus>;
    }
    interface DataSourceInlineDocumentEnrichmentConfigurationArgs {
        /**
         * Configuration of the condition used for the target document attribute or metadata field when ingesting documents into Amazon Q Business .
         */
        condition?: pulumi.Input<inputs.qbusiness.DataSourceDocumentAttributeConditionArgs>;
        /**
         * `TRUE` to delete content if the condition used for the target attribute is met.
         */
        documentContentOperator?: pulumi.Input<enums.qbusiness.DataSourceDocumentContentOperator>;
        /**
         * Configuration of the target document attribute or metadata field when ingesting documents into Amazon Q Business . You can also include a value.
         */
        target?: pulumi.Input<inputs.qbusiness.DataSourceDocumentAttributeTargetArgs>;
    }
    interface DataSourceMediaExtractionConfigurationArgs {
        /**
         * Configuration settings for extracting and processing audio content from media files.
         */
        audioExtractionConfiguration?: pulumi.Input<inputs.qbusiness.DataSourceAudioExtractionConfigurationArgs>;
        /**
         * The configuration for extracting semantic meaning from images in documents. For more information, see [Extracting semantic meaning from images and visuals](https://docs.aws.amazon.com/amazonq/latest/qbusiness-ug/extracting-meaning-from-images.html) .
         */
        imageExtractionConfiguration?: pulumi.Input<inputs.qbusiness.DataSourceImageExtractionConfigurationArgs>;
        /**
         * Configuration settings for extracting and processing video content from media files.
         */
        videoExtractionConfiguration?: pulumi.Input<inputs.qbusiness.DataSourceVideoExtractionConfigurationArgs>;
    }
    interface DataSourceVideoExtractionConfigurationArgs {
        /**
         * The status of video extraction (ENABLED or DISABLED) for processing video content from files.
         */
        videoExtractionStatus: pulumi.Input<enums.qbusiness.DataSourceVideoExtractionStatus>;
    }
    interface DataSourceVpcConfigurationArgs {
        /**
         * A list of identifiers of security groups within your Amazon VPC. The security groups should enable Amazon Q Business to connect to the data source.
         */
        securityGroupIds: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * A list of identifiers for subnets within your Amazon VPC. The subnets should be able to connect to each other in the VPC, and they should have outgoing access to the Internet through a NAT device.
         */
        subnetIds: pulumi.Input<pulumi.Input<string>[]>;
    }
    interface IndexCapacityConfigurationArgs {
        /**
         * The number of storage units configured for an Amazon Q Business index.
         */
        units?: pulumi.Input<number>;
    }
    interface IndexDocumentAttributeConfigurationArgs {
        /**
         * The name of the document attribute.
         */
        name?: pulumi.Input<string>;
        /**
         * Information about whether the document attribute can be used by an end user to search for information on their web experience.
         */
        search?: pulumi.Input<enums.qbusiness.QBusinessIndexStatus>;
        /**
         * The type of document attribute.
         */
        type?: pulumi.Input<enums.qbusiness.IndexAttributeType>;
    }
    interface PluginApiSchema0PropertiesArgs {
        payload: pulumi.Input<string>;
    }
    interface PluginApiSchema1PropertiesArgs {
        s3: pulumi.Input<inputs.qbusiness.PluginS3Args>;
    }
    interface PluginAuthConfiguration0PropertiesArgs {
        basicAuthConfiguration: pulumi.Input<inputs.qbusiness.PluginBasicAuthConfigurationArgs>;
    }
    interface PluginAuthConfiguration1PropertiesArgs {
        oAuth2ClientCredentialConfiguration: pulumi.Input<inputs.qbusiness.PluginOAuth2ClientCredentialConfigurationArgs>;
    }
    interface PluginAuthConfiguration2PropertiesArgs {
        noAuthConfiguration: pulumi.Input<inputs.qbusiness.PluginNoAuthConfigurationArgs>;
    }
    interface PluginBasicAuthConfigurationArgs {
        roleArn: pulumi.Input<string>;
        secretArn: pulumi.Input<string>;
    }
    interface PluginCustomPluginConfigurationArgs {
        /**
         * Contains either details about the S3 object containing the OpenAPI schema for the action group or the JSON or YAML-formatted payload defining the schema.
         */
        apiSchema: pulumi.Input<inputs.qbusiness.PluginApiSchema0PropertiesArgs | inputs.qbusiness.PluginApiSchema1PropertiesArgs>;
        /**
         * The type of OpenAPI schema to use.
         */
        apiSchemaType: pulumi.Input<enums.qbusiness.PluginApiSchemaType>;
        /**
         * A description for your custom plugin configuration.
         */
        description: pulumi.Input<string>;
    }
    interface PluginNoAuthConfigurationArgs {
    }
    interface PluginOAuth2ClientCredentialConfigurationArgs {
        authorizationUrl?: pulumi.Input<string>;
        roleArn: pulumi.Input<string>;
        secretArn: pulumi.Input<string>;
        tokenUrl?: pulumi.Input<string>;
    }
    interface PluginS3Args {
        bucket: pulumi.Input<string>;
        key: pulumi.Input<string>;
    }
    interface RetrieverConfiguration0PropertiesArgs {
        nativeIndexConfiguration: pulumi.Input<inputs.qbusiness.RetrieverNativeIndexConfigurationArgs>;
    }
    interface RetrieverConfiguration1PropertiesArgs {
        kendraIndexConfiguration: pulumi.Input<inputs.qbusiness.RetrieverKendraIndexConfigurationArgs>;
    }
    interface RetrieverKendraIndexConfigurationArgs {
        indexId: pulumi.Input<string>;
    }
    interface RetrieverNativeIndexConfigurationArgs {
        indexId: pulumi.Input<string>;
    }
    interface WebExperienceBrowserExtensionConfigurationArgs {
        /**
         * Specify the browser extensions allowed for your Amazon Q web experience.
         *
         * - `CHROME` — Enables the extension for Chromium-based browsers (Google Chrome, Microsoft Edge, Opera, etc.).
         * - `FIREFOX` — Enables the extension for Mozilla Firefox.
         * - `CHROME` and `FIREFOX` — Enable the extension for Chromium-based browsers and Mozilla Firefox.
         */
        enabledBrowserExtensions: pulumi.Input<pulumi.Input<enums.qbusiness.WebExperienceBrowserExtension>[]>;
    }
    interface WebExperienceCustomizationConfigurationArgs {
        /**
         * Provides the URL where the custom CSS file is hosted for an Amazon Q web experience.
         */
        customCssUrl?: pulumi.Input<string>;
        /**
         * Provides the URL where the custom favicon file is hosted for an Amazon Q web experience.
         */
        faviconUrl?: pulumi.Input<string>;
        /**
         * Provides the URL where the custom font file is hosted for an Amazon Q web experience.
         */
        fontUrl?: pulumi.Input<string>;
        /**
         * Provides the URL where the custom logo file is hosted for an Amazon Q web experience.
         */
        logoUrl?: pulumi.Input<string>;
    }
    interface WebExperienceIdentityProviderConfiguration0PropertiesArgs {
        samlConfiguration: pulumi.Input<inputs.qbusiness.WebExperienceSamlProviderConfigurationArgs>;
    }
    interface WebExperienceIdentityProviderConfiguration1PropertiesArgs {
        openIdConnectConfiguration: pulumi.Input<inputs.qbusiness.WebExperienceOpenIdConnectProviderConfigurationArgs>;
    }
    interface WebExperienceOpenIdConnectProviderConfigurationArgs {
        secretsArn: pulumi.Input<string>;
        secretsRole: pulumi.Input<string>;
    }
    interface WebExperienceSamlProviderConfigurationArgs {
        authenticationUrl: pulumi.Input<string>;
    }
}
export declare namespace qldb {
    interface StreamKinesisConfigurationArgs {
        /**
         * Enables QLDB to publish multiple data records in a single Kinesis Data Streams record, increasing the number of records sent per API call.
         *
         * Default: `True`
         *
         * > Record aggregation has important implications for processing records and requires de-aggregation in your stream consumer. To learn more, see [KPL Key Concepts](https://docs.aws.amazon.com/streams/latest/dev/kinesis-kpl-concepts.html) and [Consumer De-aggregation](https://docs.aws.amazon.com/streams/latest/dev/kinesis-kpl-consumer-deaggregation.html) in the *Amazon Kinesis Data Streams Developer Guide* .
         */
        aggregationEnabled?: pulumi.Input<boolean>;
        /**
         * The Amazon Resource Name (ARN) of the Kinesis Data Streams resource.
         */
        streamArn?: pulumi.Input<string>;
    }
}
export declare namespace quicksight {
    interface AnalysisAggregationFunctionArgs {
        /**
         * Aggregation for attributes.
         */
        attributeAggregationFunction?: pulumi.Input<inputs.quicksight.AnalysisAttributeAggregationFunctionArgs>;
        /**
         * Aggregation for categorical values.
         *
         * - `COUNT` : Aggregate by the total number of values, including duplicates.
         * - `DISTINCT_COUNT` : Aggregate by the total number of distinct values.
         */
        categoricalAggregationFunction?: pulumi.Input<enums.quicksight.AnalysisCategoricalAggregationFunction>;
        /**
         * Aggregation for date values.
         *
         * - `COUNT` : Aggregate by the total number of values, including duplicates.
         * - `DISTINCT_COUNT` : Aggregate by the total number of distinct values.
         * - `MIN` : Select the smallest date value.
         * - `MAX` : Select the largest date value.
         */
        dateAggregationFunction?: pulumi.Input<enums.quicksight.AnalysisDateAggregationFunction>;
        /**
         * Aggregation for numerical values.
         */
        numericalAggregationFunction?: pulumi.Input<inputs.quicksight.AnalysisNumericalAggregationFunctionArgs>;
    }
    interface AnalysisAggregationSortConfigurationArgs {
        /**
         * The function that aggregates the values in `Column` .
         */
        aggregationFunction?: pulumi.Input<inputs.quicksight.AnalysisAggregationFunctionArgs>;
        /**
         * The column that determines the sort order of aggregated values.
         */
        column: pulumi.Input<inputs.quicksight.AnalysisColumnIdentifierArgs>;
        /**
         * The sort direction of values.
         *
         * - `ASC` : Sort in ascending order.
         * - `DESC` : Sort in descending order.
         */
        sortDirection: pulumi.Input<enums.quicksight.AnalysisSortDirection>;
    }
    interface AnalysisAllSheetsFilterScopeConfigurationArgs {
    }
    interface AnalysisAnchorDateConfigurationArgs {
        /**
         * The options for the date configuration. Choose one of the options below:
         *
         * - `NOW`
         */
        anchorOption?: pulumi.Input<enums.quicksight.AnalysisAnchorOption>;
        /**
         * The name of the parameter that is used for the anchor date configuration.
         */
        parameterName?: pulumi.Input<string>;
    }
    interface AnalysisArcAxisConfigurationArgs {
        /**
         * The arc axis range of a `GaugeChartVisual` .
         */
        range?: pulumi.Input<inputs.quicksight.AnalysisArcAxisDisplayRangeArgs>;
        /**
         * The reserved range of the arc axis.
         */
        reserveRange?: pulumi.Input<number>;
    }
    interface AnalysisArcAxisDisplayRangeArgs {
        /**
         * The maximum value of the arc axis range.
         */
        max?: pulumi.Input<number>;
        /**
         * The minimum value of the arc axis range.
         */
        min?: pulumi.Input<number>;
    }
    interface AnalysisArcConfigurationArgs {
        /**
         * The option that determines the arc angle of a `GaugeChartVisual` .
         */
        arcAngle?: pulumi.Input<number>;
        /**
         * The options that determine the arc thickness of a `GaugeChartVisual` .
         */
        arcThickness?: pulumi.Input<enums.quicksight.AnalysisArcThicknessOptions>;
    }
    interface AnalysisArcOptionsArgs {
        /**
         * The arc thickness of a `GaugeChartVisual` .
         */
        arcThickness?: pulumi.Input<enums.quicksight.AnalysisArcThickness>;
    }
    interface AnalysisAssetOptionsArgs {
        /**
         * Determines the timezone for the analysis.
         */
        timezone?: pulumi.Input<string>;
        /**
         * Determines the week start day for an analysis.
         */
        weekStart?: pulumi.Input<enums.quicksight.AnalysisDayOfTheWeek>;
    }
    interface AnalysisAttributeAggregationFunctionArgs {
        /**
         * The built-in aggregation functions for attributes.
         *
         * - `UNIQUE_VALUE` : Returns the unique value for a field, aggregated by the dimension fields.
         */
        simpleAttributeAggregation?: pulumi.Input<enums.quicksight.AnalysisSimpleAttributeAggregationFunction>;
        /**
         * Used by the `UNIQUE_VALUE` aggregation function. If there are multiple values for the field used by the aggregation, the value for this property will be returned instead. Defaults to '*'.
         */
        valueForMultipleValues?: pulumi.Input<string>;
    }
    interface AnalysisAxisDataOptionsArgs {
        /**
         * The options for an axis with a date field.
         */
        dateAxisOptions?: pulumi.Input<inputs.quicksight.AnalysisDateAxisOptionsArgs>;
        /**
         * The options for an axis with a numeric field.
         */
        numericAxisOptions?: pulumi.Input<inputs.quicksight.AnalysisNumericAxisOptionsArgs>;
    }
    interface AnalysisAxisDisplayDataDrivenRangeArgs {
    }
    interface AnalysisAxisDisplayMinMaxRangeArgs {
        /**
         * The maximum setup for an axis display range.
         */
        maximum?: pulumi.Input<number>;
        /**
         * The minimum setup for an axis display range.
         */
        minimum?: pulumi.Input<number>;
    }
    interface AnalysisAxisDisplayOptionsArgs {
        /**
         * Determines whether or not the axis line is visible.
         */
        axisLineVisibility?: pulumi.Input<enums.quicksight.AnalysisVisibility>;
        /**
         * String based length that is composed of value and unit in px
         */
        axisOffset?: pulumi.Input<string>;
        /**
         * The data options for an axis.
         */
        dataOptions?: pulumi.Input<inputs.quicksight.AnalysisAxisDataOptionsArgs>;
        /**
         * Determines whether or not the grid line is visible.
         */
        gridLineVisibility?: pulumi.Input<enums.quicksight.AnalysisVisibility>;
        /**
         * The scroll bar options for an axis.
         */
        scrollbarOptions?: pulumi.Input<inputs.quicksight.AnalysisScrollBarOptionsArgs>;
        /**
         * The tick label options of an axis.
         */
        tickLabelOptions?: pulumi.Input<inputs.quicksight.AnalysisAxisTickLabelOptionsArgs>;
    }
    interface AnalysisAxisDisplayRangeArgs {
        /**
         * The data-driven setup of an axis display range.
         */
        dataDriven?: pulumi.Input<inputs.quicksight.AnalysisAxisDisplayDataDrivenRangeArgs>;
        /**
         * The minimum and maximum setup of an axis display range.
         */
        minMax?: pulumi.Input<inputs.quicksight.AnalysisAxisDisplayMinMaxRangeArgs>;
    }
    interface AnalysisAxisLabelOptionsArgs {
        /**
         * The options that indicate which field the label belongs to.
         */
        applyTo?: pulumi.Input<inputs.quicksight.AnalysisAxisLabelReferenceOptionsArgs>;
        /**
         * The text for the axis label.
         */
        customLabel?: pulumi.Input<string>;
        /**
         * The font configuration of the axis label.
         */
        fontConfiguration?: pulumi.Input<inputs.quicksight.AnalysisFontConfigurationArgs>;
    }
    interface AnalysisAxisLabelReferenceOptionsArgs {
        /**
         * The column that the axis label is targeted to.
         */
        column: pulumi.Input<inputs.quicksight.AnalysisColumnIdentifierArgs>;
        /**
         * The field that the axis label is targeted to.
         */
        fieldId: pulumi.Input<string>;
    }
    interface AnalysisAxisLinearScaleArgs {
        /**
         * The step count setup of a linear axis.
         */
        stepCount?: pulumi.Input<number>;
        /**
         * The step size setup of a linear axis.
         */
        stepSize?: pulumi.Input<number>;
    }
    interface AnalysisAxisLogarithmicScaleArgs {
        /**
         * The base setup of a logarithmic axis scale.
         */
        base?: pulumi.Input<number>;
    }
    interface AnalysisAxisScaleArgs {
        /**
         * The linear axis scale setup.
         */
        linear?: pulumi.Input<inputs.quicksight.AnalysisAxisLinearScaleArgs>;
        /**
         * The logarithmic axis scale setup.
         */
        logarithmic?: pulumi.Input<inputs.quicksight.AnalysisAxisLogarithmicScaleArgs>;
    }
    interface AnalysisAxisTickLabelOptionsArgs {
        /**
         * Determines whether or not the axis ticks are visible.
         */
        labelOptions?: pulumi.Input<inputs.quicksight.AnalysisLabelOptionsArgs>;
        /**
         * The rotation angle of the axis tick labels.
         */
        rotationAngle?: pulumi.Input<number>;
    }
    interface AnalysisBarChartAggregatedFieldWellsArgs {
        /**
         * The category (y-axis) field well of a bar chart.
         */
        category?: pulumi.Input<pulumi.Input<inputs.quicksight.AnalysisDimensionFieldArgs>[]>;
        /**
         * The color (group/color) field well of a bar chart.
         */
        colors?: pulumi.Input<pulumi.Input<inputs.quicksight.AnalysisDimensionFieldArgs>[]>;
        /**
         * The small multiples field well of a bar chart.
         */
        smallMultiples?: pulumi.Input<pulumi.Input<inputs.quicksight.AnalysisDimensionFieldArgs>[]>;
        /**
         * The value field wells of a bar chart. Values are aggregated by category.
         */
        values?: pulumi.Input<pulumi.Input<inputs.quicksight.AnalysisMeasureFieldArgs>[]>;
    }
    interface AnalysisBarChartConfigurationArgs {
        /**
         * Determines the arrangement of the bars. The orientation and arrangement of bars determine the type of bar that is used in the visual.
         */
        barsArrangement?: pulumi.Input<enums.quicksight.AnalysisBarsArrangement>;
        /**
         * The label display options (grid line, range, scale, axis step) for bar chart category.
         */
        categoryAxis?: pulumi.Input<inputs.quicksight.AnalysisAxisDisplayOptionsArgs>;
        /**
         * The label options (label text, label visibility and sort icon visibility) for a bar chart.
         */
        categoryLabelOptions?: pulumi.Input<inputs.quicksight.AnalysisChartAxisLabelOptionsArgs>;
        /**
         * The label options (label text, label visibility and sort icon visibility) for a color that is used in a bar chart.
         */
        colorLabelOptions?: pulumi.Input<inputs.quicksight.AnalysisChartAxisLabelOptionsArgs>;
        /**
         * The contribution analysis (anomaly configuration) setup of the visual.
         */
        contributionAnalysisDefaults?: pulumi.Input<pulumi.Input<inputs.quicksight.AnalysisContributionAnalysisDefaultArgs>[]>;
        /**
         * The options that determine if visual data labels are displayed.
         */
        dataLabels?: pulumi.Input<inputs.quicksight.AnalysisDataLabelOptionsArgs>;
        /**
         * The field wells of the visual.
         */
        fieldWells?: pulumi.Input<inputs.quicksight.AnalysisBarChartFieldWellsArgs>;
        /**
         * The general visual interactions setup for a visual.
         */
        interactions?: pulumi.Input<inputs.quicksight.AnalysisVisualInteractionOptionsArgs>;
        /**
         * The legend display setup of the visual.
         */
        legend?: pulumi.Input<inputs.quicksight.AnalysisLegendOptionsArgs>;
        /**
         * The orientation of the bars in a bar chart visual. There are two valid values in this structure:
         *
         * - `HORIZONTAL` : Used for charts that have horizontal bars. Visuals that use this value are horizontal bar charts, horizontal stacked bar charts, and horizontal stacked 100% bar charts.
         * - `VERTICAL` : Used for charts that have vertical bars. Visuals that use this value are vertical bar charts, vertical stacked bar charts, and vertical stacked 100% bar charts.
         */
        orientation?: pulumi.Input<enums.quicksight.AnalysisBarChartOrientation>;
        /**
         * The reference line setup of the visual.
         */
        referenceLines?: pulumi.Input<pulumi.Input<inputs.quicksight.AnalysisReferenceLineArgs>[]>;
        /**
         * The small multiples setup for the visual.
         */
        smallMultiplesOptions?: pulumi.Input<inputs.quicksight.AnalysisSmallMultiplesOptionsArgs>;
        /**
         * The sort configuration of a `BarChartVisual` .
         */
        sortConfiguration?: pulumi.Input<inputs.quicksight.AnalysisBarChartSortConfigurationArgs>;
        /**
         * The tooltip display setup of the visual.
         */
        tooltip?: pulumi.Input<inputs.quicksight.AnalysisTooltipOptionsArgs>;
        /**
         * The label display options (grid line, range, scale, axis step) for a bar chart value.
         */
        valueAxis?: pulumi.Input<inputs.quicksight.AnalysisAxisDisplayOptionsArgs>;
        /**
         * The label options (label text, label visibility and sort icon visibility) for a bar chart value.
         */
        valueLabelOptions?: pulumi.Input<inputs.quicksight.AnalysisChartAxisLabelOptionsArgs>;
        /**
         * The palette (chart color) display setup of the visual.
         */
        visualPalette?: pulumi.Input<inputs.quicksight.AnalysisVisualPaletteArgs>;
    }
    interface AnalysisBarChartFieldWellsArgs {
        /**
         * The aggregated field wells of a bar chart.
         */
        barChartAggregatedFieldWells?: pulumi.Input<inputs.quicksight.AnalysisBarChartAggregatedFieldWellsArgs>;
    }
    interface AnalysisBarChartSortConfigurationArgs {
        /**
         * The limit on the number of categories displayed in a bar chart.
         */
        categoryItemsLimit?: pulumi.Input<inputs.quicksight.AnalysisItemsLimitConfigurationArgs>;
        /**
         * The sort configuration of category fields.
         */
        categorySort?: pulumi.Input<pulumi.Input<inputs.quicksight.AnalysisFieldSortOptionsArgs>[]>;
        /**
         * The limit on the number of values displayed in a bar chart.
         */
        colorItemsLimit?: pulumi.Input<inputs.quicksight.AnalysisItemsLimitConfigurationArgs>;
        /**
         * The sort configuration of color fields in a bar chart.
         */
        colorSort?: pulumi.Input<pulumi.Input<inputs.quicksight.AnalysisFieldSortOptionsArgs>[]>;
        /**
         * The limit on the number of small multiples panels that are displayed.
         */
        smallMultiplesLimitConfiguration?: pulumi.Input<inputs.quicksight.AnalysisItemsLimitConfigurationArgs>;
        /**
         * The sort configuration of the small multiples field.
         */
        smallMultiplesSort?: pulumi.Input<pulumi.Input<inputs.quicksight.AnalysisFieldSortOptionsArgs>[]>;
    }
    interface AnalysisBarChartVisualArgs {
        /**
         * The list of custom actions that are configured for a visual.
         */
        actions?: pulumi.Input<pulumi.Input<inputs.quicksight.AnalysisVisualCustomActionArgs>[]>;
        /**
         * The configuration settings of the visual.
         */
        chartConfiguration?: pulumi.Input<inputs.quicksight.AnalysisBarChartConfigurationArgs>;
        /**
         * The column hierarchy that is used during drill-downs and drill-ups.
         */
        columnHierarchies?: pulumi.Input<pulumi.Input<inputs.quicksight.AnalysisColumnHierarchyArgs>[]>;
        /**
         * The subtitle that is displayed on the visual.
         */
        subtitle?: pulumi.Input<inputs.quicksight.AnalysisVisualSubtitleLabelOptionsArgs>;
        /**
         * The title that is displayed on the visual.
         */
        title?: pulumi.Input<inputs.quicksight.AnalysisVisualTitleLabelOptionsArgs>;
        /**
         * The alt text for the visual.
         */
        visualContentAltText?: pulumi.Input<string>;
        /**
         * The unique identifier of a visual. This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers.
         */
        visualId: pulumi.Input<string>;
    }
    interface AnalysisBinCountOptionsArgs {
        /**
         * The options that determine the bin count value.
         */
        value?: pulumi.Input<number>;
    }
    interface AnalysisBinWidthOptionsArgs {
        /**
         * The options that determine the bin count limit.
         */
        binCountLimit?: pulumi.Input<number>;
        /**
         * The options that determine the bin width value.
         */
        value?: pulumi.Input<number>;
    }
    interface AnalysisBodySectionConfigurationArgs {
        /**
         * The configuration of content in a body section.
         */
        content: pulumi.Input<inputs.quicksight.AnalysisBodySectionContentArgs>;
        /**
         * The configuration of a page break for a section.
         */
        pageBreakConfiguration?: pulumi.Input<inputs.quicksight.AnalysisSectionPageBreakConfigurationArgs>;
        /**
         * Describes the configurations that are required to declare a section as repeating.
         */
        repeatConfiguration?: pulumi.Input<inputs.quicksight.AnalysisBodySectionRepeatConfigurationArgs>;
        /**
         * The unique identifier of a body section.
         */
        sectionId: pulumi.Input<string>;
        /**
         * The style options of a body section.
         */
        style?: pulumi.Input<inputs.quicksight.AnalysisSectionStyleArgs>;
    }
    interface AnalysisBodySectionContentArgs {
        /**
         * The layout configuration of a body section.
         */
        layout?: pulumi.Input<inputs.quicksight.AnalysisSectionLayoutConfigurationArgs>;
    }
    interface AnalysisBodySectionDynamicCategoryDimensionConfigurationArgs {
        column: pulumi.Input<inputs.quicksight.AnalysisColumnIdentifierArgs>;
        /**
         * Number of values to use from the column for repetition.
         */
        limit?: pulumi.Input<number>;
        /**
         * Sort criteria on the column values that you use for repetition.
         */
        sortByMetrics?: pulumi.Input<pulumi.Input<inputs.quicksight.AnalysisColumnSortArgs>[]>;
    }
    interface AnalysisBodySectionDynamicNumericDimensionConfigurationArgs {
        column: pulumi.Input<inputs.quicksight.AnalysisColumnIdentifierArgs>;
        /**
         * Number of values to use from the column for repetition.
         */
        limit?: pulumi.Input<number>;
        /**
         * Sort criteria on the column values that you use for repetition.
         */
        sortByMetrics?: pulumi.Input<pulumi.Input<inputs.quicksight.AnalysisColumnSortArgs>[]>;
    }
    interface AnalysisBodySectionRepeatConfigurationArgs {
        /**
         * List of `BodySectionRepeatDimensionConfiguration` values that describe the dataset column and constraints for the column used to repeat the contents of a section.
         */
        dimensionConfigurations?: pulumi.Input<pulumi.Input<inputs.quicksight.AnalysisBodySectionRepeatDimensionConfigurationArgs>[]>;
        /**
         * List of visuals to exclude from repetition in repeating sections. The visuals will render identically, and ignore the repeating configurations in all repeating instances.
         */
        nonRepeatingVisuals?: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * Page break configuration to apply for each repeating instance.
         */
        pageBreakConfiguration?: pulumi.Input<inputs.quicksight.AnalysisBodySectionRepeatPageBreakConfigurationArgs>;
    }
    interface AnalysisBodySectionRepeatDimensionConfigurationArgs {
        /**
         * Describes the *Category* dataset column and constraints around the dynamic values that will be used in repeating the section contents.
         */
        dynamicCategoryDimensionConfiguration?: pulumi.Input<inputs.quicksight.AnalysisBodySectionDynamicCategoryDimensionConfigurationArgs>;
        /**
         * Describes the *Numeric* dataset column and constraints around the dynamic values used to repeat the contents of a section.
         */
        dynamicNumericDimensionConfiguration?: pulumi.Input<inputs.quicksight.AnalysisBodySectionDynamicNumericDimensionConfigurationArgs>;
    }
    interface AnalysisBodySectionRepeatPageBreakConfigurationArgs {
        after?: pulumi.Input<inputs.quicksight.AnalysisSectionAfterPageBreakArgs>;
    }
    interface AnalysisBoxPlotAggregatedFieldWellsArgs {
        /**
         * The group by field well of a box plot chart. Values are grouped based on group by fields.
         */
        groupBy?: pulumi.Input<pulumi.Input<inputs.quicksight.AnalysisDimensionFieldArgs>[]>;
        /**
         * The value field well of a box plot chart. Values are aggregated based on group by fields.
         */
        values?: pulumi.Input<pulumi.Input<inputs.quicksight.AnalysisMeasureFieldArgs>[]>;
    }
    interface AnalysisBoxPlotChartConfigurationArgs {
        /**
         * The box plot chart options for a box plot visual
         */
        boxPlotOptions?: pulumi.Input<inputs.quicksight.AnalysisBoxPlotOptionsArgs>;
        /**
         * The label display options (grid line, range, scale, axis step) of a box plot category.
         */
        categoryAxis?: pulumi.Input<inputs.quicksight.AnalysisAxisDisplayOptionsArgs>;
        /**
         * The label options (label text, label visibility and sort Icon visibility) of a box plot category.
         */
        categoryLabelOptions?: pulumi.Input<inputs.quicksight.AnalysisChartAxisLabelOptionsArgs>;
        /**
         * The field wells of the visual.
         */
        fieldWells?: pulumi.Input<inputs.quicksight.AnalysisBoxPlotFieldWellsArgs>;
        /**
         * The general visual interactions setup for a visual.
         */
        interactions?: pulumi.Input<inputs.quicksight.AnalysisVisualInteractionOptionsArgs>;
        legend?: pulumi.Input<inputs.quicksight.AnalysisLegendOptionsArgs>;
        /**
         * The label display options (grid line, range, scale, axis step) of a box plot category.
         */
        primaryYAxisDisplayOptions?: pulumi.Input<inputs.quicksight.AnalysisAxisDisplayOptionsArgs>;
        /**
         * The label options (label text, label visibility and sort icon visibility) of a box plot value.
         */
        primaryYAxisLabelOptions?: pulumi.Input<inputs.quicksight.AnalysisChartAxisLabelOptionsArgs>;
        /**
         * The reference line setup of the visual.
         */
        referenceLines?: pulumi.Input<pulumi.Input<inputs.quicksight.AnalysisReferenceLineArgs>[]>;
        /**
         * The sort configuration of a `BoxPlotVisual` .
         */
        sortConfiguration?: pulumi.Input<inputs.quicksight.AnalysisBoxPlotSortConfigurationArgs>;
        /**
         * The tooltip display setup of the visual.
         */
        tooltip?: pulumi.Input<inputs.quicksight.AnalysisTooltipOptionsArgs>;
        /**
         * The palette (chart color) display setup of the visual.
         */
        visualPalette?: pulumi.Input<inputs.quicksight.AnalysisVisualPaletteArgs>;
    }
    interface AnalysisBoxPlotFieldWellsArgs {
        /**
         * The aggregated field wells of a box plot.
         */
        boxPlotAggregatedFieldWells?: pulumi.Input<inputs.quicksight.AnalysisBoxPlotAggregatedFieldWellsArgs>;
    }
    interface AnalysisBoxPlotOptionsArgs {
        /**
         * Determines the visibility of all data points of the box plot.
         */
        allDataPointsVisibility?: pulumi.Input<enums.quicksight.AnalysisVisibility>;
        /**
         * Determines the visibility of the outlier in a box plot.
         */
        outlierVisibility?: pulumi.Input<enums.quicksight.AnalysisVisibility>;
        /**
         * The style options of the box plot.
         */
        styleOptions?: pulumi.Input<inputs.quicksight.AnalysisBoxPlotStyleOptionsArgs>;
    }
    interface AnalysisBoxPlotSortConfigurationArgs {
        /**
         * The sort configuration of a group by fields.
         */
        categorySort?: pulumi.Input<pulumi.Input<inputs.quicksight.AnalysisFieldSortOptionsArgs>[]>;
        /**
         * The pagination configuration of a table visual or box plot.
         */
        paginationConfiguration?: pulumi.Input<inputs.quicksight.AnalysisPaginationConfigurationArgs>;
    }
    interface AnalysisBoxPlotStyleOptionsArgs {
        /**
         * The fill styles (solid, transparent) of the box plot.
         */
        fillStyle?: pulumi.Input<enums.quicksight.AnalysisBoxPlotFillStyle>;
    }
    interface AnalysisBoxPlotVisualArgs {
        /**
         * The list of custom actions that are configured for a visual.
         */
        actions?: pulumi.Input<pulumi.Input<inputs.quicksight.AnalysisVisualCustomActionArgs>[]>;
        /**
         * The configuration settings of the visual.
         */
        chartConfiguration?: pulumi.Input<inputs.quicksight.AnalysisBoxPlotChartConfigurationArgs>;
        /**
         * The column hierarchy that is used during drill-downs and drill-ups.
         */
        columnHierarchies?: pulumi.Input<pulumi.Input<inputs.quicksight.AnalysisColumnHierarchyArgs>[]>;
        /**
         * The subtitle that is displayed on the visual.
         */
        subtitle?: pulumi.Input<inputs.quicksight.AnalysisVisualSubtitleLabelOptionsArgs>;
        /**
         * The title that is displayed on the visual.
         */
        title?: pulumi.Input<inputs.quicksight.AnalysisVisualTitleLabelOptionsArgs>;
        /**
         * The alt text for the visual.
         */
        visualContentAltText?: pulumi.Input<string>;
        /**
         * The unique identifier of a visual. This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers..
         */
        visualId: pulumi.Input<string>;
    }
    interface AnalysisCalculatedFieldArgs {
        /**
         * The data set that is used in this calculated field.
         */
        dataSetIdentifier: pulumi.Input<string>;
        /**
         * The expression of the calculated field.
         */
        expression: pulumi.Input<string>;
        /**
         * The name of the calculated field.
         */
        name: pulumi.Input<string>;
    }
    interface AnalysisCalculatedMeasureFieldArgs {
        /**
         * The expression in the table calculation.
         */
        expression: pulumi.Input<string>;
        /**
         * The custom field ID.
         */
        fieldId: pulumi.Input<string>;
    }
    interface AnalysisCascadingControlConfigurationArgs {
        /**
         * A list of source controls that determine the values that are used in the current control.
         */
        sourceControls?: pulumi.Input<pulumi.Input<inputs.quicksight.AnalysisCascadingControlSourceArgs>[]>;
    }
    interface AnalysisCascadingControlSourceArgs {
        /**
         * The column identifier that determines which column to look up for the source sheet control.
         */
        columnToMatch?: pulumi.Input<inputs.quicksight.AnalysisColumnIdentifierArgs>;
        /**
         * The source sheet control ID of a `CascadingControlSource` .
         */
        sourceSheetControlId?: pulumi.Input<string>;
    }
    interface AnalysisCategoricalDimensionFieldArgs {
        /**
         * The column that is used in the `CategoricalDimensionField` .
         */
        column: pulumi.Input<inputs.quicksight.AnalysisColumnIdentifierArgs>;
        /**
         * The custom field ID.
         */
        fieldId: pulumi.Input<string>;
        /**
         * The format configuration of the field.
         */
        formatConfiguration?: pulumi.Input<inputs.quicksight.AnalysisStringFormatConfigurationArgs>;
        /**
         * The custom hierarchy ID.
         */
        hierarchyId?: pulumi.Input<string>;
    }
    interface AnalysisCategoricalMeasureFieldArgs {
        /**
         * The aggregation function of the measure field.
         */
        aggregationFunction?: pulumi.Input<enums.quicksight.AnalysisCategoricalAggregationFunction>;
        /**
         * The column that is used in the `CategoricalMeasureField` .
         */
        column: pulumi.Input<inputs.quicksight.AnalysisColumnIdentifierArgs>;
        /**
         * The custom field ID.
         */
        fieldId: pulumi.Input<string>;
        /**
         * The format configuration of the field.
         */
        formatConfiguration?: pulumi.Input<inputs.quicksight.AnalysisStringFormatConfigurationArgs>;
    }
    interface AnalysisCategoryDrillDownFilterArgs {
        /**
         * A list of the string inputs that are the values of the category drill down filter.
         */
        categoryValues: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * The column that the filter is applied to.
         */
        column: pulumi.Input<inputs.quicksight.AnalysisColumnIdentifierArgs>;
    }
    interface AnalysisCategoryFilterArgs {
        /**
         * The column that the filter is applied to.
         */
        column: pulumi.Input<inputs.quicksight.AnalysisColumnIdentifierArgs>;
        /**
         * The configuration for a `CategoryFilter` .
         */
        configuration: pulumi.Input<inputs.quicksight.AnalysisCategoryFilterConfigurationArgs>;
        /**
         * The default configurations for the associated controls. This applies only for filters that are scoped to multiple sheets.
         */
        defaultFilterControlConfiguration?: pulumi.Input<inputs.quicksight.AnalysisDefaultFilterControlConfigurationArgs>;
        /**
         * An identifier that uniquely identifies a filter within a dashboard, analysis, or template.
         */
        filterId: pulumi.Input<string>;
    }
    interface AnalysisCategoryFilterConfigurationArgs {
        /**
         * A custom filter that filters based on a single value. This filter can be partially matched.
         */
        customFilterConfiguration?: pulumi.Input<inputs.quicksight.AnalysisCustomFilterConfigurationArgs>;
        /**
         * A list of custom filter values. In the Amazon QuickSight console, this filter type is called a custom filter list.
         */
        customFilterListConfiguration?: pulumi.Input<inputs.quicksight.AnalysisCustomFilterListConfigurationArgs>;
        /**
         * A list of filter configurations. In the Amazon QuickSight console, this filter type is called a filter list.
         */
        filterListConfiguration?: pulumi.Input<inputs.quicksight.AnalysisFilterListConfigurationArgs>;
    }
    interface AnalysisCategoryInnerFilterArgs {
        column: pulumi.Input<inputs.quicksight.AnalysisColumnIdentifierArgs>;
        configuration: pulumi.Input<inputs.quicksight.AnalysisCategoryFilterConfigurationArgs>;
        defaultFilterControlConfiguration?: pulumi.Input<inputs.quicksight.AnalysisDefaultFilterControlConfigurationArgs>;
    }
    interface AnalysisChartAxisLabelOptionsArgs {
        /**
         * The label options for a chart axis.
         */
        axisLabelOptions?: pulumi.Input<pulumi.Input<inputs.quicksight.AnalysisAxisLabelOptionsArgs>[]>;
        /**
         * The visibility configuration of the sort icon on a chart's axis label.
         */
        sortIconVisibility?: pulumi.Input<enums.quicksight.AnalysisVisibility>;
        /**
         * The visibility of an axis label on a chart. Choose one of the following options:
         *
         * - `VISIBLE` : Shows the axis.
         * - `HIDDEN` : Hides the axis.
         */
        visibility?: pulumi.Input<enums.quicksight.AnalysisVisibility>;
    }
    interface AnalysisClusterMarkerArgs {
        /**
         * The simple cluster marker of the cluster marker.
         */
        simpleClusterMarker?: pulumi.Input<inputs.quicksight.AnalysisSimpleClusterMarkerArgs>;
    }
    interface AnalysisClusterMarkerConfigurationArgs {
        /**
         * The cluster marker that is a part of the cluster marker configuration.
         */
        clusterMarker?: pulumi.Input<inputs.quicksight.AnalysisClusterMarkerArgs>;
    }
    interface AnalysisColorScaleArgs {
        /**
         * Determines the color fill type.
         */
        colorFillType: pulumi.Input<enums.quicksight.AnalysisColorFillType>;
        /**
         * Determines the list of colors that are applied to the visual.
         */
        colors: pulumi.Input<pulumi.Input<inputs.quicksight.AnalysisDataColorArgs>[]>;
        /**
         * Determines the color that is applied to null values.
         */
        nullValueColor?: pulumi.Input<inputs.quicksight.AnalysisDataColorArgs>;
    }
    interface AnalysisColorsConfigurationArgs {
        /**
         * A list of up to 50 custom colors.
         */
        customColors?: pulumi.Input<pulumi.Input<inputs.quicksight.AnalysisCustomColorArgs>[]>;
    }
    interface AnalysisColumnConfigurationArgs {
        /**
         * The color configurations of the column.
         */
        colorsConfiguration?: pulumi.Input<inputs.quicksight.AnalysisColorsConfigurationArgs>;
        /**
         * The column.
         */
        column: pulumi.Input<inputs.quicksight.AnalysisColumnIdentifierArgs>;
        /**
         * The format configuration of a column.
         */
        formatConfiguration?: pulumi.Input<inputs.quicksight.AnalysisFormatConfigurationArgs>;
        /**
         * The role of the column.
         */
        role?: pulumi.Input<enums.quicksight.AnalysisColumnRole>;
    }
    interface AnalysisColumnHierarchyArgs {
        /**
         * The option that determines the hierarchy of any `DateTime` fields.
         */
        dateTimeHierarchy?: pulumi.Input<inputs.quicksight.AnalysisDateTimeHierarchyArgs>;
        /**
         * The option that determines the hierarchy of the fields that are built within a visual's field wells. These fields can't be duplicated to other visuals.
         */
        explicitHierarchy?: pulumi.Input<inputs.quicksight.AnalysisExplicitHierarchyArgs>;
        /**
         * The option that determines the hierarchy of the fields that are defined during data preparation. These fields are available to use in any analysis that uses the data source.
         */
        predefinedHierarchy?: pulumi.Input<inputs.quicksight.AnalysisPredefinedHierarchyArgs>;
    }
    interface AnalysisColumnIdentifierArgs {
        /**
         * The name of the column.
         */
        columnName: pulumi.Input<string>;
        /**
         * The data set that the column belongs to.
         */
        dataSetIdentifier: pulumi.Input<string>;
    }
    interface AnalysisColumnSortArgs {
        /**
         * The aggregation function that is defined in the column sort.
         */
        aggregationFunction?: pulumi.Input<inputs.quicksight.AnalysisAggregationFunctionArgs>;
        /**
         * The sort direction.
         */
        direction: pulumi.Input<enums.quicksight.AnalysisSortDirection>;
        sortBy: pulumi.Input<inputs.quicksight.AnalysisColumnIdentifierArgs>;
    }
    interface AnalysisColumnTooltipItemArgs {
        /**
         * The aggregation function of the column tooltip item.
         */
        aggregation?: pulumi.Input<inputs.quicksight.AnalysisAggregationFunctionArgs>;
        /**
         * The target column of the tooltip item.
         */
        column: pulumi.Input<inputs.quicksight.AnalysisColumnIdentifierArgs>;
        /**
         * The label of the tooltip item.
         */
        label?: pulumi.Input<string>;
        /**
         * Determines the target of the column tooltip item in a combo chart visual.
         */
        tooltipTarget?: pulumi.Input<enums.quicksight.AnalysisTooltipTarget>;
        /**
         * The visibility of the tooltip item.
         */
        visibility?: pulumi.Input<enums.quicksight.AnalysisVisibility>;
    }
    interface AnalysisComboChartAggregatedFieldWellsArgs {
        /**
         * The aggregated `BarValues` field well of a combo chart.
         */
        barValues?: pulumi.Input<pulumi.Input<inputs.quicksight.AnalysisMeasureFieldArgs>[]>;
        /**
         * The aggregated category field wells of a combo chart.
         */
        category?: pulumi.Input<pulumi.Input<inputs.quicksight.AnalysisDimensionFieldArgs>[]>;
        /**
         * The aggregated colors field well of a combo chart.
         */
        colors?: pulumi.Input<pulumi.Input<inputs.quicksight.AnalysisDimensionFieldArgs>[]>;
        /**
         * The aggregated `LineValues` field well of a combo chart.
         */
        lineValues?: pulumi.Input<pulumi.Input<inputs.quicksight.AnalysisMeasureFieldArgs>[]>;
    }
    interface AnalysisComboChartConfigurationArgs {
        /**
         * The options that determine if visual data labels are displayed.
         *
         * The data label options for a bar in a combo chart.
         */
        barDataLabels?: pulumi.Input<inputs.quicksight.AnalysisDataLabelOptionsArgs>;
        /**
         * Determines the bar arrangement in a combo chart. The following are valid values in this structure:
         *
         * - `CLUSTERED` : For clustered bar combo charts.
         * - `STACKED` : For stacked bar combo charts.
         * - `STACKED_PERCENT` : Do not use. If you use this value, the operation returns a validation error.
         */
        barsArrangement?: pulumi.Input<enums.quicksight.AnalysisBarsArrangement>;
        /**
         * The category axis of a combo chart.
         */
        categoryAxis?: pulumi.Input<inputs.quicksight.AnalysisAxisDisplayOptionsArgs>;
        /**
         * The label options (label text, label visibility, and sort icon visibility) of a combo chart category (group/color) field well.
         */
        categoryLabelOptions?: pulumi.Input<inputs.quicksight.AnalysisChartAxisLabelOptionsArgs>;
        /**
         * The label options (label text, label visibility, and sort icon visibility) of a combo chart's color field well.
         */
        colorLabelOptions?: pulumi.Input<inputs.quicksight.AnalysisChartAxisLabelOptionsArgs>;
        /**
         * The field wells of the visual.
         */
        fieldWells?: pulumi.Input<inputs.quicksight.AnalysisComboChartFieldWellsArgs>;
        /**
         * The general visual interactions setup for a visual.
         */
        interactions?: pulumi.Input<inputs.quicksight.AnalysisVisualInteractionOptionsArgs>;
        /**
         * The legend display setup of the visual.
         */
        legend?: pulumi.Input<inputs.quicksight.AnalysisLegendOptionsArgs>;
        /**
         * The options that determine if visual data labels are displayed.
         *
         * The data label options for a line in a combo chart.
         */
        lineDataLabels?: pulumi.Input<inputs.quicksight.AnalysisDataLabelOptionsArgs>;
        /**
         * The label display options (grid line, range, scale, and axis step) of a combo chart's primary y-axis (bar) field well.
         */
        primaryYAxisDisplayOptions?: pulumi.Input<inputs.quicksight.AnalysisAxisDisplayOptionsArgs>;
        /**
         * The label options (label text, label visibility, and sort icon visibility) of a combo chart's primary y-axis (bar) field well.
         */
        primaryYAxisLabelOptions?: pulumi.Input<inputs.quicksight.AnalysisChartAxisLabelOptionsArgs>;
        /**
         * The reference line setup of the visual.
         */
        referenceLines?: pulumi.Input<pulumi.Input<inputs.quicksight.AnalysisReferenceLineArgs>[]>;
        /**
         * The label display options (grid line, range, scale, axis step) of a combo chart's secondary y-axis (line) field well.
         */
        secondaryYAxisDisplayOptions?: pulumi.Input<inputs.quicksight.AnalysisAxisDisplayOptionsArgs>;
        /**
         * The label options (label text, label visibility, and sort icon visibility) of a combo chart's secondary y-axis(line) field well.
         */
        secondaryYAxisLabelOptions?: pulumi.Input<inputs.quicksight.AnalysisChartAxisLabelOptionsArgs>;
        singleAxisOptions?: pulumi.Input<inputs.quicksight.AnalysisSingleAxisOptionsArgs>;
        /**
         * The sort configuration of a `ComboChartVisual` .
         */
        sortConfiguration?: pulumi.Input<inputs.quicksight.AnalysisComboChartSortConfigurationArgs>;
        /**
         * The legend display setup of the visual.
         */
        tooltip?: pulumi.Input<inputs.quicksight.AnalysisTooltipOptionsArgs>;
        /**
         * The palette (chart color) display setup of the visual.
         */
        visualPalette?: pulumi.Input<inputs.quicksight.AnalysisVisualPaletteArgs>;
    }
    interface AnalysisComboChartFieldWellsArgs {
        /**
         * The aggregated field wells of a combo chart. Combo charts only have aggregated field wells. Columns in a combo chart are aggregated by category.
         */
        comboChartAggregatedFieldWells?: pulumi.Input<inputs.quicksight.AnalysisComboChartAggregatedFieldWellsArgs>;
    }
    interface AnalysisComboChartSortConfigurationArgs {
        /**
         * The item limit configuration for the category field well of a combo chart.
         */
        categoryItemsLimit?: pulumi.Input<inputs.quicksight.AnalysisItemsLimitConfigurationArgs>;
        /**
         * The sort configuration of the category field well in a combo chart.
         */
        categorySort?: pulumi.Input<pulumi.Input<inputs.quicksight.AnalysisFieldSortOptionsArgs>[]>;
        /**
         * The item limit configuration of the color field well in a combo chart.
         */
        colorItemsLimit?: pulumi.Input<inputs.quicksight.AnalysisItemsLimitConfigurationArgs>;
        /**
         * The sort configuration of the color field well in a combo chart.
         */
        colorSort?: pulumi.Input<pulumi.Input<inputs.quicksight.AnalysisFieldSortOptionsArgs>[]>;
    }
    interface AnalysisComboChartVisualArgs {
        /**
         * The list of custom actions that are configured for a visual.
         */
        actions?: pulumi.Input<pulumi.Input<inputs.quicksight.AnalysisVisualCustomActionArgs>[]>;
        /**
         * The configuration settings of the visual.
         */
        chartConfiguration?: pulumi.Input<inputs.quicksight.AnalysisComboChartConfigurationArgs>;
        /**
         * The column hierarchy that is used during drill-downs and drill-ups.
         */
        columnHierarchies?: pulumi.Input<pulumi.Input<inputs.quicksight.AnalysisColumnHierarchyArgs>[]>;
        /**
         * The subtitle that is displayed on the visual.
         */
        subtitle?: pulumi.Input<inputs.quicksight.AnalysisVisualSubtitleLabelOptionsArgs>;
        /**
         * The title that is displayed on the visual.
         */
        title?: pulumi.Input<inputs.quicksight.AnalysisVisualTitleLabelOptionsArgs>;
        /**
         * The alt text for the visual.
         */
        visualContentAltText?: pulumi.Input<string>;
        /**
         * The unique identifier of a visual. This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers.
         */
        visualId: pulumi.Input<string>;
    }
    interface AnalysisComparisonConfigurationArgs {
        /**
         * The format of the comparison.
         */
        comparisonFormat?: pulumi.Input<inputs.quicksight.AnalysisComparisonFormatConfigurationArgs>;
        /**
         * The method of the comparison. Choose from the following options:
         *
         * - `DIFFERENCE`
         * - `PERCENT_DIFFERENCE`
         * - `PERCENT`
         */
        comparisonMethod?: pulumi.Input<enums.quicksight.AnalysisComparisonMethod>;
    }
    interface AnalysisComparisonFormatConfigurationArgs {
        /**
         * The number display format.
         */
        numberDisplayFormatConfiguration?: pulumi.Input<inputs.quicksight.AnalysisNumberDisplayFormatConfigurationArgs>;
        /**
         * The percentage display format.
         */
        percentageDisplayFormatConfiguration?: pulumi.Input<inputs.quicksight.AnalysisPercentageDisplayFormatConfigurationArgs>;
    }
    interface AnalysisComputationArgs {
        /**
         * The forecast computation configuration.
         */
        forecast?: pulumi.Input<inputs.quicksight.AnalysisForecastComputationArgs>;
        /**
         * The growth rate computation configuration.
         */
        growthRate?: pulumi.Input<inputs.quicksight.AnalysisGrowthRateComputationArgs>;
        /**
         * The maximum and minimum computation configuration.
         */
        maximumMinimum?: pulumi.Input<inputs.quicksight.AnalysisMaximumMinimumComputationArgs>;
        /**
         * The metric comparison computation configuration.
         */
        metricComparison?: pulumi.Input<inputs.quicksight.AnalysisMetricComparisonComputationArgs>;
        /**
         * The period over period computation configuration.
         */
        periodOverPeriod?: pulumi.Input<inputs.quicksight.AnalysisPeriodOverPeriodComputationArgs>;
        /**
         * The period to `DataSetIdentifier` computation configuration.
         */
        periodToDate?: pulumi.Input<inputs.quicksight.AnalysisPeriodToDateComputationArgs>;
        /**
         * The top movers and bottom movers computation configuration.
         */
        topBottomMovers?: pulumi.Input<inputs.quicksight.AnalysisTopBottomMoversComputationArgs>;
        /**
         * The top ranked and bottom ranked computation configuration.
         */
        topBottomRanked?: pulumi.Input<inputs.quicksight.AnalysisTopBottomRankedComputationArgs>;
        /**
         * The total aggregation computation configuration.
         */
        totalAggregation?: pulumi.Input<inputs.quicksight.AnalysisTotalAggregationComputationArgs>;
        /**
         * The unique values computation configuration.
         */
        uniqueValues?: pulumi.Input<inputs.quicksight.AnalysisUniqueValuesComputationArgs>;
    }
    interface AnalysisConditionalFormattingColorArgs {
        /**
         * Formatting configuration for gradient color.
         */
        gradient?: pulumi.Input<inputs.quicksight.AnalysisConditionalFormattingGradientColorArgs>;
        /**
         * Formatting configuration for solid color.
         */
        solid?: pulumi.Input<inputs.quicksight.AnalysisConditionalFormattingSolidColorArgs>;
    }
    interface AnalysisConditionalFormattingCustomIconConditionArgs {
        /**
         * Determines the color of the icon.
         */
        color?: pulumi.Input<string>;
        /**
         * Determines the icon display configuration.
         */
        displayConfiguration?: pulumi.Input<inputs.quicksight.AnalysisConditionalFormattingIconDisplayConfigurationArgs>;
        /**
         * The expression that determines the condition of the icon set.
         */
        expression: pulumi.Input<string>;
        /**
         * Custom icon options for an icon set.
         */
        iconOptions: pulumi.Input<inputs.quicksight.AnalysisConditionalFormattingCustomIconOptionsArgs>;
    }
    interface AnalysisConditionalFormattingCustomIconOptionsArgs {
        /**
         * Determines the type of icon.
         */
        icon?: pulumi.Input<enums.quicksight.AnalysisIcon>;
        /**
         * Determines the Unicode icon type.
         */
        unicodeIcon?: pulumi.Input<string>;
    }
    interface AnalysisConditionalFormattingGradientColorArgs {
        /**
         * Determines the color.
         */
        color: pulumi.Input<inputs.quicksight.AnalysisGradientColorArgs>;
        /**
         * The expression that determines the formatting configuration for gradient color.
         */
        expression: pulumi.Input<string>;
    }
    interface AnalysisConditionalFormattingIconArgs {
        /**
         * Determines the custom condition for an icon set.
         */
        customCondition?: pulumi.Input<inputs.quicksight.AnalysisConditionalFormattingCustomIconConditionArgs>;
        /**
         * Formatting configuration for icon set.
         */
        iconSet?: pulumi.Input<inputs.quicksight.AnalysisConditionalFormattingIconSetArgs>;
    }
    interface AnalysisConditionalFormattingIconDisplayConfigurationArgs {
        /**
         * Determines the icon display configuration.
         */
        iconDisplayOption?: pulumi.Input<enums.quicksight.AnalysisConditionalFormattingIconDisplayOption>;
    }
    interface AnalysisConditionalFormattingIconSetArgs {
        /**
         * The expression that determines the formatting configuration for the icon set.
         */
        expression: pulumi.Input<string>;
        /**
         * Determines the icon set type.
         */
        iconSetType?: pulumi.Input<enums.quicksight.AnalysisConditionalFormattingIconSetType>;
    }
    interface AnalysisConditionalFormattingSolidColorArgs {
        /**
         * Determines the color.
         */
        color?: pulumi.Input<string>;
        /**
         * The expression that determines the formatting configuration for solid color.
         */
        expression: pulumi.Input<string>;
    }
    interface AnalysisContextMenuOptionArgs {
        /**
         * The availability status of the context menu options. If the value of this property is set to `ENABLED` , dashboard readers can interact with the context menu.
         */
        availabilityStatus?: pulumi.Input<enums.quicksight.AnalysisDashboardBehavior>;
    }
    interface AnalysisContributionAnalysisDefaultArgs {
        /**
         * The dimensions columns that are used in the contribution analysis, usually a list of `ColumnIdentifiers` .
         */
        contributorDimensions: pulumi.Input<pulumi.Input<inputs.quicksight.AnalysisColumnIdentifierArgs>[]>;
        /**
         * The measure field that is used in the contribution analysis.
         */
        measureFieldId: pulumi.Input<string>;
    }
    interface AnalysisCurrencyDisplayFormatConfigurationArgs {
        /**
         * The option that determines the decimal places configuration.
         */
        decimalPlacesConfiguration?: pulumi.Input<inputs.quicksight.AnalysisDecimalPlacesConfigurationArgs>;
        /**
         * The options that determine the negative value configuration.
         */
        negativeValueConfiguration?: pulumi.Input<inputs.quicksight.AnalysisNegativeValueConfigurationArgs>;
        /**
         * The options that determine the null value format configuration.
         */
        nullValueFormatConfiguration?: pulumi.Input<inputs.quicksight.AnalysisNullValueFormatConfigurationArgs>;
        /**
         * Determines the number scale value for the currency format.
         */
        numberScale?: pulumi.Input<enums.quicksight.AnalysisNumberScale>;
        /**
         * Determines the prefix value of the currency format.
         */
        prefix?: pulumi.Input<string>;
        /**
         * The options that determine the numeric separator configuration.
         */
        separatorConfiguration?: pulumi.Input<inputs.quicksight.AnalysisNumericSeparatorConfigurationArgs>;
        /**
         * Determines the suffix value of the currency format.
         */
        suffix?: pulumi.Input<string>;
        /**
         * Determines the symbol for the currency format.
         */
        symbol?: pulumi.Input<string>;
    }
    interface AnalysisCustomActionFilterOperationArgs {
        /**
         * The configuration that chooses the fields to be filtered.
         */
        selectedFieldsConfiguration: pulumi.Input<inputs.quicksight.AnalysisFilterOperationSelectedFieldsConfigurationArgs>;
        /**
         * The configuration that chooses the target visuals to be filtered.
         */
        targetVisualsConfiguration: pulumi.Input<inputs.quicksight.AnalysisFilterOperationTargetVisualsConfigurationArgs>;
    }
    interface AnalysisCustomActionNavigationOperationArgs {
        /**
         * The configuration that chooses the navigation target.
         */
        localNavigationConfiguration?: pulumi.Input<inputs.quicksight.AnalysisLocalNavigationConfigurationArgs>;
    }
    interface AnalysisCustomActionSetParametersOperationArgs {
        /**
         * The parameter that determines the value configuration.
         */
        parameterValueConfigurations: pulumi.Input<pulumi.Input<inputs.quicksight.AnalysisSetParameterValueConfigurationArgs>[]>;
    }
    interface AnalysisCustomActionUrlOperationArgs {
        /**
         * The target of the `CustomActionURLOperation` .
         *
         * Valid values are defined as follows:
         *
         * - `NEW_TAB` : Opens the target URL in a new browser tab.
         * - `NEW_WINDOW` : Opens the target URL in a new browser window.
         * - `SAME_TAB` : Opens the target URL in the same browser tab.
         */
        urlTarget: pulumi.Input<enums.quicksight.AnalysisUrlTargetConfiguration>;
        /**
         * THe URL link of the `CustomActionURLOperation` .
         */
        urlTemplate: pulumi.Input<string>;
    }
    interface AnalysisCustomColorArgs {
        /**
         * The color that is applied to the data value.
         */
        color: pulumi.Input<string>;
        /**
         * The data value that the color is applied to.
         */
        fieldValue?: pulumi.Input<string>;
        /**
         * The value of a special data value.
         */
        specialValue?: pulumi.Input<enums.quicksight.AnalysisSpecialValue>;
    }
    interface AnalysisCustomContentConfigurationArgs {
        /**
         * The content type of the custom content visual. You can use this to have the visual render as an image.
         */
        contentType?: pulumi.Input<enums.quicksight.AnalysisCustomContentType>;
        /**
         * The input URL that links to the custom content that you want in the custom visual.
         */
        contentUrl?: pulumi.Input<string>;
        /**
         * The sizing options for the size of the custom content visual. This structure is required when the `ContentType` of the visual is `'IMAGE'` .
         */
        imageScaling?: pulumi.Input<enums.quicksight.AnalysisCustomContentImageScalingConfiguration>;
        /**
         * The general visual interactions setup for a visual.
         */
        interactions?: pulumi.Input<inputs.quicksight.AnalysisVisualInteractionOptionsArgs>;
    }
    interface AnalysisCustomContentVisualArgs {
        /**
         * The list of custom actions that are configured for a visual.
         */
        actions?: pulumi.Input<pulumi.Input<inputs.quicksight.AnalysisVisualCustomActionArgs>[]>;
        /**
         * The configuration of a `CustomContentVisual` .
         */
        chartConfiguration?: pulumi.Input<inputs.quicksight.AnalysisCustomContentConfigurationArgs>;
        /**
         * The dataset that is used to create the custom content visual. You can't create a visual without a dataset.
         */
        dataSetIdentifier: pulumi.Input<string>;
        /**
         * The subtitle that is displayed on the visual.
         */
        subtitle?: pulumi.Input<inputs.quicksight.AnalysisVisualSubtitleLabelOptionsArgs>;
        /**
         * The title that is displayed on the visual.
         */
        title?: pulumi.Input<inputs.quicksight.AnalysisVisualTitleLabelOptionsArgs>;
        /**
         * The alt text for the visual.
         */
        visualContentAltText?: pulumi.Input<string>;
        /**
         * The unique identifier of a visual. This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers.
         */
        visualId: pulumi.Input<string>;
    }
    interface AnalysisCustomFilterConfigurationArgs {
        /**
         * The category value for the filter.
         *
         * This field is mutually exclusive to `ParameterName` .
         */
        categoryValue?: pulumi.Input<string>;
        /**
         * The match operator that is used to determine if a filter should be applied.
         */
        matchOperator: pulumi.Input<enums.quicksight.AnalysisCategoryFilterMatchOperator>;
        /**
         * This option determines how null values should be treated when filtering data.
         *
         * - `ALL_VALUES` : Include null values in filtered results.
         * - `NULLS_ONLY` : Only include null values in filtered results.
         * - `NON_NULLS_ONLY` : Exclude null values from filtered results.
         */
        nullOption: pulumi.Input<enums.quicksight.AnalysisFilterNullOption>;
        /**
         * The parameter whose value should be used for the filter value.
         *
         * This field is mutually exclusive to `CategoryValue` .
         */
        parameterName?: pulumi.Input<string>;
        /**
         * Select all of the values. Null is not the assigned value of select all.
         *
         * - `FILTER_ALL_VALUES`
         */
        selectAllOptions?: pulumi.Input<enums.quicksight.AnalysisCategoryFilterSelectAllOptions>;
    }
    interface AnalysisCustomFilterListConfigurationArgs {
        /**
         * The list of category values for the filter.
         */
        categoryValues?: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * The match operator that is used to determine if a filter should be applied.
         */
        matchOperator: pulumi.Input<enums.quicksight.AnalysisCategoryFilterMatchOperator>;
        /**
         * This option determines how null values should be treated when filtering data.
         *
         * - `ALL_VALUES` : Include null values in filtered results.
         * - `NULLS_ONLY` : Only include null values in filtered results.
         * - `NON_NULLS_ONLY` : Exclude null values from filtered results.
         */
        nullOption: pulumi.Input<enums.quicksight.AnalysisFilterNullOption>;
        /**
         * Select all of the values. Null is not the assigned value of select all.
         *
         * - `FILTER_ALL_VALUES`
         */
        selectAllOptions?: pulumi.Input<enums.quicksight.AnalysisCategoryFilterSelectAllOptions>;
    }
    interface AnalysisCustomNarrativeOptionsArgs {
        /**
         * The string input of custom narrative.
         */
        narrative: pulumi.Input<string>;
    }
    interface AnalysisCustomParameterValuesArgs {
        /**
         * A list of datetime-type parameter values.
         */
        dateTimeValues?: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * A list of decimal-type parameter values.
         */
        decimalValues?: pulumi.Input<pulumi.Input<number>[]>;
        /**
         * A list of integer-type parameter values.
         */
        integerValues?: pulumi.Input<pulumi.Input<number>[]>;
        /**
         * A list of string-type parameter values.
         */
        stringValues?: pulumi.Input<pulumi.Input<string>[]>;
    }
    interface AnalysisCustomValuesConfigurationArgs {
        customValues: pulumi.Input<inputs.quicksight.AnalysisCustomParameterValuesArgs>;
        /**
         * Includes the null value in custom action parameter values.
         */
        includeNullValue?: pulumi.Input<boolean>;
    }
    interface AnalysisDataBarsOptionsArgs {
        /**
         * The field ID for the data bars options.
         */
        fieldId: pulumi.Input<string>;
        /**
         * The color of the negative data bar.
         */
        negativeColor?: pulumi.Input<string>;
        /**
         * The color of the positive data bar.
         */
        positiveColor?: pulumi.Input<string>;
    }
    interface AnalysisDataColorArgs {
        /**
         * The color that is applied to the data value.
         */
        color?: pulumi.Input<string>;
        /**
         * The data value that the color is applied to.
         */
        dataValue?: pulumi.Input<number>;
    }
    interface AnalysisDataFieldSeriesItemArgs {
        /**
         * The axis that you are binding the field to.
         */
        axisBinding: pulumi.Input<enums.quicksight.AnalysisAxisBinding>;
        /**
         * The field ID of the field that you are setting the axis binding to.
         */
        fieldId: pulumi.Input<string>;
        /**
         * The field value of the field that you are setting the axis binding to.
         */
        fieldValue?: pulumi.Input<string>;
        /**
         * The options that determine the presentation of line series associated to the field.
         */
        settings?: pulumi.Input<inputs.quicksight.AnalysisLineChartSeriesSettingsArgs>;
    }
    interface AnalysisDataLabelOptionsArgs {
        /**
         * Determines the visibility of the category field labels.
         */
        categoryLabelVisibility?: pulumi.Input<enums.quicksight.AnalysisVisibility>;
        /**
         * The option that determines the data label type.
         */
        dataLabelTypes?: pulumi.Input<pulumi.Input<inputs.quicksight.AnalysisDataLabelTypeArgs>[]>;
        /**
         * Determines the color of the data labels.
         */
        labelColor?: pulumi.Input<string>;
        /**
         * Determines the content of the data labels.
         */
        labelContent?: pulumi.Input<enums.quicksight.AnalysisDataLabelContent>;
        /**
         * Determines the font configuration of the data labels.
         */
        labelFontConfiguration?: pulumi.Input<inputs.quicksight.AnalysisFontConfigurationArgs>;
        /**
         * Determines the visibility of the measure field labels.
         */
        measureLabelVisibility?: pulumi.Input<enums.quicksight.AnalysisVisibility>;
        /**
         * Determines whether overlap is enabled or disabled for the data labels.
         */
        overlap?: pulumi.Input<enums.quicksight.AnalysisDataLabelOverlap>;
        /**
         * Determines the position of the data labels.
         */
        position?: pulumi.Input<enums.quicksight.AnalysisDataLabelPosition>;
        /**
         * Determines the visibility of the total.
         */
        totalsVisibility?: pulumi.Input<enums.quicksight.AnalysisVisibility>;
        /**
         * Determines the visibility of the data labels.
         */
        visibility?: pulumi.Input<enums.quicksight.AnalysisVisibility>;
    }
    interface AnalysisDataLabelTypeArgs {
        /**
         * The option that specifies individual data values for labels.
         */
        dataPathLabelType?: pulumi.Input<inputs.quicksight.AnalysisDataPathLabelTypeArgs>;
        /**
         * Determines the label configuration for the entire field.
         */
        fieldLabelType?: pulumi.Input<inputs.quicksight.AnalysisFieldLabelTypeArgs>;
        /**
         * Determines the label configuration for the maximum value in a visual.
         */
        maximumLabelType?: pulumi.Input<inputs.quicksight.AnalysisMaximumLabelTypeArgs>;
        /**
         * Determines the label configuration for the minimum value in a visual.
         */
        minimumLabelType?: pulumi.Input<inputs.quicksight.AnalysisMinimumLabelTypeArgs>;
        /**
         * Determines the label configuration for range end value in a visual.
         */
        rangeEndsLabelType?: pulumi.Input<inputs.quicksight.AnalysisRangeEndsLabelTypeArgs>;
    }
    interface AnalysisDataPathColorArgs {
        /**
         * The color that needs to be applied to the element.
         */
        color: pulumi.Input<string>;
        /**
         * The element that the color needs to be applied to.
         */
        element: pulumi.Input<inputs.quicksight.AnalysisDataPathValueArgs>;
        /**
         * The time granularity of the field that the color needs to be applied to.
         */
        timeGranularity?: pulumi.Input<enums.quicksight.AnalysisTimeGranularity>;
    }
    interface AnalysisDataPathLabelTypeArgs {
        /**
         * The field ID of the field that the data label needs to be applied to.
         */
        fieldId?: pulumi.Input<string>;
        /**
         * The actual value of the field that is labeled.
         */
        fieldValue?: pulumi.Input<string>;
        /**
         * The visibility of the data label.
         */
        visibility?: pulumi.Input<enums.quicksight.AnalysisVisibility>;
    }
    interface AnalysisDataPathSortArgs {
        /**
         * Determines the sort direction.
         */
        direction: pulumi.Input<enums.quicksight.AnalysisSortDirection>;
        /**
         * The list of data paths that need to be sorted.
         */
        sortPaths: pulumi.Input<pulumi.Input<inputs.quicksight.AnalysisDataPathValueArgs>[]>;
    }
    interface AnalysisDataPathTypeArgs {
        /**
         * The type of data path value utilized in a pivot table. Choose one of the following options:
         *
         * - `HIERARCHY_ROWS_LAYOUT_COLUMN` - The type of data path for the rows layout column, when `RowsLayout` is set to `HIERARCHY` .
         * - `MULTIPLE_ROW_METRICS_COLUMN` - The type of data path for the metric column when the row is set to Metric Placement.
         * - `EMPTY_COLUMN_HEADER` - The type of data path for the column with empty column header, when there is no field in `ColumnsFieldWell` and the row is set to Metric Placement.
         * - `COUNT_METRIC_COLUMN` - The type of data path for the column with `COUNT` as the metric, when there is no field in the `ValuesFieldWell` .
         */
        pivotTableDataPathType?: pulumi.Input<enums.quicksight.AnalysisPivotTableDataPathType>;
    }
    interface AnalysisDataPathValueArgs {
        /**
         * The type configuration of the field.
         */
        dataPathType?: pulumi.Input<inputs.quicksight.AnalysisDataPathTypeArgs>;
        /**
         * The field ID of the field that needs to be sorted.
         */
        fieldId?: pulumi.Input<string>;
        /**
         * The actual value of the field that needs to be sorted.
         */
        fieldValue?: pulumi.Input<string>;
    }
    interface AnalysisDataSetIdentifierDeclarationArgs {
        /**
         * The Amazon Resource Name (ARN) of the data set.
         */
        dataSetArn: pulumi.Input<string>;
        /**
         * The identifier of the data set, typically the data set's name.
         */
        identifier: pulumi.Input<string>;
    }
    /**
     * <p>Dataset reference.</p>
     */
    interface AnalysisDataSetReferenceArgs {
        /**
         * <p>Dataset Amazon Resource Name (ARN).</p>
         */
        dataSetArn: pulumi.Input<string>;
        /**
         * <p>Dataset placeholder.</p>
         */
        dataSetPlaceholder: pulumi.Input<string>;
    }
    interface AnalysisDateAxisOptionsArgs {
        /**
         * Determines whether or not missing dates are displayed.
         */
        missingDateVisibility?: pulumi.Input<enums.quicksight.AnalysisVisibility>;
    }
    interface AnalysisDateDimensionFieldArgs {
        /**
         * The column that is used in the `DateDimensionField` .
         */
        column: pulumi.Input<inputs.quicksight.AnalysisColumnIdentifierArgs>;
        /**
         * The date granularity of the `DateDimensionField` . Choose one of the following options:
         *
         * - `YEAR`
         * - `QUARTER`
         * - `MONTH`
         * - `WEEK`
         * - `DAY`
         * - `HOUR`
         * - `MINUTE`
         * - `SECOND`
         * - `MILLISECOND`
         */
        dateGranularity?: pulumi.Input<enums.quicksight.AnalysisTimeGranularity>;
        /**
         * The custom field ID.
         */
        fieldId: pulumi.Input<string>;
        /**
         * The format configuration of the field.
         */
        formatConfiguration?: pulumi.Input<inputs.quicksight.AnalysisDateTimeFormatConfigurationArgs>;
        /**
         * The custom hierarchy ID.
         */
        hierarchyId?: pulumi.Input<string>;
    }
    interface AnalysisDateMeasureFieldArgs {
        /**
         * The aggregation function of the measure field.
         */
        aggregationFunction?: pulumi.Input<enums.quicksight.AnalysisDateAggregationFunction>;
        /**
         * The column that is used in the `DateMeasureField` .
         */
        column: pulumi.Input<inputs.quicksight.AnalysisColumnIdentifierArgs>;
        /**
         * The custom field ID.
         */
        fieldId: pulumi.Input<string>;
        /**
         * The format configuration of the field.
         */
        formatConfiguration?: pulumi.Input<inputs.quicksight.AnalysisDateTimeFormatConfigurationArgs>;
    }
    interface AnalysisDateTimeDefaultValuesArgs {
        /**
         * The dynamic value of the `DataTimeDefaultValues` . Different defaults are displayed according to users, groups, and values mapping.
         */
        dynamicValue?: pulumi.Input<inputs.quicksight.AnalysisDynamicDefaultValueArgs>;
        /**
         * The rolling date of the `DataTimeDefaultValues` . The date is determined from the dataset based on input expression.
         */
        rollingDate?: pulumi.Input<inputs.quicksight.AnalysisRollingDateConfigurationArgs>;
        /**
         * The static values of the `DataTimeDefaultValues` .
         */
        staticValues?: pulumi.Input<pulumi.Input<string>[]>;
    }
    interface AnalysisDateTimeFormatConfigurationArgs {
        /**
         * Determines the `DateTime` format.
         */
        dateTimeFormat?: pulumi.Input<string>;
        /**
         * The options that determine the null value format configuration.
         */
        nullValueFormatConfiguration?: pulumi.Input<inputs.quicksight.AnalysisNullValueFormatConfigurationArgs>;
        /**
         * The formatting configuration for numeric `DateTime` fields.
         */
        numericFormatConfiguration?: pulumi.Input<inputs.quicksight.AnalysisNumericFormatConfigurationArgs>;
    }
    interface AnalysisDateTimeHierarchyArgs {
        /**
         * The option that determines the drill down filters for the `DateTime` hierarchy.
         */
        drillDownFilters?: pulumi.Input<pulumi.Input<inputs.quicksight.AnalysisDrillDownFilterArgs>[]>;
        /**
         * The hierarchy ID of the `DateTime` hierarchy.
         */
        hierarchyId: pulumi.Input<string>;
    }
    /**
     * <p>A date-time parameter.</p>
     */
    interface AnalysisDateTimeParameterArgs {
        /**
         * <p>A display name for the date-time parameter.</p>
         */
        name: pulumi.Input<string>;
        /**
         * <p>The values for the date-time parameter.</p>
         */
        values: pulumi.Input<pulumi.Input<string>[]>;
    }
    interface AnalysisDateTimeParameterDeclarationArgs {
        /**
         * The default values of a parameter. If the parameter is a single-value parameter, a maximum of one default value can be provided.
         */
        defaultValues?: pulumi.Input<inputs.quicksight.AnalysisDateTimeDefaultValuesArgs>;
        mappedDataSetParameters?: pulumi.Input<pulumi.Input<inputs.quicksight.AnalysisMappedDataSetParameterArgs>[]>;
        /**
         * The name of the parameter that is being declared.
         */
        name: pulumi.Input<string>;
        /**
         * The level of time precision that is used to aggregate `DateTime` values.
         */
        timeGranularity?: pulumi.Input<enums.quicksight.AnalysisTimeGranularity>;
        /**
         * The configuration that defines the default value of a `DateTime` parameter when a value has not been set.
         */
        valueWhenUnset?: pulumi.Input<inputs.quicksight.AnalysisDateTimeValueWhenUnsetConfigurationArgs>;
    }
    interface AnalysisDateTimePickerControlDisplayOptionsArgs {
        /**
         * The date icon visibility of the `DateTimePickerControlDisplayOptions` .
         */
        dateIconVisibility?: pulumi.Input<enums.quicksight.AnalysisVisibility>;
        /**
         * Customize how dates are formatted in controls.
         */
        dateTimeFormat?: pulumi.Input<string>;
        /**
         * The helper text visibility of the `DateTimePickerControlDisplayOptions` .
         */
        helperTextVisibility?: pulumi.Input<enums.quicksight.AnalysisVisibility>;
        /**
         * The configuration of info icon label options.
         */
        infoIconLabelOptions?: pulumi.Input<inputs.quicksight.AnalysisSheetControlInfoIconLabelOptionsArgs>;
        /**
         * The options to configure the title visibility, name, and font size.
         */
        titleOptions?: pulumi.Input<inputs.quicksight.AnalysisLabelOptionsArgs>;
    }
    interface AnalysisDateTimeValueWhenUnsetConfigurationArgs {
        /**
         * A custom value that's used when the value of a parameter isn't set.
         */
        customValue?: pulumi.Input<string>;
        /**
         * The built-in options for default values. The value can be one of the following:
         *
         * - `RECOMMENDED` : The recommended value.
         * - `NULL` : The `NULL` value.
         */
        valueWhenUnsetOption?: pulumi.Input<enums.quicksight.AnalysisValueWhenUnsetOption>;
    }
    interface AnalysisDecimalDefaultValuesArgs {
        /**
         * The dynamic value of the `DecimalDefaultValues` . Different defaults are displayed according to users, groups, and values mapping.
         */
        dynamicValue?: pulumi.Input<inputs.quicksight.AnalysisDynamicDefaultValueArgs>;
        /**
         * The static values of the `DecimalDefaultValues` .
         */
        staticValues?: pulumi.Input<pulumi.Input<number>[]>;
    }
    /**
     * <p>A decimal parameter.</p>
     */
    interface AnalysisDecimalParameterArgs {
        /**
         * <p>A display name for the decimal parameter.</p>
         */
        name: pulumi.Input<string>;
        /**
         * <p>The values for the decimal parameter.</p>
         */
        values: pulumi.Input<pulumi.Input<number>[]>;
    }
    interface AnalysisDecimalParameterDeclarationArgs {
        /**
         * The default values of a parameter. If the parameter is a single-value parameter, a maximum of one default value can be provided.
         */
        defaultValues?: pulumi.Input<inputs.quicksight.AnalysisDecimalDefaultValuesArgs>;
        mappedDataSetParameters?: pulumi.Input<pulumi.Input<inputs.quicksight.AnalysisMappedDataSetParameterArgs>[]>;
        /**
         * The name of the parameter that is being declared.
         */
        name: pulumi.Input<string>;
        /**
         * The value type determines whether the parameter is a single-value or multi-value parameter.
         */
        parameterValueType: pulumi.Input<enums.quicksight.AnalysisParameterValueType>;
        /**
         * The configuration that defines the default value of a `Decimal` parameter when a value has not been set.
         */
        valueWhenUnset?: pulumi.Input<inputs.quicksight.AnalysisDecimalValueWhenUnsetConfigurationArgs>;
    }
    interface AnalysisDecimalPlacesConfigurationArgs {
        /**
         * The values of the decimal places.
         */
        decimalPlaces: pulumi.Input<number>;
    }
    interface AnalysisDecimalValueWhenUnsetConfigurationArgs {
        /**
         * A custom value that's used when the value of a parameter isn't set.
         */
        customValue?: pulumi.Input<number>;
        /**
         * The built-in options for default values. The value can be one of the following:
         *
         * - `RECOMMENDED` : The recommended value.
         * - `NULL` : The `NULL` value.
         */
        valueWhenUnsetOption?: pulumi.Input<enums.quicksight.AnalysisValueWhenUnsetOption>;
    }
    interface AnalysisDefaultDateTimePickerControlOptionsArgs {
        /**
         * The visibility configuration of the Apply button on a `DateTimePickerControl` .
         */
        commitMode?: pulumi.Input<enums.quicksight.AnalysisCommitMode>;
        /**
         * The display options of a control.
         */
        displayOptions?: pulumi.Input<inputs.quicksight.AnalysisDateTimePickerControlDisplayOptionsArgs>;
        /**
         * The date time picker type of the `DefaultDateTimePickerControlOptions` . Choose one of the following options:
         *
         * - `SINGLE_VALUED` : The filter condition is a fixed date.
         * - `DATE_RANGE` : The filter condition is a date time range.
         */
        type?: pulumi.Input<enums.quicksight.AnalysisSheetControlDateTimePickerType>;
    }
    interface AnalysisDefaultFilterControlConfigurationArgs {
        /**
         * The control option for the `DefaultFilterControlConfiguration` .
         */
        controlOptions: pulumi.Input<inputs.quicksight.AnalysisDefaultFilterControlOptionsArgs>;
        /**
         * The title of the `DefaultFilterControlConfiguration` . This title is shared by all controls that are tied to this filter.
         */
        title: pulumi.Input<string>;
    }
    interface AnalysisDefaultFilterControlOptionsArgs {
        /**
         * The default options that correspond to the filter control type of a `DateTimePicker` .
         */
        defaultDateTimePickerOptions?: pulumi.Input<inputs.quicksight.AnalysisDefaultDateTimePickerControlOptionsArgs>;
        /**
         * The default options that correspond to the `Dropdown` filter control type.
         */
        defaultDropdownOptions?: pulumi.Input<inputs.quicksight.AnalysisDefaultFilterDropDownControlOptionsArgs>;
        /**
         * The default options that correspond to the `List` filter control type.
         */
        defaultListOptions?: pulumi.Input<inputs.quicksight.AnalysisDefaultFilterListControlOptionsArgs>;
        /**
         * The default options that correspond to the `RelativeDateTime` filter control type.
         */
        defaultRelativeDateTimeOptions?: pulumi.Input<inputs.quicksight.AnalysisDefaultRelativeDateTimeControlOptionsArgs>;
        /**
         * The default options that correspond to the `Slider` filter control type.
         */
        defaultSliderOptions?: pulumi.Input<inputs.quicksight.AnalysisDefaultSliderControlOptionsArgs>;
        /**
         * The default options that correspond to the `TextArea` filter control type.
         */
        defaultTextAreaOptions?: pulumi.Input<inputs.quicksight.AnalysisDefaultTextAreaControlOptionsArgs>;
        /**
         * The default options that correspond to the `TextField` filter control type.
         */
        defaultTextFieldOptions?: pulumi.Input<inputs.quicksight.AnalysisDefaultTextFieldControlOptionsArgs>;
    }
    interface AnalysisDefaultFilterDropDownControlOptionsArgs {
        /**
         * The visibility configuration of the Apply button on a `FilterDropDownControl` .
         */
        commitMode?: pulumi.Input<enums.quicksight.AnalysisCommitMode>;
        /**
         * The display options of a control.
         */
        displayOptions?: pulumi.Input<inputs.quicksight.AnalysisDropDownControlDisplayOptionsArgs>;
        /**
         * A list of selectable values that are used in a control.
         */
        selectableValues?: pulumi.Input<inputs.quicksight.AnalysisFilterSelectableValuesArgs>;
        /**
         * The type of the `FilterDropDownControl` . Choose one of the following options:
         *
         * - `MULTI_SELECT` : The user can select multiple entries from a dropdown menu.
         * - `SINGLE_SELECT` : The user can select a single entry from a dropdown menu.
         */
        type?: pulumi.Input<enums.quicksight.AnalysisSheetControlListType>;
    }
    interface AnalysisDefaultFilterListControlOptionsArgs {
        /**
         * The display options of a control.
         */
        displayOptions?: pulumi.Input<inputs.quicksight.AnalysisListControlDisplayOptionsArgs>;
        /**
         * A list of selectable values that are used in a control.
         */
        selectableValues?: pulumi.Input<inputs.quicksight.AnalysisFilterSelectableValuesArgs>;
        /**
         * The type of the `DefaultFilterListControlOptions` . Choose one of the following options:
         *
         * - `MULTI_SELECT` : The user can select multiple entries from the list.
         * - `SINGLE_SELECT` : The user can select a single entry from the list.
         */
        type?: pulumi.Input<enums.quicksight.AnalysisSheetControlListType>;
    }
    interface AnalysisDefaultFreeFormLayoutConfigurationArgs {
        /**
         * Determines the screen canvas size options for a free-form layout.
         */
        canvasSizeOptions: pulumi.Input<inputs.quicksight.AnalysisFreeFormLayoutCanvasSizeOptionsArgs>;
    }
    interface AnalysisDefaultGridLayoutConfigurationArgs {
        /**
         * Determines the screen canvas size options for a grid layout.
         */
        canvasSizeOptions: pulumi.Input<inputs.quicksight.AnalysisGridLayoutCanvasSizeOptionsArgs>;
    }
    interface AnalysisDefaultInteractiveLayoutConfigurationArgs {
        /**
         * The options that determine the default settings of a free-form layout configuration.
         */
        freeForm?: pulumi.Input<inputs.quicksight.AnalysisDefaultFreeFormLayoutConfigurationArgs>;
        /**
         * The options that determine the default settings for a grid layout configuration.
         */
        grid?: pulumi.Input<inputs.quicksight.AnalysisDefaultGridLayoutConfigurationArgs>;
    }
    interface AnalysisDefaultNewSheetConfigurationArgs {
        /**
         * The options that determine the default settings for interactive layout configuration.
         */
        interactiveLayoutConfiguration?: pulumi.Input<inputs.quicksight.AnalysisDefaultInteractiveLayoutConfigurationArgs>;
        /**
         * The options that determine the default settings for a paginated layout configuration.
         */
        paginatedLayoutConfiguration?: pulumi.Input<inputs.quicksight.AnalysisDefaultPaginatedLayoutConfigurationArgs>;
        /**
         * The option that determines the sheet content type.
         */
        sheetContentType?: pulumi.Input<enums.quicksight.AnalysisSheetContentType>;
    }
    interface AnalysisDefaultPaginatedLayoutConfigurationArgs {
        /**
         * The options that determine the default settings for a section-based layout configuration.
         */
        sectionBased?: pulumi.Input<inputs.quicksight.AnalysisDefaultSectionBasedLayoutConfigurationArgs>;
    }
    interface AnalysisDefaultRelativeDateTimeControlOptionsArgs {
        /**
         * The visibility configuration of the Apply button on a `RelativeDateTimeControl` .
         */
        commitMode?: pulumi.Input<enums.quicksight.AnalysisCommitMode>;
        /**
         * The display options of a control.
         */
        displayOptions?: pulumi.Input<inputs.quicksight.AnalysisRelativeDateTimeControlDisplayOptionsArgs>;
    }
    interface AnalysisDefaultSectionBasedLayoutConfigurationArgs {
        /**
         * Determines the screen canvas size options for a section-based layout.
         */
        canvasSizeOptions: pulumi.Input<inputs.quicksight.AnalysisSectionBasedLayoutCanvasSizeOptionsArgs>;
    }
    interface AnalysisDefaultSliderControlOptionsArgs {
        /**
         * The display options of a control.
         */
        displayOptions?: pulumi.Input<inputs.quicksight.AnalysisSliderControlDisplayOptionsArgs>;
        /**
         * The larger value that is displayed at the right of the slider.
         */
        maximumValue: pulumi.Input<number>;
        /**
         * The smaller value that is displayed at the left of the slider.
         */
        minimumValue: pulumi.Input<number>;
        /**
         * The number of increments that the slider bar is divided into.
         */
        stepSize: pulumi.Input<number>;
        /**
         * The type of the `DefaultSliderControlOptions` . Choose one of the following options:
         *
         * - `SINGLE_POINT` : Filter against(equals) a single data point.
         * - `RANGE` : Filter data that is in a specified range.
         */
        type?: pulumi.Input<enums.quicksight.AnalysisSheetControlSliderType>;
    }
    interface AnalysisDefaultTextAreaControlOptionsArgs {
        /**
         * The delimiter that is used to separate the lines in text.
         */
        delimiter?: pulumi.Input<string>;
        /**
         * The display options of a control.
         */
        displayOptions?: pulumi.Input<inputs.quicksight.AnalysisTextAreaControlDisplayOptionsArgs>;
    }
    interface AnalysisDefaultTextFieldControlOptionsArgs {
        /**
         * The display options of a control.
         */
        displayOptions?: pulumi.Input<inputs.quicksight.AnalysisTextFieldControlDisplayOptionsArgs>;
    }
    interface AnalysisDefaultsArgs {
        /**
         * The configuration for default new sheet settings.
         */
        defaultNewSheetConfiguration: pulumi.Input<inputs.quicksight.AnalysisDefaultNewSheetConfigurationArgs>;
    }
    interface AnalysisDefinitionArgs {
        analysisDefaults?: pulumi.Input<inputs.quicksight.AnalysisDefaultsArgs>;
        /**
         * An array of calculated field definitions for the analysis.
         */
        calculatedFields?: pulumi.Input<pulumi.Input<inputs.quicksight.AnalysisCalculatedFieldArgs>[]>;
        /**
         * An array of analysis-level column configurations. Column configurations can be used to set default formatting for a column to be used throughout an analysis.
         */
        columnConfigurations?: pulumi.Input<pulumi.Input<inputs.quicksight.AnalysisColumnConfigurationArgs>[]>;
        /**
         * An array of dataset identifier declarations. This mapping allows the usage of dataset identifiers instead of dataset ARNs throughout analysis sub-structures.
         */
        dataSetIdentifierDeclarations: pulumi.Input<pulumi.Input<inputs.quicksight.AnalysisDataSetIdentifierDeclarationArgs>[]>;
        /**
         * Filter definitions for an analysis.
         *
         * For more information, see [Filtering Data in Amazon QuickSight](https://docs.aws.amazon.com/quicksight/latest/user/adding-a-filter.html) in the *Amazon QuickSight User Guide* .
         */
        filterGroups?: pulumi.Input<pulumi.Input<inputs.quicksight.AnalysisFilterGroupArgs>[]>;
        /**
         * An array of option definitions for an analysis.
         */
        options?: pulumi.Input<inputs.quicksight.AnalysisAssetOptionsArgs>;
        /**
         * An array of parameter declarations for an analysis.
         *
         * Parameters are named variables that can transfer a value for use by an action or an object.
         *
         * For more information, see [Parameters in Amazon QuickSight](https://docs.aws.amazon.com/quicksight/latest/user/parameters-in-quicksight.html) in the *Amazon QuickSight User Guide* .
         */
        parameterDeclarations?: pulumi.Input<pulumi.Input<inputs.quicksight.AnalysisParameterDeclarationArgs>[]>;
        queryExecutionOptions?: pulumi.Input<inputs.quicksight.AnalysisQueryExecutionOptionsArgs>;
        /**
         * An array of sheet definitions for an analysis. Each `SheetDefinition` provides detailed information about a sheet within this analysis.
         */
        sheets?: pulumi.Input<pulumi.Input<inputs.quicksight.AnalysisSheetDefinitionArgs>[]>;
        /**
         * The static files for the definition.
         */
        staticFiles?: pulumi.Input<pulumi.Input<inputs.quicksight.AnalysisStaticFileArgs>[]>;
    }
    interface AnalysisDestinationParameterValueConfigurationArgs {
        /**
         * The configuration of custom values for destination parameter in `DestinationParameterValueConfiguration` .
         */
        customValuesConfiguration?: pulumi.Input<inputs.quicksight.AnalysisCustomValuesConfigurationArgs>;
        /**
         * The configuration that selects all options.
         */
        selectAllValueOptions?: pulumi.Input<enums.quicksight.AnalysisSelectAllValueOptions>;
        /**
         * A column of a data set.
         */
        sourceColumn?: pulumi.Input<inputs.quicksight.AnalysisColumnIdentifierArgs>;
        /**
         * The source field ID of the destination parameter.
         */
        sourceField?: pulumi.Input<string>;
        /**
         * The source parameter name of the destination parameter.
         */
        sourceParameterName?: pulumi.Input<string>;
    }
    interface AnalysisDimensionFieldArgs {
        /**
         * The dimension type field with categorical type columns.
         */
        categoricalDimensionField?: pulumi.Input<inputs.quicksight.AnalysisCategoricalDimensionFieldArgs>;
        /**
         * The dimension type field with date type columns.
         */
        dateDimensionField?: pulumi.Input<inputs.quicksight.AnalysisDateDimensionFieldArgs>;
        /**
         * The dimension type field with numerical type columns.
         */
        numericalDimensionField?: pulumi.Input<inputs.quicksight.AnalysisNumericalDimensionFieldArgs>;
    }
    interface AnalysisDonutCenterOptionsArgs {
        /**
         * Determines the visibility of the label in a donut chart. In the Amazon QuickSight console, this option is called `'Show total'` .
         */
        labelVisibility?: pulumi.Input<enums.quicksight.AnalysisVisibility>;
    }
    interface AnalysisDonutOptionsArgs {
        /**
         * The option for define the arc of the chart shape. Valid values are as follows:
         *
         * - `WHOLE` - A pie chart
         * - `SMALL` - A small-sized donut chart
         * - `MEDIUM` - A medium-sized donut chart
         * - `LARGE` - A large-sized donut chart
         */
        arcOptions?: pulumi.Input<inputs.quicksight.AnalysisArcOptionsArgs>;
        /**
         * The label options of the label that is displayed in the center of a donut chart. This option isn't available for pie charts.
         */
        donutCenterOptions?: pulumi.Input<inputs.quicksight.AnalysisDonutCenterOptionsArgs>;
    }
    interface AnalysisDrillDownFilterArgs {
        /**
         * The category type drill down filter. This filter is used for string type columns.
         */
        categoryFilter?: pulumi.Input<inputs.quicksight.AnalysisCategoryDrillDownFilterArgs>;
        /**
         * The numeric equality type drill down filter. This filter is used for number type columns.
         */
        numericEqualityFilter?: pulumi.Input<inputs.quicksight.AnalysisNumericEqualityDrillDownFilterArgs>;
        /**
         * The time range drill down filter. This filter is used for date time columns.
         */
        timeRangeFilter?: pulumi.Input<inputs.quicksight.AnalysisTimeRangeDrillDownFilterArgs>;
    }
    interface AnalysisDropDownControlDisplayOptionsArgs {
        /**
         * The configuration of info icon label options.
         */
        infoIconLabelOptions?: pulumi.Input<inputs.quicksight.AnalysisSheetControlInfoIconLabelOptionsArgs>;
        /**
         * The configuration of the `Select all` options in a dropdown control.
         */
        selectAllOptions?: pulumi.Input<inputs.quicksight.AnalysisListControlSelectAllOptionsArgs>;
        /**
         * The options to configure the title visibility, name, and font size.
         */
        titleOptions?: pulumi.Input<inputs.quicksight.AnalysisLabelOptionsArgs>;
    }
    interface AnalysisDynamicDefaultValueArgs {
        /**
         * The column that contains the default value of each user or group.
         */
        defaultValueColumn: pulumi.Input<inputs.quicksight.AnalysisColumnIdentifierArgs>;
        /**
         * The column that contains the group name.
         */
        groupNameColumn?: pulumi.Input<inputs.quicksight.AnalysisColumnIdentifierArgs>;
        /**
         * The column that contains the username.
         */
        userNameColumn?: pulumi.Input<inputs.quicksight.AnalysisColumnIdentifierArgs>;
    }
    interface AnalysisEmptyVisualArgs {
        /**
         * The list of custom actions that are configured for a visual.
         */
        actions?: pulumi.Input<pulumi.Input<inputs.quicksight.AnalysisVisualCustomActionArgs>[]>;
        /**
         * The data set that is used in the empty visual. Every visual requires a dataset to render.
         */
        dataSetIdentifier: pulumi.Input<string>;
        /**
         * The unique identifier of a visual. This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers.
         */
        visualId: pulumi.Input<string>;
    }
    interface AnalysisEntityArgs {
        /**
         * The hierarchical path of the entity within the analysis, template, or dashboard definition tree.
         */
        path?: pulumi.Input<string>;
    }
    /**
     * <p>Analysis error.</p>
     */
    interface AnalysisErrorArgs {
        /**
         * <p>The message associated with the analysis error.</p>
         */
        message?: pulumi.Input<string>;
        /**
         * The type of the analysis error.
         */
        type?: pulumi.Input<enums.quicksight.AnalysisErrorType>;
        /**
         * <p>Lists the violated entities that caused the analysis error</p>
         */
        violatedEntities?: pulumi.Input<pulumi.Input<inputs.quicksight.AnalysisEntityArgs>[]>;
    }
    interface AnalysisExcludePeriodConfigurationArgs {
        /**
         * The amount or number of the exclude period.
         */
        amount: pulumi.Input<number>;
        /**
         * The granularity or unit (day, month, year) of the exclude period.
         */
        granularity: pulumi.Input<enums.quicksight.AnalysisTimeGranularity>;
        /**
         * The status of the exclude period. Choose from the following options:
         *
         * - `ENABLED`
         * - `DISABLED`
         */
        status?: pulumi.Input<enums.quicksight.AnalysisWidgetStatus>;
    }
    interface AnalysisExplicitHierarchyArgs {
        /**
         * The list of columns that define the explicit hierarchy.
         */
        columns: pulumi.Input<pulumi.Input<inputs.quicksight.AnalysisColumnIdentifierArgs>[]>;
        /**
         * The option that determines the drill down filters for the explicit hierarchy.
         */
        drillDownFilters?: pulumi.Input<pulumi.Input<inputs.quicksight.AnalysisDrillDownFilterArgs>[]>;
        /**
         * The hierarchy ID of the explicit hierarchy.
         */
        hierarchyId: pulumi.Input<string>;
    }
    interface AnalysisFieldBasedTooltipArgs {
        /**
         * The visibility of `Show aggregations` .
         */
        aggregationVisibility?: pulumi.Input<enums.quicksight.AnalysisVisibility>;
        /**
         * The fields configuration in the tooltip.
         */
        tooltipFields?: pulumi.Input<pulumi.Input<inputs.quicksight.AnalysisTooltipItemArgs>[]>;
        /**
         * The type for the >tooltip title. Choose one of the following options:
         *
         * - `NONE` : Doesn't use the primary value as the title.
         * - `PRIMARY_VALUE` : Uses primary value as the title.
         */
        tooltipTitleType?: pulumi.Input<enums.quicksight.AnalysisTooltipTitleType>;
    }
    interface AnalysisFieldLabelTypeArgs {
        /**
         * Indicates the field that is targeted by the field label.
         */
        fieldId?: pulumi.Input<string>;
        /**
         * The visibility of the field label.
         */
        visibility?: pulumi.Input<enums.quicksight.AnalysisVisibility>;
    }
    interface AnalysisFieldSeriesItemArgs {
        /**
         * The axis that you are binding the field to.
         */
        axisBinding: pulumi.Input<enums.quicksight.AnalysisAxisBinding>;
        /**
         * The field ID of the field for which you are setting the axis binding.
         */
        fieldId: pulumi.Input<string>;
        /**
         * The options that determine the presentation of line series associated to the field.
         */
        settings?: pulumi.Input<inputs.quicksight.AnalysisLineChartSeriesSettingsArgs>;
    }
    interface AnalysisFieldSortArgs {
        /**
         * The sort direction. Choose one of the following options:
         *
         * - `ASC` : Ascending
         * - `DESC` : Descending
         */
        direction: pulumi.Input<enums.quicksight.AnalysisSortDirection>;
        /**
         * The sort configuration target field.
         */
        fieldId: pulumi.Input<string>;
    }
    interface AnalysisFieldSortOptionsArgs {
        /**
         * The sort configuration for a column that is not used in a field well.
         */
        columnSort?: pulumi.Input<inputs.quicksight.AnalysisColumnSortArgs>;
        /**
         * The sort configuration for a field in a field well.
         */
        fieldSort?: pulumi.Input<inputs.quicksight.AnalysisFieldSortArgs>;
    }
    interface AnalysisFieldTooltipItemArgs {
        /**
         * The unique ID of the field that is targeted by the tooltip.
         */
        fieldId: pulumi.Input<string>;
        /**
         * The label of the tooltip item.
         */
        label?: pulumi.Input<string>;
        /**
         * Determines the target of the field tooltip item in a combo chart visual.
         */
        tooltipTarget?: pulumi.Input<enums.quicksight.AnalysisTooltipTarget>;
        /**
         * The visibility of the tooltip item.
         */
        visibility?: pulumi.Input<enums.quicksight.AnalysisVisibility>;
    }
    interface AnalysisFilledMapAggregatedFieldWellsArgs {
        /**
         * The aggregated location field well of the filled map. Values are grouped by location fields.
         */
        geospatial?: pulumi.Input<pulumi.Input<inputs.quicksight.AnalysisDimensionFieldArgs>[]>;
        /**
         * The aggregated color field well of a filled map. Values are aggregated based on location fields.
         */
        values?: pulumi.Input<pulumi.Input<inputs.quicksight.AnalysisMeasureFieldArgs>[]>;
    }
    interface AnalysisFilledMapConditionalFormattingArgs {
        /**
         * Conditional formatting options of a `FilledMapVisual` .
         */
        conditionalFormattingOptions: pulumi.Input<pulumi.Input<inputs.quicksight.AnalysisFilledMapConditionalFormattingOptionArgs>[]>;
    }
    interface AnalysisFilledMapConditionalFormattingOptionArgs {
        /**
         * The conditional formatting that determines the shape of the filled map.
         */
        shape: pulumi.Input<inputs.quicksight.AnalysisFilledMapShapeConditionalFormattingArgs>;
    }
    interface AnalysisFilledMapConfigurationArgs {
        /**
         * The field wells of the visual.
         */
        fieldWells?: pulumi.Input<inputs.quicksight.AnalysisFilledMapFieldWellsArgs>;
        /**
         * The general visual interactions setup for a visual.
         */
        interactions?: pulumi.Input<inputs.quicksight.AnalysisVisualInteractionOptionsArgs>;
        /**
         * The legend display setup of the visual.
         */
        legend?: pulumi.Input<inputs.quicksight.AnalysisLegendOptionsArgs>;
        /**
         * The map style options of the filled map visual.
         */
        mapStyleOptions?: pulumi.Input<inputs.quicksight.AnalysisGeospatialMapStyleOptionsArgs>;
        /**
         * The sort configuration of a `FilledMapVisual` .
         */
        sortConfiguration?: pulumi.Input<inputs.quicksight.AnalysisFilledMapSortConfigurationArgs>;
        /**
         * The tooltip display setup of the visual.
         */
        tooltip?: pulumi.Input<inputs.quicksight.AnalysisTooltipOptionsArgs>;
        /**
         * The window options of the filled map visual.
         */
        windowOptions?: pulumi.Input<inputs.quicksight.AnalysisGeospatialWindowOptionsArgs>;
    }
    interface AnalysisFilledMapFieldWellsArgs {
        /**
         * The aggregated field well of the filled map.
         */
        filledMapAggregatedFieldWells?: pulumi.Input<inputs.quicksight.AnalysisFilledMapAggregatedFieldWellsArgs>;
    }
    interface AnalysisFilledMapShapeConditionalFormattingArgs {
        /**
         * The field ID of the filled map shape.
         */
        fieldId: pulumi.Input<string>;
        /**
         * The conditional formatting that determines the background color of a filled map's shape.
         */
        format?: pulumi.Input<inputs.quicksight.AnalysisShapeConditionalFormatArgs>;
    }
    interface AnalysisFilledMapSortConfigurationArgs {
        /**
         * The sort configuration of the location fields.
         */
        categorySort?: pulumi.Input<pulumi.Input<inputs.quicksight.AnalysisFieldSortOptionsArgs>[]>;
    }
    interface AnalysisFilledMapVisualArgs {
        /**
         * The list of custom actions that are configured for a visual.
         */
        actions?: pulumi.Input<pulumi.Input<inputs.quicksight.AnalysisVisualCustomActionArgs>[]>;
        /**
         * The configuration settings of the visual.
         */
        chartConfiguration?: pulumi.Input<inputs.quicksight.AnalysisFilledMapConfigurationArgs>;
        /**
         * The column hierarchy that is used during drill-downs and drill-ups.
         */
        columnHierarchies?: pulumi.Input<pulumi.Input<inputs.quicksight.AnalysisColumnHierarchyArgs>[]>;
        /**
         * The conditional formatting of a `FilledMapVisual` .
         */
        conditionalFormatting?: pulumi.Input<inputs.quicksight.AnalysisFilledMapConditionalFormattingArgs>;
        /**
         * The subtitle that is displayed on the visual.
         */
        subtitle?: pulumi.Input<inputs.quicksight.AnalysisVisualSubtitleLabelOptionsArgs>;
        /**
         * The title that is displayed on the visual.
         */
        title?: pulumi.Input<inputs.quicksight.AnalysisVisualTitleLabelOptionsArgs>;
        /**
         * The alt text for the visual.
         */
        visualContentAltText?: pulumi.Input<string>;
        /**
         * The unique identifier of a visual. This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers..
         */
        visualId: pulumi.Input<string>;
    }
    interface AnalysisFilterArgs {
        /**
         * A `CategoryFilter` filters text values.
         *
         * For more information, see [Adding text filters](https://docs.aws.amazon.com/quicksight/latest/user/add-a-text-filter-data-prep.html) in the *Amazon QuickSight User Guide* .
         */
        categoryFilter?: pulumi.Input<inputs.quicksight.AnalysisCategoryFilterArgs>;
        /**
         * A `NestedFilter` filters data with a subset of data that is defined by the nested inner filter.
         */
        nestedFilter?: pulumi.Input<inputs.quicksight.AnalysisNestedFilterArgs>;
        /**
         * A `NumericEqualityFilter` filters numeric values that equal or do not equal a given numeric value.
         */
        numericEqualityFilter?: pulumi.Input<inputs.quicksight.AnalysisNumericEqualityFilterArgs>;
        /**
         * A `NumericRangeFilter` filters numeric values that are either inside or outside a given numeric range.
         */
        numericRangeFilter?: pulumi.Input<inputs.quicksight.AnalysisNumericRangeFilterArgs>;
        /**
         * A `RelativeDatesFilter` filters date values that are relative to a given date.
         */
        relativeDatesFilter?: pulumi.Input<inputs.quicksight.AnalysisRelativeDatesFilterArgs>;
        /**
         * A `TimeEqualityFilter` filters date-time values that equal or do not equal a given date/time value.
         */
        timeEqualityFilter?: pulumi.Input<inputs.quicksight.AnalysisTimeEqualityFilterArgs>;
        /**
         * A `TimeRangeFilter` filters date-time values that are either inside or outside a given date/time range.
         */
        timeRangeFilter?: pulumi.Input<inputs.quicksight.AnalysisTimeRangeFilterArgs>;
        /**
         * A `TopBottomFilter` filters data to the top or bottom values for a given column.
         */
        topBottomFilter?: pulumi.Input<inputs.quicksight.AnalysisTopBottomFilterArgs>;
    }
    interface AnalysisFilterControlArgs {
        /**
         * A control from a filter that is scoped across more than one sheet. This represents your filter control on a sheet
         */
        crossSheet?: pulumi.Input<inputs.quicksight.AnalysisFilterCrossSheetControlArgs>;
        /**
         * A control from a date filter that is used to specify date and time.
         */
        dateTimePicker?: pulumi.Input<inputs.quicksight.AnalysisFilterDateTimePickerControlArgs>;
        /**
         * A control to display a dropdown list with buttons that are used to select a single value.
         */
        dropdown?: pulumi.Input<inputs.quicksight.AnalysisFilterDropDownControlArgs>;
        /**
         * A control to display a list of buttons or boxes. This is used to select either a single value or multiple values.
         */
        list?: pulumi.Input<inputs.quicksight.AnalysisFilterListControlArgs>;
        /**
         * A control from a date filter that is used to specify the relative date.
         */
        relativeDateTime?: pulumi.Input<inputs.quicksight.AnalysisFilterRelativeDateTimeControlArgs>;
        /**
         * A control to display a horizontal toggle bar. This is used to change a value by sliding the toggle.
         */
        slider?: pulumi.Input<inputs.quicksight.AnalysisFilterSliderControlArgs>;
        /**
         * A control to display a text box that is used to enter multiple entries.
         */
        textArea?: pulumi.Input<inputs.quicksight.AnalysisFilterTextAreaControlArgs>;
        /**
         * A control to display a text box that is used to enter a single entry.
         */
        textField?: pulumi.Input<inputs.quicksight.AnalysisFilterTextFieldControlArgs>;
    }
    interface AnalysisFilterCrossSheetControlArgs {
        /**
         * The values that are displayed in a control can be configured to only show values that are valid based on what's selected in other controls.
         */
        cascadingControlConfiguration?: pulumi.Input<inputs.quicksight.AnalysisCascadingControlConfigurationArgs>;
        /**
         * The ID of the `FilterCrossSheetControl` .
         */
        filterControlId: pulumi.Input<string>;
        /**
         * The source filter ID of the `FilterCrossSheetControl` .
         */
        sourceFilterId: pulumi.Input<string>;
    }
    interface AnalysisFilterDateTimePickerControlArgs {
        /**
         * The visibility configurationof the Apply button on a `DateTimePickerControl` .
         */
        commitMode?: pulumi.Input<enums.quicksight.AnalysisCommitMode>;
        /**
         * The display options of a control.
         */
        displayOptions?: pulumi.Input<inputs.quicksight.AnalysisDateTimePickerControlDisplayOptionsArgs>;
        /**
         * The ID of the `FilterDateTimePickerControl` .
         */
        filterControlId: pulumi.Input<string>;
        /**
         * The source filter ID of the `FilterDateTimePickerControl` .
         */
        sourceFilterId: pulumi.Input<string>;
        /**
         * The title of the `FilterDateTimePickerControl` .
         */
        title: pulumi.Input<string>;
        /**
         * The type of the `FilterDropDownControl` . Choose one of the following options:
         *
         * - `MULTI_SELECT` : The user can select multiple entries from a dropdown menu.
         * - `SINGLE_SELECT` : The user can select a single entry from a dropdown menu.
         */
        type?: pulumi.Input<enums.quicksight.AnalysisSheetControlDateTimePickerType>;
    }
    interface AnalysisFilterDropDownControlArgs {
        /**
         * The values that are displayed in a control can be configured to only show values that are valid based on what's selected in other controls.
         */
        cascadingControlConfiguration?: pulumi.Input<inputs.quicksight.AnalysisCascadingControlConfigurationArgs>;
        /**
         * The visibility configuration of the Apply button on a `FilterDropDownControl` .
         */
        commitMode?: pulumi.Input<enums.quicksight.AnalysisCommitMode>;
        /**
         * The display options of the `FilterDropDownControl` .
         */
        displayOptions?: pulumi.Input<inputs.quicksight.AnalysisDropDownControlDisplayOptionsArgs>;
        /**
         * The ID of the `FilterDropDownControl` .
         */
        filterControlId: pulumi.Input<string>;
        /**
         * A list of selectable values that are used in a control.
         */
        selectableValues?: pulumi.Input<inputs.quicksight.AnalysisFilterSelectableValuesArgs>;
        /**
         * The source filter ID of the `FilterDropDownControl` .
         */
        sourceFilterId: pulumi.Input<string>;
        /**
         * The title of the `FilterDropDownControl` .
         */
        title: pulumi.Input<string>;
        /**
         * The type of the `FilterDropDownControl` . Choose one of the following options:
         *
         * - `MULTI_SELECT` : The user can select multiple entries from a dropdown menu.
         * - `SINGLE_SELECT` : The user can select a single entry from a dropdown menu.
         */
        type?: pulumi.Input<enums.quicksight.AnalysisSheetControlListType>;
    }
    interface AnalysisFilterGroupArgs {
        /**
         * The filter new feature which can apply filter group to all data sets. Choose one of the following options:
         *
         * - `ALL_DATASETS`
         * - `SINGLE_DATASET`
         */
        crossDataset: pulumi.Input<enums.quicksight.AnalysisCrossDatasetTypes>;
        /**
         * The value that uniquely identifies a `FilterGroup` within a dashboard, template, or analysis.
         */
        filterGroupId: pulumi.Input<string>;
        /**
         * The list of filters that are present in a `FilterGroup` .
         */
        filters: pulumi.Input<pulumi.Input<inputs.quicksight.AnalysisFilterArgs>[]>;
        /**
         * The configuration that specifies what scope to apply to a `FilterGroup` .
         *
         * This is a union type structure. For this structure to be valid, only one of the attributes can be defined.
         */
        scopeConfiguration: pulumi.Input<inputs.quicksight.AnalysisFilterScopeConfigurationArgs>;
        /**
         * The status of the `FilterGroup` .
         */
        status?: pulumi.Input<enums.quicksight.AnalysisWidgetStatus>;
    }
    interface AnalysisFilterListConfigurationArgs {
        /**
         * The list of category values for the filter.
         */
        categoryValues?: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * The match operator that is used to determine if a filter should be applied.
         */
        matchOperator: pulumi.Input<enums.quicksight.AnalysisCategoryFilterMatchOperator>;
        /**
         * This option determines how null values should be treated when filtering data.
         *
         * - `ALL_VALUES` : Include null values in filtered results.
         * - `NULLS_ONLY` : Only include null values in filtered results.
         * - `NON_NULLS_ONLY` : Exclude null values from filtered results.
         */
        nullOption?: pulumi.Input<enums.quicksight.AnalysisFilterNullOption>;
        /**
         * Select all of the values. Null is not the assigned value of select all.
         *
         * - `FILTER_ALL_VALUES`
         */
        selectAllOptions?: pulumi.Input<enums.quicksight.AnalysisCategoryFilterSelectAllOptions>;
    }
    interface AnalysisFilterListControlArgs {
        /**
         * The values that are displayed in a control can be configured to only show values that are valid based on what's selected in other controls.
         */
        cascadingControlConfiguration?: pulumi.Input<inputs.quicksight.AnalysisCascadingControlConfigurationArgs>;
        /**
         * The display options of a control.
         */
        displayOptions?: pulumi.Input<inputs.quicksight.AnalysisListControlDisplayOptionsArgs>;
        /**
         * The ID of the `FilterListControl` .
         */
        filterControlId: pulumi.Input<string>;
        /**
         * A list of selectable values that are used in a control.
         */
        selectableValues?: pulumi.Input<inputs.quicksight.AnalysisFilterSelectableValuesArgs>;
        /**
         * The source filter ID of the `FilterListControl` .
         */
        sourceFilterId: pulumi.Input<string>;
        /**
         * The title of the `FilterListControl` .
         */
        title: pulumi.Input<string>;
        /**
         * The type of the `FilterListControl` . Choose one of the following options:
         *
         * - `MULTI_SELECT` : The user can select multiple entries from the list.
         * - `SINGLE_SELECT` : The user can select a single entry from the list.
         */
        type?: pulumi.Input<enums.quicksight.AnalysisSheetControlListType>;
    }
    interface AnalysisFilterOperationSelectedFieldsConfigurationArgs {
        /**
         * <p>The selected columns of a dataset.</p>
         */
        selectedColumns?: pulumi.Input<pulumi.Input<inputs.quicksight.AnalysisColumnIdentifierArgs>[]>;
        /**
         * A structure that contains the options that choose which fields are filtered in the `CustomActionFilterOperation` .
         *
         * Valid values are defined as follows:
         *
         * - `ALL_FIELDS` : Applies the filter operation to all fields.
         */
        selectedFieldOptions?: pulumi.Input<enums.quicksight.AnalysisSelectedFieldOptions>;
        /**
         * Chooses the fields that are filtered in `CustomActionFilterOperation` .
         */
        selectedFields?: pulumi.Input<pulumi.Input<string>[]>;
    }
    interface AnalysisFilterOperationTargetVisualsConfigurationArgs {
        /**
         * The configuration of the same-sheet target visuals that you want to be filtered.
         */
        sameSheetTargetVisualConfiguration?: pulumi.Input<inputs.quicksight.AnalysisSameSheetTargetVisualConfigurationArgs>;
    }
    interface AnalysisFilterRelativeDateTimeControlArgs {
        /**
         * The visibility configuration of the Apply button on a `FilterRelativeDateTimeControl` .
         */
        commitMode?: pulumi.Input<enums.quicksight.AnalysisCommitMode>;
        /**
         * The display options of a control.
         */
        displayOptions?: pulumi.Input<inputs.quicksight.AnalysisRelativeDateTimeControlDisplayOptionsArgs>;
        /**
         * The ID of the `FilterTextAreaControl` .
         */
        filterControlId: pulumi.Input<string>;
        /**
         * The source filter ID of the `FilterTextAreaControl` .
         */
        sourceFilterId: pulumi.Input<string>;
        /**
         * The title of the `FilterTextAreaControl` .
         */
        title: pulumi.Input<string>;
    }
    interface AnalysisFilterScopeConfigurationArgs {
        /**
         * The configuration that applies a filter to all sheets. When you choose `AllSheets` as the value for a `FilterScopeConfiguration` , this filter is applied to all visuals of all sheets in an Analysis, Dashboard, or Template. The `AllSheetsFilterScopeConfiguration` is chosen.
         */
        allSheets?: pulumi.Input<inputs.quicksight.AnalysisAllSheetsFilterScopeConfigurationArgs>;
        /**
         * The configuration for applying a filter to specific sheets.
         */
        selectedSheets?: pulumi.Input<inputs.quicksight.AnalysisSelectedSheetsFilterScopeConfigurationArgs>;
    }
    interface AnalysisFilterSelectableValuesArgs {
        /**
         * The values that are used in the `FilterSelectableValues` .
         */
        values?: pulumi.Input<pulumi.Input<string>[]>;
    }
    interface AnalysisFilterSliderControlArgs {
        /**
         * The display options of a control.
         */
        displayOptions?: pulumi.Input<inputs.quicksight.AnalysisSliderControlDisplayOptionsArgs>;
        /**
         * The ID of the `FilterSliderControl` .
         */
        filterControlId: pulumi.Input<string>;
        /**
         * The larger value that is displayed at the right of the slider.
         */
        maximumValue: pulumi.Input<number>;
        /**
         * The smaller value that is displayed at the left of the slider.
         */
        minimumValue: pulumi.Input<number>;
        /**
         * The source filter ID of the `FilterSliderControl` .
         */
        sourceFilterId: pulumi.Input<string>;
        /**
         * The number of increments that the slider bar is divided into.
         */
        stepSize: pulumi.Input<number>;
        /**
         * The title of the `FilterSliderControl` .
         */
        title: pulumi.Input<string>;
        /**
         * The type of the `FilterSliderControl` . Choose one of the following options:
         *
         * - `SINGLE_POINT` : Filter against(equals) a single data point.
         * - `RANGE` : Filter data that is in a specified range.
         */
        type?: pulumi.Input<enums.quicksight.AnalysisSheetControlSliderType>;
    }
    interface AnalysisFilterTextAreaControlArgs {
        /**
         * The delimiter that is used to separate the lines in text.
         */
        delimiter?: pulumi.Input<string>;
        /**
         * The display options of a control.
         */
        displayOptions?: pulumi.Input<inputs.quicksight.AnalysisTextAreaControlDisplayOptionsArgs>;
        /**
         * The ID of the `FilterTextAreaControl` .
         */
        filterControlId: pulumi.Input<string>;
        /**
         * The source filter ID of the `FilterTextAreaControl` .
         */
        sourceFilterId: pulumi.Input<string>;
        /**
         * The title of the `FilterTextAreaControl` .
         */
        title: pulumi.Input<string>;
    }
    interface AnalysisFilterTextFieldControlArgs {
        /**
         * The display options of a control.
         */
        displayOptions?: pulumi.Input<inputs.quicksight.AnalysisTextFieldControlDisplayOptionsArgs>;
        /**
         * The ID of the `FilterTextFieldControl` .
         */
        filterControlId: pulumi.Input<string>;
        /**
         * The source filter ID of the `FilterTextFieldControl` .
         */
        sourceFilterId: pulumi.Input<string>;
        /**
         * The title of the `FilterTextFieldControl` .
         */
        title: pulumi.Input<string>;
    }
    interface AnalysisFontConfigurationArgs {
        /**
         * Determines the color of the text.
         */
        fontColor?: pulumi.Input<string>;
        /**
         * Determines the appearance of decorative lines on the text.
         */
        fontDecoration?: pulumi.Input<enums.quicksight.AnalysisFontDecoration>;
        /**
         * The font family that you want to use.
         */
        fontFamily?: pulumi.Input<string>;
        /**
         * The option that determines the text display size.
         */
        fontSize?: pulumi.Input<inputs.quicksight.AnalysisFontSizeArgs>;
        /**
         * Determines the text display face that is inherited by the given font family.
         */
        fontStyle?: pulumi.Input<enums.quicksight.AnalysisFontStyle>;
        /**
         * The option that determines the text display weight, or boldness.
         */
        fontWeight?: pulumi.Input<inputs.quicksight.AnalysisFontWeightArgs>;
    }
    interface AnalysisFontSizeArgs {
        /**
         * String based length that is composed of value and unit in px
         */
        absolute?: pulumi.Input<string>;
        /**
         * The lexical name for the text size, proportional to its surrounding context.
         */
        relative?: pulumi.Input<enums.quicksight.AnalysisRelativeFontSize>;
    }
    interface AnalysisFontWeightArgs {
        /**
         * The lexical name for the level of boldness of the text display.
         */
        name?: pulumi.Input<enums.quicksight.AnalysisFontWeightName>;
    }
    interface AnalysisForecastComputationArgs {
        /**
         * The ID for a computation.
         */
        computationId: pulumi.Input<string>;
        /**
         * The custom seasonality value setup of a forecast computation.
         */
        customSeasonalityValue?: pulumi.Input<number>;
        /**
         * The lower boundary setup of a forecast computation.
         */
        lowerBoundary?: pulumi.Input<number>;
        /**
         * The name of a computation.
         */
        name?: pulumi.Input<string>;
        /**
         * The periods backward setup of a forecast computation.
         */
        periodsBackward?: pulumi.Input<number>;
        /**
         * The periods forward setup of a forecast computation.
         */
        periodsForward?: pulumi.Input<number>;
        /**
         * The prediction interval setup of a forecast computation.
         */
        predictionInterval?: pulumi.Input<number>;
        /**
         * The seasonality setup of a forecast computation. Choose one of the following options:
         *
         * - `AUTOMATIC`
         * - `CUSTOM` : Checks the custom seasonality value.
         */
        seasonality?: pulumi.Input<enums.quicksight.AnalysisForecastComputationSeasonality>;
        /**
         * The time field that is used in a computation.
         */
        time?: pulumi.Input<inputs.quicksight.AnalysisDimensionFieldArgs>;
        /**
         * The upper boundary setup of a forecast computation.
         */
        upperBoundary?: pulumi.Input<number>;
        /**
         * The value field that is used in a computation.
         */
        value?: pulumi.Input<inputs.quicksight.AnalysisMeasureFieldArgs>;
    }
    interface AnalysisForecastConfigurationArgs {
        /**
         * The forecast properties setup of a forecast in the line chart.
         */
        forecastProperties?: pulumi.Input<inputs.quicksight.AnalysisTimeBasedForecastPropertiesArgs>;
        /**
         * The forecast scenario of a forecast in the line chart.
         */
        scenario?: pulumi.Input<inputs.quicksight.AnalysisForecastScenarioArgs>;
    }
    interface AnalysisForecastScenarioArgs {
        /**
         * The what-if analysis forecast setup with the target date.
         */
        whatIfPointScenario?: pulumi.Input<inputs.quicksight.AnalysisWhatIfPointScenarioArgs>;
        /**
         * The what-if analysis forecast setup with the date range.
         */
        whatIfRangeScenario?: pulumi.Input<inputs.quicksight.AnalysisWhatIfRangeScenarioArgs>;
    }
    interface AnalysisFormatConfigurationArgs {
        /**
         * Formatting configuration for `DateTime` fields.
         */
        dateTimeFormatConfiguration?: pulumi.Input<inputs.quicksight.AnalysisDateTimeFormatConfigurationArgs>;
        /**
         * Formatting configuration for number fields.
         */
        numberFormatConfiguration?: pulumi.Input<inputs.quicksight.AnalysisNumberFormatConfigurationArgs>;
        /**
         * Formatting configuration for string fields.
         */
        stringFormatConfiguration?: pulumi.Input<inputs.quicksight.AnalysisStringFormatConfigurationArgs>;
    }
    interface AnalysisFreeFormLayoutCanvasSizeOptionsArgs {
        /**
         * The options that determine the sizing of the canvas used in a free-form layout.
         */
        screenCanvasSizeOptions?: pulumi.Input<inputs.quicksight.AnalysisFreeFormLayoutScreenCanvasSizeOptionsArgs>;
    }
    interface AnalysisFreeFormLayoutConfigurationArgs {
        canvasSizeOptions?: pulumi.Input<inputs.quicksight.AnalysisFreeFormLayoutCanvasSizeOptionsArgs>;
        /**
         * The elements that are included in a free-form layout.
         */
        elements: pulumi.Input<pulumi.Input<inputs.quicksight.AnalysisFreeFormLayoutElementArgs>[]>;
    }
    interface AnalysisFreeFormLayoutElementArgs {
        /**
         * The background style configuration of a free-form layout element.
         */
        backgroundStyle?: pulumi.Input<inputs.quicksight.AnalysisFreeFormLayoutElementBackgroundStyleArgs>;
        /**
         * The border style configuration of a free-form layout element.
         */
        borderStyle?: pulumi.Input<inputs.quicksight.AnalysisFreeFormLayoutElementBorderStyleArgs>;
        /**
         * A unique identifier for an element within a free-form layout.
         */
        elementId: pulumi.Input<string>;
        /**
         * The type of element.
         */
        elementType: pulumi.Input<enums.quicksight.AnalysisLayoutElementType>;
        /**
         * String based length that is composed of value and unit in px
         */
        height: pulumi.Input<string>;
        /**
         * The loading animation configuration of a free-form layout element.
         */
        loadingAnimation?: pulumi.Input<inputs.quicksight.AnalysisLoadingAnimationArgs>;
        /**
         * The rendering rules that determine when an element should be displayed within a free-form layout.
         */
        renderingRules?: pulumi.Input<pulumi.Input<inputs.quicksight.AnalysisSheetElementRenderingRuleArgs>[]>;
        /**
         * The border style configuration of a free-form layout element. This border style is used when the element is selected.
         */
        selectedBorderStyle?: pulumi.Input<inputs.quicksight.AnalysisFreeFormLayoutElementBorderStyleArgs>;
        /**
         * The visibility of an element within a free-form layout.
         */
        visibility?: pulumi.Input<enums.quicksight.AnalysisVisibility>;
        /**
         * String based length that is composed of value and unit in px
         */
        width: pulumi.Input<string>;
        /**
         * String based length that is composed of value and unit in px
         */
        xAxisLocation: pulumi.Input<string>;
        /**
         * String based length that is composed of value and unit in px with Integer.MAX_VALUE as maximum value
         */
        yAxisLocation: pulumi.Input<string>;
    }
    interface AnalysisFreeFormLayoutElementBackgroundStyleArgs {
        /**
         * The background color of a free-form layout element.
         */
        color?: pulumi.Input<string>;
        /**
         * The background visibility of a free-form layout element.
         */
        visibility?: pulumi.Input<enums.quicksight.AnalysisVisibility>;
    }
    interface AnalysisFreeFormLayoutElementBorderStyleArgs {
        /**
         * The border color of a free-form layout element.
         */
        color?: pulumi.Input<string>;
        /**
         * The border visibility of a free-form layout element.
         */
        visibility?: pulumi.Input<enums.quicksight.AnalysisVisibility>;
    }
    interface AnalysisFreeFormLayoutScreenCanvasSizeOptionsArgs {
        /**
         * String based length that is composed of value and unit in px
         */
        optimizedViewPortWidth: pulumi.Input<string>;
    }
    interface AnalysisFreeFormSectionLayoutConfigurationArgs {
        /**
         * The elements that are included in the free-form layout.
         */
        elements: pulumi.Input<pulumi.Input<inputs.quicksight.AnalysisFreeFormLayoutElementArgs>[]>;
    }
    interface AnalysisFunnelChartAggregatedFieldWellsArgs {
        /**
         * The category field wells of a funnel chart. Values are grouped by category fields.
         */
        category?: pulumi.Input<pulumi.Input<inputs.quicksight.AnalysisDimensionFieldArgs>[]>;
        /**
         * The value field wells of a funnel chart. Values are aggregated based on categories.
         */
        values?: pulumi.Input<pulumi.Input<inputs.quicksight.AnalysisMeasureFieldArgs>[]>;
    }
    interface AnalysisFunnelChartConfigurationArgs {
        /**
         * The label options of the categories that are displayed in a `FunnelChartVisual` .
         */
        categoryLabelOptions?: pulumi.Input<inputs.quicksight.AnalysisChartAxisLabelOptionsArgs>;
        /**
         * The options that determine the presentation of the data labels.
         */
        dataLabelOptions?: pulumi.Input<inputs.quicksight.AnalysisFunnelChartDataLabelOptionsArgs>;
        /**
         * The field well configuration of a `FunnelChartVisual` .
         */
        fieldWells?: pulumi.Input<inputs.quicksight.AnalysisFunnelChartFieldWellsArgs>;
        /**
         * The general visual interactions setup for a visual.
         */
        interactions?: pulumi.Input<inputs.quicksight.AnalysisVisualInteractionOptionsArgs>;
        /**
         * The sort configuration of a `FunnelChartVisual` .
         */
        sortConfiguration?: pulumi.Input<inputs.quicksight.AnalysisFunnelChartSortConfigurationArgs>;
        /**
         * The tooltip configuration of a `FunnelChartVisual` .
         */
        tooltip?: pulumi.Input<inputs.quicksight.AnalysisTooltipOptionsArgs>;
        /**
         * The label options for the values that are displayed in a `FunnelChartVisual` .
         */
        valueLabelOptions?: pulumi.Input<inputs.quicksight.AnalysisChartAxisLabelOptionsArgs>;
        /**
         * The visual palette configuration of a `FunnelChartVisual` .
         */
        visualPalette?: pulumi.Input<inputs.quicksight.AnalysisVisualPaletteArgs>;
    }
    interface AnalysisFunnelChartDataLabelOptionsArgs {
        /**
         * The visibility of the category labels within the data labels.
         */
        categoryLabelVisibility?: pulumi.Input<enums.quicksight.AnalysisVisibility>;
        /**
         * The color of the data label text.
         */
        labelColor?: pulumi.Input<string>;
        /**
         * The font configuration for the data labels.
         *
         * Only the `FontSize` attribute of the font configuration is used for data labels.
         */
        labelFontConfiguration?: pulumi.Input<inputs.quicksight.AnalysisFontConfigurationArgs>;
        /**
         * Determines the style of the metric labels.
         */
        measureDataLabelStyle?: pulumi.Input<enums.quicksight.AnalysisFunnelChartMeasureDataLabelStyle>;
        /**
         * The visibility of the measure labels within the data labels.
         */
        measureLabelVisibility?: pulumi.Input<enums.quicksight.AnalysisVisibility>;
        /**
         * Determines the positioning of the data label relative to a section of the funnel.
         */
        position?: pulumi.Input<enums.quicksight.AnalysisDataLabelPosition>;
        /**
         * The visibility option that determines if data labels are displayed.
         */
        visibility?: pulumi.Input<enums.quicksight.AnalysisVisibility>;
    }
    interface AnalysisFunnelChartFieldWellsArgs {
        /**
         * The field well configuration of a `FunnelChartVisual` .
         */
        funnelChartAggregatedFieldWells?: pulumi.Input<inputs.quicksight.AnalysisFunnelChartAggregatedFieldWellsArgs>;
    }
    interface AnalysisFunnelChartSortConfigurationArgs {
        /**
         * The limit on the number of categories displayed.
         */
        categoryItemsLimit?: pulumi.Input<inputs.quicksight.AnalysisItemsLimitConfigurationArgs>;
        /**
         * The sort configuration of the category fields.
         */
        categorySort?: pulumi.Input<pulumi.Input<inputs.quicksight.AnalysisFieldSortOptionsArgs>[]>;
    }
    interface AnalysisFunnelChartVisualArgs {
        /**
         * The list of custom actions that are configured for a visual.
         */
        actions?: pulumi.Input<pulumi.Input<inputs.quicksight.AnalysisVisualCustomActionArgs>[]>;
        /**
         * The configuration of a `FunnelChartVisual` .
         */
        chartConfiguration?: pulumi.Input<inputs.quicksight.AnalysisFunnelChartConfigurationArgs>;
        /**
         * The column hierarchy that is used during drill-downs and drill-ups.
         */
        columnHierarchies?: pulumi.Input<pulumi.Input<inputs.quicksight.AnalysisColumnHierarchyArgs>[]>;
        /**
         * The subtitle that is displayed on the visual.
         */
        subtitle?: pulumi.Input<inputs.quicksight.AnalysisVisualSubtitleLabelOptionsArgs>;
        /**
         * The title that is displayed on the visual.
         */
        title?: pulumi.Input<inputs.quicksight.AnalysisVisualTitleLabelOptionsArgs>;
        /**
         * The alt text for the visual.
         */
        visualContentAltText?: pulumi.Input<string>;
        /**
         * The unique identifier of a visual. This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers..
         */
        visualId: pulumi.Input<string>;
    }
    interface AnalysisGaugeChartArcConditionalFormattingArgs {
        /**
         * The conditional formatting of the arc foreground color.
         */
        foregroundColor?: pulumi.Input<inputs.quicksight.AnalysisConditionalFormattingColorArgs>;
    }
    interface AnalysisGaugeChartColorConfigurationArgs {
        /**
         * The background color configuration of a `GaugeChartVisual` .
         */
        backgroundColor?: pulumi.Input<string>;
        /**
         * The foreground color configuration of a `GaugeChartVisual` .
         */
        foregroundColor?: pulumi.Input<string>;
    }
    interface AnalysisGaugeChartConditionalFormattingArgs {
        /**
         * Conditional formatting options of a `GaugeChartVisual` .
         */
        conditionalFormattingOptions?: pulumi.Input<pulumi.Input<inputs.quicksight.AnalysisGaugeChartConditionalFormattingOptionArgs>[]>;
    }
    interface AnalysisGaugeChartConditionalFormattingOptionArgs {
        /**
         * The options that determine the presentation of the arc of a `GaugeChartVisual` .
         */
        arc?: pulumi.Input<inputs.quicksight.AnalysisGaugeChartArcConditionalFormattingArgs>;
        /**
         * The conditional formatting for the primary value of a `GaugeChartVisual` .
         */
        primaryValue?: pulumi.Input<inputs.quicksight.AnalysisGaugeChartPrimaryValueConditionalFormattingArgs>;
    }
    interface AnalysisGaugeChartConfigurationArgs {
        /**
         * The color configuration of a `GaugeChartVisual` .
         */
        colorConfiguration?: pulumi.Input<inputs.quicksight.AnalysisGaugeChartColorConfigurationArgs>;
        /**
         * The data label configuration of a `GaugeChartVisual` .
         */
        dataLabels?: pulumi.Input<inputs.quicksight.AnalysisDataLabelOptionsArgs>;
        /**
         * The field well configuration of a `GaugeChartVisual` .
         */
        fieldWells?: pulumi.Input<inputs.quicksight.AnalysisGaugeChartFieldWellsArgs>;
        /**
         * The options that determine the presentation of the `GaugeChartVisual` .
         */
        gaugeChartOptions?: pulumi.Input<inputs.quicksight.AnalysisGaugeChartOptionsArgs>;
        /**
         * The general visual interactions setup for a visual.
         */
        interactions?: pulumi.Input<inputs.quicksight.AnalysisVisualInteractionOptionsArgs>;
        /**
         * The tooltip configuration of a `GaugeChartVisual` .
         */
        tooltipOptions?: pulumi.Input<inputs.quicksight.AnalysisTooltipOptionsArgs>;
        /**
         * The visual palette configuration of a `GaugeChartVisual` .
         */
        visualPalette?: pulumi.Input<inputs.quicksight.AnalysisVisualPaletteArgs>;
    }
    interface AnalysisGaugeChartFieldWellsArgs {
        /**
         * The target value field wells of a `GaugeChartVisual` .
         */
        targetValues?: pulumi.Input<pulumi.Input<inputs.quicksight.AnalysisMeasureFieldArgs>[]>;
        /**
         * The value field wells of a `GaugeChartVisual` .
         */
        values?: pulumi.Input<pulumi.Input<inputs.quicksight.AnalysisMeasureFieldArgs>[]>;
    }
    interface AnalysisGaugeChartOptionsArgs {
        /**
         * The arc configuration of a `GaugeChartVisual` .
         */
        arc?: pulumi.Input<inputs.quicksight.AnalysisArcConfigurationArgs>;
        /**
         * The arc axis configuration of a `GaugeChartVisual` .
         */
        arcAxis?: pulumi.Input<inputs.quicksight.AnalysisArcAxisConfigurationArgs>;
        /**
         * The comparison configuration of a `GaugeChartVisual` .
         */
        comparison?: pulumi.Input<inputs.quicksight.AnalysisComparisonConfigurationArgs>;
        /**
         * The options that determine the primary value display type.
         */
        primaryValueDisplayType?: pulumi.Input<enums.quicksight.AnalysisPrimaryValueDisplayType>;
        /**
         * The options that determine the primary value font configuration.
         */
        primaryValueFontConfiguration?: pulumi.Input<inputs.quicksight.AnalysisFontConfigurationArgs>;
    }
    interface AnalysisGaugeChartPrimaryValueConditionalFormattingArgs {
        /**
         * The conditional formatting of the primary value icon.
         */
        icon?: pulumi.Input<inputs.quicksight.AnalysisConditionalFormattingIconArgs>;
        /**
         * The conditional formatting of the primary value text color.
         */
        textColor?: pulumi.Input<inputs.quicksight.AnalysisConditionalFormattingColorArgs>;
    }
    interface AnalysisGaugeChartVisualArgs {
        /**
         * The list of custom actions that are configured for a visual.
         */
        actions?: pulumi.Input<pulumi.Input<inputs.quicksight.AnalysisVisualCustomActionArgs>[]>;
        /**
         * The configuration of a `GaugeChartVisual` .
         */
        chartConfiguration?: pulumi.Input<inputs.quicksight.AnalysisGaugeChartConfigurationArgs>;
        /**
         * The conditional formatting of a `GaugeChartVisual` .
         */
        conditionalFormatting?: pulumi.Input<inputs.quicksight.AnalysisGaugeChartConditionalFormattingArgs>;
        /**
         * The subtitle that is displayed on the visual.
         */
        subtitle?: pulumi.Input<inputs.quicksight.AnalysisVisualSubtitleLabelOptionsArgs>;
        /**
         * The title that is displayed on the visual.
         */
        title?: pulumi.Input<inputs.quicksight.AnalysisVisualTitleLabelOptionsArgs>;
        /**
         * The alt text for the visual.
         */
        visualContentAltText?: pulumi.Input<string>;
        /**
         * The unique identifier of a visual. This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers.
         */
        visualId: pulumi.Input<string>;
    }
    interface AnalysisGeospatialCategoricalColorArgs {
        /**
         * A list of categorical data colors for each category.
         */
        categoryDataColors: pulumi.Input<pulumi.Input<inputs.quicksight.AnalysisGeospatialCategoricalDataColorArgs>[]>;
        /**
         * The default opacity of a categorical color.
         */
        defaultOpacity?: pulumi.Input<number>;
        /**
         * The null data visualization settings.
         */
        nullDataSettings?: pulumi.Input<inputs.quicksight.AnalysisGeospatialNullDataSettingsArgs>;
        /**
         * The state of visibility for null data.
         */
        nullDataVisibility?: pulumi.Input<enums.quicksight.AnalysisVisibility>;
    }
    interface AnalysisGeospatialCategoricalDataColorArgs {
        /**
         * The color and opacity values for the category data color.
         */
        color: pulumi.Input<string>;
        /**
         * The data value for the category data color.
         */
        dataValue: pulumi.Input<string>;
    }
    interface AnalysisGeospatialCircleRadiusArgs {
        /**
         * The positive value for the radius of a circle.
         */
        radius?: pulumi.Input<number>;
    }
    interface AnalysisGeospatialCircleSymbolStyleArgs {
        /**
         * The radius of the circle.
         */
        circleRadius?: pulumi.Input<inputs.quicksight.AnalysisGeospatialCircleRadiusArgs>;
        /**
         * The color and opacity values for the fill color.
         */
        fillColor?: pulumi.Input<inputs.quicksight.AnalysisGeospatialColorArgs>;
        /**
         * The color and opacity values for the stroke color.
         */
        strokeColor?: pulumi.Input<inputs.quicksight.AnalysisGeospatialColorArgs>;
        /**
         * The width of the stroke (border).
         */
        strokeWidth?: pulumi.Input<inputs.quicksight.AnalysisGeospatialLineWidthArgs>;
    }
    interface AnalysisGeospatialColorArgs {
        /**
         * The visualization properties for the categorical color.
         */
        categorical?: pulumi.Input<inputs.quicksight.AnalysisGeospatialCategoricalColorArgs>;
        /**
         * The visualization properties for the gradient color.
         */
        gradient?: pulumi.Input<inputs.quicksight.AnalysisGeospatialGradientColorArgs>;
        /**
         * The visualization properties for the solid color.
         */
        solid?: pulumi.Input<inputs.quicksight.AnalysisGeospatialSolidColorArgs>;
    }
    interface AnalysisGeospatialCoordinateBoundsArgs {
        /**
         * The longitude of the east bound of the geospatial coordinate bounds.
         */
        east: pulumi.Input<number>;
        /**
         * The latitude of the north bound of the geospatial coordinate bounds.
         */
        north: pulumi.Input<number>;
        /**
         * The latitude of the south bound of the geospatial coordinate bounds.
         */
        south: pulumi.Input<number>;
        /**
         * The longitude of the west bound of the geospatial coordinate bounds.
         */
        west: pulumi.Input<number>;
    }
    interface AnalysisGeospatialDataSourceItemArgs {
        /**
         * The static file data source properties for the geospatial data.
         */
        staticFileDataSource?: pulumi.Input<inputs.quicksight.AnalysisGeospatialStaticFileSourceArgs>;
    }
    interface AnalysisGeospatialGradientColorArgs {
        /**
         * The default opacity for the gradient color.
         */
        defaultOpacity?: pulumi.Input<number>;
        /**
         * The null data visualization settings.
         */
        nullDataSettings?: pulumi.Input<inputs.quicksight.AnalysisGeospatialNullDataSettingsArgs>;
        /**
         * The state of visibility for null data.
         */
        nullDataVisibility?: pulumi.Input<enums.quicksight.AnalysisVisibility>;
        /**
         * A list of gradient step colors for the gradient.
         */
        stepColors: pulumi.Input<pulumi.Input<inputs.quicksight.AnalysisGeospatialGradientStepColorArgs>[]>;
    }
    interface AnalysisGeospatialGradientStepColorArgs {
        /**
         * The color and opacity values for the gradient step color.
         */
        color: pulumi.Input<string>;
        /**
         * The data value for the gradient step color.
         */
        dataValue: pulumi.Input<number>;
    }
    interface AnalysisGeospatialHeatmapColorScaleArgs {
        /**
         * The list of colors to be used in heatmap point style.
         */
        colors?: pulumi.Input<pulumi.Input<inputs.quicksight.AnalysisGeospatialHeatmapDataColorArgs>[]>;
    }
    interface AnalysisGeospatialHeatmapConfigurationArgs {
        /**
         * The color scale specification for the heatmap point style.
         */
        heatmapColor?: pulumi.Input<inputs.quicksight.AnalysisGeospatialHeatmapColorScaleArgs>;
    }
    interface AnalysisGeospatialHeatmapDataColorArgs {
        /**
         * The hex color to be used in the heatmap point style.
         */
        color: pulumi.Input<string>;
    }
    interface AnalysisGeospatialLayerColorFieldArgs {
        /**
         * A list of color dimension fields.
         */
        colorDimensionsFields?: pulumi.Input<pulumi.Input<inputs.quicksight.AnalysisDimensionFieldArgs>[]>;
        /**
         * A list of color measure fields.
         */
        colorValuesFields?: pulumi.Input<pulumi.Input<inputs.quicksight.AnalysisMeasureFieldArgs>[]>;
    }
    interface AnalysisGeospatialLayerDefinitionArgs {
        /**
         * The definition for a line layer.
         */
        lineLayer?: pulumi.Input<inputs.quicksight.AnalysisGeospatialLineLayerArgs>;
        /**
         * The definition for a point layer.
         */
        pointLayer?: pulumi.Input<inputs.quicksight.AnalysisGeospatialPointLayerArgs>;
        /**
         * The definition for a polygon layer.
         */
        polygonLayer?: pulumi.Input<inputs.quicksight.AnalysisGeospatialPolygonLayerArgs>;
    }
    interface AnalysisGeospatialLayerItemArgs {
        /**
         * A list of custom actions for a layer.
         */
        actions?: pulumi.Input<pulumi.Input<inputs.quicksight.AnalysisLayerCustomActionArgs>[]>;
        /**
         * The data source for the layer.
         */
        dataSource?: pulumi.Input<inputs.quicksight.AnalysisGeospatialDataSourceItemArgs>;
        /**
         * The join definition properties for a layer.
         */
        joinDefinition?: pulumi.Input<inputs.quicksight.AnalysisGeospatialLayerJoinDefinitionArgs>;
        /**
         * The label that is displayed for the layer.
         */
        label?: pulumi.Input<string>;
        /**
         * The definition properties for a layer.
         */
        layerDefinition?: pulumi.Input<inputs.quicksight.AnalysisGeospatialLayerDefinitionArgs>;
        /**
         * The ID of the layer.
         */
        layerId: pulumi.Input<string>;
        /**
         * The layer type.
         */
        layerType?: pulumi.Input<enums.quicksight.AnalysisGeospatialLayerType>;
        tooltip?: pulumi.Input<inputs.quicksight.AnalysisTooltipOptionsArgs>;
        /**
         * The state of visibility for the layer.
         */
        visibility?: pulumi.Input<enums.quicksight.AnalysisVisibility>;
    }
    interface AnalysisGeospatialLayerJoinDefinitionArgs {
        /**
         * The geospatial color field for the join definition.
         */
        colorField?: pulumi.Input<inputs.quicksight.AnalysisGeospatialLayerColorFieldArgs>;
        datasetKeyField?: pulumi.Input<inputs.quicksight.AnalysisUnaggregatedFieldArgs>;
        /**
         * The name of the field or property in the geospatial data source.
         */
        shapeKeyField?: pulumi.Input<string>;
    }
    interface AnalysisGeospatialLayerMapConfigurationArgs {
        interactions?: pulumi.Input<inputs.quicksight.AnalysisVisualInteractionOptionsArgs>;
        legend?: pulumi.Input<inputs.quicksight.AnalysisLegendOptionsArgs>;
        /**
         * The geospatial layers to visualize on the map.
         */
        mapLayers?: pulumi.Input<pulumi.Input<inputs.quicksight.AnalysisGeospatialLayerItemArgs>[]>;
        /**
         * The map state properties for the map.
         */
        mapState?: pulumi.Input<inputs.quicksight.AnalysisGeospatialMapStateArgs>;
        /**
         * The map style properties for the map.
         */
        mapStyle?: pulumi.Input<inputs.quicksight.AnalysisGeospatialMapStyleArgs>;
    }
    interface AnalysisGeospatialLineLayerArgs {
        /**
         * The visualization style for a line layer.
         */
        style: pulumi.Input<inputs.quicksight.AnalysisGeospatialLineStyleArgs>;
    }
    interface AnalysisGeospatialLineStyleArgs {
        /**
         * The symbol style for a line style.
         */
        lineSymbolStyle?: pulumi.Input<inputs.quicksight.AnalysisGeospatialLineSymbolStyleArgs>;
    }
    interface AnalysisGeospatialLineSymbolStyleArgs {
        /**
         * The color and opacity values for the fill color.
         */
        fillColor?: pulumi.Input<inputs.quicksight.AnalysisGeospatialColorArgs>;
        /**
         * The width value for a line.
         */
        lineWidth?: pulumi.Input<inputs.quicksight.AnalysisGeospatialLineWidthArgs>;
    }
    interface AnalysisGeospatialLineWidthArgs {
        /**
         * The positive value for the width of a line.
         */
        lineWidth?: pulumi.Input<number>;
    }
    interface AnalysisGeospatialMapAggregatedFieldWellsArgs {
        /**
         * The color field wells of a geospatial map.
         */
        colors?: pulumi.Input<pulumi.Input<inputs.quicksight.AnalysisDimensionFieldArgs>[]>;
        /**
         * The geospatial field wells of a geospatial map. Values are grouped by geospatial fields.
         */
        geospatial?: pulumi.Input<pulumi.Input<inputs.quicksight.AnalysisDimensionFieldArgs>[]>;
        /**
         * The size field wells of a geospatial map. Values are aggregated based on geospatial fields.
         */
        values?: pulumi.Input<pulumi.Input<inputs.quicksight.AnalysisMeasureFieldArgs>[]>;
    }
    interface AnalysisGeospatialMapConfigurationArgs {
        /**
         * The field wells of the visual.
         */
        fieldWells?: pulumi.Input<inputs.quicksight.AnalysisGeospatialMapFieldWellsArgs>;
        /**
         * The general visual interactions setup for a visual.
         */
        interactions?: pulumi.Input<inputs.quicksight.AnalysisVisualInteractionOptionsArgs>;
        /**
         * The legend display setup of the visual.
         */
        legend?: pulumi.Input<inputs.quicksight.AnalysisLegendOptionsArgs>;
        /**
         * The map style options of the geospatial map.
         */
        mapStyleOptions?: pulumi.Input<inputs.quicksight.AnalysisGeospatialMapStyleOptionsArgs>;
        /**
         * The point style options of the geospatial map.
         */
        pointStyleOptions?: pulumi.Input<inputs.quicksight.AnalysisGeospatialPointStyleOptionsArgs>;
        /**
         * The tooltip display setup of the visual.
         */
        tooltip?: pulumi.Input<inputs.quicksight.AnalysisTooltipOptionsArgs>;
        visualPalette?: pulumi.Input<inputs.quicksight.AnalysisVisualPaletteArgs>;
        /**
         * The window options of the geospatial map.
         */
        windowOptions?: pulumi.Input<inputs.quicksight.AnalysisGeospatialWindowOptionsArgs>;
    }
    interface AnalysisGeospatialMapFieldWellsArgs {
        /**
         * The aggregated field well for a geospatial map.
         */
        geospatialMapAggregatedFieldWells?: pulumi.Input<inputs.quicksight.AnalysisGeospatialMapAggregatedFieldWellsArgs>;
    }
    interface AnalysisGeospatialMapStateArgs {
        bounds?: pulumi.Input<inputs.quicksight.AnalysisGeospatialCoordinateBoundsArgs>;
        /**
         * Enables or disables map navigation for a map.
         */
        mapNavigation?: pulumi.Input<enums.quicksight.AnalysisGeospatialMapNavigation>;
    }
    interface AnalysisGeospatialMapStyleArgs {
        /**
         * The background color and opacity values for a map.
         */
        backgroundColor?: pulumi.Input<string>;
        /**
         * The selected base map style.
         */
        baseMapStyle?: pulumi.Input<enums.quicksight.AnalysisBaseMapStyleType>;
        /**
         * The state of visibility for the base map.
         */
        baseMapVisibility?: pulumi.Input<enums.quicksight.AnalysisVisibility>;
    }
    interface AnalysisGeospatialMapStyleOptionsArgs {
        /**
         * The base map style of the geospatial map.
         */
        baseMapStyle?: pulumi.Input<enums.quicksight.AnalysisBaseMapStyleType>;
    }
    interface AnalysisGeospatialMapVisualArgs {
        /**
         * The list of custom actions that are configured for a visual.
         */
        actions?: pulumi.Input<pulumi.Input<inputs.quicksight.AnalysisVisualCustomActionArgs>[]>;
        /**
         * The configuration settings of the visual.
         */
        chartConfiguration?: pulumi.Input<inputs.quicksight.AnalysisGeospatialMapConfigurationArgs>;
        /**
         * The column hierarchy that is used during drill-downs and drill-ups.
         */
        columnHierarchies?: pulumi.Input<pulumi.Input<inputs.quicksight.AnalysisColumnHierarchyArgs>[]>;
        /**
         * The subtitle that is displayed on the visual.
         */
        subtitle?: pulumi.Input<inputs.quicksight.AnalysisVisualSubtitleLabelOptionsArgs>;
        /**
         * The title that is displayed on the visual.
         */
        title?: pulumi.Input<inputs.quicksight.AnalysisVisualTitleLabelOptionsArgs>;
        /**
         * The alt text for the visual.
         */
        visualContentAltText?: pulumi.Input<string>;
        /**
         * The unique identifier of a visual. This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers..
         */
        visualId: pulumi.Input<string>;
    }
    interface AnalysisGeospatialNullDataSettingsArgs {
        /**
         * The symbol style for null data.
         */
        symbolStyle: pulumi.Input<inputs.quicksight.AnalysisGeospatialNullSymbolStyleArgs>;
    }
    interface AnalysisGeospatialNullSymbolStyleArgs {
        /**
         * The color and opacity values for the fill color.
         */
        fillColor?: pulumi.Input<string>;
        /**
         * The color and opacity values for the stroke color.
         */
        strokeColor?: pulumi.Input<string>;
        /**
         * The width of the border stroke.
         */
        strokeWidth?: pulumi.Input<number>;
    }
    interface AnalysisGeospatialPointLayerArgs {
        /**
         * The visualization style for a point layer.
         */
        style: pulumi.Input<inputs.quicksight.AnalysisGeospatialPointStyleArgs>;
    }
    interface AnalysisGeospatialPointStyleArgs {
        /**
         * The circle symbol style for a point layer.
         */
        circleSymbolStyle?: pulumi.Input<inputs.quicksight.AnalysisGeospatialCircleSymbolStyleArgs>;
    }
    interface AnalysisGeospatialPointStyleOptionsArgs {
        /**
         * The cluster marker configuration of the geospatial point style.
         */
        clusterMarkerConfiguration?: pulumi.Input<inputs.quicksight.AnalysisClusterMarkerConfigurationArgs>;
        /**
         * The heatmap configuration of the geospatial point style.
         */
        heatmapConfiguration?: pulumi.Input<inputs.quicksight.AnalysisGeospatialHeatmapConfigurationArgs>;
        /**
         * The selected point styles (point, cluster) of the geospatial map.
         */
        selectedPointStyle?: pulumi.Input<enums.quicksight.AnalysisGeospatialSelectedPointStyle>;
    }
    interface AnalysisGeospatialPolygonLayerArgs {
        /**
         * The visualization style for a polygon layer.
         */
        style: pulumi.Input<inputs.quicksight.AnalysisGeospatialPolygonStyleArgs>;
    }
    interface AnalysisGeospatialPolygonStyleArgs {
        /**
         * The polygon symbol style for a polygon layer.
         */
        polygonSymbolStyle?: pulumi.Input<inputs.quicksight.AnalysisGeospatialPolygonSymbolStyleArgs>;
    }
    interface AnalysisGeospatialPolygonSymbolStyleArgs {
        /**
         * The color and opacity values for the fill color.
         */
        fillColor?: pulumi.Input<inputs.quicksight.AnalysisGeospatialColorArgs>;
        /**
         * The color and opacity values for the stroke color.
         */
        strokeColor?: pulumi.Input<inputs.quicksight.AnalysisGeospatialColorArgs>;
        /**
         * The width of the border stroke.
         */
        strokeWidth?: pulumi.Input<inputs.quicksight.AnalysisGeospatialLineWidthArgs>;
    }
    /**
     * Describes the properties for a solid color
     */
    interface AnalysisGeospatialSolidColorArgs {
        /**
         * The color and opacity values for the color.
         */
        color: pulumi.Input<string>;
        /**
         * Enables and disables the view state of the color.
         */
        state?: pulumi.Input<enums.quicksight.AnalysisGeospatialColorState>;
    }
    interface AnalysisGeospatialStaticFileSourceArgs {
        /**
         * The ID of the static file.
         */
        staticFileId: pulumi.Input<string>;
    }
    interface AnalysisGeospatialWindowOptionsArgs {
        /**
         * The bounds options (north, south, west, east) of the geospatial window options.
         */
        bounds?: pulumi.Input<inputs.quicksight.AnalysisGeospatialCoordinateBoundsArgs>;
        /**
         * The map zoom modes (manual, auto) of the geospatial window options.
         */
        mapZoomMode?: pulumi.Input<enums.quicksight.AnalysisMapZoomMode>;
    }
    interface AnalysisGlobalTableBorderOptionsArgs {
        /**
         * Determines the options for side specific border.
         */
        sideSpecificBorder?: pulumi.Input<inputs.quicksight.AnalysisTableSideBorderOptionsArgs>;
        /**
         * Determines the options for uniform border.
         */
        uniformBorder?: pulumi.Input<inputs.quicksight.AnalysisTableBorderOptionsArgs>;
    }
    interface AnalysisGradientColorArgs {
        /**
         * The list of gradient color stops.
         */
        stops?: pulumi.Input<pulumi.Input<inputs.quicksight.AnalysisGradientStopArgs>[]>;
    }
    interface AnalysisGradientStopArgs {
        /**
         * Determines the color.
         */
        color?: pulumi.Input<string>;
        /**
         * Determines the data value.
         */
        dataValue?: pulumi.Input<number>;
        /**
         * Determines gradient offset value.
         */
        gradientOffset: pulumi.Input<number>;
    }
    interface AnalysisGridLayoutCanvasSizeOptionsArgs {
        /**
         * The options that determine the sizing of the canvas used in a grid layout.
         */
        screenCanvasSizeOptions?: pulumi.Input<inputs.quicksight.AnalysisGridLayoutScreenCanvasSizeOptionsArgs>;
    }
    interface AnalysisGridLayoutConfigurationArgs {
        canvasSizeOptions?: pulumi.Input<inputs.quicksight.AnalysisGridLayoutCanvasSizeOptionsArgs>;
        /**
         * The elements that are included in a grid layout.
         */
        elements: pulumi.Input<pulumi.Input<inputs.quicksight.AnalysisGridLayoutElementArgs>[]>;
    }
    interface AnalysisGridLayoutElementArgs {
        /**
         * The column index for the upper left corner of an element.
         */
        columnIndex?: pulumi.Input<number>;
        /**
         * The width of a grid element expressed as a number of grid columns.
         */
        columnSpan: pulumi.Input<number>;
        /**
         * A unique identifier for an element within a grid layout.
         */
        elementId: pulumi.Input<string>;
        /**
         * The type of element.
         */
        elementType: pulumi.Input<enums.quicksight.AnalysisLayoutElementType>;
        /**
         * The row index for the upper left corner of an element.
         */
        rowIndex?: pulumi.Input<number>;
        /**
         * The height of a grid element expressed as a number of grid rows.
         */
        rowSpan: pulumi.Input<number>;
    }
    interface AnalysisGridLayoutScreenCanvasSizeOptionsArgs {
        /**
         * String based length that is composed of value and unit in px
         */
        optimizedViewPortWidth?: pulumi.Input<string>;
        /**
         * This value determines the layout behavior when the viewport is resized.
         *
         * - `FIXED` : A fixed width will be used when optimizing the layout. In the Amazon QuickSight console, this option is called `Classic` .
         * - `RESPONSIVE` : The width of the canvas will be responsive and optimized to the view port. In the Amazon QuickSight console, this option is called `Tiled` .
         */
        resizeOption: pulumi.Input<enums.quicksight.AnalysisResizeOption>;
    }
    interface AnalysisGrowthRateComputationArgs {
        /**
         * The ID for a computation.
         */
        computationId: pulumi.Input<string>;
        /**
         * The name of a computation.
         */
        name?: pulumi.Input<string>;
        /**
         * The period size setup of a growth rate computation.
         */
        periodSize?: pulumi.Input<number>;
        /**
         * The time field that is used in a computation.
         */
        time?: pulumi.Input<inputs.quicksight.AnalysisDimensionFieldArgs>;
        /**
         * The value field that is used in a computation.
         */
        value?: pulumi.Input<inputs.quicksight.AnalysisMeasureFieldArgs>;
    }
    interface AnalysisHeaderFooterSectionConfigurationArgs {
        /**
         * The layout configuration of the header or footer section.
         */
        layout: pulumi.Input<inputs.quicksight.AnalysisSectionLayoutConfigurationArgs>;
        /**
         * The unique identifier of the header or footer section.
         */
        sectionId: pulumi.Input<string>;
        /**
         * The style options of a header or footer section.
         */
        style?: pulumi.Input<inputs.quicksight.AnalysisSectionStyleArgs>;
    }
    interface AnalysisHeatMapAggregatedFieldWellsArgs {
        /**
         * The columns field well of a heat map.
         */
        columns?: pulumi.Input<pulumi.Input<inputs.quicksight.AnalysisDimensionFieldArgs>[]>;
        /**
         * The rows field well of a heat map.
         */
        rows?: pulumi.Input<pulumi.Input<inputs.quicksight.AnalysisDimensionFieldArgs>[]>;
        /**
         * The values field well of a heat map.
         */
        values?: pulumi.Input<pulumi.Input<inputs.quicksight.AnalysisMeasureFieldArgs>[]>;
    }
    interface AnalysisHeatMapConfigurationArgs {
        /**
         * The color options (gradient color, point of divergence) in a heat map.
         */
        colorScale?: pulumi.Input<inputs.quicksight.AnalysisColorScaleArgs>;
        /**
         * The label options of the column that is displayed in a heat map.
         */
        columnLabelOptions?: pulumi.Input<inputs.quicksight.AnalysisChartAxisLabelOptionsArgs>;
        /**
         * The options that determine if visual data labels are displayed.
         */
        dataLabels?: pulumi.Input<inputs.quicksight.AnalysisDataLabelOptionsArgs>;
        /**
         * The field wells of the visual.
         */
        fieldWells?: pulumi.Input<inputs.quicksight.AnalysisHeatMapFieldWellsArgs>;
        /**
         * The general visual interactions setup for a visual.
         */
        interactions?: pulumi.Input<inputs.quicksight.AnalysisVisualInteractionOptionsArgs>;
        /**
         * The legend display setup of the visual.
         */
        legend?: pulumi.Input<inputs.quicksight.AnalysisLegendOptionsArgs>;
        /**
         * The label options of the row that is displayed in a `heat map` .
         */
        rowLabelOptions?: pulumi.Input<inputs.quicksight.AnalysisChartAxisLabelOptionsArgs>;
        /**
         * The sort configuration of a heat map.
         */
        sortConfiguration?: pulumi.Input<inputs.quicksight.AnalysisHeatMapSortConfigurationArgs>;
        /**
         * The tooltip display setup of the visual.
         */
        tooltip?: pulumi.Input<inputs.quicksight.AnalysisTooltipOptionsArgs>;
    }
    interface AnalysisHeatMapFieldWellsArgs {
        /**
         * The aggregated field wells of a heat map.
         */
        heatMapAggregatedFieldWells?: pulumi.Input<inputs.quicksight.AnalysisHeatMapAggregatedFieldWellsArgs>;
    }
    interface AnalysisHeatMapSortConfigurationArgs {
        /**
         * The limit on the number of columns that are displayed in a heat map.
         */
        heatMapColumnItemsLimitConfiguration?: pulumi.Input<inputs.quicksight.AnalysisItemsLimitConfigurationArgs>;
        /**
         * The column sort configuration for heat map for columns that aren't a part of a field well.
         */
        heatMapColumnSort?: pulumi.Input<pulumi.Input<inputs.quicksight.AnalysisFieldSortOptionsArgs>[]>;
        /**
         * The limit on the number of rows that are displayed in a heat map.
         */
        heatMapRowItemsLimitConfiguration?: pulumi.Input<inputs.quicksight.AnalysisItemsLimitConfigurationArgs>;
        /**
         * The field sort configuration of the rows fields.
         */
        heatMapRowSort?: pulumi.Input<pulumi.Input<inputs.quicksight.AnalysisFieldSortOptionsArgs>[]>;
    }
    interface AnalysisHeatMapVisualArgs {
        /**
         * The list of custom actions that are configured for a visual.
         */
        actions?: pulumi.Input<pulumi.Input<inputs.quicksight.AnalysisVisualCustomActionArgs>[]>;
        /**
         * The configuration of a heat map.
         */
        chartConfiguration?: pulumi.Input<inputs.quicksight.AnalysisHeatMapConfigurationArgs>;
        /**
         * The column hierarchy that is used during drill-downs and drill-ups.
         */
        columnHierarchies?: pulumi.Input<pulumi.Input<inputs.quicksight.AnalysisColumnHierarchyArgs>[]>;
        /**
         * The subtitle that is displayed on the visual.
         */
        subtitle?: pulumi.Input<inputs.quicksight.AnalysisVisualSubtitleLabelOptionsArgs>;
        /**
         * The title that is displayed on the visual.
         */
        title?: pulumi.Input<inputs.quicksight.AnalysisVisualTitleLabelOptionsArgs>;
        /**
         * The alt text for the visual.
         */
        visualContentAltText?: pulumi.Input<string>;
        /**
         * The unique identifier of a visual. This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers.
         */
        visualId: pulumi.Input<string>;
    }
    interface AnalysisHistogramAggregatedFieldWellsArgs {
        /**
         * The value field wells of a histogram. Values are aggregated by `COUNT` or `DISTINCT_COUNT` .
         */
        values?: pulumi.Input<pulumi.Input<inputs.quicksight.AnalysisMeasureFieldArgs>[]>;
    }
    interface AnalysisHistogramBinOptionsArgs {
        /**
         * The options that determine the bin count of a histogram.
         */
        binCount?: pulumi.Input<inputs.quicksight.AnalysisBinCountOptionsArgs>;
        /**
         * The options that determine the bin width of a histogram.
         */
        binWidth?: pulumi.Input<inputs.quicksight.AnalysisBinWidthOptionsArgs>;
        /**
         * The options that determine the selected bin type.
         */
        selectedBinType?: pulumi.Input<enums.quicksight.AnalysisHistogramBinType>;
        /**
         * The options that determine the bin start value.
         */
        startValue?: pulumi.Input<number>;
    }
    interface AnalysisHistogramConfigurationArgs {
        /**
         * The options that determine the presentation of histogram bins.
         */
        binOptions?: pulumi.Input<inputs.quicksight.AnalysisHistogramBinOptionsArgs>;
        /**
         * The data label configuration of a histogram.
         */
        dataLabels?: pulumi.Input<inputs.quicksight.AnalysisDataLabelOptionsArgs>;
        /**
         * The field well configuration of a histogram.
         */
        fieldWells?: pulumi.Input<inputs.quicksight.AnalysisHistogramFieldWellsArgs>;
        /**
         * The general visual interactions setup for a visual.
         */
        interactions?: pulumi.Input<inputs.quicksight.AnalysisVisualInteractionOptionsArgs>;
        /**
         * The tooltip configuration of a histogram.
         */
        tooltip?: pulumi.Input<inputs.quicksight.AnalysisTooltipOptionsArgs>;
        /**
         * The visual palette configuration of a histogram.
         */
        visualPalette?: pulumi.Input<inputs.quicksight.AnalysisVisualPaletteArgs>;
        /**
         * The options that determine the presentation of the x-axis.
         */
        xAxisDisplayOptions?: pulumi.Input<inputs.quicksight.AnalysisAxisDisplayOptionsArgs>;
        /**
         * The options that determine the presentation of the x-axis label.
         */
        xAxisLabelOptions?: pulumi.Input<inputs.quicksight.AnalysisChartAxisLabelOptionsArgs>;
        /**
         * The options that determine the presentation of the y-axis.
         */
        yAxisDisplayOptions?: pulumi.Input<inputs.quicksight.AnalysisAxisDisplayOptionsArgs>;
    }
    interface AnalysisHistogramFieldWellsArgs {
        /**
         * The field well configuration of a histogram.
         */
        histogramAggregatedFieldWells?: pulumi.Input<inputs.quicksight.AnalysisHistogramAggregatedFieldWellsArgs>;
    }
    interface AnalysisHistogramVisualArgs {
        /**
         * The list of custom actions that are configured for a visual.
         */
        actions?: pulumi.Input<pulumi.Input<inputs.quicksight.AnalysisVisualCustomActionArgs>[]>;
        /**
         * The configuration for a `HistogramVisual` .
         */
        chartConfiguration?: pulumi.Input<inputs.quicksight.AnalysisHistogramConfigurationArgs>;
        /**
         * The subtitle that is displayed on the visual.
         */
        subtitle?: pulumi.Input<inputs.quicksight.AnalysisVisualSubtitleLabelOptionsArgs>;
        /**
         * The title that is displayed on the visual.
         */
        title?: pulumi.Input<inputs.quicksight.AnalysisVisualTitleLabelOptionsArgs>;
        /**
         * The alt text for the visual.
         */
        visualContentAltText?: pulumi.Input<string>;
        /**
         * The unique identifier of a visual. This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers.
         */
        visualId: pulumi.Input<string>;
    }
    interface AnalysisImageCustomActionArgs {
        /**
         * A list of `ImageCustomActionOperations` .
         *
         * This is a union type structure. For this structure to be valid, only one of the attributes can be defined.
         */
        actionOperations: pulumi.Input<pulumi.Input<inputs.quicksight.AnalysisImageCustomActionOperationArgs>[]>;
        /**
         * The ID of the custom action.
         */
        customActionId: pulumi.Input<string>;
        /**
         * The name of the custom action.
         */
        name: pulumi.Input<string>;
        /**
         * The status of the custom action.
         */
        status?: pulumi.Input<enums.quicksight.AnalysisWidgetStatus>;
        /**
         * The trigger of the `VisualCustomAction` .
         *
         * Valid values are defined as follows:
         *
         * - `CLICK` : Initiates a custom action by a left pointer click on a data point.
         * - `MENU` : Initiates a custom action by right pointer click from the menu.
         */
        trigger: pulumi.Input<enums.quicksight.AnalysisImageCustomActionTrigger>;
    }
    interface AnalysisImageCustomActionOperationArgs {
        navigationOperation?: pulumi.Input<inputs.quicksight.AnalysisCustomActionNavigationOperationArgs>;
        setParametersOperation?: pulumi.Input<inputs.quicksight.AnalysisCustomActionSetParametersOperationArgs>;
        urlOperation?: pulumi.Input<inputs.quicksight.AnalysisCustomActionUrlOperationArgs>;
    }
    interface AnalysisImageInteractionOptionsArgs {
        /**
         * The menu options for the image.
         */
        imageMenuOption?: pulumi.Input<inputs.quicksight.AnalysisImageMenuOptionArgs>;
    }
    interface AnalysisImageMenuOptionArgs {
        /**
         * The availability status of the image menu. If the value of this property is set to `ENABLED` , dashboard readers can interact with the image menu.
         */
        availabilityStatus?: pulumi.Input<enums.quicksight.AnalysisDashboardBehavior>;
    }
    interface AnalysisImageStaticFileArgs {
        /**
         * The source of the image static file.
         */
        source?: pulumi.Input<inputs.quicksight.AnalysisStaticFileSourceArgs>;
        /**
         * The ID of the static file that contains an image.
         */
        staticFileId: pulumi.Input<string>;
    }
    interface AnalysisInnerFilterArgs {
        /**
         * A `CategoryInnerFilter` filters text values for the `NestedFilter` .
         */
        categoryInnerFilter?: pulumi.Input<inputs.quicksight.AnalysisCategoryInnerFilterArgs>;
    }
    interface AnalysisInsightConfigurationArgs {
        /**
         * The computations configurations of the insight visual
         */
        computations?: pulumi.Input<pulumi.Input<inputs.quicksight.AnalysisComputationArgs>[]>;
        /**
         * The custom narrative of the insight visual.
         */
        customNarrative?: pulumi.Input<inputs.quicksight.AnalysisCustomNarrativeOptionsArgs>;
        /**
         * The general visual interactions setup for a visual.
         */
        interactions?: pulumi.Input<inputs.quicksight.AnalysisVisualInteractionOptionsArgs>;
    }
    interface AnalysisInsightVisualArgs {
        /**
         * The list of custom actions that are configured for a visual.
         */
        actions?: pulumi.Input<pulumi.Input<inputs.quicksight.AnalysisVisualCustomActionArgs>[]>;
        /**
         * The dataset that is used in the insight visual.
         */
        dataSetIdentifier: pulumi.Input<string>;
        /**
         * The configuration of an insight visual.
         */
        insightConfiguration?: pulumi.Input<inputs.quicksight.AnalysisInsightConfigurationArgs>;
        /**
         * The subtitle that is displayed on the visual.
         */
        subtitle?: pulumi.Input<inputs.quicksight.AnalysisVisualSubtitleLabelOptionsArgs>;
        /**
         * The title that is displayed on the visual.
         */
        title?: pulumi.Input<inputs.quicksight.AnalysisVisualTitleLabelOptionsArgs>;
        /**
         * The alt text for the visual.
         */
        visualContentAltText?: pulumi.Input<string>;
        /**
         * The unique identifier of a visual. This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers.
         */
        visualId: pulumi.Input<string>;
    }
    interface AnalysisIntegerDefaultValuesArgs {
        /**
         * The dynamic value of the `IntegerDefaultValues` . Different defaults are displayed according to users, groups, and values mapping.
         */
        dynamicValue?: pulumi.Input<inputs.quicksight.AnalysisDynamicDefaultValueArgs>;
        /**
         * The static values of the `IntegerDefaultValues` .
         */
        staticValues?: pulumi.Input<pulumi.Input<number>[]>;
    }
    /**
     * <p>An integer parameter.</p>
     */
    interface AnalysisIntegerParameterArgs {
        /**
         * <p>The name of the integer parameter.</p>
         */
        name: pulumi.Input<string>;
        /**
         * <p>The values for the integer parameter.</p>
         */
        values: pulumi.Input<pulumi.Input<number>[]>;
    }
    interface AnalysisIntegerParameterDeclarationArgs {
        /**
         * The default values of a parameter. If the parameter is a single-value parameter, a maximum of one default value can be provided.
         */
        defaultValues?: pulumi.Input<inputs.quicksight.AnalysisIntegerDefaultValuesArgs>;
        mappedDataSetParameters?: pulumi.Input<pulumi.Input<inputs.quicksight.AnalysisMappedDataSetParameterArgs>[]>;
        /**
         * The name of the parameter that is being declared.
         */
        name: pulumi.Input<string>;
        /**
         * The value type determines whether the parameter is a single-value or multi-value parameter.
         */
        parameterValueType: pulumi.Input<enums.quicksight.AnalysisParameterValueType>;
        /**
         * A parameter declaration for the `Integer` data type.
         */
        valueWhenUnset?: pulumi.Input<inputs.quicksight.AnalysisIntegerValueWhenUnsetConfigurationArgs>;
    }
    interface AnalysisIntegerValueWhenUnsetConfigurationArgs {
        /**
         * A custom value that's used when the value of a parameter isn't set.
         */
        customValue?: pulumi.Input<number>;
        /**
         * The built-in options for default values. The value can be one of the following:
         *
         * - `RECOMMENDED` : The recommended value.
         * - `NULL` : The `NULL` value.
         */
        valueWhenUnsetOption?: pulumi.Input<enums.quicksight.AnalysisValueWhenUnsetOption>;
    }
    interface AnalysisItemsLimitConfigurationArgs {
        /**
         * The limit on how many items of a field are showed in the chart. For example, the number of slices that are displayed in a pie chart.
         */
        itemsLimit?: pulumi.Input<number>;
        /**
         * The `Show other` of an axis in the chart. Choose one of the following options:
         *
         * - `INCLUDE`
         * - `EXCLUDE`
         */
        otherCategories?: pulumi.Input<enums.quicksight.AnalysisOtherCategories>;
    }
    interface AnalysisKpiActualValueConditionalFormattingArgs {
        /**
         * The conditional formatting of the actual value's icon.
         */
        icon?: pulumi.Input<inputs.quicksight.AnalysisConditionalFormattingIconArgs>;
        /**
         * The conditional formatting of the actual value's text color.
         */
        textColor?: pulumi.Input<inputs.quicksight.AnalysisConditionalFormattingColorArgs>;
    }
    interface AnalysisKpiComparisonValueConditionalFormattingArgs {
        /**
         * The conditional formatting of the comparison value's icon.
         */
        icon?: pulumi.Input<inputs.quicksight.AnalysisConditionalFormattingIconArgs>;
        /**
         * The conditional formatting of the comparison value's text color.
         */
        textColor?: pulumi.Input<inputs.quicksight.AnalysisConditionalFormattingColorArgs>;
    }
    interface AnalysisKpiConditionalFormattingArgs {
        /**
         * The conditional formatting options of a KPI visual.
         */
        conditionalFormattingOptions?: pulumi.Input<pulumi.Input<inputs.quicksight.AnalysisKpiConditionalFormattingOptionArgs>[]>;
    }
    interface AnalysisKpiConditionalFormattingOptionArgs {
        /**
         * The conditional formatting for the actual value of a KPI visual.
         */
        actualValue?: pulumi.Input<inputs.quicksight.AnalysisKpiActualValueConditionalFormattingArgs>;
        /**
         * The conditional formatting for the comparison value of a KPI visual.
         */
        comparisonValue?: pulumi.Input<inputs.quicksight.AnalysisKpiComparisonValueConditionalFormattingArgs>;
        /**
         * The conditional formatting for the primary value of a KPI visual.
         */
        primaryValue?: pulumi.Input<inputs.quicksight.AnalysisKpiPrimaryValueConditionalFormattingArgs>;
        /**
         * The conditional formatting for the progress bar of a KPI visual.
         */
        progressBar?: pulumi.Input<inputs.quicksight.AnalysisKpiProgressBarConditionalFormattingArgs>;
    }
    interface AnalysisKpiConfigurationArgs {
        /**
         * The field well configuration of a KPI visual.
         */
        fieldWells?: pulumi.Input<inputs.quicksight.AnalysisKpiFieldWellsArgs>;
        /**
         * The general visual interactions setup for a visual.
         */
        interactions?: pulumi.Input<inputs.quicksight.AnalysisVisualInteractionOptionsArgs>;
        /**
         * The options that determine the presentation of a KPI visual.
         */
        kpiOptions?: pulumi.Input<inputs.quicksight.AnalysisKpiOptionsArgs>;
        /**
         * The sort configuration of a KPI visual.
         */
        sortConfiguration?: pulumi.Input<inputs.quicksight.AnalysisKpiSortConfigurationArgs>;
    }
    interface AnalysisKpiFieldWellsArgs {
        /**
         * The target value field wells of a KPI visual.
         */
        targetValues?: pulumi.Input<pulumi.Input<inputs.quicksight.AnalysisMeasureFieldArgs>[]>;
        /**
         * The trend group field wells of a KPI visual.
         */
        trendGroups?: pulumi.Input<pulumi.Input<inputs.quicksight.AnalysisDimensionFieldArgs>[]>;
        /**
         * The value field wells of a KPI visual.
         */
        values?: pulumi.Input<pulumi.Input<inputs.quicksight.AnalysisMeasureFieldArgs>[]>;
    }
    interface AnalysisKpiOptionsArgs {
        /**
         * The comparison configuration of a KPI visual.
         */
        comparison?: pulumi.Input<inputs.quicksight.AnalysisComparisonConfigurationArgs>;
        /**
         * The options that determine the primary value display type.
         */
        primaryValueDisplayType?: pulumi.Input<enums.quicksight.AnalysisPrimaryValueDisplayType>;
        /**
         * The options that determine the primary value font configuration.
         */
        primaryValueFontConfiguration?: pulumi.Input<inputs.quicksight.AnalysisFontConfigurationArgs>;
        /**
         * The options that determine the presentation of the progress bar of a KPI visual.
         */
        progressBar?: pulumi.Input<inputs.quicksight.AnalysisProgressBarOptionsArgs>;
        /**
         * The options that determine the presentation of the secondary value of a KPI visual.
         */
        secondaryValue?: pulumi.Input<inputs.quicksight.AnalysisSecondaryValueOptionsArgs>;
        /**
         * The options that determine the secondary value font configuration.
         */
        secondaryValueFontConfiguration?: pulumi.Input<inputs.quicksight.AnalysisFontConfigurationArgs>;
        /**
         * The options that determine the visibility, color, type, and tooltip visibility of the sparkline of a KPI visual.
         */
        sparkline?: pulumi.Input<inputs.quicksight.AnalysisKpiSparklineOptionsArgs>;
        /**
         * The options that determine the presentation of trend arrows in a KPI visual.
         */
        trendArrows?: pulumi.Input<inputs.quicksight.AnalysisTrendArrowOptionsArgs>;
        /**
         * The options that determine the layout a KPI visual.
         */
        visualLayoutOptions?: pulumi.Input<inputs.quicksight.AnalysisKpiVisualLayoutOptionsArgs>;
    }
    interface AnalysisKpiPrimaryValueConditionalFormattingArgs {
        /**
         * The conditional formatting of the primary value's icon.
         */
        icon?: pulumi.Input<inputs.quicksight.AnalysisConditionalFormattingIconArgs>;
        /**
         * The conditional formatting of the primary value's text color.
         */
        textColor?: pulumi.Input<inputs.quicksight.AnalysisConditionalFormattingColorArgs>;
    }
    interface AnalysisKpiProgressBarConditionalFormattingArgs {
        /**
         * The conditional formatting of the progress bar's foreground color.
         */
        foregroundColor?: pulumi.Input<inputs.quicksight.AnalysisConditionalFormattingColorArgs>;
    }
    interface AnalysisKpiSortConfigurationArgs {
        /**
         * The sort configuration of the trend group fields.
         */
        trendGroupSort?: pulumi.Input<pulumi.Input<inputs.quicksight.AnalysisFieldSortOptionsArgs>[]>;
    }
    interface AnalysisKpiSparklineOptionsArgs {
        /**
         * The color of the sparkline.
         */
        color?: pulumi.Input<string>;
        /**
         * The tooltip visibility of the sparkline.
         */
        tooltipVisibility?: pulumi.Input<enums.quicksight.AnalysisVisibility>;
        /**
         * The type of the sparkline.
         */
        type: pulumi.Input<enums.quicksight.AnalysisKpiSparklineType>;
        /**
         * The visibility of the sparkline.
         */
        visibility?: pulumi.Input<enums.quicksight.AnalysisVisibility>;
    }
    interface AnalysisKpiVisualArgs {
        /**
         * The list of custom actions that are configured for a visual.
         */
        actions?: pulumi.Input<pulumi.Input<inputs.quicksight.AnalysisVisualCustomActionArgs>[]>;
        /**
         * The configuration of a KPI visual.
         */
        chartConfiguration?: pulumi.Input<inputs.quicksight.AnalysisKpiConfigurationArgs>;
        /**
         * The column hierarchy that is used during drill-downs and drill-ups.
         */
        columnHierarchies?: pulumi.Input<pulumi.Input<inputs.quicksight.AnalysisColumnHierarchyArgs>[]>;
        /**
         * The conditional formatting of a KPI visual.
         */
        conditionalFormatting?: pulumi.Input<inputs.quicksight.AnalysisKpiConditionalFormattingArgs>;
        /**
         * The subtitle that is displayed on the visual.
         */
        subtitle?: pulumi.Input<inputs.quicksight.AnalysisVisualSubtitleLabelOptionsArgs>;
        /**
         * The title that is displayed on the visual.
         */
        title?: pulumi.Input<inputs.quicksight.AnalysisVisualTitleLabelOptionsArgs>;
        /**
         * The alt text for the visual.
         */
        visualContentAltText?: pulumi.Input<string>;
        /**
         * The unique identifier of a visual. This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers.
         */
        visualId: pulumi.Input<string>;
    }
    interface AnalysisKpiVisualLayoutOptionsArgs {
        /**
         * The standard layout of the KPI visual.
         */
        standardLayout?: pulumi.Input<inputs.quicksight.AnalysisKpiVisualStandardLayoutArgs>;
    }
    interface AnalysisKpiVisualStandardLayoutArgs {
        /**
         * The standard layout type.
         */
        type: pulumi.Input<enums.quicksight.AnalysisKpiVisualStandardLayoutType>;
    }
    interface AnalysisLabelOptionsArgs {
        /**
         * The text for the label.
         */
        customLabel?: pulumi.Input<string>;
        /**
         * The font configuration of the label.
         */
        fontConfiguration?: pulumi.Input<inputs.quicksight.AnalysisFontConfigurationArgs>;
        /**
         * Determines whether or not the label is visible.
         */
        visibility?: pulumi.Input<enums.quicksight.AnalysisVisibility>;
    }
    interface AnalysisLayerCustomActionArgs {
        /**
         * A list of `LayerCustomActionOperations` .
         *
         * This is a union type structure. For this structure to be valid, only one of the attributes can be defined.
         */
        actionOperations: pulumi.Input<pulumi.Input<inputs.quicksight.AnalysisLayerCustomActionOperationArgs>[]>;
        /**
         * The ID of the custom action.
         */
        customActionId: pulumi.Input<string>;
        /**
         * The name of the custom action.
         */
        name: pulumi.Input<string>;
        /**
         * The status of the `LayerCustomAction` .
         */
        status?: pulumi.Input<enums.quicksight.AnalysisWidgetStatus>;
        /**
         * The trigger of the `LayerCustomAction` .
         *
         * Valid values are defined as follows:
         *
         * - `DATA_POINT_CLICK` : Initiates a custom action by a left pointer click on a data point.
         * - `DATA_POINT_MENU` : Initiates a custom action by right pointer click from the menu.
         */
        trigger: pulumi.Input<enums.quicksight.AnalysisLayerCustomActionTrigger>;
    }
    interface AnalysisLayerCustomActionOperationArgs {
        filterOperation?: pulumi.Input<inputs.quicksight.AnalysisCustomActionFilterOperationArgs>;
        navigationOperation?: pulumi.Input<inputs.quicksight.AnalysisCustomActionNavigationOperationArgs>;
        setParametersOperation?: pulumi.Input<inputs.quicksight.AnalysisCustomActionSetParametersOperationArgs>;
        urlOperation?: pulumi.Input<inputs.quicksight.AnalysisCustomActionUrlOperationArgs>;
    }
    interface AnalysisLayerMapVisualArgs {
        /**
         * The configuration settings of the visual.
         */
        chartConfiguration?: pulumi.Input<inputs.quicksight.AnalysisGeospatialLayerMapConfigurationArgs>;
        /**
         * The dataset that is used to create the layer map visual. You can't create a visual without a dataset.
         */
        dataSetIdentifier: pulumi.Input<string>;
        subtitle?: pulumi.Input<inputs.quicksight.AnalysisVisualSubtitleLabelOptionsArgs>;
        title?: pulumi.Input<inputs.quicksight.AnalysisVisualTitleLabelOptionsArgs>;
        /**
         * The alt text for the visual.
         */
        visualContentAltText?: pulumi.Input<string>;
        /**
         * The ID of the visual.
         */
        visualId: pulumi.Input<string>;
    }
    interface AnalysisLayoutArgs {
        /**
         * The configuration that determines what the type of layout for a sheet.
         */
        configuration: pulumi.Input<inputs.quicksight.AnalysisLayoutConfigurationArgs>;
    }
    interface AnalysisLayoutConfigurationArgs {
        /**
         * A free-form is optimized for a fixed width and has more control over the exact placement of layout elements.
         */
        freeFormLayout?: pulumi.Input<inputs.quicksight.AnalysisFreeFormLayoutConfigurationArgs>;
        /**
         * A type of layout that can be used on a sheet. In a grid layout, visuals snap to a grid with standard spacing and alignment. Dashboards are displayed as designed, with options to fit to screen or view at actual size. A grid layout can be configured to behave in one of two ways when the viewport is resized: `FIXED` or `RESPONSIVE` .
         */
        gridLayout?: pulumi.Input<inputs.quicksight.AnalysisGridLayoutConfigurationArgs>;
        /**
         * A section based layout organizes visuals into multiple sections and has customized header, footer and page break.
         */
        sectionBasedLayout?: pulumi.Input<inputs.quicksight.AnalysisSectionBasedLayoutConfigurationArgs>;
    }
    interface AnalysisLegendOptionsArgs {
        /**
         * String based length that is composed of value and unit in px
         */
        height?: pulumi.Input<string>;
        /**
         * The positions for the legend. Choose one of the following options:
         *
         * - `AUTO`
         * - `RIGHT`
         * - `BOTTOM`
         * - `LEFT`
         */
        position?: pulumi.Input<enums.quicksight.AnalysisLegendPosition>;
        /**
         * The custom title for the legend.
         */
        title?: pulumi.Input<inputs.quicksight.AnalysisLabelOptionsArgs>;
        valueFontConfiguration?: pulumi.Input<inputs.quicksight.AnalysisFontConfigurationArgs>;
        /**
         * Determines whether or not the legend is visible.
         */
        visibility?: pulumi.Input<enums.quicksight.AnalysisVisibility>;
        /**
         * String based length that is composed of value and unit in px
         */
        width?: pulumi.Input<string>;
    }
    interface AnalysisLineChartAggregatedFieldWellsArgs {
        /**
         * The category field wells of a line chart. Values are grouped by category fields.
         */
        category?: pulumi.Input<pulumi.Input<inputs.quicksight.AnalysisDimensionFieldArgs>[]>;
        /**
         * The color field wells of a line chart. Values are grouped by category fields.
         */
        colors?: pulumi.Input<pulumi.Input<inputs.quicksight.AnalysisDimensionFieldArgs>[]>;
        /**
         * The small multiples field well of a line chart.
         */
        smallMultiples?: pulumi.Input<pulumi.Input<inputs.quicksight.AnalysisDimensionFieldArgs>[]>;
        /**
         * The value field wells of a line chart. Values are aggregated based on categories.
         */
        values?: pulumi.Input<pulumi.Input<inputs.quicksight.AnalysisMeasureFieldArgs>[]>;
    }
    interface AnalysisLineChartConfigurationArgs {
        /**
         * The default configuration of a line chart's contribution analysis.
         */
        contributionAnalysisDefaults?: pulumi.Input<pulumi.Input<inputs.quicksight.AnalysisContributionAnalysisDefaultArgs>[]>;
        /**
         * The data label configuration of a line chart.
         */
        dataLabels?: pulumi.Input<inputs.quicksight.AnalysisDataLabelOptionsArgs>;
        /**
         * The options that determine the default presentation of all line series in `LineChartVisual` .
         */
        defaultSeriesSettings?: pulumi.Input<inputs.quicksight.AnalysisLineChartDefaultSeriesSettingsArgs>;
        /**
         * The field well configuration of a line chart.
         */
        fieldWells?: pulumi.Input<inputs.quicksight.AnalysisLineChartFieldWellsArgs>;
        /**
         * The forecast configuration of a line chart.
         */
        forecastConfigurations?: pulumi.Input<pulumi.Input<inputs.quicksight.AnalysisForecastConfigurationArgs>[]>;
        /**
         * The general visual interactions setup for a visual.
         */
        interactions?: pulumi.Input<inputs.quicksight.AnalysisVisualInteractionOptionsArgs>;
        /**
         * The legend configuration of a line chart.
         */
        legend?: pulumi.Input<inputs.quicksight.AnalysisLegendOptionsArgs>;
        /**
         * The series axis configuration of a line chart.
         */
        primaryYAxisDisplayOptions?: pulumi.Input<inputs.quicksight.AnalysisLineSeriesAxisDisplayOptionsArgs>;
        /**
         * The options that determine the presentation of the y-axis label.
         */
        primaryYAxisLabelOptions?: pulumi.Input<inputs.quicksight.AnalysisChartAxisLabelOptionsArgs>;
        /**
         * The reference lines configuration of a line chart.
         */
        referenceLines?: pulumi.Input<pulumi.Input<inputs.quicksight.AnalysisReferenceLineArgs>[]>;
        /**
         * The series axis configuration of a line chart.
         */
        secondaryYAxisDisplayOptions?: pulumi.Input<inputs.quicksight.AnalysisLineSeriesAxisDisplayOptionsArgs>;
        /**
         * The options that determine the presentation of the secondary y-axis label.
         */
        secondaryYAxisLabelOptions?: pulumi.Input<inputs.quicksight.AnalysisChartAxisLabelOptionsArgs>;
        /**
         * The series item configuration of a line chart.
         */
        series?: pulumi.Input<pulumi.Input<inputs.quicksight.AnalysisSeriesItemArgs>[]>;
        singleAxisOptions?: pulumi.Input<inputs.quicksight.AnalysisSingleAxisOptionsArgs>;
        /**
         * The small multiples setup for the visual.
         */
        smallMultiplesOptions?: pulumi.Input<inputs.quicksight.AnalysisSmallMultiplesOptionsArgs>;
        /**
         * The sort configuration of a line chart.
         */
        sortConfiguration?: pulumi.Input<inputs.quicksight.AnalysisLineChartSortConfigurationArgs>;
        /**
         * The tooltip configuration of a line chart.
         */
        tooltip?: pulumi.Input<inputs.quicksight.AnalysisTooltipOptionsArgs>;
        /**
         * Determines the type of the line chart.
         */
        type?: pulumi.Input<enums.quicksight.AnalysisLineChartType>;
        /**
         * The visual palette configuration of a line chart.
         */
        visualPalette?: pulumi.Input<inputs.quicksight.AnalysisVisualPaletteArgs>;
        /**
         * The options that determine the presentation of the x-axis.
         */
        xAxisDisplayOptions?: pulumi.Input<inputs.quicksight.AnalysisAxisDisplayOptionsArgs>;
        /**
         * The options that determine the presentation of the x-axis label.
         */
        xAxisLabelOptions?: pulumi.Input<inputs.quicksight.AnalysisChartAxisLabelOptionsArgs>;
    }
    interface AnalysisLineChartDefaultSeriesSettingsArgs {
        /**
         * The axis to which you are binding all line series to.
         */
        axisBinding?: pulumi.Input<enums.quicksight.AnalysisAxisBinding>;
        /**
         * Line styles options for all line series in the visual.
         */
        lineStyleSettings?: pulumi.Input<inputs.quicksight.AnalysisLineChartLineStyleSettingsArgs>;
        /**
         * Marker styles options for all line series in the visual.
         */
        markerStyleSettings?: pulumi.Input<inputs.quicksight.AnalysisLineChartMarkerStyleSettingsArgs>;
    }
    interface AnalysisLineChartFieldWellsArgs {
        /**
         * The field well configuration of a line chart.
         */
        lineChartAggregatedFieldWells?: pulumi.Input<inputs.quicksight.AnalysisLineChartAggregatedFieldWellsArgs>;
    }
    interface AnalysisLineChartLineStyleSettingsArgs {
        /**
         * Interpolation style for line series.
         *
         * - `LINEAR` : Show as default, linear style.
         * - `SMOOTH` : Show as a smooth curve.
         * - `STEPPED` : Show steps in line.
         */
        lineInterpolation?: pulumi.Input<enums.quicksight.AnalysisLineInterpolation>;
        /**
         * Line style for line series.
         *
         * - `SOLID` : Show as a solid line.
         * - `DOTTED` : Show as a dotted line.
         * - `DASHED` : Show as a dashed line.
         */
        lineStyle?: pulumi.Input<enums.quicksight.AnalysisLineChartLineStyle>;
        /**
         * Configuration option that determines whether to show the line for the series.
         */
        lineVisibility?: pulumi.Input<enums.quicksight.AnalysisVisibility>;
        /**
         * String based length that is composed of value and unit in px
         */
        lineWidth?: pulumi.Input<string>;
    }
    interface AnalysisLineChartMarkerStyleSettingsArgs {
        /**
         * Color of marker in the series.
         */
        markerColor?: pulumi.Input<string>;
        /**
         * Shape option for markers in the series.
         *
         * - `CIRCLE` : Show marker as a circle.
         * - `TRIANGLE` : Show marker as a triangle.
         * - `SQUARE` : Show marker as a square.
         * - `DIAMOND` : Show marker as a diamond.
         * - `ROUNDED_SQUARE` : Show marker as a rounded square.
         */
        markerShape?: pulumi.Input<enums.quicksight.AnalysisLineChartMarkerShape>;
        /**
         * String based length that is composed of value and unit in px
         */
        markerSize?: pulumi.Input<string>;
        /**
         * Configuration option that determines whether to show the markers in the series.
         */
        markerVisibility?: pulumi.Input<enums.quicksight.AnalysisVisibility>;
    }
    interface AnalysisLineChartSeriesSettingsArgs {
        /**
         * Line styles options for a line series in `LineChartVisual` .
         */
        lineStyleSettings?: pulumi.Input<inputs.quicksight.AnalysisLineChartLineStyleSettingsArgs>;
        /**
         * Marker styles options for a line series in `LineChartVisual` .
         */
        markerStyleSettings?: pulumi.Input<inputs.quicksight.AnalysisLineChartMarkerStyleSettingsArgs>;
    }
    interface AnalysisLineChartSortConfigurationArgs {
        /**
         * The limit on the number of categories that are displayed in a line chart.
         */
        categoryItemsLimitConfiguration?: pulumi.Input<inputs.quicksight.AnalysisItemsLimitConfigurationArgs>;
        /**
         * The sort configuration of the category fields.
         */
        categorySort?: pulumi.Input<pulumi.Input<inputs.quicksight.AnalysisFieldSortOptionsArgs>[]>;
        /**
         * The limit on the number of lines that are displayed in a line chart.
         */
        colorItemsLimitConfiguration?: pulumi.Input<inputs.quicksight.AnalysisItemsLimitConfigurationArgs>;
        /**
         * The limit on the number of small multiples panels that are displayed.
         */
        smallMultiplesLimitConfiguration?: pulumi.Input<inputs.quicksight.AnalysisItemsLimitConfigurationArgs>;
        /**
         * The sort configuration of the small multiples field.
         */
        smallMultiplesSort?: pulumi.Input<pulumi.Input<inputs.quicksight.AnalysisFieldSortOptionsArgs>[]>;
    }
    interface AnalysisLineChartVisualArgs {
        /**
         * The list of custom actions that are configured for a visual.
         */
        actions?: pulumi.Input<pulumi.Input<inputs.quicksight.AnalysisVisualCustomActionArgs>[]>;
        /**
         * The configuration of a line chart.
         */
        chartConfiguration?: pulumi.Input<inputs.quicksight.AnalysisLineChartConfigurationArgs>;
        /**
         * The column hierarchy that is used during drill-downs and drill-ups.
         */
        columnHierarchies?: pulumi.Input<pulumi.Input<inputs.quicksight.AnalysisColumnHierarchyArgs>[]>;
        /**
         * The subtitle that is displayed on the visual.
         */
        subtitle?: pulumi.Input<inputs.quicksight.AnalysisVisualSubtitleLabelOptionsArgs>;
        /**
         * The title that is displayed on the visual.
         */
        title?: pulumi.Input<inputs.quicksight.AnalysisVisualTitleLabelOptionsArgs>;
        /**
         * The alt text for the visual.
         */
        visualContentAltText?: pulumi.Input<string>;
        /**
         * The unique identifier of a visual. This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers.
         */
        visualId: pulumi.Input<string>;
    }
    interface AnalysisLineSeriesAxisDisplayOptionsArgs {
        /**
         * The options that determine the presentation of the line series axis.
         */
        axisOptions?: pulumi.Input<inputs.quicksight.AnalysisAxisDisplayOptionsArgs>;
        /**
         * The configuration options that determine how missing data is treated during the rendering of a line chart.
         */
        missingDataConfigurations?: pulumi.Input<pulumi.Input<inputs.quicksight.AnalysisMissingDataConfigurationArgs>[]>;
    }
    interface AnalysisListControlDisplayOptionsArgs {
        /**
         * The configuration of info icon label options.
         */
        infoIconLabelOptions?: pulumi.Input<inputs.quicksight.AnalysisSheetControlInfoIconLabelOptionsArgs>;
        /**
         * The configuration of the search options in a list control.
         */
        searchOptions?: pulumi.Input<inputs.quicksight.AnalysisListControlSearchOptionsArgs>;
        /**
         * The configuration of the `Select all` options in a list control.
         */
        selectAllOptions?: pulumi.Input<inputs.quicksight.AnalysisListControlSelectAllOptionsArgs>;
        /**
         * The options to configure the title visibility, name, and font size.
         */
        titleOptions?: pulumi.Input<inputs.quicksight.AnalysisLabelOptionsArgs>;
    }
    interface AnalysisListControlSearchOptionsArgs {
        /**
         * The visibility configuration of the search options in a list control.
         */
        visibility?: pulumi.Input<enums.quicksight.AnalysisVisibility>;
    }
    interface AnalysisListControlSelectAllOptionsArgs {
        /**
         * The visibility configuration of the `Select all` options in a list control.
         */
        visibility?: pulumi.Input<enums.quicksight.AnalysisVisibility>;
    }
    interface AnalysisLoadingAnimationArgs {
        /**
         * The visibility configuration of `LoadingAnimation` .
         */
        visibility?: pulumi.Input<enums.quicksight.AnalysisVisibility>;
    }
    interface AnalysisLocalNavigationConfigurationArgs {
        /**
         * The sheet that is targeted for navigation in the same analysis.
         */
        targetSheetId: pulumi.Input<string>;
    }
    interface AnalysisLongFormatTextArgs {
        /**
         * Plain text format.
         */
        plainText?: pulumi.Input<string>;
        /**
         * Rich text. Examples of rich text include bold, underline, and italics.
         */
        richText?: pulumi.Input<string>;
    }
    interface AnalysisMappedDataSetParameterArgs {
        /**
         * A unique name that identifies a dataset within the analysis or dashboard.
         */
        dataSetIdentifier: pulumi.Input<string>;
        /**
         * The name of the dataset parameter.
         */
        dataSetParameterName: pulumi.Input<string>;
    }
    interface AnalysisMaximumLabelTypeArgs {
        /**
         * The visibility of the maximum label.
         */
        visibility?: pulumi.Input<enums.quicksight.AnalysisVisibility>;
    }
    interface AnalysisMaximumMinimumComputationArgs {
        /**
         * The ID for a computation.
         */
        computationId: pulumi.Input<string>;
        /**
         * The name of a computation.
         */
        name?: pulumi.Input<string>;
        /**
         * The time field that is used in a computation.
         */
        time?: pulumi.Input<inputs.quicksight.AnalysisDimensionFieldArgs>;
        /**
         * The type of computation. Choose one of the following options:
         *
         * - MAXIMUM: A maximum computation.
         * - MINIMUM: A minimum computation.
         */
        type: pulumi.Input<enums.quicksight.AnalysisMaximumMinimumComputationType>;
        /**
         * The value field that is used in a computation.
         */
        value?: pulumi.Input<inputs.quicksight.AnalysisMeasureFieldArgs>;
    }
    interface AnalysisMeasureFieldArgs {
        /**
         * The calculated measure field only used in pivot tables.
         */
        calculatedMeasureField?: pulumi.Input<inputs.quicksight.AnalysisCalculatedMeasureFieldArgs>;
        /**
         * The measure type field with categorical type columns.
         */
        categoricalMeasureField?: pulumi.Input<inputs.quicksight.AnalysisCategoricalMeasureFieldArgs>;
        /**
         * The measure type field with date type columns.
         */
        dateMeasureField?: pulumi.Input<inputs.quicksight.AnalysisDateMeasureFieldArgs>;
        /**
         * The measure type field with numerical type columns.
         */
        numericalMeasureField?: pulumi.Input<inputs.quicksight.AnalysisNumericalMeasureFieldArgs>;
    }
    interface AnalysisMetricComparisonComputationArgs {
        /**
         * The ID for a computation.
         */
        computationId: pulumi.Input<string>;
        /**
         * The field that is used in a metric comparison from value setup.
         */
        fromValue?: pulumi.Input<inputs.quicksight.AnalysisMeasureFieldArgs>;
        /**
         * The name of a computation.
         */
        name?: pulumi.Input<string>;
        /**
         * The field that is used in a metric comparison to value setup.
         */
        targetValue?: pulumi.Input<inputs.quicksight.AnalysisMeasureFieldArgs>;
        /**
         * The time field that is used in a computation.
         */
        time?: pulumi.Input<inputs.quicksight.AnalysisDimensionFieldArgs>;
    }
    interface AnalysisMinimumLabelTypeArgs {
        /**
         * The visibility of the minimum label.
         */
        visibility?: pulumi.Input<enums.quicksight.AnalysisVisibility>;
    }
    interface AnalysisMissingDataConfigurationArgs {
        /**
         * The treatment option that determines how missing data should be rendered. Choose from the following options:
         *
         * - `INTERPOLATE` : Interpolate missing values between the prior and the next known value.
         * - `SHOW_AS_ZERO` : Show missing values as the value `0` .
         * - `SHOW_AS_BLANK` : Display a blank space when rendering missing data.
         */
        treatmentOption?: pulumi.Input<enums.quicksight.AnalysisMissingDataTreatmentOption>;
    }
    interface AnalysisNegativeValueConfigurationArgs {
        /**
         * Determines the display mode of the negative value configuration.
         */
        displayMode: pulumi.Input<enums.quicksight.AnalysisNegativeValueDisplayMode>;
    }
    interface AnalysisNestedFilterArgs {
        /**
         * The column that the filter is applied to.
         */
        column: pulumi.Input<inputs.quicksight.AnalysisColumnIdentifierArgs>;
        /**
         * An identifier that uniquely identifies a filter within a dashboard, analysis, or template.
         */
        filterId: pulumi.Input<string>;
        /**
         * A boolean condition to include or exclude the subset that is defined by the values of the nested inner filter.
         */
        includeInnerSet: pulumi.Input<boolean>;
        /**
         * The `InnerFilter` defines the subset of data to be used with the `NestedFilter` .
         */
        innerFilter: pulumi.Input<inputs.quicksight.AnalysisInnerFilterArgs>;
    }
    interface AnalysisNullValueFormatConfigurationArgs {
        /**
         * Determines the null string of null values.
         */
        nullString: pulumi.Input<string>;
    }
    interface AnalysisNumberDisplayFormatConfigurationArgs {
        /**
         * The option that determines the decimal places configuration.
         */
        decimalPlacesConfiguration?: pulumi.Input<inputs.quicksight.AnalysisDecimalPlacesConfigurationArgs>;
        /**
         * The options that determine the negative value configuration.
         */
        negativeValueConfiguration?: pulumi.Input<inputs.quicksight.AnalysisNegativeValueConfigurationArgs>;
        /**
         * The options that determine the null value format configuration.
         */
        nullValueFormatConfiguration?: pulumi.Input<inputs.quicksight.AnalysisNullValueFormatConfigurationArgs>;
        /**
         * Determines the number scale value of the number format.
         */
        numberScale?: pulumi.Input<enums.quicksight.AnalysisNumberScale>;
        /**
         * Determines the prefix value of the number format.
         */
        prefix?: pulumi.Input<string>;
        /**
         * The options that determine the numeric separator configuration.
         */
        separatorConfiguration?: pulumi.Input<inputs.quicksight.AnalysisNumericSeparatorConfigurationArgs>;
        /**
         * Determines the suffix value of the number format.
         */
        suffix?: pulumi.Input<string>;
    }
    interface AnalysisNumberFormatConfigurationArgs {
        /**
         * The options that determine the numeric format configuration.
         */
        formatConfiguration?: pulumi.Input<inputs.quicksight.AnalysisNumericFormatConfigurationArgs>;
    }
    interface AnalysisNumericAxisOptionsArgs {
        /**
         * The range setup of a numeric axis.
         */
        range?: pulumi.Input<inputs.quicksight.AnalysisAxisDisplayRangeArgs>;
        /**
         * The scale setup of a numeric axis.
         */
        scale?: pulumi.Input<inputs.quicksight.AnalysisAxisScaleArgs>;
    }
    interface AnalysisNumericEqualityDrillDownFilterArgs {
        /**
         * The column that the filter is applied to.
         */
        column: pulumi.Input<inputs.quicksight.AnalysisColumnIdentifierArgs>;
        /**
         * The value of the double input numeric drill down filter.
         */
        value: pulumi.Input<number>;
    }
    interface AnalysisNumericEqualityFilterArgs {
        /**
         * The aggregation function of the filter.
         */
        aggregationFunction?: pulumi.Input<inputs.quicksight.AnalysisAggregationFunctionArgs>;
        /**
         * The column that the filter is applied to.
         */
        column: pulumi.Input<inputs.quicksight.AnalysisColumnIdentifierArgs>;
        /**
         * The default configurations for the associated controls. This applies only for filters that are scoped to multiple sheets.
         */
        defaultFilterControlConfiguration?: pulumi.Input<inputs.quicksight.AnalysisDefaultFilterControlConfigurationArgs>;
        /**
         * An identifier that uniquely identifies a filter within a dashboard, analysis, or template.
         */
        filterId: pulumi.Input<string>;
        /**
         * The match operator that is used to determine if a filter should be applied.
         */
        matchOperator: pulumi.Input<enums.quicksight.AnalysisNumericEqualityMatchOperator>;
        /**
         * This option determines how null values should be treated when filtering data.
         *
         * - `ALL_VALUES` : Include null values in filtered results.
         * - `NULLS_ONLY` : Only include null values in filtered results.
         * - `NON_NULLS_ONLY` : Exclude null values from filtered results.
         */
        nullOption: pulumi.Input<enums.quicksight.AnalysisFilterNullOption>;
        /**
         * The parameter whose value should be used for the filter value.
         */
        parameterName?: pulumi.Input<string>;
        /**
         * Select all of the values. Null is not the assigned value of select all.
         *
         * - `FILTER_ALL_VALUES`
         */
        selectAllOptions?: pulumi.Input<enums.quicksight.AnalysisNumericFilterSelectAllOptions>;
        /**
         * The input value.
         */
        value?: pulumi.Input<number>;
    }
    interface AnalysisNumericFormatConfigurationArgs {
        /**
         * The options that determine the currency display format configuration.
         */
        currencyDisplayFormatConfiguration?: pulumi.Input<inputs.quicksight.AnalysisCurrencyDisplayFormatConfigurationArgs>;
        /**
         * The options that determine the number display format configuration.
         */
        numberDisplayFormatConfiguration?: pulumi.Input<inputs.quicksight.AnalysisNumberDisplayFormatConfigurationArgs>;
        /**
         * The options that determine the percentage display format configuration.
         */
        percentageDisplayFormatConfiguration?: pulumi.Input<inputs.quicksight.AnalysisPercentageDisplayFormatConfigurationArgs>;
    }
    interface AnalysisNumericRangeFilterArgs {
        /**
         * The aggregation function of the filter.
         */
        aggregationFunction?: pulumi.Input<inputs.quicksight.AnalysisAggregationFunctionArgs>;
        /**
         * The column that the filter is applied to.
         */
        column: pulumi.Input<inputs.quicksight.AnalysisColumnIdentifierArgs>;
        /**
         * The default configurations for the associated controls. This applies only for filters that are scoped to multiple sheets.
         */
        defaultFilterControlConfiguration?: pulumi.Input<inputs.quicksight.AnalysisDefaultFilterControlConfigurationArgs>;
        /**
         * An identifier that uniquely identifies a filter within a dashboard, analysis, or template.
         */
        filterId: pulumi.Input<string>;
        /**
         * Determines whether the maximum value in the filter value range should be included in the filtered results.
         */
        includeMaximum?: pulumi.Input<boolean>;
        /**
         * Determines whether the minimum value in the filter value range should be included in the filtered results.
         */
        includeMinimum?: pulumi.Input<boolean>;
        /**
         * This option determines how null values should be treated when filtering data.
         *
         * - `ALL_VALUES` : Include null values in filtered results.
         * - `NULLS_ONLY` : Only include null values in filtered results.
         * - `NON_NULLS_ONLY` : Exclude null values from filtered results.
         */
        nullOption: pulumi.Input<enums.quicksight.AnalysisFilterNullOption>;
        /**
         * The maximum value for the filter value range.
         */
        rangeMaximum?: pulumi.Input<inputs.quicksight.AnalysisNumericRangeFilterValueArgs>;
        /**
         * The minimum value for the filter value range.
         */
        rangeMinimum?: pulumi.Input<inputs.quicksight.AnalysisNumericRangeFilterValueArgs>;
        /**
         * Select all of the values. Null is not the assigned value of select all.
         *
         * - `FILTER_ALL_VALUES`
         */
        selectAllOptions?: pulumi.Input<enums.quicksight.AnalysisNumericFilterSelectAllOptions>;
    }
    interface AnalysisNumericRangeFilterValueArgs {
        /**
         * The parameter that is used in the numeric range.
         */
        parameter?: pulumi.Input<string>;
        /**
         * The static value of the numeric range filter.
         */
        staticValue?: pulumi.Input<number>;
    }
    interface AnalysisNumericSeparatorConfigurationArgs {
        /**
         * Determines the decimal separator.
         */
        decimalSeparator?: pulumi.Input<enums.quicksight.AnalysisNumericSeparatorSymbol>;
        /**
         * The options that determine the thousands separator configuration.
         */
        thousandsSeparator?: pulumi.Input<inputs.quicksight.AnalysisThousandSeparatorOptionsArgs>;
    }
    interface AnalysisNumericalAggregationFunctionArgs {
        /**
         * An aggregation based on the percentile of values in a dimension or measure.
         */
        percentileAggregation?: pulumi.Input<inputs.quicksight.AnalysisPercentileAggregationArgs>;
        /**
         * Built-in aggregation functions for numerical values.
         *
         * - `SUM` : The sum of a dimension or measure.
         * - `AVERAGE` : The average of a dimension or measure.
         * - `MIN` : The minimum value of a dimension or measure.
         * - `MAX` : The maximum value of a dimension or measure.
         * - `COUNT` : The count of a dimension or measure.
         * - `DISTINCT_COUNT` : The count of distinct values in a dimension or measure.
         * - `VAR` : The variance of a dimension or measure.
         * - `VARP` : The partitioned variance of a dimension or measure.
         * - `STDEV` : The standard deviation of a dimension or measure.
         * - `STDEVP` : The partitioned standard deviation of a dimension or measure.
         * - `MEDIAN` : The median value of a dimension or measure.
         */
        simpleNumericalAggregation?: pulumi.Input<enums.quicksight.AnalysisSimpleNumericalAggregationFunction>;
    }
    interface AnalysisNumericalDimensionFieldArgs {
        /**
         * The column that is used in the `NumericalDimensionField` .
         */
        column: pulumi.Input<inputs.quicksight.AnalysisColumnIdentifierArgs>;
        /**
         * The custom field ID.
         */
        fieldId: pulumi.Input<string>;
        /**
         * The format configuration of the field.
         */
        formatConfiguration?: pulumi.Input<inputs.quicksight.AnalysisNumberFormatConfigurationArgs>;
        /**
         * The custom hierarchy ID.
         */
        hierarchyId?: pulumi.Input<string>;
    }
    interface AnalysisNumericalMeasureFieldArgs {
        /**
         * The aggregation function of the measure field.
         */
        aggregationFunction?: pulumi.Input<inputs.quicksight.AnalysisNumericalAggregationFunctionArgs>;
        /**
         * The column that is used in the `NumericalMeasureField` .
         */
        column: pulumi.Input<inputs.quicksight.AnalysisColumnIdentifierArgs>;
        /**
         * The custom field ID.
         */
        fieldId: pulumi.Input<string>;
        /**
         * The format configuration of the field.
         */
        formatConfiguration?: pulumi.Input<inputs.quicksight.AnalysisNumberFormatConfigurationArgs>;
    }
    interface AnalysisPaginationConfigurationArgs {
        /**
         * Indicates the page number.
         */
        pageNumber: pulumi.Input<number>;
        /**
         * Indicates how many items render in one page.
         */
        pageSize: pulumi.Input<number>;
    }
    interface AnalysisPanelConfigurationArgs {
        /**
         * Sets the background color for each panel.
         */
        backgroundColor?: pulumi.Input<string>;
        /**
         * Determines whether or not a background for each small multiples panel is rendered.
         */
        backgroundVisibility?: pulumi.Input<enums.quicksight.AnalysisVisibility>;
        /**
         * Sets the line color of panel borders.
         */
        borderColor?: pulumi.Input<string>;
        /**
         * Sets the line style of panel borders.
         */
        borderStyle?: pulumi.Input<enums.quicksight.AnalysisPanelBorderStyle>;
        /**
         * String based length that is composed of value and unit in px
         */
        borderThickness?: pulumi.Input<string>;
        /**
         * Determines whether or not each panel displays a border.
         */
        borderVisibility?: pulumi.Input<enums.quicksight.AnalysisVisibility>;
        /**
         * String based length that is composed of value and unit in px
         */
        gutterSpacing?: pulumi.Input<string>;
        /**
         * Determines whether or not negative space between sibling panels is rendered.
         */
        gutterVisibility?: pulumi.Input<enums.quicksight.AnalysisVisibility>;
        /**
         * Configures the title display within each small multiples panel.
         */
        title?: pulumi.Input<inputs.quicksight.AnalysisPanelTitleOptionsArgs>;
    }
    interface AnalysisPanelTitleOptionsArgs {
        fontConfiguration?: pulumi.Input<inputs.quicksight.AnalysisFontConfigurationArgs>;
        /**
         * Sets the horizontal text alignment of the title within each panel.
         */
        horizontalTextAlignment?: pulumi.Input<enums.quicksight.AnalysisHorizontalTextAlignment>;
        /**
         * Determines whether or not panel titles are displayed.
         */
        visibility?: pulumi.Input<enums.quicksight.AnalysisVisibility>;
    }
    interface AnalysisParameterControlArgs {
        /**
         * A control from a date parameter that specifies date and time.
         */
        dateTimePicker?: pulumi.Input<inputs.quicksight.AnalysisParameterDateTimePickerControlArgs>;
        /**
         * A control to display a dropdown list with buttons that are used to select a single value.
         */
        dropdown?: pulumi.Input<inputs.quicksight.AnalysisParameterDropDownControlArgs>;
        /**
         * A control to display a list with buttons or boxes that are used to select either a single value or multiple values.
         */
        list?: pulumi.Input<inputs.quicksight.AnalysisParameterListControlArgs>;
        /**
         * A control to display a horizontal toggle bar. This is used to change a value by sliding the toggle.
         */
        slider?: pulumi.Input<inputs.quicksight.AnalysisParameterSliderControlArgs>;
        /**
         * A control to display a text box that is used to enter multiple entries.
         */
        textArea?: pulumi.Input<inputs.quicksight.AnalysisParameterTextAreaControlArgs>;
        /**
         * A control to display a text box that is used to enter a single entry.
         */
        textField?: pulumi.Input<inputs.quicksight.AnalysisParameterTextFieldControlArgs>;
    }
    interface AnalysisParameterDateTimePickerControlArgs {
        /**
         * The display options of a control.
         */
        displayOptions?: pulumi.Input<inputs.quicksight.AnalysisDateTimePickerControlDisplayOptionsArgs>;
        /**
         * The ID of the `ParameterDateTimePickerControl` .
         */
        parameterControlId: pulumi.Input<string>;
        /**
         * The name of the `ParameterDateTimePickerControl` .
         */
        sourceParameterName: pulumi.Input<string>;
        /**
         * The title of the `ParameterDateTimePickerControl` .
         */
        title: pulumi.Input<string>;
    }
    interface AnalysisParameterDeclarationArgs {
        /**
         * A parameter declaration for the `DateTime` data type.
         */
        dateTimeParameterDeclaration?: pulumi.Input<inputs.quicksight.AnalysisDateTimeParameterDeclarationArgs>;
        /**
         * A parameter declaration for the `Decimal` data type.
         */
        decimalParameterDeclaration?: pulumi.Input<inputs.quicksight.AnalysisDecimalParameterDeclarationArgs>;
        /**
         * A parameter declaration for the `Integer` data type.
         */
        integerParameterDeclaration?: pulumi.Input<inputs.quicksight.AnalysisIntegerParameterDeclarationArgs>;
        /**
         * A parameter declaration for the `String` data type.
         */
        stringParameterDeclaration?: pulumi.Input<inputs.quicksight.AnalysisStringParameterDeclarationArgs>;
    }
    interface AnalysisParameterDropDownControlArgs {
        /**
         * The values that are displayed in a control can be configured to only show values that are valid based on what's selected in other controls.
         */
        cascadingControlConfiguration?: pulumi.Input<inputs.quicksight.AnalysisCascadingControlConfigurationArgs>;
        /**
         * The visibility configuration of the Apply button on a `ParameterDropDownControl` .
         */
        commitMode?: pulumi.Input<enums.quicksight.AnalysisCommitMode>;
        /**
         * The display options of a control.
         */
        displayOptions?: pulumi.Input<inputs.quicksight.AnalysisDropDownControlDisplayOptionsArgs>;
        /**
         * The ID of the `ParameterDropDownControl` .
         */
        parameterControlId: pulumi.Input<string>;
        /**
         * A list of selectable values that are used in a control.
         */
        selectableValues?: pulumi.Input<inputs.quicksight.AnalysisParameterSelectableValuesArgs>;
        /**
         * The source parameter name of the `ParameterDropDownControl` .
         */
        sourceParameterName: pulumi.Input<string>;
        /**
         * The title of the `ParameterDropDownControl` .
         */
        title: pulumi.Input<string>;
        /**
         * The type parameter name of the `ParameterDropDownControl` .
         */
        type?: pulumi.Input<enums.quicksight.AnalysisSheetControlListType>;
    }
    interface AnalysisParameterListControlArgs {
        /**
         * The values that are displayed in a control can be configured to only show values that are valid based on what's selected in other controls.
         */
        cascadingControlConfiguration?: pulumi.Input<inputs.quicksight.AnalysisCascadingControlConfigurationArgs>;
        /**
         * The display options of a control.
         */
        displayOptions?: pulumi.Input<inputs.quicksight.AnalysisListControlDisplayOptionsArgs>;
        /**
         * The ID of the `ParameterListControl` .
         */
        parameterControlId: pulumi.Input<string>;
        /**
         * A list of selectable values that are used in a control.
         */
        selectableValues?: pulumi.Input<inputs.quicksight.AnalysisParameterSelectableValuesArgs>;
        /**
         * The source parameter name of the `ParameterListControl` .
         */
        sourceParameterName: pulumi.Input<string>;
        /**
         * The title of the `ParameterListControl` .
         */
        title: pulumi.Input<string>;
        /**
         * The type of `ParameterListControl` .
         */
        type?: pulumi.Input<enums.quicksight.AnalysisSheetControlListType>;
    }
    interface AnalysisParameterSelectableValuesArgs {
        /**
         * The column identifier that fetches values from the data set.
         */
        linkToDataSetColumn?: pulumi.Input<inputs.quicksight.AnalysisColumnIdentifierArgs>;
        /**
         * The values that are used in `ParameterSelectableValues` .
         */
        values?: pulumi.Input<pulumi.Input<string>[]>;
    }
    interface AnalysisParameterSliderControlArgs {
        /**
         * The display options of a control.
         */
        displayOptions?: pulumi.Input<inputs.quicksight.AnalysisSliderControlDisplayOptionsArgs>;
        /**
         * The larger value that is displayed at the right of the slider.
         */
        maximumValue: pulumi.Input<number>;
        /**
         * The smaller value that is displayed at the left of the slider.
         */
        minimumValue: pulumi.Input<number>;
        /**
         * The ID of the `ParameterSliderControl` .
         */
        parameterControlId: pulumi.Input<string>;
        /**
         * The source parameter name of the `ParameterSliderControl` .
         */
        sourceParameterName: pulumi.Input<string>;
        /**
         * The number of increments that the slider bar is divided into.
         */
        stepSize: pulumi.Input<number>;
        /**
         * The title of the `ParameterSliderControl` .
         */
        title: pulumi.Input<string>;
    }
    interface AnalysisParameterTextAreaControlArgs {
        /**
         * The delimiter that is used to separate the lines in text.
         */
        delimiter?: pulumi.Input<string>;
        /**
         * The display options of a control.
         */
        displayOptions?: pulumi.Input<inputs.quicksight.AnalysisTextAreaControlDisplayOptionsArgs>;
        /**
         * The ID of the `ParameterTextAreaControl` .
         */
        parameterControlId: pulumi.Input<string>;
        /**
         * The source parameter name of the `ParameterTextAreaControl` .
         */
        sourceParameterName: pulumi.Input<string>;
        /**
         * The title of the `ParameterTextAreaControl` .
         */
        title: pulumi.Input<string>;
    }
    interface AnalysisParameterTextFieldControlArgs {
        /**
         * The display options of a control.
         */
        displayOptions?: pulumi.Input<inputs.quicksight.AnalysisTextFieldControlDisplayOptionsArgs>;
        /**
         * The ID of the `ParameterTextFieldControl` .
         */
        parameterControlId: pulumi.Input<string>;
        /**
         * The source parameter name of the `ParameterTextFieldControl` .
         */
        sourceParameterName: pulumi.Input<string>;
        /**
         * The title of the `ParameterTextFieldControl` .
         */
        title: pulumi.Input<string>;
    }
    /**
     * <p>A list of Amazon QuickSight parameters and the list's override values.</p>
     */
    interface AnalysisParametersArgs {
        /**
         * <p>The parameters that have a data type of date-time.</p>
         */
        dateTimeParameters?: pulumi.Input<pulumi.Input<inputs.quicksight.AnalysisDateTimeParameterArgs>[]>;
        /**
         * <p>The parameters that have a data type of decimal.</p>
         */
        decimalParameters?: pulumi.Input<pulumi.Input<inputs.quicksight.AnalysisDecimalParameterArgs>[]>;
        /**
         * <p>The parameters that have a data type of integer.</p>
         */
        integerParameters?: pulumi.Input<pulumi.Input<inputs.quicksight.AnalysisIntegerParameterArgs>[]>;
        /**
         * <p>The parameters that have a data type of string.</p>
         */
        stringParameters?: pulumi.Input<pulumi.Input<inputs.quicksight.AnalysisStringParameterArgs>[]>;
    }
    interface AnalysisPercentVisibleRangeArgs {
        /**
         * The lower bound of the range.
         */
        from?: pulumi.Input<number>;
        /**
         * The top bound of the range.
         */
        to?: pulumi.Input<number>;
    }
    interface AnalysisPercentageDisplayFormatConfigurationArgs {
        /**
         * The option that determines the decimal places configuration.
         */
        decimalPlacesConfiguration?: pulumi.Input<inputs.quicksight.AnalysisDecimalPlacesConfigurationArgs>;
        /**
         * The options that determine the negative value configuration.
         */
        negativeValueConfiguration?: pulumi.Input<inputs.quicksight.AnalysisNegativeValueConfigurationArgs>;
        /**
         * The options that determine the null value format configuration.
         */
        nullValueFormatConfiguration?: pulumi.Input<inputs.quicksight.AnalysisNullValueFormatConfigurationArgs>;
        /**
         * Determines the prefix value of the percentage format.
         */
        prefix?: pulumi.Input<string>;
        /**
         * The options that determine the numeric separator configuration.
         */
        separatorConfiguration?: pulumi.Input<inputs.quicksight.AnalysisNumericSeparatorConfigurationArgs>;
        /**
         * Determines the suffix value of the percentage format.
         */
        suffix?: pulumi.Input<string>;
    }
    interface AnalysisPercentileAggregationArgs {
        /**
         * The percentile value. This value can be any numeric constant 0–100. A percentile value of 50 computes the median value of the measure.
         */
        percentileValue?: pulumi.Input<number>;
    }
    interface AnalysisPeriodOverPeriodComputationArgs {
        /**
         * The ID for a computation.
         */
        computationId: pulumi.Input<string>;
        /**
         * The name of a computation.
         */
        name?: pulumi.Input<string>;
        /**
         * The time field that is used in a computation.
         */
        time?: pulumi.Input<inputs.quicksight.AnalysisDimensionFieldArgs>;
        /**
         * The value field that is used in a computation.
         */
        value?: pulumi.Input<inputs.quicksight.AnalysisMeasureFieldArgs>;
    }
    interface AnalysisPeriodToDateComputationArgs {
        /**
         * The ID for a computation.
         */
        computationId: pulumi.Input<string>;
        /**
         * The name of a computation.
         */
        name?: pulumi.Input<string>;
        /**
         * The time granularity setup of period to date computation. Choose from the following options:
         *
         * - YEAR: Year to date.
         * - MONTH: Month to date.
         */
        periodTimeGranularity?: pulumi.Input<enums.quicksight.AnalysisTimeGranularity>;
        /**
         * The time field that is used in a computation.
         */
        time?: pulumi.Input<inputs.quicksight.AnalysisDimensionFieldArgs>;
        /**
         * The value field that is used in a computation.
         */
        value?: pulumi.Input<inputs.quicksight.AnalysisMeasureFieldArgs>;
    }
    interface AnalysisPieChartAggregatedFieldWellsArgs {
        /**
         * The category (group/color) field wells of a pie chart.
         */
        category?: pulumi.Input<pulumi.Input<inputs.quicksight.AnalysisDimensionFieldArgs>[]>;
        /**
         * The small multiples field well of a pie chart.
         */
        smallMultiples?: pulumi.Input<pulumi.Input<inputs.quicksight.AnalysisDimensionFieldArgs>[]>;
        /**
         * The value field wells of a pie chart. Values are aggregated based on categories.
         */
        values?: pulumi.Input<pulumi.Input<inputs.quicksight.AnalysisMeasureFieldArgs>[]>;
    }
    interface AnalysisPieChartConfigurationArgs {
        /**
         * The label options of the group/color that is displayed in a pie chart.
         */
        categoryLabelOptions?: pulumi.Input<inputs.quicksight.AnalysisChartAxisLabelOptionsArgs>;
        /**
         * The contribution analysis (anomaly configuration) setup of the visual.
         */
        contributionAnalysisDefaults?: pulumi.Input<pulumi.Input<inputs.quicksight.AnalysisContributionAnalysisDefaultArgs>[]>;
        /**
         * The options that determine if visual data labels are displayed.
         */
        dataLabels?: pulumi.Input<inputs.quicksight.AnalysisDataLabelOptionsArgs>;
        /**
         * The options that determine the shape of the chart. This option determines whether the chart is a pie chart or a donut chart.
         */
        donutOptions?: pulumi.Input<inputs.quicksight.AnalysisDonutOptionsArgs>;
        /**
         * The field wells of the visual.
         */
        fieldWells?: pulumi.Input<inputs.quicksight.AnalysisPieChartFieldWellsArgs>;
        /**
         * The general visual interactions setup for a visual.
         */
        interactions?: pulumi.Input<inputs.quicksight.AnalysisVisualInteractionOptionsArgs>;
        /**
         * The legend display setup of the visual.
         */
        legend?: pulumi.Input<inputs.quicksight.AnalysisLegendOptionsArgs>;
        /**
         * The small multiples setup for the visual.
         */
        smallMultiplesOptions?: pulumi.Input<inputs.quicksight.AnalysisSmallMultiplesOptionsArgs>;
        /**
         * The sort configuration of a pie chart.
         */
        sortConfiguration?: pulumi.Input<inputs.quicksight.AnalysisPieChartSortConfigurationArgs>;
        /**
         * The tooltip display setup of the visual.
         */
        tooltip?: pulumi.Input<inputs.quicksight.AnalysisTooltipOptionsArgs>;
        /**
         * The label options for the value that is displayed in a pie chart.
         */
        valueLabelOptions?: pulumi.Input<inputs.quicksight.AnalysisChartAxisLabelOptionsArgs>;
        /**
         * The palette (chart color) display setup of the visual.
         */
        visualPalette?: pulumi.Input<inputs.quicksight.AnalysisVisualPaletteArgs>;
    }
    interface AnalysisPieChartFieldWellsArgs {
        /**
         * The field well configuration of a pie chart.
         */
        pieChartAggregatedFieldWells?: pulumi.Input<inputs.quicksight.AnalysisPieChartAggregatedFieldWellsArgs>;
    }
    interface AnalysisPieChartSortConfigurationArgs {
        /**
         * The limit on the number of categories that are displayed in a pie chart.
         */
        categoryItemsLimit?: pulumi.Input<inputs.quicksight.AnalysisItemsLimitConfigurationArgs>;
        /**
         * The sort configuration of the category fields.
         */
        categorySort?: pulumi.Input<pulumi.Input<inputs.quicksight.AnalysisFieldSortOptionsArgs>[]>;
        /**
         * The limit on the number of small multiples panels that are displayed.
         */
        smallMultiplesLimitConfiguration?: pulumi.Input<inputs.quicksight.AnalysisItemsLimitConfigurationArgs>;
        /**
         * The sort configuration of the small multiples field.
         */
        smallMultiplesSort?: pulumi.Input<pulumi.Input<inputs.quicksight.AnalysisFieldSortOptionsArgs>[]>;
    }
    interface AnalysisPieChartVisualArgs {
        /**
         * The list of custom actions that are configured for a visual.
         */
        actions?: pulumi.Input<pulumi.Input<inputs.quicksight.AnalysisVisualCustomActionArgs>[]>;
        /**
         * The configuration of a pie chart.
         */
        chartConfiguration?: pulumi.Input<inputs.quicksight.AnalysisPieChartConfigurationArgs>;
        /**
         * The column hierarchy that is used during drill-downs and drill-ups.
         */
        columnHierarchies?: pulumi.Input<pulumi.Input<inputs.quicksight.AnalysisColumnHierarchyArgs>[]>;
        /**
         * The subtitle that is displayed on the visual.
         */
        subtitle?: pulumi.Input<inputs.quicksight.AnalysisVisualSubtitleLabelOptionsArgs>;
        /**
         * The title that is displayed on the visual.
         */
        title?: pulumi.Input<inputs.quicksight.AnalysisVisualTitleLabelOptionsArgs>;
        /**
         * The alt text for the visual.
         */
        visualContentAltText?: pulumi.Input<string>;
        /**
         * The unique identifier of a visual. This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers.
         */
        visualId: pulumi.Input<string>;
    }
    interface AnalysisPivotFieldSortOptionsArgs {
        /**
         * The field ID for the field sort options.
         */
        fieldId: pulumi.Input<string>;
        /**
         * The sort by field for the field sort options.
         */
        sortBy: pulumi.Input<inputs.quicksight.AnalysisPivotTableSortByArgs>;
    }
    interface AnalysisPivotTableAggregatedFieldWellsArgs {
        /**
         * The columns field well for a pivot table. Values are grouped by columns fields.
         */
        columns?: pulumi.Input<pulumi.Input<inputs.quicksight.AnalysisDimensionFieldArgs>[]>;
        /**
         * The rows field well for a pivot table. Values are grouped by rows fields.
         */
        rows?: pulumi.Input<pulumi.Input<inputs.quicksight.AnalysisDimensionFieldArgs>[]>;
        /**
         * The values field well for a pivot table. Values are aggregated based on rows and columns fields.
         */
        values?: pulumi.Input<pulumi.Input<inputs.quicksight.AnalysisMeasureFieldArgs>[]>;
    }
    interface AnalysisPivotTableCellConditionalFormattingArgs {
        /**
         * The field ID of the cell for conditional formatting.
         */
        fieldId: pulumi.Input<string>;
        /**
         * The scope of the cell for conditional formatting.
         */
        scope?: pulumi.Input<inputs.quicksight.AnalysisPivotTableConditionalFormattingScopeArgs>;
        /**
         * A list of cell scopes for conditional formatting.
         */
        scopes?: pulumi.Input<pulumi.Input<inputs.quicksight.AnalysisPivotTableConditionalFormattingScopeArgs>[]>;
        /**
         * The text format of the cell for conditional formatting.
         */
        textFormat?: pulumi.Input<inputs.quicksight.AnalysisTextConditionalFormatArgs>;
    }
    interface AnalysisPivotTableConditionalFormattingArgs {
        /**
         * Conditional formatting options for a `PivotTableVisual` .
         */
        conditionalFormattingOptions?: pulumi.Input<pulumi.Input<inputs.quicksight.AnalysisPivotTableConditionalFormattingOptionArgs>[]>;
    }
    interface AnalysisPivotTableConditionalFormattingOptionArgs {
        /**
         * The cell conditional formatting option for a pivot table.
         */
        cell?: pulumi.Input<inputs.quicksight.AnalysisPivotTableCellConditionalFormattingArgs>;
    }
    interface AnalysisPivotTableConditionalFormattingScopeArgs {
        /**
         * The role (field, field total, grand total) of the cell for conditional formatting.
         */
        role?: pulumi.Input<enums.quicksight.AnalysisPivotTableConditionalFormattingScopeRole>;
    }
    interface AnalysisPivotTableConfigurationArgs {
        /**
         * The field options for a pivot table visual.
         */
        fieldOptions?: pulumi.Input<inputs.quicksight.AnalysisPivotTableFieldOptionsArgs>;
        /**
         * The field wells of the visual.
         */
        fieldWells?: pulumi.Input<inputs.quicksight.AnalysisPivotTableFieldWellsArgs>;
        /**
         * The general visual interactions setup for a visual.
         */
        interactions?: pulumi.Input<inputs.quicksight.AnalysisVisualInteractionOptionsArgs>;
        /**
         * The paginated report options for a pivot table visual.
         */
        paginatedReportOptions?: pulumi.Input<inputs.quicksight.AnalysisPivotTablePaginatedReportOptionsArgs>;
        /**
         * The sort configuration for a `PivotTableVisual` .
         */
        sortConfiguration?: pulumi.Input<inputs.quicksight.AnalysisPivotTableSortConfigurationArgs>;
        /**
         * The table options for a pivot table visual.
         */
        tableOptions?: pulumi.Input<inputs.quicksight.AnalysisPivotTableOptionsArgs>;
        /**
         * The total options for a pivot table visual.
         */
        totalOptions?: pulumi.Input<inputs.quicksight.AnalysisPivotTableTotalOptionsArgs>;
    }
    interface AnalysisPivotTableDataPathOptionArgs {
        /**
         * The list of data path values for the data path options.
         */
        dataPathList: pulumi.Input<pulumi.Input<inputs.quicksight.AnalysisDataPathValueArgs>[]>;
        /**
         * String based length that is composed of value and unit in px
         */
        width?: pulumi.Input<string>;
    }
    interface AnalysisPivotTableFieldCollapseStateOptionArgs {
        /**
         * The state of the field target of a pivot table. Choose one of the following options:
         *
         * - `COLLAPSED`
         * - `EXPANDED`
         */
        state?: pulumi.Input<enums.quicksight.AnalysisPivotTableFieldCollapseState>;
        /**
         * A tagged-union object that sets the collapse state.
         */
        target: pulumi.Input<inputs.quicksight.AnalysisPivotTableFieldCollapseStateTargetArgs>;
    }
    interface AnalysisPivotTableFieldCollapseStateTargetArgs {
        /**
         * The data path of the pivot table's header. Used to set the collapse state.
         */
        fieldDataPathValues?: pulumi.Input<pulumi.Input<inputs.quicksight.AnalysisDataPathValueArgs>[]>;
        /**
         * The field ID of the pivot table that the collapse state needs to be set to.
         */
        fieldId?: pulumi.Input<string>;
    }
    interface AnalysisPivotTableFieldOptionArgs {
        /**
         * The custom label of the pivot table field.
         */
        customLabel?: pulumi.Input<string>;
        /**
         * The field ID of the pivot table field.
         */
        fieldId: pulumi.Input<string>;
        /**
         * The visibility of the pivot table field.
         */
        visibility?: pulumi.Input<enums.quicksight.AnalysisVisibility>;
    }
    interface AnalysisPivotTableFieldOptionsArgs {
        /**
         * The collapse state options for the pivot table field options.
         */
        collapseStateOptions?: pulumi.Input<pulumi.Input<inputs.quicksight.AnalysisPivotTableFieldCollapseStateOptionArgs>[]>;
        /**
         * The data path options for the pivot table field options.
         */
        dataPathOptions?: pulumi.Input<pulumi.Input<inputs.quicksight.AnalysisPivotTableDataPathOptionArgs>[]>;
        /**
         * The selected field options for the pivot table field options.
         */
        selectedFieldOptions?: pulumi.Input<pulumi.Input<inputs.quicksight.AnalysisPivotTableFieldOptionArgs>[]>;
    }
    interface AnalysisPivotTableFieldSubtotalOptionsArgs {
        /**
         * The field ID of the subtotal options.
         */
        fieldId?: pulumi.Input<string>;
    }
    interface AnalysisPivotTableFieldWellsArgs {
        /**
         * The aggregated field well for the pivot table.
         */
        pivotTableAggregatedFieldWells?: pulumi.Input<inputs.quicksight.AnalysisPivotTableAggregatedFieldWellsArgs>;
    }
    interface AnalysisPivotTableOptionsArgs {
        /**
         * The table cell style of cells.
         */
        cellStyle?: pulumi.Input<inputs.quicksight.AnalysisTableCellStyleArgs>;
        /**
         * The visibility setting of a pivot table's collapsed row dimension fields. If the value of this structure is `HIDDEN` , all collapsed columns in a pivot table are automatically hidden. The default value is `VISIBLE` .
         */
        collapsedRowDimensionsVisibility?: pulumi.Input<enums.quicksight.AnalysisVisibility>;
        /**
         * The table cell style of the column header.
         */
        columnHeaderStyle?: pulumi.Input<inputs.quicksight.AnalysisTableCellStyleArgs>;
        /**
         * The visibility of the column names.
         */
        columnNamesVisibility?: pulumi.Input<enums.quicksight.AnalysisVisibility>;
        /**
         * String based length that is composed of value and unit in px
         */
        defaultCellWidth?: pulumi.Input<string>;
        /**
         * The metric placement (row, column) options.
         */
        metricPlacement?: pulumi.Input<enums.quicksight.AnalysisPivotTableMetricPlacement>;
        /**
         * The row alternate color options (widget status, row alternate colors).
         */
        rowAlternateColorOptions?: pulumi.Input<inputs.quicksight.AnalysisRowAlternateColorOptionsArgs>;
        /**
         * The table cell style of row field names.
         */
        rowFieldNamesStyle?: pulumi.Input<inputs.quicksight.AnalysisTableCellStyleArgs>;
        /**
         * The table cell style of the row headers.
         */
        rowHeaderStyle?: pulumi.Input<inputs.quicksight.AnalysisTableCellStyleArgs>;
        /**
         * The options for the label that is located above the row headers. This option is only applicable when `RowsLayout` is set to `HIERARCHY` .
         */
        rowsLabelOptions?: pulumi.Input<inputs.quicksight.AnalysisPivotTableRowsLabelOptionsArgs>;
        /**
         * The layout for the row dimension headers of a pivot table. Choose one of the following options.
         *
         * - `TABULAR` : (Default) Each row field is displayed in a separate column.
         * - `HIERARCHY` : All row fields are displayed in a single column. Indentation is used to differentiate row headers of different fields.
         */
        rowsLayout?: pulumi.Input<enums.quicksight.AnalysisPivotTableRowsLayout>;
        /**
         * The visibility of the single metric options.
         */
        singleMetricVisibility?: pulumi.Input<enums.quicksight.AnalysisVisibility>;
        /**
         * Determines the visibility of the pivot table.
         */
        toggleButtonsVisibility?: pulumi.Input<enums.quicksight.AnalysisVisibility>;
    }
    interface AnalysisPivotTablePaginatedReportOptionsArgs {
        /**
         * The visibility of the repeating header rows on each page.
         */
        overflowColumnHeaderVisibility?: pulumi.Input<enums.quicksight.AnalysisVisibility>;
        /**
         * The visibility of the printing table overflow across pages.
         */
        verticalOverflowVisibility?: pulumi.Input<enums.quicksight.AnalysisVisibility>;
    }
    interface AnalysisPivotTableRowsLabelOptionsArgs {
        /**
         * The custom label string for the rows label.
         */
        customLabel?: pulumi.Input<string>;
        /**
         * The visibility of the rows label.
         */
        visibility?: pulumi.Input<enums.quicksight.AnalysisVisibility>;
    }
    interface AnalysisPivotTableSortByArgs {
        /**
         * The column sort (field id, direction) for the pivot table sort by options.
         */
        column?: pulumi.Input<inputs.quicksight.AnalysisColumnSortArgs>;
        /**
         * The data path sort (data path value, direction) for the pivot table sort by options.
         */
        dataPath?: pulumi.Input<inputs.quicksight.AnalysisDataPathSortArgs>;
        /**
         * The field sort (field id, direction) for the pivot table sort by options.
         */
        field?: pulumi.Input<inputs.quicksight.AnalysisFieldSortArgs>;
    }
    interface AnalysisPivotTableSortConfigurationArgs {
        /**
         * The field sort options for a pivot table sort configuration.
         */
        fieldSortOptions?: pulumi.Input<pulumi.Input<inputs.quicksight.AnalysisPivotFieldSortOptionsArgs>[]>;
    }
    interface AnalysisPivotTableTotalOptionsArgs {
        /**
         * The column subtotal options.
         */
        columnSubtotalOptions?: pulumi.Input<inputs.quicksight.AnalysisSubtotalOptionsArgs>;
        /**
         * The column total options.
         */
        columnTotalOptions?: pulumi.Input<inputs.quicksight.AnalysisPivotTotalOptionsArgs>;
        /**
         * The row subtotal options.
         */
        rowSubtotalOptions?: pulumi.Input<inputs.quicksight.AnalysisSubtotalOptionsArgs>;
        /**
         * The row total options.
         */
        rowTotalOptions?: pulumi.Input<inputs.quicksight.AnalysisPivotTotalOptionsArgs>;
    }
    interface AnalysisPivotTableVisualArgs {
        /**
         * The list of custom actions that are configured for a visual.
         */
        actions?: pulumi.Input<pulumi.Input<inputs.quicksight.AnalysisVisualCustomActionArgs>[]>;
        /**
         * The configuration settings of the visual.
         */
        chartConfiguration?: pulumi.Input<inputs.quicksight.AnalysisPivotTableConfigurationArgs>;
        /**
         * The conditional formatting for a `PivotTableVisual` .
         */
        conditionalFormatting?: pulumi.Input<inputs.quicksight.AnalysisPivotTableConditionalFormattingArgs>;
        /**
         * The subtitle that is displayed on the visual.
         */
        subtitle?: pulumi.Input<inputs.quicksight.AnalysisVisualSubtitleLabelOptionsArgs>;
        /**
         * The title that is displayed on the visual.
         */
        title?: pulumi.Input<inputs.quicksight.AnalysisVisualTitleLabelOptionsArgs>;
        /**
         * The alt text for the visual.
         */
        visualContentAltText?: pulumi.Input<string>;
        /**
         * The unique identifier of a visual. This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers..
         */
        visualId: pulumi.Input<string>;
    }
    interface AnalysisPivotTotalOptionsArgs {
        /**
         * The custom label string for the total cells.
         */
        customLabel?: pulumi.Input<string>;
        /**
         * The cell styling options for the total of header cells.
         */
        metricHeaderCellStyle?: pulumi.Input<inputs.quicksight.AnalysisTableCellStyleArgs>;
        /**
         * The placement (start, end) for the total cells.
         */
        placement?: pulumi.Input<enums.quicksight.AnalysisTableTotalsPlacement>;
        /**
         * The scroll status (pinned, scrolled) for the total cells.
         */
        scrollStatus?: pulumi.Input<enums.quicksight.AnalysisTableTotalsScrollStatus>;
        /**
         * The total aggregation options for each value field.
         */
        totalAggregationOptions?: pulumi.Input<pulumi.Input<inputs.quicksight.AnalysisTotalAggregationOptionArgs>[]>;
        /**
         * The cell styling options for the total cells.
         */
        totalCellStyle?: pulumi.Input<inputs.quicksight.AnalysisTableCellStyleArgs>;
        /**
         * The visibility configuration for the total cells.
         */
        totalsVisibility?: pulumi.Input<enums.quicksight.AnalysisVisibility>;
        /**
         * The cell styling options for the totals of value cells.
         */
        valueCellStyle?: pulumi.Input<inputs.quicksight.AnalysisTableCellStyleArgs>;
    }
    interface AnalysisPluginVisualArgs {
        /**
         * A description of the plugin field wells and their persisted properties.
         */
        chartConfiguration?: pulumi.Input<inputs.quicksight.AnalysisPluginVisualConfigurationArgs>;
        /**
         * The Amazon Resource Name (ARN) that reflects the plugin and version.
         */
        pluginArn: pulumi.Input<string>;
        subtitle?: pulumi.Input<inputs.quicksight.AnalysisVisualSubtitleLabelOptionsArgs>;
        title?: pulumi.Input<inputs.quicksight.AnalysisVisualTitleLabelOptionsArgs>;
        /**
         * The alt text for the visual.
         */
        visualContentAltText?: pulumi.Input<string>;
        /**
         * The ID of the visual that you want to use.
         */
        visualId: pulumi.Input<string>;
    }
    interface AnalysisPluginVisualConfigurationArgs {
        /**
         * The field wells configuration of the plugin visual.
         */
        fieldWells?: pulumi.Input<pulumi.Input<inputs.quicksight.AnalysisPluginVisualFieldWellArgs>[]>;
        /**
         * The sort configuration of the plugin visual.
         */
        sortConfiguration?: pulumi.Input<inputs.quicksight.AnalysisPluginVisualSortConfigurationArgs>;
        /**
         * The persisted properties of the plugin visual.
         */
        visualOptions?: pulumi.Input<inputs.quicksight.AnalysisPluginVisualOptionsArgs>;
    }
    interface AnalysisPluginVisualFieldWellArgs {
        /**
         * The semantic axis name for the field well.
         */
        axisName?: pulumi.Input<enums.quicksight.AnalysisPluginVisualAxisName>;
        /**
         * A list of dimensions for the field well.
         */
        dimensions?: pulumi.Input<pulumi.Input<inputs.quicksight.AnalysisDimensionFieldArgs>[]>;
        /**
         * A list of measures that exist in the field well.
         */
        measures?: pulumi.Input<pulumi.Input<inputs.quicksight.AnalysisMeasureFieldArgs>[]>;
        /**
         * A list of unaggregated fields that exist in the field well.
         */
        unaggregated?: pulumi.Input<pulumi.Input<inputs.quicksight.AnalysisUnaggregatedFieldArgs>[]>;
    }
    interface AnalysisPluginVisualItemsLimitConfigurationArgs {
        /**
         * Determines how many values are be fetched at once.
         */
        itemsLimit?: pulumi.Input<number>;
    }
    interface AnalysisPluginVisualOptionsArgs {
        /**
         * The persisted properties and their values.
         */
        visualProperties?: pulumi.Input<pulumi.Input<inputs.quicksight.AnalysisPluginVisualPropertyArgs>[]>;
    }
    interface AnalysisPluginVisualPropertyArgs {
        /**
         * The name of the plugin visual property.
         */
        name?: pulumi.Input<string>;
        /**
         * The value of the plugin visual property.
         */
        value?: pulumi.Input<string>;
    }
    interface AnalysisPluginVisualSortConfigurationArgs {
        /**
         * The table query sorting options for the plugin visual.
         */
        pluginVisualTableQuerySort?: pulumi.Input<inputs.quicksight.AnalysisPluginVisualTableQuerySortArgs>;
    }
    interface AnalysisPluginVisualTableQuerySortArgs {
        /**
         * The maximum amount of data to be returned by a query.
         */
        itemsLimitConfiguration?: pulumi.Input<inputs.quicksight.AnalysisPluginVisualItemsLimitConfigurationArgs>;
        /**
         * Determines how data is sorted in the response.
         */
        rowSort?: pulumi.Input<pulumi.Input<inputs.quicksight.AnalysisFieldSortOptionsArgs>[]>;
    }
    interface AnalysisPredefinedHierarchyArgs {
        /**
         * The list of columns that define the predefined hierarchy.
         */
        columns: pulumi.Input<pulumi.Input<inputs.quicksight.AnalysisColumnIdentifierArgs>[]>;
        /**
         * The option that determines the drill down filters for the predefined hierarchy.
         */
        drillDownFilters?: pulumi.Input<pulumi.Input<inputs.quicksight.AnalysisDrillDownFilterArgs>[]>;
        /**
         * The hierarchy ID of the predefined hierarchy.
         */
        hierarchyId: pulumi.Input<string>;
    }
    interface AnalysisProgressBarOptionsArgs {
        /**
         * The visibility of the progress bar.
         */
        visibility?: pulumi.Input<enums.quicksight.AnalysisVisibility>;
    }
    interface AnalysisQueryExecutionOptionsArgs {
        /**
         * A structure that describes the query execution mode.
         */
        queryExecutionMode?: pulumi.Input<enums.quicksight.AnalysisQueryExecutionMode>;
    }
    interface AnalysisRadarChartAggregatedFieldWellsArgs {
        /**
         * The aggregated field well categories of a radar chart.
         */
        category?: pulumi.Input<pulumi.Input<inputs.quicksight.AnalysisDimensionFieldArgs>[]>;
        /**
         * The color that are assigned to the aggregated field wells of a radar chart.
         */
        color?: pulumi.Input<pulumi.Input<inputs.quicksight.AnalysisDimensionFieldArgs>[]>;
        /**
         * The values that are assigned to the aggregated field wells of a radar chart.
         */
        values?: pulumi.Input<pulumi.Input<inputs.quicksight.AnalysisMeasureFieldArgs>[]>;
    }
    interface AnalysisRadarChartAreaStyleSettingsArgs {
        /**
         * The visibility settings of a radar chart.
         */
        visibility?: pulumi.Input<enums.quicksight.AnalysisVisibility>;
    }
    interface AnalysisRadarChartConfigurationArgs {
        /**
         * Determines the visibility of the colors of alternatign bands in a radar chart.
         */
        alternateBandColorsVisibility?: pulumi.Input<enums.quicksight.AnalysisVisibility>;
        /**
         * The color of the even-numbered alternate bands of a radar chart.
         */
        alternateBandEvenColor?: pulumi.Input<string>;
        /**
         * The color of the odd-numbered alternate bands of a radar chart.
         */
        alternateBandOddColor?: pulumi.Input<string>;
        /**
         * The axis behavior options of a radar chart.
         */
        axesRangeScale?: pulumi.Input<enums.quicksight.AnalysisRadarChartAxesRangeScale>;
        /**
         * The base sreies settings of a radar chart.
         */
        baseSeriesSettings?: pulumi.Input<inputs.quicksight.AnalysisRadarChartSeriesSettingsArgs>;
        /**
         * The category axis of a radar chart.
         */
        categoryAxis?: pulumi.Input<inputs.quicksight.AnalysisAxisDisplayOptionsArgs>;
        /**
         * The category label options of a radar chart.
         */
        categoryLabelOptions?: pulumi.Input<inputs.quicksight.AnalysisChartAxisLabelOptionsArgs>;
        /**
         * The color axis of a radar chart.
         */
        colorAxis?: pulumi.Input<inputs.quicksight.AnalysisAxisDisplayOptionsArgs>;
        /**
         * The color label options of a radar chart.
         */
        colorLabelOptions?: pulumi.Input<inputs.quicksight.AnalysisChartAxisLabelOptionsArgs>;
        /**
         * The field well configuration of a `RadarChartVisual` .
         */
        fieldWells?: pulumi.Input<inputs.quicksight.AnalysisRadarChartFieldWellsArgs>;
        /**
         * The general visual interactions setup for a visual.
         */
        interactions?: pulumi.Input<inputs.quicksight.AnalysisVisualInteractionOptionsArgs>;
        /**
         * The legend display setup of the visual.
         */
        legend?: pulumi.Input<inputs.quicksight.AnalysisLegendOptionsArgs>;
        /**
         * The shape of the radar chart.
         */
        shape?: pulumi.Input<enums.quicksight.AnalysisRadarChartShape>;
        /**
         * The sort configuration of a `RadarChartVisual` .
         */
        sortConfiguration?: pulumi.Input<inputs.quicksight.AnalysisRadarChartSortConfigurationArgs>;
        /**
         * The start angle of a radar chart's axis.
         */
        startAngle?: pulumi.Input<number>;
        /**
         * The palette (chart color) display setup of the visual.
         */
        visualPalette?: pulumi.Input<inputs.quicksight.AnalysisVisualPaletteArgs>;
    }
    interface AnalysisRadarChartFieldWellsArgs {
        /**
         * The aggregated field wells of a radar chart visual.
         */
        radarChartAggregatedFieldWells?: pulumi.Input<inputs.quicksight.AnalysisRadarChartAggregatedFieldWellsArgs>;
    }
    interface AnalysisRadarChartSeriesSettingsArgs {
        /**
         * The area style settings of a radar chart.
         */
        areaStyleSettings?: pulumi.Input<inputs.quicksight.AnalysisRadarChartAreaStyleSettingsArgs>;
    }
    interface AnalysisRadarChartSortConfigurationArgs {
        /**
         * The category items limit for a radar chart.
         */
        categoryItemsLimit?: pulumi.Input<inputs.quicksight.AnalysisItemsLimitConfigurationArgs>;
        /**
         * The category sort options of a radar chart.
         */
        categorySort?: pulumi.Input<pulumi.Input<inputs.quicksight.AnalysisFieldSortOptionsArgs>[]>;
        /**
         * The color items limit of a radar chart.
         */
        colorItemsLimit?: pulumi.Input<inputs.quicksight.AnalysisItemsLimitConfigurationArgs>;
        /**
         * The color sort configuration of a radar chart.
         */
        colorSort?: pulumi.Input<pulumi.Input<inputs.quicksight.AnalysisFieldSortOptionsArgs>[]>;
    }
    interface AnalysisRadarChartVisualArgs {
        /**
         * The list of custom actions that are configured for a visual.
         */
        actions?: pulumi.Input<pulumi.Input<inputs.quicksight.AnalysisVisualCustomActionArgs>[]>;
        /**
         * The configuration settings of the visual.
         */
        chartConfiguration?: pulumi.Input<inputs.quicksight.AnalysisRadarChartConfigurationArgs>;
        /**
         * The column hierarchy that is used during drill-downs and drill-ups.
         */
        columnHierarchies?: pulumi.Input<pulumi.Input<inputs.quicksight.AnalysisColumnHierarchyArgs>[]>;
        /**
         * The subtitle that is displayed on the visual.
         */
        subtitle?: pulumi.Input<inputs.quicksight.AnalysisVisualSubtitleLabelOptionsArgs>;
        /**
         * The title that is displayed on the visual.
         */
        title?: pulumi.Input<inputs.quicksight.AnalysisVisualTitleLabelOptionsArgs>;
        /**
         * The alt text for the visual.
         */
        visualContentAltText?: pulumi.Input<string>;
        /**
         * The unique identifier of a visual. This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers.
         */
        visualId: pulumi.Input<string>;
    }
    interface AnalysisRangeEndsLabelTypeArgs {
        /**
         * The visibility of the range ends label.
         */
        visibility?: pulumi.Input<enums.quicksight.AnalysisVisibility>;
    }
    interface AnalysisReferenceLineArgs {
        /**
         * The data configuration of the reference line.
         */
        dataConfiguration: pulumi.Input<inputs.quicksight.AnalysisReferenceLineDataConfigurationArgs>;
        /**
         * The label configuration of the reference line.
         */
        labelConfiguration?: pulumi.Input<inputs.quicksight.AnalysisReferenceLineLabelConfigurationArgs>;
        /**
         * The status of the reference line. Choose one of the following options:
         *
         * - `ENABLE`
         * - `DISABLE`
         */
        status?: pulumi.Input<enums.quicksight.AnalysisWidgetStatus>;
        /**
         * The style configuration of the reference line.
         */
        styleConfiguration?: pulumi.Input<inputs.quicksight.AnalysisReferenceLineStyleConfigurationArgs>;
    }
    interface AnalysisReferenceLineCustomLabelConfigurationArgs {
        /**
         * The string text of the custom label.
         */
        customLabel: pulumi.Input<string>;
    }
    interface AnalysisReferenceLineDataConfigurationArgs {
        /**
         * The axis binding type of the reference line. Choose one of the following options:
         *
         * - `PrimaryY`
         * - `SecondaryY`
         */
        axisBinding?: pulumi.Input<enums.quicksight.AnalysisAxisBinding>;
        /**
         * The dynamic configuration of the reference line data configuration.
         */
        dynamicConfiguration?: pulumi.Input<inputs.quicksight.AnalysisReferenceLineDynamicDataConfigurationArgs>;
        /**
         * The series type of the reference line data configuration. Choose one of the following options:
         *
         * - `BAR`
         * - `LINE`
         */
        seriesType?: pulumi.Input<enums.quicksight.AnalysisReferenceLineSeriesType>;
        /**
         * The static data configuration of the reference line data configuration.
         */
        staticConfiguration?: pulumi.Input<inputs.quicksight.AnalysisReferenceLineStaticDataConfigurationArgs>;
    }
    interface AnalysisReferenceLineDynamicDataConfigurationArgs {
        /**
         * The calculation that is used in the dynamic data.
         */
        calculation: pulumi.Input<inputs.quicksight.AnalysisNumericalAggregationFunctionArgs>;
        /**
         * The column that the dynamic data targets.
         */
        column: pulumi.Input<inputs.quicksight.AnalysisColumnIdentifierArgs>;
        /**
         * The aggregation function that is used in the dynamic data.
         */
        measureAggregationFunction?: pulumi.Input<inputs.quicksight.AnalysisAggregationFunctionArgs>;
    }
    interface AnalysisReferenceLineLabelConfigurationArgs {
        /**
         * The custom label configuration of the label in a reference line.
         */
        customLabelConfiguration?: pulumi.Input<inputs.quicksight.AnalysisReferenceLineCustomLabelConfigurationArgs>;
        /**
         * The font color configuration of the label in a reference line.
         */
        fontColor?: pulumi.Input<string>;
        /**
         * The font configuration of the label in a reference line.
         */
        fontConfiguration?: pulumi.Input<inputs.quicksight.AnalysisFontConfigurationArgs>;
        /**
         * The horizontal position configuration of the label in a reference line. Choose one of the following options:
         *
         * - `LEFT`
         * - `CENTER`
         * - `RIGHT`
         */
        horizontalPosition?: pulumi.Input<enums.quicksight.AnalysisReferenceLineLabelHorizontalPosition>;
        /**
         * The value label configuration of the label in a reference line.
         */
        valueLabelConfiguration?: pulumi.Input<inputs.quicksight.AnalysisReferenceLineValueLabelConfigurationArgs>;
        /**
         * The vertical position configuration of the label in a reference line. Choose one of the following options:
         *
         * - `ABOVE`
         * - `BELOW`
         */
        verticalPosition?: pulumi.Input<enums.quicksight.AnalysisReferenceLineLabelVerticalPosition>;
    }
    interface AnalysisReferenceLineStaticDataConfigurationArgs {
        /**
         * The double input of the static data.
         */
        value: pulumi.Input<number>;
    }
    interface AnalysisReferenceLineStyleConfigurationArgs {
        /**
         * The hex color of the reference line.
         */
        color?: pulumi.Input<string>;
        /**
         * The pattern type of the line style. Choose one of the following options:
         *
         * - `SOLID`
         * - `DASHED`
         * - `DOTTED`
         */
        pattern?: pulumi.Input<enums.quicksight.AnalysisReferenceLinePatternType>;
    }
    interface AnalysisReferenceLineValueLabelConfigurationArgs {
        /**
         * The format configuration of the value label.
         */
        formatConfiguration?: pulumi.Input<inputs.quicksight.AnalysisNumericFormatConfigurationArgs>;
        /**
         * The relative position of the value label. Choose one of the following options:
         *
         * - `BEFORE_CUSTOM_LABEL`
         * - `AFTER_CUSTOM_LABEL`
         */
        relativePosition?: pulumi.Input<enums.quicksight.AnalysisReferenceLineValueLabelRelativePosition>;
    }
    interface AnalysisRelativeDateTimeControlDisplayOptionsArgs {
        /**
         * Customize how dates are formatted in controls.
         */
        dateTimeFormat?: pulumi.Input<string>;
        /**
         * The configuration of info icon label options.
         */
        infoIconLabelOptions?: pulumi.Input<inputs.quicksight.AnalysisSheetControlInfoIconLabelOptionsArgs>;
        /**
         * The options to configure the title visibility, name, and font size.
         */
        titleOptions?: pulumi.Input<inputs.quicksight.AnalysisLabelOptionsArgs>;
    }
    interface AnalysisRelativeDatesFilterArgs {
        /**
         * The date configuration of the filter.
         */
        anchorDateConfiguration: pulumi.Input<inputs.quicksight.AnalysisAnchorDateConfigurationArgs>;
        /**
         * The column that the filter is applied to.
         */
        column: pulumi.Input<inputs.quicksight.AnalysisColumnIdentifierArgs>;
        /**
         * The default configurations for the associated controls. This applies only for filters that are scoped to multiple sheets.
         */
        defaultFilterControlConfiguration?: pulumi.Input<inputs.quicksight.AnalysisDefaultFilterControlConfigurationArgs>;
        /**
         * The configuration for the exclude period of the filter.
         */
        excludePeriodConfiguration?: pulumi.Input<inputs.quicksight.AnalysisExcludePeriodConfigurationArgs>;
        /**
         * An identifier that uniquely identifies a filter within a dashboard, analysis, or template.
         */
        filterId: pulumi.Input<string>;
        /**
         * The minimum granularity (period granularity) of the relative dates filter.
         */
        minimumGranularity?: pulumi.Input<enums.quicksight.AnalysisTimeGranularity>;
        /**
         * This option determines how null values should be treated when filtering data.
         *
         * - `ALL_VALUES` : Include null values in filtered results.
         * - `NULLS_ONLY` : Only include null values in filtered results.
         * - `NON_NULLS_ONLY` : Exclude null values from filtered results.
         */
        nullOption: pulumi.Input<enums.quicksight.AnalysisFilterNullOption>;
        /**
         * The parameter whose value should be used for the filter value.
         */
        parameterName?: pulumi.Input<string>;
        /**
         * The range date type of the filter. Choose one of the options below:
         *
         * - `PREVIOUS`
         * - `THIS`
         * - `LAST`
         * - `NOW`
         * - `NEXT`
         */
        relativeDateType: pulumi.Input<enums.quicksight.AnalysisRelativeDateType>;
        /**
         * The date value of the filter.
         */
        relativeDateValue?: pulumi.Input<number>;
        /**
         * The level of time precision that is used to aggregate `DateTime` values.
         */
        timeGranularity: pulumi.Input<enums.quicksight.AnalysisTimeGranularity>;
    }
    /**
     * <p>Permission for the resource.</p>
     */
    interface AnalysisResourcePermissionArgs {
        /**
         * <p>The IAM action to grant or revoke permissions on.</p>
         */
        actions: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * <p>The Amazon Resource Name (ARN) of the principal. This can be one of the
         *             following:</p>
         *          <ul>
         *             <li>
         *                <p>The ARN of an Amazon QuickSight user or group associated with a data source or dataset. (This is common.)</p>
         *             </li>
         *             <li>
         *                <p>The ARN of an Amazon QuickSight user, group, or namespace associated with an analysis, dashboard, template, or theme. (This is common.)</p>
         *             </li>
         *             <li>
         *                <p>The ARN of an Amazon Web Services account root: This is an IAM ARN rather than a QuickSight
         *                     ARN. Use this option only to share resources (templates) across Amazon Web Services accounts.
         *                     (This is less common.) </p>
         *             </li>
         *          </ul>
         */
        principal: pulumi.Input<string>;
    }
    interface AnalysisRollingDateConfigurationArgs {
        /**
         * The data set that is used in the rolling date configuration.
         */
        dataSetIdentifier?: pulumi.Input<string>;
        /**
         * The expression of the rolling date configuration.
         */
        expression: pulumi.Input<string>;
    }
    interface AnalysisRowAlternateColorOptionsArgs {
        /**
         * Determines the list of row alternate colors.
         */
        rowAlternateColors?: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * Determines the widget status.
         */
        status?: pulumi.Input<enums.quicksight.AnalysisWidgetStatus>;
        /**
         * The primary background color options for alternate rows.
         */
        usePrimaryBackgroundColor?: pulumi.Input<enums.quicksight.AnalysisWidgetStatus>;
    }
    interface AnalysisSameSheetTargetVisualConfigurationArgs {
        /**
         * The options that choose the target visual in the same sheet.
         *
         * Valid values are defined as follows:
         *
         * - `ALL_VISUALS` : Applies the filter operation to all visuals in the same sheet.
         */
        targetVisualOptions?: pulumi.Input<enums.quicksight.AnalysisTargetVisualOptions>;
        /**
         * A list of the target visual IDs that are located in the same sheet of the analysis.
         */
        targetVisuals?: pulumi.Input<pulumi.Input<string>[]>;
    }
    interface AnalysisSankeyDiagramAggregatedFieldWellsArgs {
        /**
         * The destination field wells of a sankey diagram.
         */
        destination?: pulumi.Input<pulumi.Input<inputs.quicksight.AnalysisDimensionFieldArgs>[]>;
        /**
         * The source field wells of a sankey diagram.
         */
        source?: pulumi.Input<pulumi.Input<inputs.quicksight.AnalysisDimensionFieldArgs>[]>;
        /**
         * The weight field wells of a sankey diagram.
         */
        weight?: pulumi.Input<pulumi.Input<inputs.quicksight.AnalysisMeasureFieldArgs>[]>;
    }
    interface AnalysisSankeyDiagramChartConfigurationArgs {
        /**
         * The data label configuration of a sankey diagram.
         */
        dataLabels?: pulumi.Input<inputs.quicksight.AnalysisDataLabelOptionsArgs>;
        /**
         * The field well configuration of a sankey diagram.
         */
        fieldWells?: pulumi.Input<inputs.quicksight.AnalysisSankeyDiagramFieldWellsArgs>;
        /**
         * The general visual interactions setup for a visual.
         */
        interactions?: pulumi.Input<inputs.quicksight.AnalysisVisualInteractionOptionsArgs>;
        /**
         * The sort configuration of a sankey diagram.
         */
        sortConfiguration?: pulumi.Input<inputs.quicksight.AnalysisSankeyDiagramSortConfigurationArgs>;
    }
    interface AnalysisSankeyDiagramFieldWellsArgs {
        /**
         * The field well configuration of a sankey diagram.
         */
        sankeyDiagramAggregatedFieldWells?: pulumi.Input<inputs.quicksight.AnalysisSankeyDiagramAggregatedFieldWellsArgs>;
    }
    interface AnalysisSankeyDiagramSortConfigurationArgs {
        /**
         * The limit on the number of destination nodes that are displayed in a sankey diagram.
         */
        destinationItemsLimit?: pulumi.Input<inputs.quicksight.AnalysisItemsLimitConfigurationArgs>;
        /**
         * The limit on the number of source nodes that are displayed in a sankey diagram.
         */
        sourceItemsLimit?: pulumi.Input<inputs.quicksight.AnalysisItemsLimitConfigurationArgs>;
        /**
         * The sort configuration of the weight fields.
         */
        weightSort?: pulumi.Input<pulumi.Input<inputs.quicksight.AnalysisFieldSortOptionsArgs>[]>;
    }
    interface AnalysisSankeyDiagramVisualArgs {
        /**
         * The list of custom actions that are configured for a visual.
         */
        actions?: pulumi.Input<pulumi.Input<inputs.quicksight.AnalysisVisualCustomActionArgs>[]>;
        /**
         * The configuration of a sankey diagram.
         */
        chartConfiguration?: pulumi.Input<inputs.quicksight.AnalysisSankeyDiagramChartConfigurationArgs>;
        /**
         * The subtitle that is displayed on the visual.
         */
        subtitle?: pulumi.Input<inputs.quicksight.AnalysisVisualSubtitleLabelOptionsArgs>;
        /**
         * The title that is displayed on the visual.
         */
        title?: pulumi.Input<inputs.quicksight.AnalysisVisualTitleLabelOptionsArgs>;
        /**
         * The alt text for the visual.
         */
        visualContentAltText?: pulumi.Input<string>;
        /**
         * The unique identifier of a visual. This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers.
         */
        visualId: pulumi.Input<string>;
    }
    interface AnalysisScatterPlotCategoricallyAggregatedFieldWellsArgs {
        /**
         * The category field well of a scatter plot.
         */
        category?: pulumi.Input<pulumi.Input<inputs.quicksight.AnalysisDimensionFieldArgs>[]>;
        /**
         * The label field well of a scatter plot.
         */
        label?: pulumi.Input<pulumi.Input<inputs.quicksight.AnalysisDimensionFieldArgs>[]>;
        /**
         * The size field well of a scatter plot.
         */
        size?: pulumi.Input<pulumi.Input<inputs.quicksight.AnalysisMeasureFieldArgs>[]>;
        /**
         * The x-axis field well of a scatter plot.
         *
         * The x-axis is aggregated by category.
         */
        xAxis?: pulumi.Input<pulumi.Input<inputs.quicksight.AnalysisMeasureFieldArgs>[]>;
        /**
         * The y-axis field well of a scatter plot.
         *
         * The y-axis is aggregated by category.
         */
        yAxis?: pulumi.Input<pulumi.Input<inputs.quicksight.AnalysisMeasureFieldArgs>[]>;
    }
    interface AnalysisScatterPlotConfigurationArgs {
        /**
         * The options that determine if visual data labels are displayed.
         */
        dataLabels?: pulumi.Input<inputs.quicksight.AnalysisDataLabelOptionsArgs>;
        /**
         * The field wells of the visual.
         */
        fieldWells?: pulumi.Input<inputs.quicksight.AnalysisScatterPlotFieldWellsArgs>;
        /**
         * The general visual interactions setup for a visual.
         */
        interactions?: pulumi.Input<inputs.quicksight.AnalysisVisualInteractionOptionsArgs>;
        /**
         * The legend display setup of the visual.
         */
        legend?: pulumi.Input<inputs.quicksight.AnalysisLegendOptionsArgs>;
        /**
         * The sort configuration of a scatter plot.
         */
        sortConfiguration?: pulumi.Input<inputs.quicksight.AnalysisScatterPlotSortConfigurationArgs>;
        /**
         * The legend display setup of the visual.
         */
        tooltip?: pulumi.Input<inputs.quicksight.AnalysisTooltipOptionsArgs>;
        /**
         * The palette (chart color) display setup of the visual.
         */
        visualPalette?: pulumi.Input<inputs.quicksight.AnalysisVisualPaletteArgs>;
        /**
         * The label display options (grid line, range, scale, and axis step) of the scatter plot's x-axis.
         */
        xAxisDisplayOptions?: pulumi.Input<inputs.quicksight.AnalysisAxisDisplayOptionsArgs>;
        /**
         * The label options (label text, label visibility, and sort icon visibility) of the scatter plot's x-axis.
         */
        xAxisLabelOptions?: pulumi.Input<inputs.quicksight.AnalysisChartAxisLabelOptionsArgs>;
        /**
         * The label display options (grid line, range, scale, and axis step) of the scatter plot's y-axis.
         */
        yAxisDisplayOptions?: pulumi.Input<inputs.quicksight.AnalysisAxisDisplayOptionsArgs>;
        /**
         * The label options (label text, label visibility, and sort icon visibility) of the scatter plot's y-axis.
         */
        yAxisLabelOptions?: pulumi.Input<inputs.quicksight.AnalysisChartAxisLabelOptionsArgs>;
    }
    interface AnalysisScatterPlotFieldWellsArgs {
        /**
         * The aggregated field wells of a scatter plot. The x and y-axes of scatter plots with aggregated field wells are aggregated by category, label, or both.
         */
        scatterPlotCategoricallyAggregatedFieldWells?: pulumi.Input<inputs.quicksight.AnalysisScatterPlotCategoricallyAggregatedFieldWellsArgs>;
        /**
         * The unaggregated field wells of a scatter plot. The x and y-axes of these scatter plots are unaggregated.
         */
        scatterPlotUnaggregatedFieldWells?: pulumi.Input<inputs.quicksight.AnalysisScatterPlotUnaggregatedFieldWellsArgs>;
    }
    interface AnalysisScatterPlotSortConfigurationArgs {
        scatterPlotLimitConfiguration?: pulumi.Input<inputs.quicksight.AnalysisItemsLimitConfigurationArgs>;
    }
    interface AnalysisScatterPlotUnaggregatedFieldWellsArgs {
        /**
         * The category field well of a scatter plot.
         */
        category?: pulumi.Input<pulumi.Input<inputs.quicksight.AnalysisDimensionFieldArgs>[]>;
        /**
         * The label field well of a scatter plot.
         */
        label?: pulumi.Input<pulumi.Input<inputs.quicksight.AnalysisDimensionFieldArgs>[]>;
        /**
         * The size field well of a scatter plot.
         */
        size?: pulumi.Input<pulumi.Input<inputs.quicksight.AnalysisMeasureFieldArgs>[]>;
        /**
         * The x-axis field well of a scatter plot.
         *
         * The x-axis is a dimension field and cannot be aggregated.
         */
        xAxis?: pulumi.Input<pulumi.Input<inputs.quicksight.AnalysisDimensionFieldArgs>[]>;
        /**
         * The y-axis field well of a scatter plot.
         *
         * The y-axis is a dimension field and cannot be aggregated.
         */
        yAxis?: pulumi.Input<pulumi.Input<inputs.quicksight.AnalysisDimensionFieldArgs>[]>;
    }
    interface AnalysisScatterPlotVisualArgs {
        /**
         * The list of custom actions that are configured for a visual.
         */
        actions?: pulumi.Input<pulumi.Input<inputs.quicksight.AnalysisVisualCustomActionArgs>[]>;
        /**
         * The configuration settings of the visual.
         */
        chartConfiguration?: pulumi.Input<inputs.quicksight.AnalysisScatterPlotConfigurationArgs>;
        /**
         * The column hierarchy that is used during drill-downs and drill-ups.
         */
        columnHierarchies?: pulumi.Input<pulumi.Input<inputs.quicksight.AnalysisColumnHierarchyArgs>[]>;
        /**
         * The subtitle that is displayed on the visual.
         */
        subtitle?: pulumi.Input<inputs.quicksight.AnalysisVisualSubtitleLabelOptionsArgs>;
        /**
         * The title that is displayed on the visual.
         */
        title?: pulumi.Input<inputs.quicksight.AnalysisVisualTitleLabelOptionsArgs>;
        /**
         * The alt text for the visual.
         */
        visualContentAltText?: pulumi.Input<string>;
        /**
         * The unique identifier of a visual. This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers.
         */
        visualId: pulumi.Input<string>;
    }
    interface AnalysisScrollBarOptionsArgs {
        /**
         * The visibility of the data zoom scroll bar.
         */
        visibility?: pulumi.Input<enums.quicksight.AnalysisVisibility>;
        /**
         * The visibility range for the data zoom scroll bar.
         */
        visibleRange?: pulumi.Input<inputs.quicksight.AnalysisVisibleRangeOptionsArgs>;
    }
    interface AnalysisSecondaryValueOptionsArgs {
        /**
         * Determines the visibility of the secondary value.
         */
        visibility?: pulumi.Input<enums.quicksight.AnalysisVisibility>;
    }
    interface AnalysisSectionAfterPageBreakArgs {
        /**
         * The option that enables or disables a page break at the end of a section.
         */
        status?: pulumi.Input<enums.quicksight.AnalysisSectionPageBreakStatus>;
    }
    interface AnalysisSectionBasedLayoutCanvasSizeOptionsArgs {
        /**
         * The options for a paper canvas of a section-based layout.
         */
        paperCanvasSizeOptions?: pulumi.Input<inputs.quicksight.AnalysisSectionBasedLayoutPaperCanvasSizeOptionsArgs>;
    }
    interface AnalysisSectionBasedLayoutConfigurationArgs {
        /**
         * A list of body section configurations.
         */
        bodySections: pulumi.Input<pulumi.Input<inputs.quicksight.AnalysisBodySectionConfigurationArgs>[]>;
        /**
         * The options for the canvas of a section-based layout.
         */
        canvasSizeOptions: pulumi.Input<inputs.quicksight.AnalysisSectionBasedLayoutCanvasSizeOptionsArgs>;
        /**
         * A list of footer section configurations.
         */
        footerSections: pulumi.Input<pulumi.Input<inputs.quicksight.AnalysisHeaderFooterSectionConfigurationArgs>[]>;
        /**
         * A list of header section configurations.
         */
        headerSections: pulumi.Input<pulumi.Input<inputs.quicksight.AnalysisHeaderFooterSectionConfigurationArgs>[]>;
    }
    interface AnalysisSectionBasedLayoutPaperCanvasSizeOptionsArgs {
        /**
         * Defines the spacing between the canvas content and the top, bottom, left, and right edges.
         */
        paperMargin?: pulumi.Input<inputs.quicksight.AnalysisSpacingArgs>;
        /**
         * The paper orientation that is used to define canvas dimensions. Choose one of the following options:
         *
         * - PORTRAIT
         * - LANDSCAPE
         */
        paperOrientation?: pulumi.Input<enums.quicksight.AnalysisPaperOrientation>;
        /**
         * The paper size that is used to define canvas dimensions.
         */
        paperSize?: pulumi.Input<enums.quicksight.AnalysisPaperSize>;
    }
    interface AnalysisSectionLayoutConfigurationArgs {
        /**
         * The free-form layout configuration of a section.
         */
        freeFormLayout: pulumi.Input<inputs.quicksight.AnalysisFreeFormSectionLayoutConfigurationArgs>;
    }
    interface AnalysisSectionPageBreakConfigurationArgs {
        /**
         * The configuration of a page break after a section.
         */
        after?: pulumi.Input<inputs.quicksight.AnalysisSectionAfterPageBreakArgs>;
    }
    interface AnalysisSectionStyleArgs {
        /**
         * String based length that is composed of value and unit in px
         */
        height?: pulumi.Input<string>;
        /**
         * The spacing between section content and its top, bottom, left, and right edges.
         *
         * There is no padding by default.
         */
        padding?: pulumi.Input<inputs.quicksight.AnalysisSpacingArgs>;
    }
    interface AnalysisSelectedSheetsFilterScopeConfigurationArgs {
        /**
         * The sheet ID and visual IDs of the sheet and visuals that the filter is applied to.
         */
        sheetVisualScopingConfigurations?: pulumi.Input<pulumi.Input<inputs.quicksight.AnalysisSheetVisualScopingConfigurationArgs>[]>;
    }
    interface AnalysisSeriesItemArgs {
        /**
         * The data field series item configuration of a line chart.
         */
        dataFieldSeriesItem?: pulumi.Input<inputs.quicksight.AnalysisDataFieldSeriesItemArgs>;
        /**
         * The field series item configuration of a line chart.
         */
        fieldSeriesItem?: pulumi.Input<inputs.quicksight.AnalysisFieldSeriesItemArgs>;
    }
    interface AnalysisSetParameterValueConfigurationArgs {
        /**
         * The destination parameter name of the `SetParameterValueConfiguration` .
         */
        destinationParameterName: pulumi.Input<string>;
        value: pulumi.Input<inputs.quicksight.AnalysisDestinationParameterValueConfigurationArgs>;
    }
    interface AnalysisShapeConditionalFormatArgs {
        /**
         * The conditional formatting for the shape background color of a filled map visual.
         */
        backgroundColor: pulumi.Input<inputs.quicksight.AnalysisConditionalFormattingColorArgs>;
    }
    /**
     * <p>A <i>sheet</i>, which is an object that contains a set of visuals that
     *             are viewed together on one page in Amazon QuickSight. Every analysis and dashboard
     *             contains at least one sheet. Each sheet contains at least one visualization widget, for
     *             example a chart, pivot table, or narrative insight. Sheets can be associated with other
     *             components, such as controls, filters, and so on.</p>
     */
    interface AnalysisSheetArgs {
        /**
         * <p>The name of a sheet. This name is displayed on the sheet's tab in the Amazon QuickSight
         *             console.</p>
         */
        name?: pulumi.Input<string>;
        /**
         * <p>The unique identifier associated with a sheet.</p>
         */
        sheetId?: pulumi.Input<string>;
    }
    interface AnalysisSheetControlInfoIconLabelOptionsArgs {
        /**
         * The text content of info icon.
         */
        infoIconText?: pulumi.Input<string>;
        /**
         * The visibility configuration of info icon label options.
         */
        visibility?: pulumi.Input<enums.quicksight.AnalysisVisibility>;
    }
    interface AnalysisSheetControlLayoutArgs {
        /**
         * The configuration that determines the elements and canvas size options of sheet control.
         */
        configuration: pulumi.Input<inputs.quicksight.AnalysisSheetControlLayoutConfigurationArgs>;
    }
    interface AnalysisSheetControlLayoutConfigurationArgs {
        /**
         * The configuration that determines the elements and canvas size options of sheet control.
         */
        gridLayout?: pulumi.Input<inputs.quicksight.AnalysisGridLayoutConfigurationArgs>;
    }
    interface AnalysisSheetDefinitionArgs {
        /**
         * The layout content type of the sheet. Choose one of the following options:
         *
         * - `PAGINATED` : Creates a sheet for a paginated report.
         * - `INTERACTIVE` : Creates a sheet for an interactive dashboard.
         */
        contentType?: pulumi.Input<enums.quicksight.AnalysisSheetContentType>;
        /**
         * A description of the sheet.
         */
        description?: pulumi.Input<string>;
        /**
         * The list of filter controls that are on a sheet.
         *
         * For more information, see [Adding filter controls to analysis sheets](https://docs.aws.amazon.com/quicksight/latest/user/filter-controls.html) in the *Amazon QuickSight User Guide* .
         */
        filterControls?: pulumi.Input<pulumi.Input<inputs.quicksight.AnalysisFilterControlArgs>[]>;
        /**
         * A list of images on a sheet.
         */
        images?: pulumi.Input<pulumi.Input<inputs.quicksight.AnalysisSheetImageArgs>[]>;
        /**
         * Layouts define how the components of a sheet are arranged.
         *
         * For more information, see [Types of layout](https://docs.aws.amazon.com/quicksight/latest/user/types-of-layout.html) in the *Amazon QuickSight User Guide* .
         */
        layouts?: pulumi.Input<pulumi.Input<inputs.quicksight.AnalysisLayoutArgs>[]>;
        /**
         * The name of the sheet. This name is displayed on the sheet's tab in the Amazon QuickSight console.
         */
        name?: pulumi.Input<string>;
        /**
         * The list of parameter controls that are on a sheet.
         *
         * For more information, see [Using a Control with a Parameter in Amazon QuickSight](https://docs.aws.amazon.com/quicksight/latest/user/parameters-controls.html) in the *Amazon QuickSight User Guide* .
         */
        parameterControls?: pulumi.Input<pulumi.Input<inputs.quicksight.AnalysisParameterControlArgs>[]>;
        /**
         * The control layouts of the sheet.
         */
        sheetControlLayouts?: pulumi.Input<pulumi.Input<inputs.quicksight.AnalysisSheetControlLayoutArgs>[]>;
        /**
         * The unique identifier of a sheet.
         */
        sheetId: pulumi.Input<string>;
        /**
         * The text boxes that are on a sheet.
         */
        textBoxes?: pulumi.Input<pulumi.Input<inputs.quicksight.AnalysisSheetTextBoxArgs>[]>;
        /**
         * The title of the sheet.
         */
        title?: pulumi.Input<string>;
        /**
         * A list of the visuals that are on a sheet. Visual placement is determined by the layout of the sheet.
         */
        visuals?: pulumi.Input<pulumi.Input<inputs.quicksight.AnalysisVisualArgs>[]>;
    }
    interface AnalysisSheetElementConfigurationOverridesArgs {
        /**
         * Determines whether or not the overrides are visible. Choose one of the following options:
         *
         * - `VISIBLE`
         * - `HIDDEN`
         */
        visibility?: pulumi.Input<enums.quicksight.AnalysisVisibility>;
    }
    interface AnalysisSheetElementRenderingRuleArgs {
        /**
         * The override configuration of the rendering rules of a sheet.
         */
        configurationOverrides: pulumi.Input<inputs.quicksight.AnalysisSheetElementConfigurationOverridesArgs>;
        /**
         * The expression of the rendering rules of a sheet.
         */
        expression: pulumi.Input<string>;
    }
    interface AnalysisSheetImageArgs {
        /**
         * A list of custom actions that are configured for an image.
         */
        actions?: pulumi.Input<pulumi.Input<inputs.quicksight.AnalysisImageCustomActionArgs>[]>;
        /**
         * The alt text for the image.
         */
        imageContentAltText?: pulumi.Input<string>;
        /**
         * The general image interactions setup for an image.
         */
        interactions?: pulumi.Input<inputs.quicksight.AnalysisImageInteractionOptionsArgs>;
        /**
         * Determines how the image is scaled.
         */
        scaling?: pulumi.Input<inputs.quicksight.AnalysisSheetImageScalingConfigurationArgs>;
        /**
         * The ID of the sheet image.
         */
        sheetImageId: pulumi.Input<string>;
        /**
         * The source of the image.
         */
        source: pulumi.Input<inputs.quicksight.AnalysisSheetImageSourceArgs>;
        /**
         * The tooltip to be shown when hovering over the image.
         */
        tooltip?: pulumi.Input<inputs.quicksight.AnalysisSheetImageTooltipConfigurationArgs>;
    }
    interface AnalysisSheetImageScalingConfigurationArgs {
        /**
         * The scaling option to use when fitting the image inside the container.
         *
         * Valid values are defined as follows:
         *
         * - `SCALE_TO_WIDTH` : The image takes up the entire width of the container. The image aspect ratio is preserved.
         * - `SCALE_TO_HEIGHT` : The image takes up the entire height of the container. The image aspect ratio is preserved.
         * - `SCALE_TO_CONTAINER` : The image takes up the entire width and height of the container. The image aspect ratio is not preserved.
         * - `SCALE_NONE` : The image is displayed in its original size and is not scaled to the container.
         */
        scalingType?: pulumi.Input<enums.quicksight.AnalysisSheetImageScalingType>;
    }
    interface AnalysisSheetImageSourceArgs {
        /**
         * The source of the static file that contains the image.
         */
        sheetImageStaticFileSource?: pulumi.Input<inputs.quicksight.AnalysisSheetImageStaticFileSourceArgs>;
    }
    interface AnalysisSheetImageStaticFileSourceArgs {
        /**
         * The ID of the static file that contains the image.
         */
        staticFileId: pulumi.Input<string>;
    }
    interface AnalysisSheetImageTooltipConfigurationArgs {
        /**
         * The text that appears in the tooltip.
         */
        tooltipText?: pulumi.Input<inputs.quicksight.AnalysisSheetImageTooltipTextArgs>;
        /**
         * The visibility of the tooltip.
         */
        visibility?: pulumi.Input<enums.quicksight.AnalysisVisibility>;
    }
    interface AnalysisSheetImageTooltipTextArgs {
        /**
         * The plain text format.
         */
        plainText?: pulumi.Input<string>;
    }
    interface AnalysisSheetTextBoxArgs {
        /**
         * The content that is displayed in the text box.
         */
        content?: pulumi.Input<string>;
        /**
         * The unique identifier for a text box. This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have text boxes that share identifiers.
         */
        sheetTextBoxId: pulumi.Input<string>;
    }
    interface AnalysisSheetVisualScopingConfigurationArgs {
        /**
         * The scope of the applied entities. Choose one of the following options:
         *
         * - `ALL_VISUALS`
         * - `SELECTED_VISUALS`
         */
        scope: pulumi.Input<enums.quicksight.AnalysisFilterVisualScope>;
        /**
         * The selected sheet that the filter is applied to.
         */
        sheetId: pulumi.Input<string>;
        /**
         * The selected visuals that the filter is applied to.
         */
        visualIds?: pulumi.Input<pulumi.Input<string>[]>;
    }
    interface AnalysisShortFormatTextArgs {
        /**
         * Plain text format.
         */
        plainText?: pulumi.Input<string>;
        /**
         * Rich text. Examples of rich text include bold, underline, and italics.
         */
        richText?: pulumi.Input<string>;
    }
    interface AnalysisSimpleClusterMarkerArgs {
        /**
         * The color of the simple cluster marker.
         */
        color?: pulumi.Input<string>;
    }
    interface AnalysisSingleAxisOptionsArgs {
        /**
         * The Y axis options of a single axis configuration.
         */
        yAxisOptions?: pulumi.Input<inputs.quicksight.AnalysisYAxisOptionsArgs>;
    }
    interface AnalysisSliderControlDisplayOptionsArgs {
        /**
         * The configuration of info icon label options.
         */
        infoIconLabelOptions?: pulumi.Input<inputs.quicksight.AnalysisSheetControlInfoIconLabelOptionsArgs>;
        /**
         * The options to configure the title visibility, name, and font size.
         */
        titleOptions?: pulumi.Input<inputs.quicksight.AnalysisLabelOptionsArgs>;
    }
    interface AnalysisSmallMultiplesAxisPropertiesArgs {
        /**
         * Defines the placement of the axis. By default, axes are rendered `OUTSIDE` of the panels. Axes with `INDEPENDENT` scale are rendered `INSIDE` the panels.
         */
        placement?: pulumi.Input<enums.quicksight.AnalysisSmallMultiplesAxisPlacement>;
        /**
         * Determines whether scale of the axes are shared or independent. The default value is `SHARED` .
         */
        scale?: pulumi.Input<enums.quicksight.AnalysisSmallMultiplesAxisScale>;
    }
    interface AnalysisSmallMultiplesOptionsArgs {
        /**
         * Sets the maximum number of visible columns to display in the grid of small multiples panels.
         *
         * The default is `Auto` , which automatically adjusts the columns in the grid to fit the overall layout and size of the given chart.
         */
        maxVisibleColumns?: pulumi.Input<number>;
        /**
         * Sets the maximum number of visible rows to display in the grid of small multiples panels.
         *
         * The default value is `Auto` , which automatically adjusts the rows in the grid to fit the overall layout and size of the given chart.
         */
        maxVisibleRows?: pulumi.Input<number>;
        /**
         * Configures the display options for each small multiples panel.
         */
        panelConfiguration?: pulumi.Input<inputs.quicksight.AnalysisPanelConfigurationArgs>;
        /**
         * The properties of a small multiples X axis.
         */
        xAxis?: pulumi.Input<inputs.quicksight.AnalysisSmallMultiplesAxisPropertiesArgs>;
        /**
         * The properties of a small multiples Y axis.
         */
        yAxis?: pulumi.Input<inputs.quicksight.AnalysisSmallMultiplesAxisPropertiesArgs>;
    }
    /**
     * <p>The source entity of an analysis.</p>
     */
    interface AnalysisSourceEntityArgs {
        /**
         * The source template for the source entity of the analysis.
         */
        sourceTemplate?: pulumi.Input<inputs.quicksight.AnalysisSourceTemplateArgs>;
    }
    /**
     * <p>The source template of an analysis.</p>
     */
    interface AnalysisSourceTemplateArgs {
        /**
         * <p>The Amazon Resource Name (ARN) of the source template of an analysis.</p>
         */
        arn: pulumi.Input<string>;
        /**
         * <p>The dataset references of the source template of an analysis.</p>
         */
        dataSetReferences: pulumi.Input<pulumi.Input<inputs.quicksight.AnalysisDataSetReferenceArgs>[]>;
    }
    interface AnalysisSpacingArgs {
        /**
         * String based length that is composed of value and unit
         */
        bottom?: pulumi.Input<string>;
        /**
         * String based length that is composed of value and unit
         */
        left?: pulumi.Input<string>;
        /**
         * String based length that is composed of value and unit
         */
        right?: pulumi.Input<string>;
        /**
         * String based length that is composed of value and unit
         */
        top?: pulumi.Input<string>;
    }
    interface AnalysisSpatialStaticFileArgs {
        /**
         * The source of the spatial static file.
         */
        source?: pulumi.Input<inputs.quicksight.AnalysisStaticFileSourceArgs>;
        /**
         * The ID of the spatial static file.
         */
        staticFileId: pulumi.Input<string>;
    }
    interface AnalysisStaticFileArgs {
        /**
         * The image static file.
         */
        imageStaticFile?: pulumi.Input<inputs.quicksight.AnalysisImageStaticFileArgs>;
        /**
         * The spacial static file.
         */
        spatialStaticFile?: pulumi.Input<inputs.quicksight.AnalysisSpatialStaticFileArgs>;
    }
    interface AnalysisStaticFileS3SourceOptionsArgs {
        /**
         * The name of the Amazon S3 bucket.
         */
        bucketName: pulumi.Input<string>;
        /**
         * The identifier of the static file in the Amazon S3 bucket.
         */
        objectKey: pulumi.Input<string>;
        /**
         * The Region of the Amazon S3 account that contains the bucket.
         */
        region: pulumi.Input<string>;
    }
    interface AnalysisStaticFileSourceArgs {
        /**
         * The structure that contains the Amazon S3 location to download the static file from.
         */
        s3Options?: pulumi.Input<inputs.quicksight.AnalysisStaticFileS3SourceOptionsArgs>;
        /**
         * The structure that contains the URL to download the static file from.
         */
        urlOptions?: pulumi.Input<inputs.quicksight.AnalysisStaticFileUrlSourceOptionsArgs>;
    }
    interface AnalysisStaticFileUrlSourceOptionsArgs {
        /**
         * The URL to download the static file from.
         */
        url: pulumi.Input<string>;
    }
    interface AnalysisStringDefaultValuesArgs {
        /**
         * The dynamic value of the `StringDefaultValues` . Different defaults displayed according to users, groups, and values mapping.
         */
        dynamicValue?: pulumi.Input<inputs.quicksight.AnalysisDynamicDefaultValueArgs>;
        /**
         * The static values of the `DecimalDefaultValues` .
         */
        staticValues?: pulumi.Input<pulumi.Input<string>[]>;
    }
    interface AnalysisStringFormatConfigurationArgs {
        /**
         * The options that determine the null value format configuration.
         */
        nullValueFormatConfiguration?: pulumi.Input<inputs.quicksight.AnalysisNullValueFormatConfigurationArgs>;
        /**
         * The formatting configuration for numeric strings.
         */
        numericFormatConfiguration?: pulumi.Input<inputs.quicksight.AnalysisNumericFormatConfigurationArgs>;
    }
    /**
     * <p>A string parameter.</p>
     */
    interface AnalysisStringParameterArgs {
        /**
         * <p>A display name for a string parameter.</p>
         */
        name: pulumi.Input<string>;
        /**
         * <p>The values of a string parameter.</p>
         */
        values: pulumi.Input<pulumi.Input<string>[]>;
    }
    interface AnalysisStringParameterDeclarationArgs {
        /**
         * The default values of a parameter. If the parameter is a single-value parameter, a maximum of one default value can be provided.
         */
        defaultValues?: pulumi.Input<inputs.quicksight.AnalysisStringDefaultValuesArgs>;
        mappedDataSetParameters?: pulumi.Input<pulumi.Input<inputs.quicksight.AnalysisMappedDataSetParameterArgs>[]>;
        /**
         * The name of the parameter that is being declared.
         */
        name: pulumi.Input<string>;
        /**
         * The value type determines whether the parameter is a single-value or multi-value parameter.
         */
        parameterValueType: pulumi.Input<enums.quicksight.AnalysisParameterValueType>;
        /**
         * The configuration that defines the default value of a `String` parameter when a value has not been set.
         */
        valueWhenUnset?: pulumi.Input<inputs.quicksight.AnalysisStringValueWhenUnsetConfigurationArgs>;
    }
    interface AnalysisStringValueWhenUnsetConfigurationArgs {
        /**
         * A custom value that's used when the value of a parameter isn't set.
         */
        customValue?: pulumi.Input<string>;
        /**
         * The built-in options for default values. The value can be one of the following:
         *
         * - `RECOMMENDED` : The recommended value.
         * - `NULL` : The `NULL` value.
         */
        valueWhenUnsetOption?: pulumi.Input<enums.quicksight.AnalysisValueWhenUnsetOption>;
    }
    interface AnalysisSubtotalOptionsArgs {
        /**
         * The custom label string for the subtotal cells.
         */
        customLabel?: pulumi.Input<string>;
        /**
         * The field level (all, custom, last) for the subtotal cells.
         */
        fieldLevel?: pulumi.Input<enums.quicksight.AnalysisPivotTableSubtotalLevel>;
        /**
         * The optional configuration of subtotal cells.
         */
        fieldLevelOptions?: pulumi.Input<pulumi.Input<inputs.quicksight.AnalysisPivotTableFieldSubtotalOptionsArgs>[]>;
        /**
         * The cell styling options for the subtotals of header cells.
         */
        metricHeaderCellStyle?: pulumi.Input<inputs.quicksight.AnalysisTableCellStyleArgs>;
        /**
         * The style targets options for subtotals.
         */
        styleTargets?: pulumi.Input<pulumi.Input<inputs.quicksight.AnalysisTableStyleTargetArgs>[]>;
        /**
         * The cell styling options for the subtotal cells.
         */
        totalCellStyle?: pulumi.Input<inputs.quicksight.AnalysisTableCellStyleArgs>;
        /**
         * The visibility configuration for the subtotal cells.
         */
        totalsVisibility?: pulumi.Input<enums.quicksight.AnalysisVisibility>;
        /**
         * The cell styling options for the subtotals of value cells.
         */
        valueCellStyle?: pulumi.Input<inputs.quicksight.AnalysisTableCellStyleArgs>;
    }
    interface AnalysisTableAggregatedFieldWellsArgs {
        /**
         * The group by field well for a pivot table. Values are grouped by group by fields.
         */
        groupBy?: pulumi.Input<pulumi.Input<inputs.quicksight.AnalysisDimensionFieldArgs>[]>;
        /**
         * The values field well for a pivot table. Values are aggregated based on group by fields.
         */
        values?: pulumi.Input<pulumi.Input<inputs.quicksight.AnalysisMeasureFieldArgs>[]>;
    }
    interface AnalysisTableBorderOptionsArgs {
        /**
         * The color of a table border.
         */
        color?: pulumi.Input<string>;
        /**
         * The style (none, solid) of a table border.
         */
        style?: pulumi.Input<enums.quicksight.AnalysisTableBorderStyle>;
        /**
         * The thickness of a table border.
         */
        thickness?: pulumi.Input<number>;
    }
    interface AnalysisTableCellConditionalFormattingArgs {
        /**
         * The field ID of the cell for conditional formatting.
         */
        fieldId: pulumi.Input<string>;
        /**
         * The text format of the cell for conditional formatting.
         */
        textFormat?: pulumi.Input<inputs.quicksight.AnalysisTextConditionalFormatArgs>;
    }
    interface AnalysisTableCellImageSizingConfigurationArgs {
        /**
         * The cell scaling configuration of the sizing options for the table image configuration.
         */
        tableCellImageScalingConfiguration?: pulumi.Input<enums.quicksight.AnalysisTableCellImageScalingConfiguration>;
    }
    interface AnalysisTableCellStyleArgs {
        /**
         * The background color for the table cells.
         */
        backgroundColor?: pulumi.Input<string>;
        /**
         * The borders for the table cells.
         */
        border?: pulumi.Input<inputs.quicksight.AnalysisGlobalTableBorderOptionsArgs>;
        /**
         * The font configuration of the table cells.
         */
        fontConfiguration?: pulumi.Input<inputs.quicksight.AnalysisFontConfigurationArgs>;
        /**
         * The height color for the table cells.
         */
        height?: pulumi.Input<number>;
        /**
         * The horizontal text alignment (left, center, right, auto) for the table cells.
         */
        horizontalTextAlignment?: pulumi.Input<enums.quicksight.AnalysisHorizontalTextAlignment>;
        /**
         * The text wrap (none, wrap) for the table cells.
         */
        textWrap?: pulumi.Input<enums.quicksight.AnalysisTextWrap>;
        /**
         * The vertical text alignment (top, middle, bottom) for the table cells.
         */
        verticalTextAlignment?: pulumi.Input<enums.quicksight.AnalysisVerticalTextAlignment>;
        /**
         * The visibility of the table cells.
         */
        visibility?: pulumi.Input<enums.quicksight.AnalysisVisibility>;
    }
    interface AnalysisTableConditionalFormattingArgs {
        /**
         * Conditional formatting options for a `PivotTableVisual` .
         */
        conditionalFormattingOptions?: pulumi.Input<pulumi.Input<inputs.quicksight.AnalysisTableConditionalFormattingOptionArgs>[]>;
    }
    interface AnalysisTableConditionalFormattingOptionArgs {
        /**
         * The cell conditional formatting option for a table.
         */
        cell?: pulumi.Input<inputs.quicksight.AnalysisTableCellConditionalFormattingArgs>;
        /**
         * The row conditional formatting option for a table.
         */
        row?: pulumi.Input<inputs.quicksight.AnalysisTableRowConditionalFormattingArgs>;
    }
    interface AnalysisTableConfigurationArgs {
        /**
         * The field options for a table visual.
         */
        fieldOptions?: pulumi.Input<inputs.quicksight.AnalysisTableFieldOptionsArgs>;
        /**
         * The field wells of the visual.
         */
        fieldWells?: pulumi.Input<inputs.quicksight.AnalysisTableFieldWellsArgs>;
        /**
         * The general visual interactions setup for a visual.
         */
        interactions?: pulumi.Input<inputs.quicksight.AnalysisVisualInteractionOptionsArgs>;
        /**
         * The paginated report options for a table visual.
         */
        paginatedReportOptions?: pulumi.Input<inputs.quicksight.AnalysisTablePaginatedReportOptionsArgs>;
        /**
         * The sort configuration for a `TableVisual` .
         */
        sortConfiguration?: pulumi.Input<inputs.quicksight.AnalysisTableSortConfigurationArgs>;
        /**
         * A collection of inline visualizations to display within a chart.
         */
        tableInlineVisualizations?: pulumi.Input<pulumi.Input<inputs.quicksight.AnalysisTableInlineVisualizationArgs>[]>;
        /**
         * The table options for a table visual.
         */
        tableOptions?: pulumi.Input<inputs.quicksight.AnalysisTableOptionsArgs>;
        /**
         * The total options for a table visual.
         */
        totalOptions?: pulumi.Input<inputs.quicksight.AnalysisTotalOptionsArgs>;
    }
    interface AnalysisTableFieldCustomIconContentArgs {
        /**
         * The icon set type (link) of the custom icon content for table URL link content.
         */
        icon?: pulumi.Input<enums.quicksight.AnalysisTableFieldIconSetType>;
    }
    interface AnalysisTableFieldCustomTextContentArgs {
        /**
         * The font configuration of the custom text content for the table URL link content.
         */
        fontConfiguration: pulumi.Input<inputs.quicksight.AnalysisFontConfigurationArgs>;
        /**
         * The string value of the custom text content for the table URL link content.
         */
        value?: pulumi.Input<string>;
    }
    interface AnalysisTableFieldImageConfigurationArgs {
        /**
         * The sizing options for the table image configuration.
         */
        sizingOptions?: pulumi.Input<inputs.quicksight.AnalysisTableCellImageSizingConfigurationArgs>;
    }
    interface AnalysisTableFieldLinkConfigurationArgs {
        /**
         * The URL content (text, icon) for the table link configuration.
         */
        content: pulumi.Input<inputs.quicksight.AnalysisTableFieldLinkContentConfigurationArgs>;
        /**
         * The URL target (new tab, new window, same tab) for the table link configuration.
         */
        target: pulumi.Input<enums.quicksight.AnalysisUrlTargetConfiguration>;
    }
    interface AnalysisTableFieldLinkContentConfigurationArgs {
        /**
         * The custom icon content for the table link content configuration.
         */
        customIconContent?: pulumi.Input<inputs.quicksight.AnalysisTableFieldCustomIconContentArgs>;
        /**
         * The custom text content (value, font configuration) for the table link content configuration.
         */
        customTextContent?: pulumi.Input<inputs.quicksight.AnalysisTableFieldCustomTextContentArgs>;
    }
    interface AnalysisTableFieldOptionArgs {
        /**
         * The custom label for a table field.
         */
        customLabel?: pulumi.Input<string>;
        /**
         * The field ID for a table field.
         */
        fieldId: pulumi.Input<string>;
        /**
         * The URL configuration for a table field.
         */
        urlStyling?: pulumi.Input<inputs.quicksight.AnalysisTableFieldUrlConfigurationArgs>;
        /**
         * The visibility of a table field.
         */
        visibility?: pulumi.Input<enums.quicksight.AnalysisVisibility>;
        /**
         * String based length that is composed of value and unit in px
         */
        width?: pulumi.Input<string>;
    }
    interface AnalysisTableFieldOptionsArgs {
        /**
         * The order of the field IDs that are configured as field options for a table visual.
         */
        order?: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * The settings for the pinned columns of a table visual.
         */
        pinnedFieldOptions?: pulumi.Input<inputs.quicksight.AnalysisTablePinnedFieldOptionsArgs>;
        /**
         * The field options to be configured to a table.
         */
        selectedFieldOptions?: pulumi.Input<pulumi.Input<inputs.quicksight.AnalysisTableFieldOptionArgs>[]>;
        /**
         * The `TableOptions` of a transposed table.
         */
        transposedTableOptions?: pulumi.Input<pulumi.Input<inputs.quicksight.AnalysisTransposedTableOptionArgs>[]>;
    }
    interface AnalysisTableFieldUrlConfigurationArgs {
        /**
         * The image configuration of a table field URL.
         */
        imageConfiguration?: pulumi.Input<inputs.quicksight.AnalysisTableFieldImageConfigurationArgs>;
        /**
         * The link configuration of a table field URL.
         */
        linkConfiguration?: pulumi.Input<inputs.quicksight.AnalysisTableFieldLinkConfigurationArgs>;
    }
    interface AnalysisTableFieldWellsArgs {
        /**
         * The aggregated field well for the table.
         */
        tableAggregatedFieldWells?: pulumi.Input<inputs.quicksight.AnalysisTableAggregatedFieldWellsArgs>;
        /**
         * The unaggregated field well for the table.
         */
        tableUnaggregatedFieldWells?: pulumi.Input<inputs.quicksight.AnalysisTableUnaggregatedFieldWellsArgs>;
    }
    interface AnalysisTableInlineVisualizationArgs {
        /**
         * The configuration of the inline visualization of the data bars within a chart.
         */
        dataBars?: pulumi.Input<inputs.quicksight.AnalysisDataBarsOptionsArgs>;
    }
    interface AnalysisTableOptionsArgs {
        /**
         * The table cell style of table cells.
         */
        cellStyle?: pulumi.Input<inputs.quicksight.AnalysisTableCellStyleArgs>;
        /**
         * The table cell style of a table header.
         */
        headerStyle?: pulumi.Input<inputs.quicksight.AnalysisTableCellStyleArgs>;
        /**
         * The orientation (vertical, horizontal) for a table.
         */
        orientation?: pulumi.Input<enums.quicksight.AnalysisTableOrientation>;
        /**
         * The row alternate color options (widget status, row alternate colors) for a table.
         */
        rowAlternateColorOptions?: pulumi.Input<inputs.quicksight.AnalysisRowAlternateColorOptionsArgs>;
    }
    interface AnalysisTablePaginatedReportOptionsArgs {
        /**
         * The visibility of repeating header rows on each page.
         */
        overflowColumnHeaderVisibility?: pulumi.Input<enums.quicksight.AnalysisVisibility>;
        /**
         * The visibility of printing table overflow across pages.
         */
        verticalOverflowVisibility?: pulumi.Input<enums.quicksight.AnalysisVisibility>;
    }
    interface AnalysisTablePinnedFieldOptionsArgs {
        /**
         * A list of columns to be pinned to the left of a table visual.
         */
        pinnedLeftFields?: pulumi.Input<pulumi.Input<string>[]>;
    }
    interface AnalysisTableRowConditionalFormattingArgs {
        /**
         * The conditional formatting color (solid, gradient) of the background for a table row.
         */
        backgroundColor?: pulumi.Input<inputs.quicksight.AnalysisConditionalFormattingColorArgs>;
        /**
         * The conditional formatting color (solid, gradient) of the text for a table row.
         */
        textColor?: pulumi.Input<inputs.quicksight.AnalysisConditionalFormattingColorArgs>;
    }
    interface AnalysisTableSideBorderOptionsArgs {
        /**
         * The table border options of the bottom border.
         */
        bottom?: pulumi.Input<inputs.quicksight.AnalysisTableBorderOptionsArgs>;
        /**
         * The table border options of the inner horizontal border.
         */
        innerHorizontal?: pulumi.Input<inputs.quicksight.AnalysisTableBorderOptionsArgs>;
        /**
         * The table border options of the inner vertical border.
         */
        innerVertical?: pulumi.Input<inputs.quicksight.AnalysisTableBorderOptionsArgs>;
        /**
         * The table border options of the left border.
         */
        left?: pulumi.Input<inputs.quicksight.AnalysisTableBorderOptionsArgs>;
        /**
         * The table border options of the right border.
         */
        right?: pulumi.Input<inputs.quicksight.AnalysisTableBorderOptionsArgs>;
        /**
         * The table border options of the top border.
         */
        top?: pulumi.Input<inputs.quicksight.AnalysisTableBorderOptionsArgs>;
    }
    interface AnalysisTableSortConfigurationArgs {
        /**
         * The pagination configuration (page size, page number) for the table.
         */
        paginationConfiguration?: pulumi.Input<inputs.quicksight.AnalysisPaginationConfigurationArgs>;
        /**
         * The field sort options for rows in the table.
         */
        rowSort?: pulumi.Input<pulumi.Input<inputs.quicksight.AnalysisFieldSortOptionsArgs>[]>;
    }
    interface AnalysisTableStyleTargetArgs {
        /**
         * The cell type of the table style target.
         */
        cellType: pulumi.Input<enums.quicksight.AnalysisStyledCellType>;
    }
    interface AnalysisTableUnaggregatedFieldWellsArgs {
        /**
         * The values field well for a pivot table. Values are unaggregated for an unaggregated table.
         */
        values?: pulumi.Input<pulumi.Input<inputs.quicksight.AnalysisUnaggregatedFieldArgs>[]>;
    }
    interface AnalysisTableVisualArgs {
        /**
         * The list of custom actions that are configured for a visual.
         */
        actions?: pulumi.Input<pulumi.Input<inputs.quicksight.AnalysisVisualCustomActionArgs>[]>;
        /**
         * The configuration settings of the visual.
         */
        chartConfiguration?: pulumi.Input<inputs.quicksight.AnalysisTableConfigurationArgs>;
        /**
         * The conditional formatting for a `PivotTableVisual` .
         */
        conditionalFormatting?: pulumi.Input<inputs.quicksight.AnalysisTableConditionalFormattingArgs>;
        /**
         * The subtitle that is displayed on the visual.
         */
        subtitle?: pulumi.Input<inputs.quicksight.AnalysisVisualSubtitleLabelOptionsArgs>;
        /**
         * The title that is displayed on the visual.
         */
        title?: pulumi.Input<inputs.quicksight.AnalysisVisualTitleLabelOptionsArgs>;
        /**
         * The alt text for the visual.
         */
        visualContentAltText?: pulumi.Input<string>;
        /**
         * The unique identifier of a visual. This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers..
         */
        visualId: pulumi.Input<string>;
    }
    interface AnalysisTextAreaControlDisplayOptionsArgs {
        /**
         * The configuration of info icon label options.
         */
        infoIconLabelOptions?: pulumi.Input<inputs.quicksight.AnalysisSheetControlInfoIconLabelOptionsArgs>;
        /**
         * The configuration of the placeholder options in a text area control.
         */
        placeholderOptions?: pulumi.Input<inputs.quicksight.AnalysisTextControlPlaceholderOptionsArgs>;
        /**
         * The options to configure the title visibility, name, and font size.
         */
        titleOptions?: pulumi.Input<inputs.quicksight.AnalysisLabelOptionsArgs>;
    }
    interface AnalysisTextConditionalFormatArgs {
        /**
         * The conditional formatting for the text background color.
         */
        backgroundColor?: pulumi.Input<inputs.quicksight.AnalysisConditionalFormattingColorArgs>;
        /**
         * The conditional formatting for the icon.
         */
        icon?: pulumi.Input<inputs.quicksight.AnalysisConditionalFormattingIconArgs>;
        /**
         * The conditional formatting for the text color.
         */
        textColor?: pulumi.Input<inputs.quicksight.AnalysisConditionalFormattingColorArgs>;
    }
    interface AnalysisTextControlPlaceholderOptionsArgs {
        /**
         * The visibility configuration of the placeholder options in a text control.
         */
        visibility?: pulumi.Input<enums.quicksight.AnalysisVisibility>;
    }
    interface AnalysisTextFieldControlDisplayOptionsArgs {
        /**
         * The configuration of info icon label options.
         */
        infoIconLabelOptions?: pulumi.Input<inputs.quicksight.AnalysisSheetControlInfoIconLabelOptionsArgs>;
        /**
         * The configuration of the placeholder options in a text field control.
         */
        placeholderOptions?: pulumi.Input<inputs.quicksight.AnalysisTextControlPlaceholderOptionsArgs>;
        /**
         * The options to configure the title visibility, name, and font size.
         */
        titleOptions?: pulumi.Input<inputs.quicksight.AnalysisLabelOptionsArgs>;
    }
    interface AnalysisThousandSeparatorOptionsArgs {
        /**
         * Determines the way numbers are styled to accommodate different readability standards. The `DEFAULT` value uses the standard international grouping system and groups numbers by the thousands. The `LAKHS` value uses the Indian numbering system and groups numbers by lakhs and crores.
         */
        groupingStyle?: pulumi.Input<enums.quicksight.AnalysisDigitGroupingStyle>;
        /**
         * Determines the thousands separator symbol.
         */
        symbol?: pulumi.Input<enums.quicksight.AnalysisNumericSeparatorSymbol>;
        /**
         * Determines the visibility of the thousands separator.
         */
        visibility?: pulumi.Input<enums.quicksight.AnalysisVisibility>;
    }
    interface AnalysisTimeBasedForecastPropertiesArgs {
        /**
         * The lower boundary setup of a forecast computation.
         */
        lowerBoundary?: pulumi.Input<number>;
        /**
         * The periods backward setup of a forecast computation.
         */
        periodsBackward?: pulumi.Input<number>;
        /**
         * The periods forward setup of a forecast computation.
         */
        periodsForward?: pulumi.Input<number>;
        /**
         * The prediction interval setup of a forecast computation.
         */
        predictionInterval?: pulumi.Input<number>;
        /**
         * The seasonality setup of a forecast computation. Choose one of the following options:
         *
         * - `NULL` : The input is set to `NULL` .
         * - `NON_NULL` : The input is set to a custom value.
         */
        seasonality?: pulumi.Input<number>;
        /**
         * The upper boundary setup of a forecast computation.
         */
        upperBoundary?: pulumi.Input<number>;
    }
    interface AnalysisTimeEqualityFilterArgs {
        /**
         * The column that the filter is applied to.
         */
        column: pulumi.Input<inputs.quicksight.AnalysisColumnIdentifierArgs>;
        /**
         * The default configurations for the associated controls. This applies only for filters that are scoped to multiple sheets.
         */
        defaultFilterControlConfiguration?: pulumi.Input<inputs.quicksight.AnalysisDefaultFilterControlConfigurationArgs>;
        /**
         * An identifier that uniquely identifies a filter within a dashboard, analysis, or template.
         */
        filterId: pulumi.Input<string>;
        /**
         * The parameter whose value should be used for the filter value.
         *
         * This field is mutually exclusive to `Value` and `RollingDate` .
         */
        parameterName?: pulumi.Input<string>;
        /**
         * The rolling date input for the `TimeEquality` filter.
         *
         * This field is mutually exclusive to `Value` and `ParameterName` .
         */
        rollingDate?: pulumi.Input<inputs.quicksight.AnalysisRollingDateConfigurationArgs>;
        /**
         * The level of time precision that is used to aggregate `DateTime` values.
         */
        timeGranularity?: pulumi.Input<enums.quicksight.AnalysisTimeGranularity>;
        /**
         * The value of a `TimeEquality` filter.
         *
         * This field is mutually exclusive to `RollingDate` and `ParameterName` .
         */
        value?: pulumi.Input<string>;
    }
    interface AnalysisTimeRangeDrillDownFilterArgs {
        /**
         * The column that the filter is applied to.
         */
        column: pulumi.Input<inputs.quicksight.AnalysisColumnIdentifierArgs>;
        /**
         * The maximum value for the filter value range.
         */
        rangeMaximum: pulumi.Input<string>;
        /**
         * The minimum value for the filter value range.
         */
        rangeMinimum: pulumi.Input<string>;
        /**
         * The level of time precision that is used to aggregate `DateTime` values.
         */
        timeGranularity: pulumi.Input<enums.quicksight.AnalysisTimeGranularity>;
    }
    interface AnalysisTimeRangeFilterArgs {
        /**
         * The column that the filter is applied to.
         */
        column: pulumi.Input<inputs.quicksight.AnalysisColumnIdentifierArgs>;
        /**
         * The default configurations for the associated controls. This applies only for filters that are scoped to multiple sheets.
         */
        defaultFilterControlConfiguration?: pulumi.Input<inputs.quicksight.AnalysisDefaultFilterControlConfigurationArgs>;
        /**
         * The exclude period of the time range filter.
         */
        excludePeriodConfiguration?: pulumi.Input<inputs.quicksight.AnalysisExcludePeriodConfigurationArgs>;
        /**
         * An identifier that uniquely identifies a filter within a dashboard, analysis, or template.
         */
        filterId: pulumi.Input<string>;
        /**
         * Determines whether the maximum value in the filter value range should be included in the filtered results.
         */
        includeMaximum?: pulumi.Input<boolean>;
        /**
         * Determines whether the minimum value in the filter value range should be included in the filtered results.
         */
        includeMinimum?: pulumi.Input<boolean>;
        /**
         * This option determines how null values should be treated when filtering data.
         *
         * - `ALL_VALUES` : Include null values in filtered results.
         * - `NULLS_ONLY` : Only include null values in filtered results.
         * - `NON_NULLS_ONLY` : Exclude null values from filtered results.
         */
        nullOption: pulumi.Input<enums.quicksight.AnalysisFilterNullOption>;
        /**
         * The maximum value for the filter value range.
         */
        rangeMaximumValue?: pulumi.Input<inputs.quicksight.AnalysisTimeRangeFilterValueArgs>;
        /**
         * The minimum value for the filter value range.
         */
        rangeMinimumValue?: pulumi.Input<inputs.quicksight.AnalysisTimeRangeFilterValueArgs>;
        /**
         * The level of time precision that is used to aggregate `DateTime` values.
         */
        timeGranularity?: pulumi.Input<enums.quicksight.AnalysisTimeGranularity>;
    }
    interface AnalysisTimeRangeFilterValueArgs {
        /**
         * The parameter type input value.
         */
        parameter?: pulumi.Input<string>;
        /**
         * The rolling date input value.
         */
        rollingDate?: pulumi.Input<inputs.quicksight.AnalysisRollingDateConfigurationArgs>;
        /**
         * The static input value.
         */
        staticValue?: pulumi.Input<string>;
    }
    interface AnalysisTooltipItemArgs {
        /**
         * The tooltip item for the columns that are not part of a field well.
         */
        columnTooltipItem?: pulumi.Input<inputs.quicksight.AnalysisColumnTooltipItemArgs>;
        /**
         * The tooltip item for the fields.
         */
        fieldTooltipItem?: pulumi.Input<inputs.quicksight.AnalysisFieldTooltipItemArgs>;
    }
    interface AnalysisTooltipOptionsArgs {
        /**
         * The setup for the detailed tooltip. The tooltip setup is always saved. The display type is decided based on the tooltip type.
         */
        fieldBasedTooltip?: pulumi.Input<inputs.quicksight.AnalysisFieldBasedTooltipArgs>;
        /**
         * The selected type for the tooltip. Choose one of the following options:
         *
         * - `BASIC` : A basic tooltip.
         * - `DETAILED` : A detailed tooltip.
         */
        selectedTooltipType?: pulumi.Input<enums.quicksight.AnalysisSelectedTooltipType>;
        /**
         * Determines whether or not the tooltip is visible.
         */
        tooltipVisibility?: pulumi.Input<enums.quicksight.AnalysisVisibility>;
    }
    interface AnalysisTopBottomFilterArgs {
        /**
         * The aggregation and sort configuration of the top bottom filter.
         */
        aggregationSortConfigurations: pulumi.Input<pulumi.Input<inputs.quicksight.AnalysisAggregationSortConfigurationArgs>[]>;
        /**
         * The column that the filter is applied to.
         */
        column: pulumi.Input<inputs.quicksight.AnalysisColumnIdentifierArgs>;
        /**
         * The default configurations for the associated controls. This applies only for filters that are scoped to multiple sheets.
         */
        defaultFilterControlConfiguration?: pulumi.Input<inputs.quicksight.AnalysisDefaultFilterControlConfigurationArgs>;
        /**
         * An identifier that uniquely identifies a filter within a dashboard, analysis, or template.
         */
        filterId: pulumi.Input<string>;
        /**
         * The number of items to include in the top bottom filter results.
         */
        limit?: pulumi.Input<number>;
        /**
         * The parameter whose value should be used for the filter value.
         */
        parameterName?: pulumi.Input<string>;
        /**
         * The level of time precision that is used to aggregate `DateTime` values.
         */
        timeGranularity?: pulumi.Input<enums.quicksight.AnalysisTimeGranularity>;
    }
    interface AnalysisTopBottomMoversComputationArgs {
        /**
         * The category field that is used in a computation.
         */
        category?: pulumi.Input<inputs.quicksight.AnalysisDimensionFieldArgs>;
        /**
         * The ID for a computation.
         */
        computationId: pulumi.Input<string>;
        /**
         * The mover size setup of the top and bottom movers computation.
         */
        moverSize?: pulumi.Input<number>;
        /**
         * The name of a computation.
         */
        name?: pulumi.Input<string>;
        /**
         * The sort order setup of the top and bottom movers computation.
         */
        sortOrder?: pulumi.Input<enums.quicksight.AnalysisTopBottomSortOrder>;
        /**
         * The time field that is used in a computation.
         */
        time?: pulumi.Input<inputs.quicksight.AnalysisDimensionFieldArgs>;
        /**
         * The computation type. Choose from the following options:
         *
         * - TOP: Top movers computation.
         * - BOTTOM: Bottom movers computation.
         */
        type: pulumi.Input<enums.quicksight.AnalysisTopBottomComputationType>;
        /**
         * The value field that is used in a computation.
         */
        value?: pulumi.Input<inputs.quicksight.AnalysisMeasureFieldArgs>;
    }
    interface AnalysisTopBottomRankedComputationArgs {
        /**
         * The category field that is used in a computation.
         */
        category?: pulumi.Input<inputs.quicksight.AnalysisDimensionFieldArgs>;
        /**
         * The ID for a computation.
         */
        computationId: pulumi.Input<string>;
        /**
         * The name of a computation.
         */
        name?: pulumi.Input<string>;
        /**
         * The result size of a top and bottom ranked computation.
         */
        resultSize?: pulumi.Input<number>;
        /**
         * The computation type. Choose one of the following options:
         *
         * - TOP: A top ranked computation.
         * - BOTTOM: A bottom ranked computation.
         */
        type: pulumi.Input<enums.quicksight.AnalysisTopBottomComputationType>;
        /**
         * The value field that is used in a computation.
         */
        value?: pulumi.Input<inputs.quicksight.AnalysisMeasureFieldArgs>;
    }
    interface AnalysisTotalAggregationComputationArgs {
        /**
         * The ID for a computation.
         */
        computationId: pulumi.Input<string>;
        /**
         * The name of a computation.
         */
        name?: pulumi.Input<string>;
        /**
         * The value field that is used in a computation.
         */
        value?: pulumi.Input<inputs.quicksight.AnalysisMeasureFieldArgs>;
    }
    interface AnalysisTotalAggregationFunctionArgs {
        /**
         * A built in aggregation function for total values.
         */
        simpleTotalAggregationFunction?: pulumi.Input<enums.quicksight.AnalysisSimpleTotalAggregationFunction>;
    }
    interface AnalysisTotalAggregationOptionArgs {
        /**
         * The field id that's associated with the total aggregation option.
         */
        fieldId: pulumi.Input<string>;
        /**
         * The total aggregation function that you want to set for a specified field id.
         */
        totalAggregationFunction: pulumi.Input<inputs.quicksight.AnalysisTotalAggregationFunctionArgs>;
    }
    interface AnalysisTotalOptionsArgs {
        /**
         * The custom label string for the total cells.
         */
        customLabel?: pulumi.Input<string>;
        /**
         * The placement (start, end) for the total cells.
         */
        placement?: pulumi.Input<enums.quicksight.AnalysisTableTotalsPlacement>;
        /**
         * The scroll status (pinned, scrolled) for the total cells.
         */
        scrollStatus?: pulumi.Input<enums.quicksight.AnalysisTableTotalsScrollStatus>;
        /**
         * The total aggregation settings for each value field.
         */
        totalAggregationOptions?: pulumi.Input<pulumi.Input<inputs.quicksight.AnalysisTotalAggregationOptionArgs>[]>;
        /**
         * Cell styling options for the total cells.
         */
        totalCellStyle?: pulumi.Input<inputs.quicksight.AnalysisTableCellStyleArgs>;
        /**
         * The visibility configuration for the total cells.
         */
        totalsVisibility?: pulumi.Input<enums.quicksight.AnalysisVisibility>;
    }
    interface AnalysisTransposedTableOptionArgs {
        /**
         * The index of a columns in a transposed table. The index range is 0-9999.
         */
        columnIndex?: pulumi.Input<number>;
        /**
         * The column type of the column in a transposed table. Choose one of the following options:
         *
         * - `ROW_HEADER_COLUMN` : Refers to the leftmost column of the row header in the transposed table.
         * - `VALUE_COLUMN` : Refers to all value columns in the transposed table.
         */
        columnType: pulumi.Input<enums.quicksight.AnalysisTransposedColumnType>;
        /**
         * String based length that is composed of value and unit in px
         */
        columnWidth?: pulumi.Input<string>;
    }
    interface AnalysisTreeMapAggregatedFieldWellsArgs {
        /**
         * The color field well of a tree map. Values are grouped by aggregations based on group by fields.
         */
        colors?: pulumi.Input<pulumi.Input<inputs.quicksight.AnalysisMeasureFieldArgs>[]>;
        /**
         * The group by field well of a tree map. Values are grouped based on group by fields.
         */
        groups?: pulumi.Input<pulumi.Input<inputs.quicksight.AnalysisDimensionFieldArgs>[]>;
        /**
         * The size field well of a tree map. Values are aggregated based on group by fields.
         */
        sizes?: pulumi.Input<pulumi.Input<inputs.quicksight.AnalysisMeasureFieldArgs>[]>;
    }
    interface AnalysisTreeMapConfigurationArgs {
        /**
         * The label options (label text, label visibility) for the colors displayed in a tree map.
         */
        colorLabelOptions?: pulumi.Input<inputs.quicksight.AnalysisChartAxisLabelOptionsArgs>;
        /**
         * The color options (gradient color, point of divergence) of a tree map.
         */
        colorScale?: pulumi.Input<inputs.quicksight.AnalysisColorScaleArgs>;
        /**
         * The options that determine if visual data labels are displayed.
         */
        dataLabels?: pulumi.Input<inputs.quicksight.AnalysisDataLabelOptionsArgs>;
        /**
         * The field wells of the visual.
         */
        fieldWells?: pulumi.Input<inputs.quicksight.AnalysisTreeMapFieldWellsArgs>;
        /**
         * The label options (label text, label visibility) of the groups that are displayed in a tree map.
         */
        groupLabelOptions?: pulumi.Input<inputs.quicksight.AnalysisChartAxisLabelOptionsArgs>;
        /**
         * The general visual interactions setup for a visual.
         */
        interactions?: pulumi.Input<inputs.quicksight.AnalysisVisualInteractionOptionsArgs>;
        /**
         * The legend display setup of the visual.
         */
        legend?: pulumi.Input<inputs.quicksight.AnalysisLegendOptionsArgs>;
        /**
         * The label options (label text, label visibility) of the sizes that are displayed in a tree map.
         */
        sizeLabelOptions?: pulumi.Input<inputs.quicksight.AnalysisChartAxisLabelOptionsArgs>;
        /**
         * The sort configuration of a tree map.
         */
        sortConfiguration?: pulumi.Input<inputs.quicksight.AnalysisTreeMapSortConfigurationArgs>;
        /**
         * The tooltip display setup of the visual.
         */
        tooltip?: pulumi.Input<inputs.quicksight.AnalysisTooltipOptionsArgs>;
    }
    interface AnalysisTreeMapFieldWellsArgs {
        /**
         * The aggregated field wells of a tree map.
         */
        treeMapAggregatedFieldWells?: pulumi.Input<inputs.quicksight.AnalysisTreeMapAggregatedFieldWellsArgs>;
    }
    interface AnalysisTreeMapSortConfigurationArgs {
        /**
         * The limit on the number of groups that are displayed.
         */
        treeMapGroupItemsLimitConfiguration?: pulumi.Input<inputs.quicksight.AnalysisItemsLimitConfigurationArgs>;
        /**
         * The sort configuration of group by fields.
         */
        treeMapSort?: pulumi.Input<pulumi.Input<inputs.quicksight.AnalysisFieldSortOptionsArgs>[]>;
    }
    interface AnalysisTreeMapVisualArgs {
        /**
         * The list of custom actions that are configured for a visual.
         */
        actions?: pulumi.Input<pulumi.Input<inputs.quicksight.AnalysisVisualCustomActionArgs>[]>;
        /**
         * The configuration settings of the visual.
         */
        chartConfiguration?: pulumi.Input<inputs.quicksight.AnalysisTreeMapConfigurationArgs>;
        /**
         * The column hierarchy that is used during drill-downs and drill-ups.
         */
        columnHierarchies?: pulumi.Input<pulumi.Input<inputs.quicksight.AnalysisColumnHierarchyArgs>[]>;
        /**
         * The subtitle that is displayed on the visual.
         */
        subtitle?: pulumi.Input<inputs.quicksight.AnalysisVisualSubtitleLabelOptionsArgs>;
        /**
         * The title that is displayed on the visual.
         */
        title?: pulumi.Input<inputs.quicksight.AnalysisVisualTitleLabelOptionsArgs>;
        /**
         * The alt text for the visual.
         */
        visualContentAltText?: pulumi.Input<string>;
        /**
         * The unique identifier of a visual. This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers..
         */
        visualId: pulumi.Input<string>;
    }
    interface AnalysisTrendArrowOptionsArgs {
        /**
         * The visibility of the trend arrows.
         */
        visibility?: pulumi.Input<enums.quicksight.AnalysisVisibility>;
    }
    interface AnalysisUnaggregatedFieldArgs {
        /**
         * The column that is used in the `UnaggregatedField` .
         */
        column: pulumi.Input<inputs.quicksight.AnalysisColumnIdentifierArgs>;
        /**
         * The custom field ID.
         */
        fieldId: pulumi.Input<string>;
        /**
         * The format configuration of the field.
         */
        formatConfiguration?: pulumi.Input<inputs.quicksight.AnalysisFormatConfigurationArgs>;
    }
    interface AnalysisUniqueValuesComputationArgs {
        /**
         * The category field that is used in a computation.
         */
        category?: pulumi.Input<inputs.quicksight.AnalysisDimensionFieldArgs>;
        /**
         * The ID for a computation.
         */
        computationId: pulumi.Input<string>;
        /**
         * The name of a computation.
         */
        name?: pulumi.Input<string>;
    }
    /**
     * <p>The option to relax the validation that is required to create and update analyses, dashboards, and templates with definition objects. When you set this value to <code>LENIENT</code>, validation is skipped for specific errors.</p>
     */
    interface AnalysisValidationStrategyArgs {
        /**
         * The mode of validation for the asset to be created or updated. When you set this value to `STRICT` , strict validation for every error is enforced. When you set this value to `LENIENT` , validation is skipped for specific UI errors.
         */
        mode: pulumi.Input<enums.quicksight.AnalysisValidationStrategyMode>;
    }
    interface AnalysisVisibleRangeOptionsArgs {
        /**
         * The percent range in the visible range.
         */
        percentRange?: pulumi.Input<inputs.quicksight.AnalysisPercentVisibleRangeArgs>;
    }
    interface AnalysisVisualArgs {
        /**
         * A bar chart.
         *
         * For more information, see [Using bar charts](https://docs.aws.amazon.com/quicksight/latest/user/bar-charts.html) in the *Amazon QuickSight User Guide* .
         */
        barChartVisual?: pulumi.Input<inputs.quicksight.AnalysisBarChartVisualArgs>;
        /**
         * A box plot.
         *
         * For more information, see [Using box plots](https://docs.aws.amazon.com/quicksight/latest/user/box-plots.html) in the *Amazon QuickSight User Guide* .
         */
        boxPlotVisual?: pulumi.Input<inputs.quicksight.AnalysisBoxPlotVisualArgs>;
        /**
         * A combo chart.
         *
         * For more information, see [Using combo charts](https://docs.aws.amazon.com/quicksight/latest/user/combo-charts.html) in the *Amazon QuickSight User Guide* .
         */
        comboChartVisual?: pulumi.Input<inputs.quicksight.AnalysisComboChartVisualArgs>;
        /**
         * A visual that contains custom content.
         *
         * For more information, see [Using custom visual content](https://docs.aws.amazon.com/quicksight/latest/user/custom-visual-content.html) in the *Amazon QuickSight User Guide* .
         */
        customContentVisual?: pulumi.Input<inputs.quicksight.AnalysisCustomContentVisualArgs>;
        /**
         * An empty visual.
         */
        emptyVisual?: pulumi.Input<inputs.quicksight.AnalysisEmptyVisualArgs>;
        /**
         * A filled map.
         *
         * For more information, see [Creating filled maps](https://docs.aws.amazon.com/quicksight/latest/user/filled-maps.html) in the *Amazon QuickSight User Guide* .
         */
        filledMapVisual?: pulumi.Input<inputs.quicksight.AnalysisFilledMapVisualArgs>;
        /**
         * A funnel chart.
         *
         * For more information, see [Using funnel charts](https://docs.aws.amazon.com/quicksight/latest/user/funnel-visual-content.html) in the *Amazon QuickSight User Guide* .
         */
        funnelChartVisual?: pulumi.Input<inputs.quicksight.AnalysisFunnelChartVisualArgs>;
        /**
         * A gauge chart.
         *
         * For more information, see [Using gauge charts](https://docs.aws.amazon.com/quicksight/latest/user/gauge-chart.html) in the *Amazon QuickSight User Guide* .
         */
        gaugeChartVisual?: pulumi.Input<inputs.quicksight.AnalysisGaugeChartVisualArgs>;
        /**
         * A geospatial map or a points on map visual.
         *
         * For more information, see [Creating point maps](https://docs.aws.amazon.com/quicksight/latest/user/point-maps.html) in the *Amazon QuickSight User Guide* .
         */
        geospatialMapVisual?: pulumi.Input<inputs.quicksight.AnalysisGeospatialMapVisualArgs>;
        /**
         * A heat map.
         *
         * For more information, see [Using heat maps](https://docs.aws.amazon.com/quicksight/latest/user/heat-map.html) in the *Amazon QuickSight User Guide* .
         */
        heatMapVisual?: pulumi.Input<inputs.quicksight.AnalysisHeatMapVisualArgs>;
        /**
         * A histogram.
         *
         * For more information, see [Using histograms](https://docs.aws.amazon.com/quicksight/latest/user/histogram-charts.html) in the *Amazon QuickSight User Guide* .
         */
        histogramVisual?: pulumi.Input<inputs.quicksight.AnalysisHistogramVisualArgs>;
        /**
         * An insight visual.
         *
         * For more information, see [Working with insights](https://docs.aws.amazon.com/quicksight/latest/user/computational-insights.html) in the *Amazon QuickSight User Guide* .
         */
        insightVisual?: pulumi.Input<inputs.quicksight.AnalysisInsightVisualArgs>;
        /**
         * A key performance indicator (KPI).
         *
         * For more information, see [Using KPIs](https://docs.aws.amazon.com/quicksight/latest/user/kpi.html) in the *Amazon QuickSight User Guide* .
         */
        kpiVisual?: pulumi.Input<inputs.quicksight.AnalysisKpiVisualArgs>;
        /**
         * The properties for a layer map visual
         */
        layerMapVisual?: pulumi.Input<inputs.quicksight.AnalysisLayerMapVisualArgs>;
        /**
         * A line chart.
         *
         * For more information, see [Using line charts](https://docs.aws.amazon.com/quicksight/latest/user/line-charts.html) in the *Amazon QuickSight User Guide* .
         */
        lineChartVisual?: pulumi.Input<inputs.quicksight.AnalysisLineChartVisualArgs>;
        /**
         * A pie or donut chart.
         *
         * For more information, see [Using pie charts](https://docs.aws.amazon.com/quicksight/latest/user/pie-chart.html) in the *Amazon QuickSight User Guide* .
         */
        pieChartVisual?: pulumi.Input<inputs.quicksight.AnalysisPieChartVisualArgs>;
        /**
         * A pivot table.
         *
         * For more information, see [Using pivot tables](https://docs.aws.amazon.com/quicksight/latest/user/pivot-table.html) in the *Amazon QuickSight User Guide* .
         */
        pivotTableVisual?: pulumi.Input<inputs.quicksight.AnalysisPivotTableVisualArgs>;
        /**
         * The custom plugin visual type.
         */
        pluginVisual?: pulumi.Input<inputs.quicksight.AnalysisPluginVisualArgs>;
        /**
         * A radar chart visual.
         *
         * For more information, see [Using radar charts](https://docs.aws.amazon.com/quicksight/latest/user/radar-chart.html) in the *Amazon QuickSight User Guide* .
         */
        radarChartVisual?: pulumi.Input<inputs.quicksight.AnalysisRadarChartVisualArgs>;
        /**
         * A sankey diagram.
         *
         * For more information, see [Using Sankey diagrams](https://docs.aws.amazon.com/quicksight/latest/user/sankey-diagram.html) in the *Amazon QuickSight User Guide* .
         */
        sankeyDiagramVisual?: pulumi.Input<inputs.quicksight.AnalysisSankeyDiagramVisualArgs>;
        /**
         * A scatter plot.
         *
         * For more information, see [Using scatter plots](https://docs.aws.amazon.com/quicksight/latest/user/scatter-plot.html) in the *Amazon QuickSight User Guide* .
         */
        scatterPlotVisual?: pulumi.Input<inputs.quicksight.AnalysisScatterPlotVisualArgs>;
        /**
         * A table visual.
         *
         * For more information, see [Using tables as visuals](https://docs.aws.amazon.com/quicksight/latest/user/tabular.html) in the *Amazon QuickSight User Guide* .
         */
        tableVisual?: pulumi.Input<inputs.quicksight.AnalysisTableVisualArgs>;
        /**
         * A tree map.
         *
         * For more information, see [Using tree maps](https://docs.aws.amazon.com/quicksight/latest/user/tree-map.html) in the *Amazon QuickSight User Guide* .
         */
        treeMapVisual?: pulumi.Input<inputs.quicksight.AnalysisTreeMapVisualArgs>;
        /**
         * A waterfall chart.
         *
         * For more information, see [Using waterfall charts](https://docs.aws.amazon.com/quicksight/latest/user/waterfall-chart.html) in the *Amazon QuickSight User Guide* .
         */
        waterfallVisual?: pulumi.Input<inputs.quicksight.AnalysisWaterfallVisualArgs>;
        /**
         * A word cloud.
         *
         * For more information, see [Using word clouds](https://docs.aws.amazon.com/quicksight/latest/user/word-cloud.html) in the *Amazon QuickSight User Guide* .
         */
        wordCloudVisual?: pulumi.Input<inputs.quicksight.AnalysisWordCloudVisualArgs>;
    }
    interface AnalysisVisualCustomActionArgs {
        /**
         * A list of `VisualCustomActionOperations` .
         *
         * This is a union type structure. For this structure to be valid, only one of the attributes can be defined.
         */
        actionOperations: pulumi.Input<pulumi.Input<inputs.quicksight.AnalysisVisualCustomActionOperationArgs>[]>;
        /**
         * The ID of the `VisualCustomAction` .
         */
        customActionId: pulumi.Input<string>;
        /**
         * The name of the `VisualCustomAction` .
         */
        name: pulumi.Input<string>;
        /**
         * The status of the `VisualCustomAction` .
         */
        status?: pulumi.Input<enums.quicksight.AnalysisWidgetStatus>;
        /**
         * The trigger of the `VisualCustomAction` .
         *
         * Valid values are defined as follows:
         *
         * - `DATA_POINT_CLICK` : Initiates a custom action by a left pointer click on a data point.
         * - `DATA_POINT_MENU` : Initiates a custom action by right pointer click from the menu.
         */
        trigger: pulumi.Input<enums.quicksight.AnalysisVisualCustomActionTrigger>;
    }
    interface AnalysisVisualCustomActionOperationArgs {
        /**
         * The filter operation that filters data included in a visual or in an entire sheet.
         */
        filterOperation?: pulumi.Input<inputs.quicksight.AnalysisCustomActionFilterOperationArgs>;
        /**
         * The navigation operation that navigates between different sheets in the same analysis.
         */
        navigationOperation?: pulumi.Input<inputs.quicksight.AnalysisCustomActionNavigationOperationArgs>;
        /**
         * The set parameter operation that sets parameters in custom action.
         */
        setParametersOperation?: pulumi.Input<inputs.quicksight.AnalysisCustomActionSetParametersOperationArgs>;
        /**
         * The URL operation that opens a link to another webpage.
         */
        urlOperation?: pulumi.Input<inputs.quicksight.AnalysisCustomActionUrlOperationArgs>;
    }
    interface AnalysisVisualInteractionOptionsArgs {
        /**
         * The context menu options for a visual.
         */
        contextMenuOption?: pulumi.Input<inputs.quicksight.AnalysisContextMenuOptionArgs>;
        /**
         * The on-visual menu options for a visual.
         */
        visualMenuOption?: pulumi.Input<inputs.quicksight.AnalysisVisualMenuOptionArgs>;
    }
    interface AnalysisVisualMenuOptionArgs {
        /**
         * The availaiblity status of a visual's menu options.
         */
        availabilityStatus?: pulumi.Input<enums.quicksight.AnalysisDashboardBehavior>;
    }
    interface AnalysisVisualPaletteArgs {
        /**
         * The chart color options for the visual palette.
         */
        chartColor?: pulumi.Input<string>;
        /**
         * The color map options for the visual palette.
         */
        colorMap?: pulumi.Input<pulumi.Input<inputs.quicksight.AnalysisDataPathColorArgs>[]>;
    }
    interface AnalysisVisualSubtitleLabelOptionsArgs {
        /**
         * The long text format of the subtitle label, such as plain text or rich text.
         */
        formatText?: pulumi.Input<inputs.quicksight.AnalysisLongFormatTextArgs>;
        /**
         * The visibility of the subtitle label.
         */
        visibility?: pulumi.Input<enums.quicksight.AnalysisVisibility>;
    }
    interface AnalysisVisualTitleLabelOptionsArgs {
        /**
         * The short text format of the title label, such as plain text or rich text.
         */
        formatText?: pulumi.Input<inputs.quicksight.AnalysisShortFormatTextArgs>;
        /**
         * The visibility of the title label.
         */
        visibility?: pulumi.Input<enums.quicksight.AnalysisVisibility>;
    }
    interface AnalysisWaterfallChartAggregatedFieldWellsArgs {
        /**
         * The breakdown field wells of a waterfall visual.
         */
        breakdowns?: pulumi.Input<pulumi.Input<inputs.quicksight.AnalysisDimensionFieldArgs>[]>;
        /**
         * The category field wells of a waterfall visual.
         */
        categories?: pulumi.Input<pulumi.Input<inputs.quicksight.AnalysisDimensionFieldArgs>[]>;
        /**
         * The value field wells of a waterfall visual.
         */
        values?: pulumi.Input<pulumi.Input<inputs.quicksight.AnalysisMeasureFieldArgs>[]>;
    }
    interface AnalysisWaterfallChartColorConfigurationArgs {
        /**
         * The color configuration for individual groups within a waterfall visual.
         */
        groupColorConfiguration?: pulumi.Input<inputs.quicksight.AnalysisWaterfallChartGroupColorConfigurationArgs>;
    }
    interface AnalysisWaterfallChartConfigurationArgs {
        /**
         * The options that determine the presentation of the category axis.
         */
        categoryAxisDisplayOptions?: pulumi.Input<inputs.quicksight.AnalysisAxisDisplayOptionsArgs>;
        /**
         * The options that determine the presentation of the category axis label.
         */
        categoryAxisLabelOptions?: pulumi.Input<inputs.quicksight.AnalysisChartAxisLabelOptionsArgs>;
        /**
         * The color configuration of a waterfall visual.
         */
        colorConfiguration?: pulumi.Input<inputs.quicksight.AnalysisWaterfallChartColorConfigurationArgs>;
        /**
         * The data label configuration of a waterfall visual.
         */
        dataLabels?: pulumi.Input<inputs.quicksight.AnalysisDataLabelOptionsArgs>;
        /**
         * The field well configuration of a waterfall visual.
         */
        fieldWells?: pulumi.Input<inputs.quicksight.AnalysisWaterfallChartFieldWellsArgs>;
        /**
         * The general visual interactions setup for a visual.
         */
        interactions?: pulumi.Input<inputs.quicksight.AnalysisVisualInteractionOptionsArgs>;
        /**
         * The legend configuration of a waterfall visual.
         */
        legend?: pulumi.Input<inputs.quicksight.AnalysisLegendOptionsArgs>;
        /**
         * The options that determine the presentation of the y-axis.
         */
        primaryYAxisDisplayOptions?: pulumi.Input<inputs.quicksight.AnalysisAxisDisplayOptionsArgs>;
        /**
         * The options that determine the presentation of the y-axis label.
         */
        primaryYAxisLabelOptions?: pulumi.Input<inputs.quicksight.AnalysisChartAxisLabelOptionsArgs>;
        /**
         * The sort configuration of a waterfall visual.
         */
        sortConfiguration?: pulumi.Input<inputs.quicksight.AnalysisWaterfallChartSortConfigurationArgs>;
        /**
         * The visual palette configuration of a waterfall visual.
         */
        visualPalette?: pulumi.Input<inputs.quicksight.AnalysisVisualPaletteArgs>;
        /**
         * The options that determine the presentation of a waterfall visual.
         */
        waterfallChartOptions?: pulumi.Input<inputs.quicksight.AnalysisWaterfallChartOptionsArgs>;
    }
    interface AnalysisWaterfallChartFieldWellsArgs {
        /**
         * The field well configuration of a waterfall visual.
         */
        waterfallChartAggregatedFieldWells?: pulumi.Input<inputs.quicksight.AnalysisWaterfallChartAggregatedFieldWellsArgs>;
    }
    interface AnalysisWaterfallChartGroupColorConfigurationArgs {
        /**
         * Defines the color for the negative bars of a waterfall chart.
         */
        negativeBarColor?: pulumi.Input<string>;
        /**
         * Defines the color for the positive bars of a waterfall chart.
         */
        positiveBarColor?: pulumi.Input<string>;
        /**
         * Defines the color for the total bars of a waterfall chart.
         */
        totalBarColor?: pulumi.Input<string>;
    }
    interface AnalysisWaterfallChartOptionsArgs {
        /**
         * This option determines the total bar label of a waterfall visual.
         */
        totalBarLabel?: pulumi.Input<string>;
    }
    interface AnalysisWaterfallChartSortConfigurationArgs {
        /**
         * The limit on the number of bar groups that are displayed.
         */
        breakdownItemsLimit?: pulumi.Input<inputs.quicksight.AnalysisItemsLimitConfigurationArgs>;
        /**
         * The sort configuration of the category fields.
         */
        categorySort?: pulumi.Input<pulumi.Input<inputs.quicksight.AnalysisFieldSortOptionsArgs>[]>;
    }
    interface AnalysisWaterfallVisualArgs {
        /**
         * The list of custom actions that are configured for a visual.
         */
        actions?: pulumi.Input<pulumi.Input<inputs.quicksight.AnalysisVisualCustomActionArgs>[]>;
        /**
         * The configuration for a waterfall visual.
         */
        chartConfiguration?: pulumi.Input<inputs.quicksight.AnalysisWaterfallChartConfigurationArgs>;
        /**
         * The column hierarchy that is used during drill-downs and drill-ups.
         */
        columnHierarchies?: pulumi.Input<pulumi.Input<inputs.quicksight.AnalysisColumnHierarchyArgs>[]>;
        /**
         * The subtitle that is displayed on the visual.
         */
        subtitle?: pulumi.Input<inputs.quicksight.AnalysisVisualSubtitleLabelOptionsArgs>;
        /**
         * The title that is displayed on the visual.
         */
        title?: pulumi.Input<inputs.quicksight.AnalysisVisualTitleLabelOptionsArgs>;
        /**
         * The alt text for the visual.
         */
        visualContentAltText?: pulumi.Input<string>;
        /**
         * The unique identifier of a visual. This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers.
         */
        visualId: pulumi.Input<string>;
    }
    interface AnalysisWhatIfPointScenarioArgs {
        /**
         * The date that you need the forecast results for.
         */
        date: pulumi.Input<string>;
        /**
         * The target value that you want to meet for the provided date.
         */
        value: pulumi.Input<number>;
    }
    interface AnalysisWhatIfRangeScenarioArgs {
        /**
         * The end date in the date range that you need the forecast results for.
         */
        endDate: pulumi.Input<string>;
        /**
         * The start date in the date range that you need the forecast results for.
         */
        startDate: pulumi.Input<string>;
        /**
         * The target value that you want to meet for the provided date range.
         */
        value: pulumi.Input<number>;
    }
    interface AnalysisWordCloudAggregatedFieldWellsArgs {
        /**
         * The group by field well of a word cloud. Values are grouped by group by fields.
         */
        groupBy?: pulumi.Input<pulumi.Input<inputs.quicksight.AnalysisDimensionFieldArgs>[]>;
        /**
         * The size field well of a word cloud. Values are aggregated based on group by fields.
         */
        size?: pulumi.Input<pulumi.Input<inputs.quicksight.AnalysisMeasureFieldArgs>[]>;
    }
    interface AnalysisWordCloudChartConfigurationArgs {
        /**
         * The label options (label text, label visibility, and sort icon visibility) for the word cloud category.
         */
        categoryLabelOptions?: pulumi.Input<inputs.quicksight.AnalysisChartAxisLabelOptionsArgs>;
        /**
         * The field wells of the visual.
         */
        fieldWells?: pulumi.Input<inputs.quicksight.AnalysisWordCloudFieldWellsArgs>;
        /**
         * The general visual interactions setup for a visual.
         */
        interactions?: pulumi.Input<inputs.quicksight.AnalysisVisualInteractionOptionsArgs>;
        /**
         * The sort configuration of a word cloud visual.
         */
        sortConfiguration?: pulumi.Input<inputs.quicksight.AnalysisWordCloudSortConfigurationArgs>;
        /**
         * The options for a word cloud visual.
         */
        wordCloudOptions?: pulumi.Input<inputs.quicksight.AnalysisWordCloudOptionsArgs>;
    }
    interface AnalysisWordCloudFieldWellsArgs {
        /**
         * The aggregated field wells of a word cloud.
         */
        wordCloudAggregatedFieldWells?: pulumi.Input<inputs.quicksight.AnalysisWordCloudAggregatedFieldWellsArgs>;
    }
    interface AnalysisWordCloudOptionsArgs {
        /**
         * The cloud layout options (fluid, normal) of a word cloud.
         */
        cloudLayout?: pulumi.Input<enums.quicksight.AnalysisWordCloudCloudLayout>;
        /**
         * The length limit of each word from 1-100.
         */
        maximumStringLength?: pulumi.Input<number>;
        /**
         * The word casing options (lower_case, existing_case) for the words in a word cloud.
         */
        wordCasing?: pulumi.Input<enums.quicksight.AnalysisWordCloudWordCasing>;
        /**
         * The word orientation options (horizontal, horizontal_and_vertical) for the words in a word cloud.
         */
        wordOrientation?: pulumi.Input<enums.quicksight.AnalysisWordCloudWordOrientation>;
        /**
         * The word padding options (none, small, medium, large) for the words in a word cloud.
         */
        wordPadding?: pulumi.Input<enums.quicksight.AnalysisWordCloudWordPadding>;
        /**
         * The word scaling options (emphasize, normal) for the words in a word cloud.
         */
        wordScaling?: pulumi.Input<enums.quicksight.AnalysisWordCloudWordScaling>;
    }
    interface AnalysisWordCloudSortConfigurationArgs {
        /**
         * The limit on the number of groups that are displayed in a word cloud.
         */
        categoryItemsLimit?: pulumi.Input<inputs.quicksight.AnalysisItemsLimitConfigurationArgs>;
        /**
         * The sort configuration of group by fields.
         */
        categorySort?: pulumi.Input<pulumi.Input<inputs.quicksight.AnalysisFieldSortOptionsArgs>[]>;
    }
    interface AnalysisWordCloudVisualArgs {
        /**
         * The list of custom actions that are configured for a visual.
         */
        actions?: pulumi.Input<pulumi.Input<inputs.quicksight.AnalysisVisualCustomActionArgs>[]>;
        /**
         * The configuration settings of the visual.
         */
        chartConfiguration?: pulumi.Input<inputs.quicksight.AnalysisWordCloudChartConfigurationArgs>;
        /**
         * The column hierarchy that is used during drill-downs and drill-ups.
         */
        columnHierarchies?: pulumi.Input<pulumi.Input<inputs.quicksight.AnalysisColumnHierarchyArgs>[]>;
        /**
         * The subtitle that is displayed on the visual.
         */
        subtitle?: pulumi.Input<inputs.quicksight.AnalysisVisualSubtitleLabelOptionsArgs>;
        /**
         * The title that is displayed on the visual.
         */
        title?: pulumi.Input<inputs.quicksight.AnalysisVisualTitleLabelOptionsArgs>;
        /**
         * The alt text for the visual.
         */
        visualContentAltText?: pulumi.Input<string>;
        /**
         * The unique identifier of a visual. This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers..
         */
        visualId: pulumi.Input<string>;
    }
    interface AnalysisYAxisOptionsArgs {
        /**
         * The Y axis type to be used in the chart.
         *
         * If you choose `PRIMARY_Y_AXIS` , the primary Y Axis is located on the leftmost vertical axis of the chart.
         */
        yAxis: pulumi.Input<enums.quicksight.AnalysisSingleYAxisOption>;
    }
    interface CustomPermissionsCapabilitiesArgs {
        /**
         * The ability to add or run anomaly detection.
         */
        addOrRunAnomalyDetectionForAnalyses?: pulumi.Input<enums.quicksight.CustomPermissionsCapabilityState>;
        /**
         * The ability to create and update email reports.
         */
        createAndUpdateDashboardEmailReports?: pulumi.Input<enums.quicksight.CustomPermissionsCapabilityState>;
        /**
         * The ability to create and update data sources.
         */
        createAndUpdateDataSources?: pulumi.Input<enums.quicksight.CustomPermissionsCapabilityState>;
        /**
         * The ability to create and update datasets.
         */
        createAndUpdateDatasets?: pulumi.Input<enums.quicksight.CustomPermissionsCapabilityState>;
        /**
         * The ability to export to Create and Update themes.
         */
        createAndUpdateThemes?: pulumi.Input<enums.quicksight.CustomPermissionsCapabilityState>;
        /**
         * The ability to create and update threshold alerts.
         */
        createAndUpdateThresholdAlerts?: pulumi.Input<enums.quicksight.CustomPermissionsCapabilityState>;
        /**
         * The ability to create shared folders.
         */
        createSharedFolders?: pulumi.Input<enums.quicksight.CustomPermissionsCapabilityState>;
        /**
         * The ability to create a SPICE dataset.
         */
        createSpiceDataset?: pulumi.Input<enums.quicksight.CustomPermissionsCapabilityState>;
        /**
         * The ability to export to CSV files.
         */
        exportToCsv?: pulumi.Input<enums.quicksight.CustomPermissionsCapabilityState>;
        /**
         * The ability to export to Excel files.
         */
        exportToExcel?: pulumi.Input<enums.quicksight.CustomPermissionsCapabilityState>;
        /**
         * The ability to rename shared folders.
         */
        renameSharedFolders?: pulumi.Input<enums.quicksight.CustomPermissionsCapabilityState>;
        /**
         * The ability to share analyses.
         */
        shareAnalyses?: pulumi.Input<enums.quicksight.CustomPermissionsCapabilityState>;
        /**
         * The ability to share dashboards.
         */
        shareDashboards?: pulumi.Input<enums.quicksight.CustomPermissionsCapabilityState>;
        /**
         * The ability to share data sources.
         */
        shareDataSources?: pulumi.Input<enums.quicksight.CustomPermissionsCapabilityState>;
        /**
         * The ability to share datasets.
         */
        shareDatasets?: pulumi.Input<enums.quicksight.CustomPermissionsCapabilityState>;
        /**
         * The ability to subscribe to email reports.
         */
        subscribeDashboardEmailReports?: pulumi.Input<enums.quicksight.CustomPermissionsCapabilityState>;
        /**
         * The ability to view account SPICE capacity.
         */
        viewAccountSpiceCapacity?: pulumi.Input<enums.quicksight.CustomPermissionsCapabilityState>;
    }
    /**
     * <p>An ad hoc (one-time) filtering option.</p>
     */
    interface DashboardAdHocFilteringOptionArgs {
        /**
         * Availability status.
         */
        availabilityStatus?: pulumi.Input<enums.quicksight.DashboardBehavior>;
    }
    interface DashboardAggregationFunctionArgs {
        /**
         * Aggregation for attributes.
         */
        attributeAggregationFunction?: pulumi.Input<inputs.quicksight.DashboardAttributeAggregationFunctionArgs>;
        /**
         * Aggregation for categorical values.
         *
         * - `COUNT` : Aggregate by the total number of values, including duplicates.
         * - `DISTINCT_COUNT` : Aggregate by the total number of distinct values.
         */
        categoricalAggregationFunction?: pulumi.Input<enums.quicksight.DashboardCategoricalAggregationFunction>;
        /**
         * Aggregation for date values.
         *
         * - `COUNT` : Aggregate by the total number of values, including duplicates.
         * - `DISTINCT_COUNT` : Aggregate by the total number of distinct values.
         * - `MIN` : Select the smallest date value.
         * - `MAX` : Select the largest date value.
         */
        dateAggregationFunction?: pulumi.Input<enums.quicksight.DashboardDateAggregationFunction>;
        /**
         * Aggregation for numerical values.
         */
        numericalAggregationFunction?: pulumi.Input<inputs.quicksight.DashboardNumericalAggregationFunctionArgs>;
    }
    interface DashboardAggregationSortConfigurationArgs {
        /**
         * The function that aggregates the values in `Column` .
         */
        aggregationFunction?: pulumi.Input<inputs.quicksight.DashboardAggregationFunctionArgs>;
        /**
         * The column that determines the sort order of aggregated values.
         */
        column: pulumi.Input<inputs.quicksight.DashboardColumnIdentifierArgs>;
        /**
         * The sort direction of values.
         *
         * - `ASC` : Sort in ascending order.
         * - `DESC` : Sort in descending order.
         */
        sortDirection: pulumi.Input<enums.quicksight.DashboardSortDirection>;
    }
    interface DashboardAllSheetsFilterScopeConfigurationArgs {
    }
    interface DashboardAnalysisDefaultsArgs {
        /**
         * The configuration for default new sheet settings.
         */
        defaultNewSheetConfiguration: pulumi.Input<inputs.quicksight.DashboardDefaultNewSheetConfigurationArgs>;
    }
    interface DashboardAnchorDateConfigurationArgs {
        /**
         * The options for the date configuration. Choose one of the options below:
         *
         * - `NOW`
         */
        anchorOption?: pulumi.Input<enums.quicksight.DashboardAnchorOption>;
        /**
         * The name of the parameter that is used for the anchor date configuration.
         */
        parameterName?: pulumi.Input<string>;
    }
    interface DashboardArcAxisConfigurationArgs {
        /**
         * The arc axis range of a `GaugeChartVisual` .
         */
        range?: pulumi.Input<inputs.quicksight.DashboardArcAxisDisplayRangeArgs>;
        /**
         * The reserved range of the arc axis.
         */
        reserveRange?: pulumi.Input<number>;
    }
    interface DashboardArcAxisDisplayRangeArgs {
        /**
         * The maximum value of the arc axis range.
         */
        max?: pulumi.Input<number>;
        /**
         * The minimum value of the arc axis range.
         */
        min?: pulumi.Input<number>;
    }
    interface DashboardArcConfigurationArgs {
        /**
         * The option that determines the arc angle of a `GaugeChartVisual` .
         */
        arcAngle?: pulumi.Input<number>;
        /**
         * The options that determine the arc thickness of a `GaugeChartVisual` .
         */
        arcThickness?: pulumi.Input<enums.quicksight.DashboardArcThicknessOptions>;
    }
    interface DashboardArcOptionsArgs {
        /**
         * The arc thickness of a `GaugeChartVisual` .
         */
        arcThickness?: pulumi.Input<enums.quicksight.DashboardArcThickness>;
    }
    interface DashboardAssetOptionsArgs {
        /**
         * Determines the timezone for the analysis.
         */
        timezone?: pulumi.Input<string>;
        /**
         * Determines the week start day for an analysis.
         */
        weekStart?: pulumi.Input<enums.quicksight.DashboardDayOfTheWeek>;
    }
    interface DashboardAttributeAggregationFunctionArgs {
        /**
         * The built-in aggregation functions for attributes.
         *
         * - `UNIQUE_VALUE` : Returns the unique value for a field, aggregated by the dimension fields.
         */
        simpleAttributeAggregation?: pulumi.Input<enums.quicksight.DashboardSimpleAttributeAggregationFunction>;
        /**
         * Used by the `UNIQUE_VALUE` aggregation function. If there are multiple values for the field used by the aggregation, the value for this property will be returned instead. Defaults to '*'.
         */
        valueForMultipleValues?: pulumi.Input<string>;
    }
    interface DashboardAxisDataOptionsArgs {
        /**
         * The options for an axis with a date field.
         */
        dateAxisOptions?: pulumi.Input<inputs.quicksight.DashboardDateAxisOptionsArgs>;
        /**
         * The options for an axis with a numeric field.
         */
        numericAxisOptions?: pulumi.Input<inputs.quicksight.DashboardNumericAxisOptionsArgs>;
    }
    interface DashboardAxisDisplayDataDrivenRangeArgs {
    }
    interface DashboardAxisDisplayMinMaxRangeArgs {
        /**
         * The maximum setup for an axis display range.
         */
        maximum?: pulumi.Input<number>;
        /**
         * The minimum setup for an axis display range.
         */
        minimum?: pulumi.Input<number>;
    }
    interface DashboardAxisDisplayOptionsArgs {
        /**
         * Determines whether or not the axis line is visible.
         */
        axisLineVisibility?: pulumi.Input<enums.quicksight.DashboardVisibility>;
        /**
         * String based length that is composed of value and unit in px
         */
        axisOffset?: pulumi.Input<string>;
        /**
         * The data options for an axis.
         */
        dataOptions?: pulumi.Input<inputs.quicksight.DashboardAxisDataOptionsArgs>;
        /**
         * Determines whether or not the grid line is visible.
         */
        gridLineVisibility?: pulumi.Input<enums.quicksight.DashboardVisibility>;
        /**
         * The scroll bar options for an axis.
         */
        scrollbarOptions?: pulumi.Input<inputs.quicksight.DashboardScrollBarOptionsArgs>;
        /**
         * The tick label options of an axis.
         */
        tickLabelOptions?: pulumi.Input<inputs.quicksight.DashboardAxisTickLabelOptionsArgs>;
    }
    interface DashboardAxisDisplayRangeArgs {
        /**
         * The data-driven setup of an axis display range.
         */
        dataDriven?: pulumi.Input<inputs.quicksight.DashboardAxisDisplayDataDrivenRangeArgs>;
        /**
         * The minimum and maximum setup of an axis display range.
         */
        minMax?: pulumi.Input<inputs.quicksight.DashboardAxisDisplayMinMaxRangeArgs>;
    }
    interface DashboardAxisLabelOptionsArgs {
        /**
         * The options that indicate which field the label belongs to.
         */
        applyTo?: pulumi.Input<inputs.quicksight.DashboardAxisLabelReferenceOptionsArgs>;
        /**
         * The text for the axis label.
         */
        customLabel?: pulumi.Input<string>;
        /**
         * The font configuration of the axis label.
         */
        fontConfiguration?: pulumi.Input<inputs.quicksight.DashboardFontConfigurationArgs>;
    }
    interface DashboardAxisLabelReferenceOptionsArgs {
        /**
         * The column that the axis label is targeted to.
         */
        column: pulumi.Input<inputs.quicksight.DashboardColumnIdentifierArgs>;
        /**
         * The field that the axis label is targeted to.
         */
        fieldId: pulumi.Input<string>;
    }
    interface DashboardAxisLinearScaleArgs {
        /**
         * The step count setup of a linear axis.
         */
        stepCount?: pulumi.Input<number>;
        /**
         * The step size setup of a linear axis.
         */
        stepSize?: pulumi.Input<number>;
    }
    interface DashboardAxisLogarithmicScaleArgs {
        /**
         * The base setup of a logarithmic axis scale.
         */
        base?: pulumi.Input<number>;
    }
    interface DashboardAxisScaleArgs {
        /**
         * The linear axis scale setup.
         */
        linear?: pulumi.Input<inputs.quicksight.DashboardAxisLinearScaleArgs>;
        /**
         * The logarithmic axis scale setup.
         */
        logarithmic?: pulumi.Input<inputs.quicksight.DashboardAxisLogarithmicScaleArgs>;
    }
    interface DashboardAxisTickLabelOptionsArgs {
        /**
         * Determines whether or not the axis ticks are visible.
         */
        labelOptions?: pulumi.Input<inputs.quicksight.DashboardLabelOptionsArgs>;
        /**
         * The rotation angle of the axis tick labels.
         */
        rotationAngle?: pulumi.Input<number>;
    }
    interface DashboardBarChartAggregatedFieldWellsArgs {
        /**
         * The category (y-axis) field well of a bar chart.
         */
        category?: pulumi.Input<pulumi.Input<inputs.quicksight.DashboardDimensionFieldArgs>[]>;
        /**
         * The color (group/color) field well of a bar chart.
         */
        colors?: pulumi.Input<pulumi.Input<inputs.quicksight.DashboardDimensionFieldArgs>[]>;
        /**
         * The small multiples field well of a bar chart.
         */
        smallMultiples?: pulumi.Input<pulumi.Input<inputs.quicksight.DashboardDimensionFieldArgs>[]>;
        /**
         * The value field wells of a bar chart. Values are aggregated by category.
         */
        values?: pulumi.Input<pulumi.Input<inputs.quicksight.DashboardMeasureFieldArgs>[]>;
    }
    interface DashboardBarChartConfigurationArgs {
        /**
         * Determines the arrangement of the bars. The orientation and arrangement of bars determine the type of bar that is used in the visual.
         */
        barsArrangement?: pulumi.Input<enums.quicksight.DashboardBarsArrangement>;
        /**
         * The label display options (grid line, range, scale, axis step) for bar chart category.
         */
        categoryAxis?: pulumi.Input<inputs.quicksight.DashboardAxisDisplayOptionsArgs>;
        /**
         * The label options (label text, label visibility and sort icon visibility) for a bar chart.
         */
        categoryLabelOptions?: pulumi.Input<inputs.quicksight.DashboardChartAxisLabelOptionsArgs>;
        /**
         * The label options (label text, label visibility and sort icon visibility) for a color that is used in a bar chart.
         */
        colorLabelOptions?: pulumi.Input<inputs.quicksight.DashboardChartAxisLabelOptionsArgs>;
        /**
         * The contribution analysis (anomaly configuration) setup of the visual.
         */
        contributionAnalysisDefaults?: pulumi.Input<pulumi.Input<inputs.quicksight.DashboardContributionAnalysisDefaultArgs>[]>;
        /**
         * The options that determine if visual data labels are displayed.
         */
        dataLabels?: pulumi.Input<inputs.quicksight.DashboardDataLabelOptionsArgs>;
        /**
         * The field wells of the visual.
         */
        fieldWells?: pulumi.Input<inputs.quicksight.DashboardBarChartFieldWellsArgs>;
        /**
         * The general visual interactions setup for a visual.
         */
        interactions?: pulumi.Input<inputs.quicksight.DashboardVisualInteractionOptionsArgs>;
        /**
         * The legend display setup of the visual.
         */
        legend?: pulumi.Input<inputs.quicksight.DashboardLegendOptionsArgs>;
        /**
         * The orientation of the bars in a bar chart visual. There are two valid values in this structure:
         *
         * - `HORIZONTAL` : Used for charts that have horizontal bars. Visuals that use this value are horizontal bar charts, horizontal stacked bar charts, and horizontal stacked 100% bar charts.
         * - `VERTICAL` : Used for charts that have vertical bars. Visuals that use this value are vertical bar charts, vertical stacked bar charts, and vertical stacked 100% bar charts.
         */
        orientation?: pulumi.Input<enums.quicksight.DashboardBarChartOrientation>;
        /**
         * The reference line setup of the visual.
         */
        referenceLines?: pulumi.Input<pulumi.Input<inputs.quicksight.DashboardReferenceLineArgs>[]>;
        /**
         * The small multiples setup for the visual.
         */
        smallMultiplesOptions?: pulumi.Input<inputs.quicksight.DashboardSmallMultiplesOptionsArgs>;
        /**
         * The sort configuration of a `BarChartVisual` .
         */
        sortConfiguration?: pulumi.Input<inputs.quicksight.DashboardBarChartSortConfigurationArgs>;
        /**
         * The tooltip display setup of the visual.
         */
        tooltip?: pulumi.Input<inputs.quicksight.DashboardTooltipOptionsArgs>;
        /**
         * The label display options (grid line, range, scale, axis step) for a bar chart value.
         */
        valueAxis?: pulumi.Input<inputs.quicksight.DashboardAxisDisplayOptionsArgs>;
        /**
         * The label options (label text, label visibility and sort icon visibility) for a bar chart value.
         */
        valueLabelOptions?: pulumi.Input<inputs.quicksight.DashboardChartAxisLabelOptionsArgs>;
        /**
         * The palette (chart color) display setup of the visual.
         */
        visualPalette?: pulumi.Input<inputs.quicksight.DashboardVisualPaletteArgs>;
    }
    interface DashboardBarChartFieldWellsArgs {
        /**
         * The aggregated field wells of a bar chart.
         */
        barChartAggregatedFieldWells?: pulumi.Input<inputs.quicksight.DashboardBarChartAggregatedFieldWellsArgs>;
    }
    interface DashboardBarChartSortConfigurationArgs {
        /**
         * The limit on the number of categories displayed in a bar chart.
         */
        categoryItemsLimit?: pulumi.Input<inputs.quicksight.DashboardItemsLimitConfigurationArgs>;
        /**
         * The sort configuration of category fields.
         */
        categorySort?: pulumi.Input<pulumi.Input<inputs.quicksight.DashboardFieldSortOptionsArgs>[]>;
        /**
         * The limit on the number of values displayed in a bar chart.
         */
        colorItemsLimit?: pulumi.Input<inputs.quicksight.DashboardItemsLimitConfigurationArgs>;
        /**
         * The sort configuration of color fields in a bar chart.
         */
        colorSort?: pulumi.Input<pulumi.Input<inputs.quicksight.DashboardFieldSortOptionsArgs>[]>;
        /**
         * The limit on the number of small multiples panels that are displayed.
         */
        smallMultiplesLimitConfiguration?: pulumi.Input<inputs.quicksight.DashboardItemsLimitConfigurationArgs>;
        /**
         * The sort configuration of the small multiples field.
         */
        smallMultiplesSort?: pulumi.Input<pulumi.Input<inputs.quicksight.DashboardFieldSortOptionsArgs>[]>;
    }
    interface DashboardBarChartVisualArgs {
        /**
         * The list of custom actions that are configured for a visual.
         */
        actions?: pulumi.Input<pulumi.Input<inputs.quicksight.DashboardVisualCustomActionArgs>[]>;
        /**
         * The configuration settings of the visual.
         */
        chartConfiguration?: pulumi.Input<inputs.quicksight.DashboardBarChartConfigurationArgs>;
        /**
         * The column hierarchy that is used during drill-downs and drill-ups.
         */
        columnHierarchies?: pulumi.Input<pulumi.Input<inputs.quicksight.DashboardColumnHierarchyArgs>[]>;
        /**
         * The subtitle that is displayed on the visual.
         */
        subtitle?: pulumi.Input<inputs.quicksight.DashboardVisualSubtitleLabelOptionsArgs>;
        /**
         * The title that is displayed on the visual.
         */
        title?: pulumi.Input<inputs.quicksight.DashboardVisualTitleLabelOptionsArgs>;
        /**
         * The alt text for the visual.
         */
        visualContentAltText?: pulumi.Input<string>;
        /**
         * The unique identifier of a visual. This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers.
         */
        visualId: pulumi.Input<string>;
    }
    interface DashboardBinCountOptionsArgs {
        /**
         * The options that determine the bin count value.
         */
        value?: pulumi.Input<number>;
    }
    interface DashboardBinWidthOptionsArgs {
        /**
         * The options that determine the bin count limit.
         */
        binCountLimit?: pulumi.Input<number>;
        /**
         * The options that determine the bin width value.
         */
        value?: pulumi.Input<number>;
    }
    interface DashboardBodySectionConfigurationArgs {
        /**
         * The configuration of content in a body section.
         */
        content: pulumi.Input<inputs.quicksight.DashboardBodySectionContentArgs>;
        /**
         * The configuration of a page break for a section.
         */
        pageBreakConfiguration?: pulumi.Input<inputs.quicksight.DashboardSectionPageBreakConfigurationArgs>;
        /**
         * Describes the configurations that are required to declare a section as repeating.
         */
        repeatConfiguration?: pulumi.Input<inputs.quicksight.DashboardBodySectionRepeatConfigurationArgs>;
        /**
         * The unique identifier of a body section.
         */
        sectionId: pulumi.Input<string>;
        /**
         * The style options of a body section.
         */
        style?: pulumi.Input<inputs.quicksight.DashboardSectionStyleArgs>;
    }
    interface DashboardBodySectionContentArgs {
        /**
         * The layout configuration of a body section.
         */
        layout?: pulumi.Input<inputs.quicksight.DashboardSectionLayoutConfigurationArgs>;
    }
    interface DashboardBodySectionDynamicCategoryDimensionConfigurationArgs {
        column: pulumi.Input<inputs.quicksight.DashboardColumnIdentifierArgs>;
        /**
         * Number of values to use from the column for repetition.
         */
        limit?: pulumi.Input<number>;
        /**
         * Sort criteria on the column values that you use for repetition.
         */
        sortByMetrics?: pulumi.Input<pulumi.Input<inputs.quicksight.DashboardColumnSortArgs>[]>;
    }
    interface DashboardBodySectionDynamicNumericDimensionConfigurationArgs {
        column: pulumi.Input<inputs.quicksight.DashboardColumnIdentifierArgs>;
        /**
         * Number of values to use from the column for repetition.
         */
        limit?: pulumi.Input<number>;
        /**
         * Sort criteria on the column values that you use for repetition.
         */
        sortByMetrics?: pulumi.Input<pulumi.Input<inputs.quicksight.DashboardColumnSortArgs>[]>;
    }
    interface DashboardBodySectionRepeatConfigurationArgs {
        /**
         * List of `BodySectionRepeatDimensionConfiguration` values that describe the dataset column and constraints for the column used to repeat the contents of a section.
         */
        dimensionConfigurations?: pulumi.Input<pulumi.Input<inputs.quicksight.DashboardBodySectionRepeatDimensionConfigurationArgs>[]>;
        /**
         * List of visuals to exclude from repetition in repeating sections. The visuals will render identically, and ignore the repeating configurations in all repeating instances.
         */
        nonRepeatingVisuals?: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * Page break configuration to apply for each repeating instance.
         */
        pageBreakConfiguration?: pulumi.Input<inputs.quicksight.DashboardBodySectionRepeatPageBreakConfigurationArgs>;
    }
    interface DashboardBodySectionRepeatDimensionConfigurationArgs {
        /**
         * Describes the *Category* dataset column and constraints around the dynamic values that will be used in repeating the section contents.
         */
        dynamicCategoryDimensionConfiguration?: pulumi.Input<inputs.quicksight.DashboardBodySectionDynamicCategoryDimensionConfigurationArgs>;
        /**
         * Describes the *Numeric* dataset column and constraints around the dynamic values used to repeat the contents of a section.
         */
        dynamicNumericDimensionConfiguration?: pulumi.Input<inputs.quicksight.DashboardBodySectionDynamicNumericDimensionConfigurationArgs>;
    }
    interface DashboardBodySectionRepeatPageBreakConfigurationArgs {
        after?: pulumi.Input<inputs.quicksight.DashboardSectionAfterPageBreakArgs>;
    }
    interface DashboardBoxPlotAggregatedFieldWellsArgs {
        /**
         * The group by field well of a box plot chart. Values are grouped based on group by fields.
         */
        groupBy?: pulumi.Input<pulumi.Input<inputs.quicksight.DashboardDimensionFieldArgs>[]>;
        /**
         * The value field well of a box plot chart. Values are aggregated based on group by fields.
         */
        values?: pulumi.Input<pulumi.Input<inputs.quicksight.DashboardMeasureFieldArgs>[]>;
    }
    interface DashboardBoxPlotChartConfigurationArgs {
        /**
         * The box plot chart options for a box plot visual
         */
        boxPlotOptions?: pulumi.Input<inputs.quicksight.DashboardBoxPlotOptionsArgs>;
        /**
         * The label display options (grid line, range, scale, axis step) of a box plot category.
         */
        categoryAxis?: pulumi.Input<inputs.quicksight.DashboardAxisDisplayOptionsArgs>;
        /**
         * The label options (label text, label visibility and sort Icon visibility) of a box plot category.
         */
        categoryLabelOptions?: pulumi.Input<inputs.quicksight.DashboardChartAxisLabelOptionsArgs>;
        /**
         * The field wells of the visual.
         */
        fieldWells?: pulumi.Input<inputs.quicksight.DashboardBoxPlotFieldWellsArgs>;
        /**
         * The general visual interactions setup for a visual.
         */
        interactions?: pulumi.Input<inputs.quicksight.DashboardVisualInteractionOptionsArgs>;
        legend?: pulumi.Input<inputs.quicksight.DashboardLegendOptionsArgs>;
        /**
         * The label display options (grid line, range, scale, axis step) of a box plot category.
         */
        primaryYAxisDisplayOptions?: pulumi.Input<inputs.quicksight.DashboardAxisDisplayOptionsArgs>;
        /**
         * The label options (label text, label visibility and sort icon visibility) of a box plot value.
         */
        primaryYAxisLabelOptions?: pulumi.Input<inputs.quicksight.DashboardChartAxisLabelOptionsArgs>;
        /**
         * The reference line setup of the visual.
         */
        referenceLines?: pulumi.Input<pulumi.Input<inputs.quicksight.DashboardReferenceLineArgs>[]>;
        /**
         * The sort configuration of a `BoxPlotVisual` .
         */
        sortConfiguration?: pulumi.Input<inputs.quicksight.DashboardBoxPlotSortConfigurationArgs>;
        /**
         * The tooltip display setup of the visual.
         */
        tooltip?: pulumi.Input<inputs.quicksight.DashboardTooltipOptionsArgs>;
        /**
         * The palette (chart color) display setup of the visual.
         */
        visualPalette?: pulumi.Input<inputs.quicksight.DashboardVisualPaletteArgs>;
    }
    interface DashboardBoxPlotFieldWellsArgs {
        /**
         * The aggregated field wells of a box plot.
         */
        boxPlotAggregatedFieldWells?: pulumi.Input<inputs.quicksight.DashboardBoxPlotAggregatedFieldWellsArgs>;
    }
    interface DashboardBoxPlotOptionsArgs {
        /**
         * Determines the visibility of all data points of the box plot.
         */
        allDataPointsVisibility?: pulumi.Input<enums.quicksight.DashboardVisibility>;
        /**
         * Determines the visibility of the outlier in a box plot.
         */
        outlierVisibility?: pulumi.Input<enums.quicksight.DashboardVisibility>;
        /**
         * The style options of the box plot.
         */
        styleOptions?: pulumi.Input<inputs.quicksight.DashboardBoxPlotStyleOptionsArgs>;
    }
    interface DashboardBoxPlotSortConfigurationArgs {
        /**
         * The sort configuration of a group by fields.
         */
        categorySort?: pulumi.Input<pulumi.Input<inputs.quicksight.DashboardFieldSortOptionsArgs>[]>;
        /**
         * The pagination configuration of a table visual or box plot.
         */
        paginationConfiguration?: pulumi.Input<inputs.quicksight.DashboardPaginationConfigurationArgs>;
    }
    interface DashboardBoxPlotStyleOptionsArgs {
        /**
         * The fill styles (solid, transparent) of the box plot.
         */
        fillStyle?: pulumi.Input<enums.quicksight.DashboardBoxPlotFillStyle>;
    }
    interface DashboardBoxPlotVisualArgs {
        /**
         * The list of custom actions that are configured for a visual.
         */
        actions?: pulumi.Input<pulumi.Input<inputs.quicksight.DashboardVisualCustomActionArgs>[]>;
        /**
         * The configuration settings of the visual.
         */
        chartConfiguration?: pulumi.Input<inputs.quicksight.DashboardBoxPlotChartConfigurationArgs>;
        /**
         * The column hierarchy that is used during drill-downs and drill-ups.
         */
        columnHierarchies?: pulumi.Input<pulumi.Input<inputs.quicksight.DashboardColumnHierarchyArgs>[]>;
        /**
         * The subtitle that is displayed on the visual.
         */
        subtitle?: pulumi.Input<inputs.quicksight.DashboardVisualSubtitleLabelOptionsArgs>;
        /**
         * The title that is displayed on the visual.
         */
        title?: pulumi.Input<inputs.quicksight.DashboardVisualTitleLabelOptionsArgs>;
        /**
         * The alt text for the visual.
         */
        visualContentAltText?: pulumi.Input<string>;
        /**
         * The unique identifier of a visual. This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers..
         */
        visualId: pulumi.Input<string>;
    }
    interface DashboardCalculatedFieldArgs {
        /**
         * The data set that is used in this calculated field.
         */
        dataSetIdentifier: pulumi.Input<string>;
        /**
         * The expression of the calculated field.
         */
        expression: pulumi.Input<string>;
        /**
         * The name of the calculated field.
         */
        name: pulumi.Input<string>;
    }
    interface DashboardCalculatedMeasureFieldArgs {
        /**
         * The expression in the table calculation.
         */
        expression: pulumi.Input<string>;
        /**
         * The custom field ID.
         */
        fieldId: pulumi.Input<string>;
    }
    interface DashboardCascadingControlConfigurationArgs {
        /**
         * A list of source controls that determine the values that are used in the current control.
         */
        sourceControls?: pulumi.Input<pulumi.Input<inputs.quicksight.DashboardCascadingControlSourceArgs>[]>;
    }
    interface DashboardCascadingControlSourceArgs {
        /**
         * The column identifier that determines which column to look up for the source sheet control.
         */
        columnToMatch?: pulumi.Input<inputs.quicksight.DashboardColumnIdentifierArgs>;
        /**
         * The source sheet control ID of a `CascadingControlSource` .
         */
        sourceSheetControlId?: pulumi.Input<string>;
    }
    interface DashboardCategoricalDimensionFieldArgs {
        /**
         * The column that is used in the `CategoricalDimensionField` .
         */
        column: pulumi.Input<inputs.quicksight.DashboardColumnIdentifierArgs>;
        /**
         * The custom field ID.
         */
        fieldId: pulumi.Input<string>;
        /**
         * The format configuration of the field.
         */
        formatConfiguration?: pulumi.Input<inputs.quicksight.DashboardStringFormatConfigurationArgs>;
        /**
         * The custom hierarchy ID.
         */
        hierarchyId?: pulumi.Input<string>;
    }
    interface DashboardCategoricalMeasureFieldArgs {
        /**
         * The aggregation function of the measure field.
         */
        aggregationFunction?: pulumi.Input<enums.quicksight.DashboardCategoricalAggregationFunction>;
        /**
         * The column that is used in the `CategoricalMeasureField` .
         */
        column: pulumi.Input<inputs.quicksight.DashboardColumnIdentifierArgs>;
        /**
         * The custom field ID.
         */
        fieldId: pulumi.Input<string>;
        /**
         * The format configuration of the field.
         */
        formatConfiguration?: pulumi.Input<inputs.quicksight.DashboardStringFormatConfigurationArgs>;
    }
    interface DashboardCategoryDrillDownFilterArgs {
        /**
         * A list of the string inputs that are the values of the category drill down filter.
         */
        categoryValues: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * The column that the filter is applied to.
         */
        column: pulumi.Input<inputs.quicksight.DashboardColumnIdentifierArgs>;
    }
    interface DashboardCategoryFilterArgs {
        /**
         * The column that the filter is applied to.
         */
        column: pulumi.Input<inputs.quicksight.DashboardColumnIdentifierArgs>;
        /**
         * The configuration for a `CategoryFilter` .
         */
        configuration: pulumi.Input<inputs.quicksight.DashboardCategoryFilterConfigurationArgs>;
        /**
         * The default configurations for the associated controls. This applies only for filters that are scoped to multiple sheets.
         */
        defaultFilterControlConfiguration?: pulumi.Input<inputs.quicksight.DashboardDefaultFilterControlConfigurationArgs>;
        /**
         * An identifier that uniquely identifies a filter within a dashboard, analysis, or template.
         */
        filterId: pulumi.Input<string>;
    }
    interface DashboardCategoryFilterConfigurationArgs {
        /**
         * A custom filter that filters based on a single value. This filter can be partially matched.
         */
        customFilterConfiguration?: pulumi.Input<inputs.quicksight.DashboardCustomFilterConfigurationArgs>;
        /**
         * A list of custom filter values. In the Amazon QuickSight console, this filter type is called a custom filter list.
         */
        customFilterListConfiguration?: pulumi.Input<inputs.quicksight.DashboardCustomFilterListConfigurationArgs>;
        /**
         * A list of filter configurations. In the Amazon QuickSight console, this filter type is called a filter list.
         */
        filterListConfiguration?: pulumi.Input<inputs.quicksight.DashboardFilterListConfigurationArgs>;
    }
    interface DashboardCategoryInnerFilterArgs {
        column: pulumi.Input<inputs.quicksight.DashboardColumnIdentifierArgs>;
        configuration: pulumi.Input<inputs.quicksight.DashboardCategoryFilterConfigurationArgs>;
        defaultFilterControlConfiguration?: pulumi.Input<inputs.quicksight.DashboardDefaultFilterControlConfigurationArgs>;
    }
    interface DashboardChartAxisLabelOptionsArgs {
        /**
         * The label options for a chart axis.
         */
        axisLabelOptions?: pulumi.Input<pulumi.Input<inputs.quicksight.DashboardAxisLabelOptionsArgs>[]>;
        /**
         * The visibility configuration of the sort icon on a chart's axis label.
         */
        sortIconVisibility?: pulumi.Input<enums.quicksight.DashboardVisibility>;
        /**
         * The visibility of an axis label on a chart. Choose one of the following options:
         *
         * - `VISIBLE` : Shows the axis.
         * - `HIDDEN` : Hides the axis.
         */
        visibility?: pulumi.Input<enums.quicksight.DashboardVisibility>;
    }
    interface DashboardClusterMarkerArgs {
        /**
         * The simple cluster marker of the cluster marker.
         */
        simpleClusterMarker?: pulumi.Input<inputs.quicksight.DashboardSimpleClusterMarkerArgs>;
    }
    interface DashboardClusterMarkerConfigurationArgs {
        /**
         * The cluster marker that is a part of the cluster marker configuration.
         */
        clusterMarker?: pulumi.Input<inputs.quicksight.DashboardClusterMarkerArgs>;
    }
    interface DashboardColorScaleArgs {
        /**
         * Determines the color fill type.
         */
        colorFillType: pulumi.Input<enums.quicksight.DashboardColorFillType>;
        /**
         * Determines the list of colors that are applied to the visual.
         */
        colors: pulumi.Input<pulumi.Input<inputs.quicksight.DashboardDataColorArgs>[]>;
        /**
         * Determines the color that is applied to null values.
         */
        nullValueColor?: pulumi.Input<inputs.quicksight.DashboardDataColorArgs>;
    }
    interface DashboardColorsConfigurationArgs {
        /**
         * A list of up to 50 custom colors.
         */
        customColors?: pulumi.Input<pulumi.Input<inputs.quicksight.DashboardCustomColorArgs>[]>;
    }
    interface DashboardColumnConfigurationArgs {
        /**
         * The color configurations of the column.
         */
        colorsConfiguration?: pulumi.Input<inputs.quicksight.DashboardColorsConfigurationArgs>;
        /**
         * The column.
         */
        column: pulumi.Input<inputs.quicksight.DashboardColumnIdentifierArgs>;
        /**
         * The format configuration of a column.
         */
        formatConfiguration?: pulumi.Input<inputs.quicksight.DashboardFormatConfigurationArgs>;
        /**
         * The role of the column.
         */
        role?: pulumi.Input<enums.quicksight.DashboardColumnRole>;
    }
    interface DashboardColumnHierarchyArgs {
        /**
         * The option that determines the hierarchy of any `DateTime` fields.
         */
        dateTimeHierarchy?: pulumi.Input<inputs.quicksight.DashboardDateTimeHierarchyArgs>;
        /**
         * The option that determines the hierarchy of the fields that are built within a visual's field wells. These fields can't be duplicated to other visuals.
         */
        explicitHierarchy?: pulumi.Input<inputs.quicksight.DashboardExplicitHierarchyArgs>;
        /**
         * The option that determines the hierarchy of the fields that are defined during data preparation. These fields are available to use in any analysis that uses the data source.
         */
        predefinedHierarchy?: pulumi.Input<inputs.quicksight.DashboardPredefinedHierarchyArgs>;
    }
    interface DashboardColumnIdentifierArgs {
        /**
         * The name of the column.
         */
        columnName: pulumi.Input<string>;
        /**
         * The data set that the column belongs to.
         */
        dataSetIdentifier: pulumi.Input<string>;
    }
    interface DashboardColumnSortArgs {
        /**
         * The aggregation function that is defined in the column sort.
         */
        aggregationFunction?: pulumi.Input<inputs.quicksight.DashboardAggregationFunctionArgs>;
        /**
         * The sort direction.
         */
        direction: pulumi.Input<enums.quicksight.DashboardSortDirection>;
        sortBy: pulumi.Input<inputs.quicksight.DashboardColumnIdentifierArgs>;
    }
    interface DashboardColumnTooltipItemArgs {
        /**
         * The aggregation function of the column tooltip item.
         */
        aggregation?: pulumi.Input<inputs.quicksight.DashboardAggregationFunctionArgs>;
        /**
         * The target column of the tooltip item.
         */
        column: pulumi.Input<inputs.quicksight.DashboardColumnIdentifierArgs>;
        /**
         * The label of the tooltip item.
         */
        label?: pulumi.Input<string>;
        /**
         * Determines the target of the column tooltip item in a combo chart visual.
         */
        tooltipTarget?: pulumi.Input<enums.quicksight.DashboardTooltipTarget>;
        /**
         * The visibility of the tooltip item.
         */
        visibility?: pulumi.Input<enums.quicksight.DashboardVisibility>;
    }
    interface DashboardComboChartAggregatedFieldWellsArgs {
        /**
         * The aggregated `BarValues` field well of a combo chart.
         */
        barValues?: pulumi.Input<pulumi.Input<inputs.quicksight.DashboardMeasureFieldArgs>[]>;
        /**
         * The aggregated category field wells of a combo chart.
         */
        category?: pulumi.Input<pulumi.Input<inputs.quicksight.DashboardDimensionFieldArgs>[]>;
        /**
         * The aggregated colors field well of a combo chart.
         */
        colors?: pulumi.Input<pulumi.Input<inputs.quicksight.DashboardDimensionFieldArgs>[]>;
        /**
         * The aggregated `LineValues` field well of a combo chart.
         */
        lineValues?: pulumi.Input<pulumi.Input<inputs.quicksight.DashboardMeasureFieldArgs>[]>;
    }
    interface DashboardComboChartConfigurationArgs {
        /**
         * The options that determine if visual data labels are displayed.
         *
         * The data label options for a bar in a combo chart.
         */
        barDataLabels?: pulumi.Input<inputs.quicksight.DashboardDataLabelOptionsArgs>;
        /**
         * Determines the bar arrangement in a combo chart. The following are valid values in this structure:
         *
         * - `CLUSTERED` : For clustered bar combo charts.
         * - `STACKED` : For stacked bar combo charts.
         * - `STACKED_PERCENT` : Do not use. If you use this value, the operation returns a validation error.
         */
        barsArrangement?: pulumi.Input<enums.quicksight.DashboardBarsArrangement>;
        /**
         * The category axis of a combo chart.
         */
        categoryAxis?: pulumi.Input<inputs.quicksight.DashboardAxisDisplayOptionsArgs>;
        /**
         * The label options (label text, label visibility, and sort icon visibility) of a combo chart category (group/color) field well.
         */
        categoryLabelOptions?: pulumi.Input<inputs.quicksight.DashboardChartAxisLabelOptionsArgs>;
        /**
         * The label options (label text, label visibility, and sort icon visibility) of a combo chart's color field well.
         */
        colorLabelOptions?: pulumi.Input<inputs.quicksight.DashboardChartAxisLabelOptionsArgs>;
        /**
         * The field wells of the visual.
         */
        fieldWells?: pulumi.Input<inputs.quicksight.DashboardComboChartFieldWellsArgs>;
        /**
         * The general visual interactions setup for a visual.
         */
        interactions?: pulumi.Input<inputs.quicksight.DashboardVisualInteractionOptionsArgs>;
        /**
         * The legend display setup of the visual.
         */
        legend?: pulumi.Input<inputs.quicksight.DashboardLegendOptionsArgs>;
        /**
         * The options that determine if visual data labels are displayed.
         *
         * The data label options for a line in a combo chart.
         */
        lineDataLabels?: pulumi.Input<inputs.quicksight.DashboardDataLabelOptionsArgs>;
        /**
         * The label display options (grid line, range, scale, and axis step) of a combo chart's primary y-axis (bar) field well.
         */
        primaryYAxisDisplayOptions?: pulumi.Input<inputs.quicksight.DashboardAxisDisplayOptionsArgs>;
        /**
         * The label options (label text, label visibility, and sort icon visibility) of a combo chart's primary y-axis (bar) field well.
         */
        primaryYAxisLabelOptions?: pulumi.Input<inputs.quicksight.DashboardChartAxisLabelOptionsArgs>;
        /**
         * The reference line setup of the visual.
         */
        referenceLines?: pulumi.Input<pulumi.Input<inputs.quicksight.DashboardReferenceLineArgs>[]>;
        /**
         * The label display options (grid line, range, scale, axis step) of a combo chart's secondary y-axis (line) field well.
         */
        secondaryYAxisDisplayOptions?: pulumi.Input<inputs.quicksight.DashboardAxisDisplayOptionsArgs>;
        /**
         * The label options (label text, label visibility, and sort icon visibility) of a combo chart's secondary y-axis(line) field well.
         */
        secondaryYAxisLabelOptions?: pulumi.Input<inputs.quicksight.DashboardChartAxisLabelOptionsArgs>;
        singleAxisOptions?: pulumi.Input<inputs.quicksight.DashboardSingleAxisOptionsArgs>;
        /**
         * The sort configuration of a `ComboChartVisual` .
         */
        sortConfiguration?: pulumi.Input<inputs.quicksight.DashboardComboChartSortConfigurationArgs>;
        /**
         * The legend display setup of the visual.
         */
        tooltip?: pulumi.Input<inputs.quicksight.DashboardTooltipOptionsArgs>;
        /**
         * The palette (chart color) display setup of the visual.
         */
        visualPalette?: pulumi.Input<inputs.quicksight.DashboardVisualPaletteArgs>;
    }
    interface DashboardComboChartFieldWellsArgs {
        /**
         * The aggregated field wells of a combo chart. Combo charts only have aggregated field wells. Columns in a combo chart are aggregated by category.
         */
        comboChartAggregatedFieldWells?: pulumi.Input<inputs.quicksight.DashboardComboChartAggregatedFieldWellsArgs>;
    }
    interface DashboardComboChartSortConfigurationArgs {
        /**
         * The item limit configuration for the category field well of a combo chart.
         */
        categoryItemsLimit?: pulumi.Input<inputs.quicksight.DashboardItemsLimitConfigurationArgs>;
        /**
         * The sort configuration of the category field well in a combo chart.
         */
        categorySort?: pulumi.Input<pulumi.Input<inputs.quicksight.DashboardFieldSortOptionsArgs>[]>;
        /**
         * The item limit configuration of the color field well in a combo chart.
         */
        colorItemsLimit?: pulumi.Input<inputs.quicksight.DashboardItemsLimitConfigurationArgs>;
        /**
         * The sort configuration of the color field well in a combo chart.
         */
        colorSort?: pulumi.Input<pulumi.Input<inputs.quicksight.DashboardFieldSortOptionsArgs>[]>;
    }
    interface DashboardComboChartVisualArgs {
        /**
         * The list of custom actions that are configured for a visual.
         */
        actions?: pulumi.Input<pulumi.Input<inputs.quicksight.DashboardVisualCustomActionArgs>[]>;
        /**
         * The configuration settings of the visual.
         */
        chartConfiguration?: pulumi.Input<inputs.quicksight.DashboardComboChartConfigurationArgs>;
        /**
         * The column hierarchy that is used during drill-downs and drill-ups.
         */
        columnHierarchies?: pulumi.Input<pulumi.Input<inputs.quicksight.DashboardColumnHierarchyArgs>[]>;
        /**
         * The subtitle that is displayed on the visual.
         */
        subtitle?: pulumi.Input<inputs.quicksight.DashboardVisualSubtitleLabelOptionsArgs>;
        /**
         * The title that is displayed on the visual.
         */
        title?: pulumi.Input<inputs.quicksight.DashboardVisualTitleLabelOptionsArgs>;
        /**
         * The alt text for the visual.
         */
        visualContentAltText?: pulumi.Input<string>;
        /**
         * The unique identifier of a visual. This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers.
         */
        visualId: pulumi.Input<string>;
    }
    interface DashboardComparisonConfigurationArgs {
        /**
         * The format of the comparison.
         */
        comparisonFormat?: pulumi.Input<inputs.quicksight.DashboardComparisonFormatConfigurationArgs>;
        /**
         * The method of the comparison. Choose from the following options:
         *
         * - `DIFFERENCE`
         * - `PERCENT_DIFFERENCE`
         * - `PERCENT`
         */
        comparisonMethod?: pulumi.Input<enums.quicksight.DashboardComparisonMethod>;
    }
    interface DashboardComparisonFormatConfigurationArgs {
        /**
         * The number display format.
         */
        numberDisplayFormatConfiguration?: pulumi.Input<inputs.quicksight.DashboardNumberDisplayFormatConfigurationArgs>;
        /**
         * The percentage display format.
         */
        percentageDisplayFormatConfiguration?: pulumi.Input<inputs.quicksight.DashboardPercentageDisplayFormatConfigurationArgs>;
    }
    interface DashboardComputationArgs {
        /**
         * The forecast computation configuration.
         */
        forecast?: pulumi.Input<inputs.quicksight.DashboardForecastComputationArgs>;
        /**
         * The growth rate computation configuration.
         */
        growthRate?: pulumi.Input<inputs.quicksight.DashboardGrowthRateComputationArgs>;
        /**
         * The maximum and minimum computation configuration.
         */
        maximumMinimum?: pulumi.Input<inputs.quicksight.DashboardMaximumMinimumComputationArgs>;
        /**
         * The metric comparison computation configuration.
         */
        metricComparison?: pulumi.Input<inputs.quicksight.DashboardMetricComparisonComputationArgs>;
        /**
         * The period over period computation configuration.
         */
        periodOverPeriod?: pulumi.Input<inputs.quicksight.DashboardPeriodOverPeriodComputationArgs>;
        /**
         * The period to `DataSetIdentifier` computation configuration.
         */
        periodToDate?: pulumi.Input<inputs.quicksight.DashboardPeriodToDateComputationArgs>;
        /**
         * The top movers and bottom movers computation configuration.
         */
        topBottomMovers?: pulumi.Input<inputs.quicksight.DashboardTopBottomMoversComputationArgs>;
        /**
         * The top ranked and bottom ranked computation configuration.
         */
        topBottomRanked?: pulumi.Input<inputs.quicksight.DashboardTopBottomRankedComputationArgs>;
        /**
         * The total aggregation computation configuration.
         */
        totalAggregation?: pulumi.Input<inputs.quicksight.DashboardTotalAggregationComputationArgs>;
        /**
         * The unique values computation configuration.
         */
        uniqueValues?: pulumi.Input<inputs.quicksight.DashboardUniqueValuesComputationArgs>;
    }
    interface DashboardConditionalFormattingColorArgs {
        /**
         * Formatting configuration for gradient color.
         */
        gradient?: pulumi.Input<inputs.quicksight.DashboardConditionalFormattingGradientColorArgs>;
        /**
         * Formatting configuration for solid color.
         */
        solid?: pulumi.Input<inputs.quicksight.DashboardConditionalFormattingSolidColorArgs>;
    }
    interface DashboardConditionalFormattingCustomIconConditionArgs {
        /**
         * Determines the color of the icon.
         */
        color?: pulumi.Input<string>;
        /**
         * Determines the icon display configuration.
         */
        displayConfiguration?: pulumi.Input<inputs.quicksight.DashboardConditionalFormattingIconDisplayConfigurationArgs>;
        /**
         * The expression that determines the condition of the icon set.
         */
        expression: pulumi.Input<string>;
        /**
         * Custom icon options for an icon set.
         */
        iconOptions: pulumi.Input<inputs.quicksight.DashboardConditionalFormattingCustomIconOptionsArgs>;
    }
    interface DashboardConditionalFormattingCustomIconOptionsArgs {
        /**
         * Determines the type of icon.
         */
        icon?: pulumi.Input<enums.quicksight.DashboardIcon>;
        /**
         * Determines the Unicode icon type.
         */
        unicodeIcon?: pulumi.Input<string>;
    }
    interface DashboardConditionalFormattingGradientColorArgs {
        /**
         * Determines the color.
         */
        color: pulumi.Input<inputs.quicksight.DashboardGradientColorArgs>;
        /**
         * The expression that determines the formatting configuration for gradient color.
         */
        expression: pulumi.Input<string>;
    }
    interface DashboardConditionalFormattingIconArgs {
        /**
         * Determines the custom condition for an icon set.
         */
        customCondition?: pulumi.Input<inputs.quicksight.DashboardConditionalFormattingCustomIconConditionArgs>;
        /**
         * Formatting configuration for icon set.
         */
        iconSet?: pulumi.Input<inputs.quicksight.DashboardConditionalFormattingIconSetArgs>;
    }
    interface DashboardConditionalFormattingIconDisplayConfigurationArgs {
        /**
         * Determines the icon display configuration.
         */
        iconDisplayOption?: pulumi.Input<enums.quicksight.DashboardConditionalFormattingIconDisplayOption>;
    }
    interface DashboardConditionalFormattingIconSetArgs {
        /**
         * The expression that determines the formatting configuration for the icon set.
         */
        expression: pulumi.Input<string>;
        /**
         * Determines the icon set type.
         */
        iconSetType?: pulumi.Input<enums.quicksight.DashboardConditionalFormattingIconSetType>;
    }
    interface DashboardConditionalFormattingSolidColorArgs {
        /**
         * Determines the color.
         */
        color?: pulumi.Input<string>;
        /**
         * The expression that determines the formatting configuration for solid color.
         */
        expression: pulumi.Input<string>;
    }
    interface DashboardContextMenuOptionArgs {
        /**
         * The availability status of the context menu options. If the value of this property is set to `ENABLED` , dashboard readers can interact with the context menu.
         */
        availabilityStatus?: pulumi.Input<enums.quicksight.DashboardBehavior>;
    }
    interface DashboardContributionAnalysisDefaultArgs {
        /**
         * The dimensions columns that are used in the contribution analysis, usually a list of `ColumnIdentifiers` .
         */
        contributorDimensions: pulumi.Input<pulumi.Input<inputs.quicksight.DashboardColumnIdentifierArgs>[]>;
        /**
         * The measure field that is used in the contribution analysis.
         */
        measureFieldId: pulumi.Input<string>;
    }
    interface DashboardCurrencyDisplayFormatConfigurationArgs {
        /**
         * The option that determines the decimal places configuration.
         */
        decimalPlacesConfiguration?: pulumi.Input<inputs.quicksight.DashboardDecimalPlacesConfigurationArgs>;
        /**
         * The options that determine the negative value configuration.
         */
        negativeValueConfiguration?: pulumi.Input<inputs.quicksight.DashboardNegativeValueConfigurationArgs>;
        /**
         * The options that determine the null value format configuration.
         */
        nullValueFormatConfiguration?: pulumi.Input<inputs.quicksight.DashboardNullValueFormatConfigurationArgs>;
        /**
         * Determines the number scale value for the currency format.
         */
        numberScale?: pulumi.Input<enums.quicksight.DashboardNumberScale>;
        /**
         * Determines the prefix value of the currency format.
         */
        prefix?: pulumi.Input<string>;
        /**
         * The options that determine the numeric separator configuration.
         */
        separatorConfiguration?: pulumi.Input<inputs.quicksight.DashboardNumericSeparatorConfigurationArgs>;
        /**
         * Determines the suffix value of the currency format.
         */
        suffix?: pulumi.Input<string>;
        /**
         * Determines the symbol for the currency format.
         */
        symbol?: pulumi.Input<string>;
    }
    interface DashboardCustomActionFilterOperationArgs {
        /**
         * The configuration that chooses the fields to be filtered.
         */
        selectedFieldsConfiguration: pulumi.Input<inputs.quicksight.DashboardFilterOperationSelectedFieldsConfigurationArgs>;
        /**
         * The configuration that chooses the target visuals to be filtered.
         */
        targetVisualsConfiguration: pulumi.Input<inputs.quicksight.DashboardFilterOperationTargetVisualsConfigurationArgs>;
    }
    interface DashboardCustomActionNavigationOperationArgs {
        /**
         * The configuration that chooses the navigation target.
         */
        localNavigationConfiguration?: pulumi.Input<inputs.quicksight.DashboardLocalNavigationConfigurationArgs>;
    }
    interface DashboardCustomActionSetParametersOperationArgs {
        /**
         * The parameter that determines the value configuration.
         */
        parameterValueConfigurations: pulumi.Input<pulumi.Input<inputs.quicksight.DashboardSetParameterValueConfigurationArgs>[]>;
    }
    interface DashboardCustomActionUrlOperationArgs {
        /**
         * The target of the `CustomActionURLOperation` .
         *
         * Valid values are defined as follows:
         *
         * - `NEW_TAB` : Opens the target URL in a new browser tab.
         * - `NEW_WINDOW` : Opens the target URL in a new browser window.
         * - `SAME_TAB` : Opens the target URL in the same browser tab.
         */
        urlTarget: pulumi.Input<enums.quicksight.DashboardUrlTargetConfiguration>;
        /**
         * THe URL link of the `CustomActionURLOperation` .
         */
        urlTemplate: pulumi.Input<string>;
    }
    interface DashboardCustomColorArgs {
        /**
         * The color that is applied to the data value.
         */
        color: pulumi.Input<string>;
        /**
         * The data value that the color is applied to.
         */
        fieldValue?: pulumi.Input<string>;
        /**
         * The value of a special data value.
         */
        specialValue?: pulumi.Input<enums.quicksight.DashboardSpecialValue>;
    }
    interface DashboardCustomContentConfigurationArgs {
        /**
         * The content type of the custom content visual. You can use this to have the visual render as an image.
         */
        contentType?: pulumi.Input<enums.quicksight.DashboardCustomContentType>;
        /**
         * The input URL that links to the custom content that you want in the custom visual.
         */
        contentUrl?: pulumi.Input<string>;
        /**
         * The sizing options for the size of the custom content visual. This structure is required when the `ContentType` of the visual is `'IMAGE'` .
         */
        imageScaling?: pulumi.Input<enums.quicksight.DashboardCustomContentImageScalingConfiguration>;
        /**
         * The general visual interactions setup for a visual.
         */
        interactions?: pulumi.Input<inputs.quicksight.DashboardVisualInteractionOptionsArgs>;
    }
    interface DashboardCustomContentVisualArgs {
        /**
         * The list of custom actions that are configured for a visual.
         */
        actions?: pulumi.Input<pulumi.Input<inputs.quicksight.DashboardVisualCustomActionArgs>[]>;
        /**
         * The configuration of a `CustomContentVisual` .
         */
        chartConfiguration?: pulumi.Input<inputs.quicksight.DashboardCustomContentConfigurationArgs>;
        /**
         * The dataset that is used to create the custom content visual. You can't create a visual without a dataset.
         */
        dataSetIdentifier: pulumi.Input<string>;
        /**
         * The subtitle that is displayed on the visual.
         */
        subtitle?: pulumi.Input<inputs.quicksight.DashboardVisualSubtitleLabelOptionsArgs>;
        /**
         * The title that is displayed on the visual.
         */
        title?: pulumi.Input<inputs.quicksight.DashboardVisualTitleLabelOptionsArgs>;
        /**
         * The alt text for the visual.
         */
        visualContentAltText?: pulumi.Input<string>;
        /**
         * The unique identifier of a visual. This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers.
         */
        visualId: pulumi.Input<string>;
    }
    interface DashboardCustomFilterConfigurationArgs {
        /**
         * The category value for the filter.
         *
         * This field is mutually exclusive to `ParameterName` .
         */
        categoryValue?: pulumi.Input<string>;
        /**
         * The match operator that is used to determine if a filter should be applied.
         */
        matchOperator: pulumi.Input<enums.quicksight.DashboardCategoryFilterMatchOperator>;
        /**
         * This option determines how null values should be treated when filtering data.
         *
         * - `ALL_VALUES` : Include null values in filtered results.
         * - `NULLS_ONLY` : Only include null values in filtered results.
         * - `NON_NULLS_ONLY` : Exclude null values from filtered results.
         */
        nullOption: pulumi.Input<enums.quicksight.DashboardFilterNullOption>;
        /**
         * The parameter whose value should be used for the filter value.
         *
         * This field is mutually exclusive to `CategoryValue` .
         */
        parameterName?: pulumi.Input<string>;
        /**
         * Select all of the values. Null is not the assigned value of select all.
         *
         * - `FILTER_ALL_VALUES`
         */
        selectAllOptions?: pulumi.Input<enums.quicksight.DashboardCategoryFilterSelectAllOptions>;
    }
    interface DashboardCustomFilterListConfigurationArgs {
        /**
         * The list of category values for the filter.
         */
        categoryValues?: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * The match operator that is used to determine if a filter should be applied.
         */
        matchOperator: pulumi.Input<enums.quicksight.DashboardCategoryFilterMatchOperator>;
        /**
         * This option determines how null values should be treated when filtering data.
         *
         * - `ALL_VALUES` : Include null values in filtered results.
         * - `NULLS_ONLY` : Only include null values in filtered results.
         * - `NON_NULLS_ONLY` : Exclude null values from filtered results.
         */
        nullOption: pulumi.Input<enums.quicksight.DashboardFilterNullOption>;
        /**
         * Select all of the values. Null is not the assigned value of select all.
         *
         * - `FILTER_ALL_VALUES`
         */
        selectAllOptions?: pulumi.Input<enums.quicksight.DashboardCategoryFilterSelectAllOptions>;
    }
    interface DashboardCustomNarrativeOptionsArgs {
        /**
         * The string input of custom narrative.
         */
        narrative: pulumi.Input<string>;
    }
    interface DashboardCustomParameterValuesArgs {
        /**
         * A list of datetime-type parameter values.
         */
        dateTimeValues?: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * A list of decimal-type parameter values.
         */
        decimalValues?: pulumi.Input<pulumi.Input<number>[]>;
        /**
         * A list of integer-type parameter values.
         */
        integerValues?: pulumi.Input<pulumi.Input<number>[]>;
        /**
         * A list of string-type parameter values.
         */
        stringValues?: pulumi.Input<pulumi.Input<string>[]>;
    }
    interface DashboardCustomValuesConfigurationArgs {
        customValues: pulumi.Input<inputs.quicksight.DashboardCustomParameterValuesArgs>;
        /**
         * Includes the null value in custom action parameter values.
         */
        includeNullValue?: pulumi.Input<boolean>;
    }
    interface DashboardDataBarsOptionsArgs {
        /**
         * The field ID for the data bars options.
         */
        fieldId: pulumi.Input<string>;
        /**
         * The color of the negative data bar.
         */
        negativeColor?: pulumi.Input<string>;
        /**
         * The color of the positive data bar.
         */
        positiveColor?: pulumi.Input<string>;
    }
    interface DashboardDataColorArgs {
        /**
         * The color that is applied to the data value.
         */
        color?: pulumi.Input<string>;
        /**
         * The data value that the color is applied to.
         */
        dataValue?: pulumi.Input<number>;
    }
    interface DashboardDataFieldSeriesItemArgs {
        /**
         * The axis that you are binding the field to.
         */
        axisBinding: pulumi.Input<enums.quicksight.DashboardAxisBinding>;
        /**
         * The field ID of the field that you are setting the axis binding to.
         */
        fieldId: pulumi.Input<string>;
        /**
         * The field value of the field that you are setting the axis binding to.
         */
        fieldValue?: pulumi.Input<string>;
        /**
         * The options that determine the presentation of line series associated to the field.
         */
        settings?: pulumi.Input<inputs.quicksight.DashboardLineChartSeriesSettingsArgs>;
    }
    interface DashboardDataLabelOptionsArgs {
        /**
         * Determines the visibility of the category field labels.
         */
        categoryLabelVisibility?: pulumi.Input<enums.quicksight.DashboardVisibility>;
        /**
         * The option that determines the data label type.
         */
        dataLabelTypes?: pulumi.Input<pulumi.Input<inputs.quicksight.DashboardDataLabelTypeArgs>[]>;
        /**
         * Determines the color of the data labels.
         */
        labelColor?: pulumi.Input<string>;
        /**
         * Determines the content of the data labels.
         */
        labelContent?: pulumi.Input<enums.quicksight.DashboardDataLabelContent>;
        /**
         * Determines the font configuration of the data labels.
         */
        labelFontConfiguration?: pulumi.Input<inputs.quicksight.DashboardFontConfigurationArgs>;
        /**
         * Determines the visibility of the measure field labels.
         */
        measureLabelVisibility?: pulumi.Input<enums.quicksight.DashboardVisibility>;
        /**
         * Determines whether overlap is enabled or disabled for the data labels.
         */
        overlap?: pulumi.Input<enums.quicksight.DashboardDataLabelOverlap>;
        /**
         * Determines the position of the data labels.
         */
        position?: pulumi.Input<enums.quicksight.DashboardDataLabelPosition>;
        /**
         * Determines the visibility of the total.
         */
        totalsVisibility?: pulumi.Input<enums.quicksight.DashboardVisibility>;
        /**
         * Determines the visibility of the data labels.
         */
        visibility?: pulumi.Input<enums.quicksight.DashboardVisibility>;
    }
    interface DashboardDataLabelTypeArgs {
        /**
         * The option that specifies individual data values for labels.
         */
        dataPathLabelType?: pulumi.Input<inputs.quicksight.DashboardDataPathLabelTypeArgs>;
        /**
         * Determines the label configuration for the entire field.
         */
        fieldLabelType?: pulumi.Input<inputs.quicksight.DashboardFieldLabelTypeArgs>;
        /**
         * Determines the label configuration for the maximum value in a visual.
         */
        maximumLabelType?: pulumi.Input<inputs.quicksight.DashboardMaximumLabelTypeArgs>;
        /**
         * Determines the label configuration for the minimum value in a visual.
         */
        minimumLabelType?: pulumi.Input<inputs.quicksight.DashboardMinimumLabelTypeArgs>;
        /**
         * Determines the label configuration for range end value in a visual.
         */
        rangeEndsLabelType?: pulumi.Input<inputs.quicksight.DashboardRangeEndsLabelTypeArgs>;
    }
    interface DashboardDataPathColorArgs {
        /**
         * The color that needs to be applied to the element.
         */
        color: pulumi.Input<string>;
        /**
         * The element that the color needs to be applied to.
         */
        element: pulumi.Input<inputs.quicksight.DashboardDataPathValueArgs>;
        /**
         * The time granularity of the field that the color needs to be applied to.
         */
        timeGranularity?: pulumi.Input<enums.quicksight.DashboardTimeGranularity>;
    }
    interface DashboardDataPathLabelTypeArgs {
        /**
         * The field ID of the field that the data label needs to be applied to.
         */
        fieldId?: pulumi.Input<string>;
        /**
         * The actual value of the field that is labeled.
         */
        fieldValue?: pulumi.Input<string>;
        /**
         * The visibility of the data label.
         */
        visibility?: pulumi.Input<enums.quicksight.DashboardVisibility>;
    }
    interface DashboardDataPathSortArgs {
        /**
         * Determines the sort direction.
         */
        direction: pulumi.Input<enums.quicksight.DashboardSortDirection>;
        /**
         * The list of data paths that need to be sorted.
         */
        sortPaths: pulumi.Input<pulumi.Input<inputs.quicksight.DashboardDataPathValueArgs>[]>;
    }
    interface DashboardDataPathTypeArgs {
        /**
         * The type of data path value utilized in a pivot table. Choose one of the following options:
         *
         * - `HIERARCHY_ROWS_LAYOUT_COLUMN` - The type of data path for the rows layout column, when `RowsLayout` is set to `HIERARCHY` .
         * - `MULTIPLE_ROW_METRICS_COLUMN` - The type of data path for the metric column when the row is set to Metric Placement.
         * - `EMPTY_COLUMN_HEADER` - The type of data path for the column with empty column header, when there is no field in `ColumnsFieldWell` and the row is set to Metric Placement.
         * - `COUNT_METRIC_COLUMN` - The type of data path for the column with `COUNT` as the metric, when there is no field in the `ValuesFieldWell` .
         */
        pivotTableDataPathType?: pulumi.Input<enums.quicksight.DashboardPivotTableDataPathType>;
    }
    interface DashboardDataPathValueArgs {
        /**
         * The type configuration of the field.
         */
        dataPathType?: pulumi.Input<inputs.quicksight.DashboardDataPathTypeArgs>;
        /**
         * The field ID of the field that needs to be sorted.
         */
        fieldId?: pulumi.Input<string>;
        /**
         * The actual value of the field that needs to be sorted.
         */
        fieldValue?: pulumi.Input<string>;
    }
    /**
     * <p>The drill down options for data points in a dashbaord.</p>
     */
    interface DashboardDataPointDrillUpDownOptionArgs {
        /**
         * The status of the drill down options of data points.
         */
        availabilityStatus?: pulumi.Input<enums.quicksight.DashboardBehavior>;
    }
    /**
     * <p>The data point menu options of a dashboard.</p>
     */
    interface DashboardDataPointMenuLabelOptionArgs {
        /**
         * The status of the data point menu options.
         */
        availabilityStatus?: pulumi.Input<enums.quicksight.DashboardBehavior>;
    }
    /**
     * <p>The data point tooltip options.</p>
     */
    interface DashboardDataPointTooltipOptionArgs {
        /**
         * The status of the data point tool tip options.
         */
        availabilityStatus?: pulumi.Input<enums.quicksight.DashboardBehavior>;
    }
    interface DashboardDataSetIdentifierDeclarationArgs {
        /**
         * The Amazon Resource Name (ARN) of the data set.
         */
        dataSetArn: pulumi.Input<string>;
        /**
         * The identifier of the data set, typically the data set's name.
         */
        identifier: pulumi.Input<string>;
    }
    /**
     * <p>Dataset reference.</p>
     */
    interface DashboardDataSetReferenceArgs {
        /**
         * <p>Dataset Amazon Resource Name (ARN).</p>
         */
        dataSetArn: pulumi.Input<string>;
        /**
         * <p>Dataset placeholder.</p>
         */
        dataSetPlaceholder: pulumi.Input<string>;
    }
    interface DashboardDateAxisOptionsArgs {
        /**
         * Determines whether or not missing dates are displayed.
         */
        missingDateVisibility?: pulumi.Input<enums.quicksight.DashboardVisibility>;
    }
    interface DashboardDateDimensionFieldArgs {
        /**
         * The column that is used in the `DateDimensionField` .
         */
        column: pulumi.Input<inputs.quicksight.DashboardColumnIdentifierArgs>;
        /**
         * The date granularity of the `DateDimensionField` . Choose one of the following options:
         *
         * - `YEAR`
         * - `QUARTER`
         * - `MONTH`
         * - `WEEK`
         * - `DAY`
         * - `HOUR`
         * - `MINUTE`
         * - `SECOND`
         * - `MILLISECOND`
         */
        dateGranularity?: pulumi.Input<enums.quicksight.DashboardTimeGranularity>;
        /**
         * The custom field ID.
         */
        fieldId: pulumi.Input<string>;
        /**
         * The format configuration of the field.
         */
        formatConfiguration?: pulumi.Input<inputs.quicksight.DashboardDateTimeFormatConfigurationArgs>;
        /**
         * The custom hierarchy ID.
         */
        hierarchyId?: pulumi.Input<string>;
    }
    interface DashboardDateMeasureFieldArgs {
        /**
         * The aggregation function of the measure field.
         */
        aggregationFunction?: pulumi.Input<enums.quicksight.DashboardDateAggregationFunction>;
        /**
         * The column that is used in the `DateMeasureField` .
         */
        column: pulumi.Input<inputs.quicksight.DashboardColumnIdentifierArgs>;
        /**
         * The custom field ID.
         */
        fieldId: pulumi.Input<string>;
        /**
         * The format configuration of the field.
         */
        formatConfiguration?: pulumi.Input<inputs.quicksight.DashboardDateTimeFormatConfigurationArgs>;
    }
    interface DashboardDateTimeDefaultValuesArgs {
        /**
         * The dynamic value of the `DataTimeDefaultValues` . Different defaults are displayed according to users, groups, and values mapping.
         */
        dynamicValue?: pulumi.Input<inputs.quicksight.DashboardDynamicDefaultValueArgs>;
        /**
         * The rolling date of the `DataTimeDefaultValues` . The date is determined from the dataset based on input expression.
         */
        rollingDate?: pulumi.Input<inputs.quicksight.DashboardRollingDateConfigurationArgs>;
        /**
         * The static values of the `DataTimeDefaultValues` .
         */
        staticValues?: pulumi.Input<pulumi.Input<string>[]>;
    }
    interface DashboardDateTimeFormatConfigurationArgs {
        /**
         * Determines the `DateTime` format.
         */
        dateTimeFormat?: pulumi.Input<string>;
        /**
         * The options that determine the null value format configuration.
         */
        nullValueFormatConfiguration?: pulumi.Input<inputs.quicksight.DashboardNullValueFormatConfigurationArgs>;
        /**
         * The formatting configuration for numeric `DateTime` fields.
         */
        numericFormatConfiguration?: pulumi.Input<inputs.quicksight.DashboardNumericFormatConfigurationArgs>;
    }
    interface DashboardDateTimeHierarchyArgs {
        /**
         * The option that determines the drill down filters for the `DateTime` hierarchy.
         */
        drillDownFilters?: pulumi.Input<pulumi.Input<inputs.quicksight.DashboardDrillDownFilterArgs>[]>;
        /**
         * The hierarchy ID of the `DateTime` hierarchy.
         */
        hierarchyId: pulumi.Input<string>;
    }
    /**
     * <p>A date-time parameter.</p>
     */
    interface DashboardDateTimeParameterArgs {
        /**
         * <p>A display name for the date-time parameter.</p>
         */
        name: pulumi.Input<string>;
        /**
         * <p>The values for the date-time parameter.</p>
         */
        values: pulumi.Input<pulumi.Input<string>[]>;
    }
    interface DashboardDateTimeParameterDeclarationArgs {
        /**
         * The default values of a parameter. If the parameter is a single-value parameter, a maximum of one default value can be provided.
         */
        defaultValues?: pulumi.Input<inputs.quicksight.DashboardDateTimeDefaultValuesArgs>;
        mappedDataSetParameters?: pulumi.Input<pulumi.Input<inputs.quicksight.DashboardMappedDataSetParameterArgs>[]>;
        /**
         * The name of the parameter that is being declared.
         */
        name: pulumi.Input<string>;
        /**
         * The level of time precision that is used to aggregate `DateTime` values.
         */
        timeGranularity?: pulumi.Input<enums.quicksight.DashboardTimeGranularity>;
        /**
         * The configuration that defines the default value of a `DateTime` parameter when a value has not been set.
         */
        valueWhenUnset?: pulumi.Input<inputs.quicksight.DashboardDateTimeValueWhenUnsetConfigurationArgs>;
    }
    interface DashboardDateTimePickerControlDisplayOptionsArgs {
        /**
         * The date icon visibility of the `DateTimePickerControlDisplayOptions` .
         */
        dateIconVisibility?: pulumi.Input<enums.quicksight.DashboardVisibility>;
        /**
         * Customize how dates are formatted in controls.
         */
        dateTimeFormat?: pulumi.Input<string>;
        /**
         * The helper text visibility of the `DateTimePickerControlDisplayOptions` .
         */
        helperTextVisibility?: pulumi.Input<enums.quicksight.DashboardVisibility>;
        /**
         * The configuration of info icon label options.
         */
        infoIconLabelOptions?: pulumi.Input<inputs.quicksight.DashboardSheetControlInfoIconLabelOptionsArgs>;
        /**
         * The options to configure the title visibility, name, and font size.
         */
        titleOptions?: pulumi.Input<inputs.quicksight.DashboardLabelOptionsArgs>;
    }
    interface DashboardDateTimeValueWhenUnsetConfigurationArgs {
        /**
         * A custom value that's used when the value of a parameter isn't set.
         */
        customValue?: pulumi.Input<string>;
        /**
         * The built-in options for default values. The value can be one of the following:
         *
         * - `RECOMMENDED` : The recommended value.
         * - `NULL` : The `NULL` value.
         */
        valueWhenUnsetOption?: pulumi.Input<enums.quicksight.DashboardValueWhenUnsetOption>;
    }
    interface DashboardDecimalDefaultValuesArgs {
        /**
         * The dynamic value of the `DecimalDefaultValues` . Different defaults are displayed according to users, groups, and values mapping.
         */
        dynamicValue?: pulumi.Input<inputs.quicksight.DashboardDynamicDefaultValueArgs>;
        /**
         * The static values of the `DecimalDefaultValues` .
         */
        staticValues?: pulumi.Input<pulumi.Input<number>[]>;
    }
    /**
     * <p>A decimal parameter.</p>
     */
    interface DashboardDecimalParameterArgs {
        /**
         * <p>A display name for the decimal parameter.</p>
         */
        name: pulumi.Input<string>;
        /**
         * <p>The values for the decimal parameter.</p>
         */
        values: pulumi.Input<pulumi.Input<number>[]>;
    }
    interface DashboardDecimalParameterDeclarationArgs {
        /**
         * The default values of a parameter. If the parameter is a single-value parameter, a maximum of one default value can be provided.
         */
        defaultValues?: pulumi.Input<inputs.quicksight.DashboardDecimalDefaultValuesArgs>;
        mappedDataSetParameters?: pulumi.Input<pulumi.Input<inputs.quicksight.DashboardMappedDataSetParameterArgs>[]>;
        /**
         * The name of the parameter that is being declared.
         */
        name: pulumi.Input<string>;
        /**
         * The value type determines whether the parameter is a single-value or multi-value parameter.
         */
        parameterValueType: pulumi.Input<enums.quicksight.DashboardParameterValueType>;
        /**
         * The configuration that defines the default value of a `Decimal` parameter when a value has not been set.
         */
        valueWhenUnset?: pulumi.Input<inputs.quicksight.DashboardDecimalValueWhenUnsetConfigurationArgs>;
    }
    interface DashboardDecimalPlacesConfigurationArgs {
        /**
         * The values of the decimal places.
         */
        decimalPlaces: pulumi.Input<number>;
    }
    interface DashboardDecimalValueWhenUnsetConfigurationArgs {
        /**
         * A custom value that's used when the value of a parameter isn't set.
         */
        customValue?: pulumi.Input<number>;
        /**
         * The built-in options for default values. The value can be one of the following:
         *
         * - `RECOMMENDED` : The recommended value.
         * - `NULL` : The `NULL` value.
         */
        valueWhenUnsetOption?: pulumi.Input<enums.quicksight.DashboardValueWhenUnsetOption>;
    }
    interface DashboardDefaultDateTimePickerControlOptionsArgs {
        /**
         * The visibility configuration of the Apply button on a `DateTimePickerControl` .
         */
        commitMode?: pulumi.Input<enums.quicksight.DashboardCommitMode>;
        /**
         * The display options of a control.
         */
        displayOptions?: pulumi.Input<inputs.quicksight.DashboardDateTimePickerControlDisplayOptionsArgs>;
        /**
         * The date time picker type of the `DefaultDateTimePickerControlOptions` . Choose one of the following options:
         *
         * - `SINGLE_VALUED` : The filter condition is a fixed date.
         * - `DATE_RANGE` : The filter condition is a date time range.
         */
        type?: pulumi.Input<enums.quicksight.DashboardSheetControlDateTimePickerType>;
    }
    interface DashboardDefaultFilterControlConfigurationArgs {
        /**
         * The control option for the `DefaultFilterControlConfiguration` .
         */
        controlOptions: pulumi.Input<inputs.quicksight.DashboardDefaultFilterControlOptionsArgs>;
        /**
         * The title of the `DefaultFilterControlConfiguration` . This title is shared by all controls that are tied to this filter.
         */
        title: pulumi.Input<string>;
    }
    interface DashboardDefaultFilterControlOptionsArgs {
        /**
         * The default options that correspond to the filter control type of a `DateTimePicker` .
         */
        defaultDateTimePickerOptions?: pulumi.Input<inputs.quicksight.DashboardDefaultDateTimePickerControlOptionsArgs>;
        /**
         * The default options that correspond to the `Dropdown` filter control type.
         */
        defaultDropdownOptions?: pulumi.Input<inputs.quicksight.DashboardDefaultFilterDropDownControlOptionsArgs>;
        /**
         * The default options that correspond to the `List` filter control type.
         */
        defaultListOptions?: pulumi.Input<inputs.quicksight.DashboardDefaultFilterListControlOptionsArgs>;
        /**
         * The default options that correspond to the `RelativeDateTime` filter control type.
         */
        defaultRelativeDateTimeOptions?: pulumi.Input<inputs.quicksight.DashboardDefaultRelativeDateTimeControlOptionsArgs>;
        /**
         * The default options that correspond to the `Slider` filter control type.
         */
        defaultSliderOptions?: pulumi.Input<inputs.quicksight.DashboardDefaultSliderControlOptionsArgs>;
        /**
         * The default options that correspond to the `TextArea` filter control type.
         */
        defaultTextAreaOptions?: pulumi.Input<inputs.quicksight.DashboardDefaultTextAreaControlOptionsArgs>;
        /**
         * The default options that correspond to the `TextField` filter control type.
         */
        defaultTextFieldOptions?: pulumi.Input<inputs.quicksight.DashboardDefaultTextFieldControlOptionsArgs>;
    }
    interface DashboardDefaultFilterDropDownControlOptionsArgs {
        /**
         * The visibility configuration of the Apply button on a `FilterDropDownControl` .
         */
        commitMode?: pulumi.Input<enums.quicksight.DashboardCommitMode>;
        /**
         * The display options of a control.
         */
        displayOptions?: pulumi.Input<inputs.quicksight.DashboardDropDownControlDisplayOptionsArgs>;
        /**
         * A list of selectable values that are used in a control.
         */
        selectableValues?: pulumi.Input<inputs.quicksight.DashboardFilterSelectableValuesArgs>;
        /**
         * The type of the `FilterDropDownControl` . Choose one of the following options:
         *
         * - `MULTI_SELECT` : The user can select multiple entries from a dropdown menu.
         * - `SINGLE_SELECT` : The user can select a single entry from a dropdown menu.
         */
        type?: pulumi.Input<enums.quicksight.DashboardSheetControlListType>;
    }
    interface DashboardDefaultFilterListControlOptionsArgs {
        /**
         * The display options of a control.
         */
        displayOptions?: pulumi.Input<inputs.quicksight.DashboardListControlDisplayOptionsArgs>;
        /**
         * A list of selectable values that are used in a control.
         */
        selectableValues?: pulumi.Input<inputs.quicksight.DashboardFilterSelectableValuesArgs>;
        /**
         * The type of the `DefaultFilterListControlOptions` . Choose one of the following options:
         *
         * - `MULTI_SELECT` : The user can select multiple entries from the list.
         * - `SINGLE_SELECT` : The user can select a single entry from the list.
         */
        type?: pulumi.Input<enums.quicksight.DashboardSheetControlListType>;
    }
    interface DashboardDefaultFreeFormLayoutConfigurationArgs {
        /**
         * Determines the screen canvas size options for a free-form layout.
         */
        canvasSizeOptions: pulumi.Input<inputs.quicksight.DashboardFreeFormLayoutCanvasSizeOptionsArgs>;
    }
    interface DashboardDefaultGridLayoutConfigurationArgs {
        /**
         * Determines the screen canvas size options for a grid layout.
         */
        canvasSizeOptions: pulumi.Input<inputs.quicksight.DashboardGridLayoutCanvasSizeOptionsArgs>;
    }
    interface DashboardDefaultInteractiveLayoutConfigurationArgs {
        /**
         * The options that determine the default settings of a free-form layout configuration.
         */
        freeForm?: pulumi.Input<inputs.quicksight.DashboardDefaultFreeFormLayoutConfigurationArgs>;
        /**
         * The options that determine the default settings for a grid layout configuration.
         */
        grid?: pulumi.Input<inputs.quicksight.DashboardDefaultGridLayoutConfigurationArgs>;
    }
    interface DashboardDefaultNewSheetConfigurationArgs {
        /**
         * The options that determine the default settings for interactive layout configuration.
         */
        interactiveLayoutConfiguration?: pulumi.Input<inputs.quicksight.DashboardDefaultInteractiveLayoutConfigurationArgs>;
        /**
         * The options that determine the default settings for a paginated layout configuration.
         */
        paginatedLayoutConfiguration?: pulumi.Input<inputs.quicksight.DashboardDefaultPaginatedLayoutConfigurationArgs>;
        /**
         * The option that determines the sheet content type.
         */
        sheetContentType?: pulumi.Input<enums.quicksight.DashboardSheetContentType>;
    }
    interface DashboardDefaultPaginatedLayoutConfigurationArgs {
        /**
         * The options that determine the default settings for a section-based layout configuration.
         */
        sectionBased?: pulumi.Input<inputs.quicksight.DashboardDefaultSectionBasedLayoutConfigurationArgs>;
    }
    interface DashboardDefaultRelativeDateTimeControlOptionsArgs {
        /**
         * The visibility configuration of the Apply button on a `RelativeDateTimeControl` .
         */
        commitMode?: pulumi.Input<enums.quicksight.DashboardCommitMode>;
        /**
         * The display options of a control.
         */
        displayOptions?: pulumi.Input<inputs.quicksight.DashboardRelativeDateTimeControlDisplayOptionsArgs>;
    }
    interface DashboardDefaultSectionBasedLayoutConfigurationArgs {
        /**
         * Determines the screen canvas size options for a section-based layout.
         */
        canvasSizeOptions: pulumi.Input<inputs.quicksight.DashboardSectionBasedLayoutCanvasSizeOptionsArgs>;
    }
    interface DashboardDefaultSliderControlOptionsArgs {
        /**
         * The display options of a control.
         */
        displayOptions?: pulumi.Input<inputs.quicksight.DashboardSliderControlDisplayOptionsArgs>;
        /**
         * The larger value that is displayed at the right of the slider.
         */
        maximumValue: pulumi.Input<number>;
        /**
         * The smaller value that is displayed at the left of the slider.
         */
        minimumValue: pulumi.Input<number>;
        /**
         * The number of increments that the slider bar is divided into.
         */
        stepSize: pulumi.Input<number>;
        /**
         * The type of the `DefaultSliderControlOptions` . Choose one of the following options:
         *
         * - `SINGLE_POINT` : Filter against(equals) a single data point.
         * - `RANGE` : Filter data that is in a specified range.
         */
        type?: pulumi.Input<enums.quicksight.DashboardSheetControlSliderType>;
    }
    interface DashboardDefaultTextAreaControlOptionsArgs {
        /**
         * The delimiter that is used to separate the lines in text.
         */
        delimiter?: pulumi.Input<string>;
        /**
         * The display options of a control.
         */
        displayOptions?: pulumi.Input<inputs.quicksight.DashboardTextAreaControlDisplayOptionsArgs>;
    }
    interface DashboardDefaultTextFieldControlOptionsArgs {
        /**
         * The display options of a control.
         */
        displayOptions?: pulumi.Input<inputs.quicksight.DashboardTextFieldControlDisplayOptionsArgs>;
    }
    interface DashboardDestinationParameterValueConfigurationArgs {
        /**
         * The configuration of custom values for destination parameter in `DestinationParameterValueConfiguration` .
         */
        customValuesConfiguration?: pulumi.Input<inputs.quicksight.DashboardCustomValuesConfigurationArgs>;
        /**
         * The configuration that selects all options.
         */
        selectAllValueOptions?: pulumi.Input<enums.quicksight.DashboardSelectAllValueOptions>;
        /**
         * A column of a data set.
         */
        sourceColumn?: pulumi.Input<inputs.quicksight.DashboardColumnIdentifierArgs>;
        /**
         * The source field ID of the destination parameter.
         */
        sourceField?: pulumi.Input<string>;
        /**
         * The source parameter name of the destination parameter.
         */
        sourceParameterName?: pulumi.Input<string>;
    }
    interface DashboardDimensionFieldArgs {
        /**
         * The dimension type field with categorical type columns.
         */
        categoricalDimensionField?: pulumi.Input<inputs.quicksight.DashboardCategoricalDimensionFieldArgs>;
        /**
         * The dimension type field with date type columns.
         */
        dateDimensionField?: pulumi.Input<inputs.quicksight.DashboardDateDimensionFieldArgs>;
        /**
         * The dimension type field with numerical type columns.
         */
        numericalDimensionField?: pulumi.Input<inputs.quicksight.DashboardNumericalDimensionFieldArgs>;
    }
    interface DashboardDonutCenterOptionsArgs {
        /**
         * Determines the visibility of the label in a donut chart. In the Amazon QuickSight console, this option is called `'Show total'` .
         */
        labelVisibility?: pulumi.Input<enums.quicksight.DashboardVisibility>;
    }
    interface DashboardDonutOptionsArgs {
        /**
         * The option for define the arc of the chart shape. Valid values are as follows:
         *
         * - `WHOLE` - A pie chart
         * - `SMALL` - A small-sized donut chart
         * - `MEDIUM` - A medium-sized donut chart
         * - `LARGE` - A large-sized donut chart
         */
        arcOptions?: pulumi.Input<inputs.quicksight.DashboardArcOptionsArgs>;
        /**
         * The label options of the label that is displayed in the center of a donut chart. This option isn't available for pie charts.
         */
        donutCenterOptions?: pulumi.Input<inputs.quicksight.DashboardDonutCenterOptionsArgs>;
    }
    interface DashboardDrillDownFilterArgs {
        /**
         * The category type drill down filter. This filter is used for string type columns.
         */
        categoryFilter?: pulumi.Input<inputs.quicksight.DashboardCategoryDrillDownFilterArgs>;
        /**
         * The numeric equality type drill down filter. This filter is used for number type columns.
         */
        numericEqualityFilter?: pulumi.Input<inputs.quicksight.DashboardNumericEqualityDrillDownFilterArgs>;
        /**
         * The time range drill down filter. This filter is used for date time columns.
         */
        timeRangeFilter?: pulumi.Input<inputs.quicksight.DashboardTimeRangeDrillDownFilterArgs>;
    }
    interface DashboardDropDownControlDisplayOptionsArgs {
        /**
         * The configuration of info icon label options.
         */
        infoIconLabelOptions?: pulumi.Input<inputs.quicksight.DashboardSheetControlInfoIconLabelOptionsArgs>;
        /**
         * The configuration of the `Select all` options in a dropdown control.
         */
        selectAllOptions?: pulumi.Input<inputs.quicksight.DashboardListControlSelectAllOptionsArgs>;
        /**
         * The options to configure the title visibility, name, and font size.
         */
        titleOptions?: pulumi.Input<inputs.quicksight.DashboardLabelOptionsArgs>;
    }
    interface DashboardDynamicDefaultValueArgs {
        /**
         * The column that contains the default value of each user or group.
         */
        defaultValueColumn: pulumi.Input<inputs.quicksight.DashboardColumnIdentifierArgs>;
        /**
         * The column that contains the group name.
         */
        groupNameColumn?: pulumi.Input<inputs.quicksight.DashboardColumnIdentifierArgs>;
        /**
         * The column that contains the username.
         */
        userNameColumn?: pulumi.Input<inputs.quicksight.DashboardColumnIdentifierArgs>;
    }
    interface DashboardEmptyVisualArgs {
        /**
         * The list of custom actions that are configured for a visual.
         */
        actions?: pulumi.Input<pulumi.Input<inputs.quicksight.DashboardVisualCustomActionArgs>[]>;
        /**
         * The data set that is used in the empty visual. Every visual requires a dataset to render.
         */
        dataSetIdentifier: pulumi.Input<string>;
        /**
         * The unique identifier of a visual. This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers.
         */
        visualId: pulumi.Input<string>;
    }
    interface DashboardExcludePeriodConfigurationArgs {
        /**
         * The amount or number of the exclude period.
         */
        amount: pulumi.Input<number>;
        /**
         * The granularity or unit (day, month, year) of the exclude period.
         */
        granularity: pulumi.Input<enums.quicksight.DashboardTimeGranularity>;
        /**
         * The status of the exclude period. Choose from the following options:
         *
         * - `ENABLED`
         * - `DISABLED`
         */
        status?: pulumi.Input<enums.quicksight.DashboardWidgetStatus>;
    }
    interface DashboardExplicitHierarchyArgs {
        /**
         * The list of columns that define the explicit hierarchy.
         */
        columns: pulumi.Input<pulumi.Input<inputs.quicksight.DashboardColumnIdentifierArgs>[]>;
        /**
         * The option that determines the drill down filters for the explicit hierarchy.
         */
        drillDownFilters?: pulumi.Input<pulumi.Input<inputs.quicksight.DashboardDrillDownFilterArgs>[]>;
        /**
         * The hierarchy ID of the explicit hierarchy.
         */
        hierarchyId: pulumi.Input<string>;
    }
    /**
     * <p>Determines if hidden fields are included in an exported dashboard.</p>
     */
    interface DashboardExportHiddenFieldsOptionArgs {
        /**
         * The status of the export hidden fields options of a dashbaord.
         */
        availabilityStatus?: pulumi.Input<enums.quicksight.DashboardBehavior>;
    }
    /**
     * <p>Export to .csv option.</p>
     */
    interface DashboardExportToCsvOptionArgs {
        /**
         * Availability status.
         */
        availabilityStatus?: pulumi.Input<enums.quicksight.DashboardBehavior>;
    }
    /**
     * <p>Determines whether or not hidden fields are visible on exported dashbaords.</p>
     */
    interface DashboardExportWithHiddenFieldsOptionArgs {
        /**
         * The status of the export with hidden fields options.
         */
        availabilityStatus?: pulumi.Input<enums.quicksight.DashboardBehavior>;
    }
    interface DashboardFieldBasedTooltipArgs {
        /**
         * The visibility of `Show aggregations` .
         */
        aggregationVisibility?: pulumi.Input<enums.quicksight.DashboardVisibility>;
        /**
         * The fields configuration in the tooltip.
         */
        tooltipFields?: pulumi.Input<pulumi.Input<inputs.quicksight.DashboardTooltipItemArgs>[]>;
        /**
         * The type for the >tooltip title. Choose one of the following options:
         *
         * - `NONE` : Doesn't use the primary value as the title.
         * - `PRIMARY_VALUE` : Uses primary value as the title.
         */
        tooltipTitleType?: pulumi.Input<enums.quicksight.DashboardTooltipTitleType>;
    }
    interface DashboardFieldLabelTypeArgs {
        /**
         * Indicates the field that is targeted by the field label.
         */
        fieldId?: pulumi.Input<string>;
        /**
         * The visibility of the field label.
         */
        visibility?: pulumi.Input<enums.quicksight.DashboardVisibility>;
    }
    interface DashboardFieldSeriesItemArgs {
        /**
         * The axis that you are binding the field to.
         */
        axisBinding: pulumi.Input<enums.quicksight.DashboardAxisBinding>;
        /**
         * The field ID of the field for which you are setting the axis binding.
         */
        fieldId: pulumi.Input<string>;
        /**
         * The options that determine the presentation of line series associated to the field.
         */
        settings?: pulumi.Input<inputs.quicksight.DashboardLineChartSeriesSettingsArgs>;
    }
    interface DashboardFieldSortArgs {
        /**
         * The sort direction. Choose one of the following options:
         *
         * - `ASC` : Ascending
         * - `DESC` : Descending
         */
        direction: pulumi.Input<enums.quicksight.DashboardSortDirection>;
        /**
         * The sort configuration target field.
         */
        fieldId: pulumi.Input<string>;
    }
    interface DashboardFieldSortOptionsArgs {
        /**
         * The sort configuration for a column that is not used in a field well.
         */
        columnSort?: pulumi.Input<inputs.quicksight.DashboardColumnSortArgs>;
        /**
         * The sort configuration for a field in a field well.
         */
        fieldSort?: pulumi.Input<inputs.quicksight.DashboardFieldSortArgs>;
    }
    interface DashboardFieldTooltipItemArgs {
        /**
         * The unique ID of the field that is targeted by the tooltip.
         */
        fieldId: pulumi.Input<string>;
        /**
         * The label of the tooltip item.
         */
        label?: pulumi.Input<string>;
        /**
         * Determines the target of the field tooltip item in a combo chart visual.
         */
        tooltipTarget?: pulumi.Input<enums.quicksight.DashboardTooltipTarget>;
        /**
         * The visibility of the tooltip item.
         */
        visibility?: pulumi.Input<enums.quicksight.DashboardVisibility>;
    }
    interface DashboardFilledMapAggregatedFieldWellsArgs {
        /**
         * The aggregated location field well of the filled map. Values are grouped by location fields.
         */
        geospatial?: pulumi.Input<pulumi.Input<inputs.quicksight.DashboardDimensionFieldArgs>[]>;
        /**
         * The aggregated color field well of a filled map. Values are aggregated based on location fields.
         */
        values?: pulumi.Input<pulumi.Input<inputs.quicksight.DashboardMeasureFieldArgs>[]>;
    }
    interface DashboardFilledMapConditionalFormattingArgs {
        /**
         * Conditional formatting options of a `FilledMapVisual` .
         */
        conditionalFormattingOptions: pulumi.Input<pulumi.Input<inputs.quicksight.DashboardFilledMapConditionalFormattingOptionArgs>[]>;
    }
    interface DashboardFilledMapConditionalFormattingOptionArgs {
        /**
         * The conditional formatting that determines the shape of the filled map.
         */
        shape: pulumi.Input<inputs.quicksight.DashboardFilledMapShapeConditionalFormattingArgs>;
    }
    interface DashboardFilledMapConfigurationArgs {
        /**
         * The field wells of the visual.
         */
        fieldWells?: pulumi.Input<inputs.quicksight.DashboardFilledMapFieldWellsArgs>;
        /**
         * The general visual interactions setup for a visual.
         */
        interactions?: pulumi.Input<inputs.quicksight.DashboardVisualInteractionOptionsArgs>;
        /**
         * The legend display setup of the visual.
         */
        legend?: pulumi.Input<inputs.quicksight.DashboardLegendOptionsArgs>;
        /**
         * The map style options of the filled map visual.
         */
        mapStyleOptions?: pulumi.Input<inputs.quicksight.DashboardGeospatialMapStyleOptionsArgs>;
        /**
         * The sort configuration of a `FilledMapVisual` .
         */
        sortConfiguration?: pulumi.Input<inputs.quicksight.DashboardFilledMapSortConfigurationArgs>;
        /**
         * The tooltip display setup of the visual.
         */
        tooltip?: pulumi.Input<inputs.quicksight.DashboardTooltipOptionsArgs>;
        /**
         * The window options of the filled map visual.
         */
        windowOptions?: pulumi.Input<inputs.quicksight.DashboardGeospatialWindowOptionsArgs>;
    }
    interface DashboardFilledMapFieldWellsArgs {
        /**
         * The aggregated field well of the filled map.
         */
        filledMapAggregatedFieldWells?: pulumi.Input<inputs.quicksight.DashboardFilledMapAggregatedFieldWellsArgs>;
    }
    interface DashboardFilledMapShapeConditionalFormattingArgs {
        /**
         * The field ID of the filled map shape.
         */
        fieldId: pulumi.Input<string>;
        /**
         * The conditional formatting that determines the background color of a filled map's shape.
         */
        format?: pulumi.Input<inputs.quicksight.DashboardShapeConditionalFormatArgs>;
    }
    interface DashboardFilledMapSortConfigurationArgs {
        /**
         * The sort configuration of the location fields.
         */
        categorySort?: pulumi.Input<pulumi.Input<inputs.quicksight.DashboardFieldSortOptionsArgs>[]>;
    }
    interface DashboardFilledMapVisualArgs {
        /**
         * The list of custom actions that are configured for a visual.
         */
        actions?: pulumi.Input<pulumi.Input<inputs.quicksight.DashboardVisualCustomActionArgs>[]>;
        /**
         * The configuration settings of the visual.
         */
        chartConfiguration?: pulumi.Input<inputs.quicksight.DashboardFilledMapConfigurationArgs>;
        /**
         * The column hierarchy that is used during drill-downs and drill-ups.
         */
        columnHierarchies?: pulumi.Input<pulumi.Input<inputs.quicksight.DashboardColumnHierarchyArgs>[]>;
        /**
         * The conditional formatting of a `FilledMapVisual` .
         */
        conditionalFormatting?: pulumi.Input<inputs.quicksight.DashboardFilledMapConditionalFormattingArgs>;
        /**
         * The subtitle that is displayed on the visual.
         */
        subtitle?: pulumi.Input<inputs.quicksight.DashboardVisualSubtitleLabelOptionsArgs>;
        /**
         * The title that is displayed on the visual.
         */
        title?: pulumi.Input<inputs.quicksight.DashboardVisualTitleLabelOptionsArgs>;
        /**
         * The alt text for the visual.
         */
        visualContentAltText?: pulumi.Input<string>;
        /**
         * The unique identifier of a visual. This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers..
         */
        visualId: pulumi.Input<string>;
    }
    interface DashboardFilterArgs {
        /**
         * A `CategoryFilter` filters text values.
         *
         * For more information, see [Adding text filters](https://docs.aws.amazon.com/quicksight/latest/user/add-a-text-filter-data-prep.html) in the *Amazon QuickSight User Guide* .
         */
        categoryFilter?: pulumi.Input<inputs.quicksight.DashboardCategoryFilterArgs>;
        /**
         * A `NestedFilter` filters data with a subset of data that is defined by the nested inner filter.
         */
        nestedFilter?: pulumi.Input<inputs.quicksight.DashboardNestedFilterArgs>;
        /**
         * A `NumericEqualityFilter` filters numeric values that equal or do not equal a given numeric value.
         */
        numericEqualityFilter?: pulumi.Input<inputs.quicksight.DashboardNumericEqualityFilterArgs>;
        /**
         * A `NumericRangeFilter` filters numeric values that are either inside or outside a given numeric range.
         */
        numericRangeFilter?: pulumi.Input<inputs.quicksight.DashboardNumericRangeFilterArgs>;
        /**
         * A `RelativeDatesFilter` filters date values that are relative to a given date.
         */
        relativeDatesFilter?: pulumi.Input<inputs.quicksight.DashboardRelativeDatesFilterArgs>;
        /**
         * A `TimeEqualityFilter` filters date-time values that equal or do not equal a given date/time value.
         */
        timeEqualityFilter?: pulumi.Input<inputs.quicksight.DashboardTimeEqualityFilterArgs>;
        /**
         * A `TimeRangeFilter` filters date-time values that are either inside or outside a given date/time range.
         */
        timeRangeFilter?: pulumi.Input<inputs.quicksight.DashboardTimeRangeFilterArgs>;
        /**
         * A `TopBottomFilter` filters data to the top or bottom values for a given column.
         */
        topBottomFilter?: pulumi.Input<inputs.quicksight.DashboardTopBottomFilterArgs>;
    }
    interface DashboardFilterControlArgs {
        /**
         * A control from a filter that is scoped across more than one sheet. This represents your filter control on a sheet
         */
        crossSheet?: pulumi.Input<inputs.quicksight.DashboardFilterCrossSheetControlArgs>;
        /**
         * A control from a date filter that is used to specify date and time.
         */
        dateTimePicker?: pulumi.Input<inputs.quicksight.DashboardFilterDateTimePickerControlArgs>;
        /**
         * A control to display a dropdown list with buttons that are used to select a single value.
         */
        dropdown?: pulumi.Input<inputs.quicksight.DashboardFilterDropDownControlArgs>;
        /**
         * A control to display a list of buttons or boxes. This is used to select either a single value or multiple values.
         */
        list?: pulumi.Input<inputs.quicksight.DashboardFilterListControlArgs>;
        /**
         * A control from a date filter that is used to specify the relative date.
         */
        relativeDateTime?: pulumi.Input<inputs.quicksight.DashboardFilterRelativeDateTimeControlArgs>;
        /**
         * A control to display a horizontal toggle bar. This is used to change a value by sliding the toggle.
         */
        slider?: pulumi.Input<inputs.quicksight.DashboardFilterSliderControlArgs>;
        /**
         * A control to display a text box that is used to enter multiple entries.
         */
        textArea?: pulumi.Input<inputs.quicksight.DashboardFilterTextAreaControlArgs>;
        /**
         * A control to display a text box that is used to enter a single entry.
         */
        textField?: pulumi.Input<inputs.quicksight.DashboardFilterTextFieldControlArgs>;
    }
    interface DashboardFilterCrossSheetControlArgs {
        /**
         * The values that are displayed in a control can be configured to only show values that are valid based on what's selected in other controls.
         */
        cascadingControlConfiguration?: pulumi.Input<inputs.quicksight.DashboardCascadingControlConfigurationArgs>;
        /**
         * The ID of the `FilterCrossSheetControl` .
         */
        filterControlId: pulumi.Input<string>;
        /**
         * The source filter ID of the `FilterCrossSheetControl` .
         */
        sourceFilterId: pulumi.Input<string>;
    }
    interface DashboardFilterDateTimePickerControlArgs {
        /**
         * The visibility configurationof the Apply button on a `DateTimePickerControl` .
         */
        commitMode?: pulumi.Input<enums.quicksight.DashboardCommitMode>;
        /**
         * The display options of a control.
         */
        displayOptions?: pulumi.Input<inputs.quicksight.DashboardDateTimePickerControlDisplayOptionsArgs>;
        /**
         * The ID of the `FilterDateTimePickerControl` .
         */
        filterControlId: pulumi.Input<string>;
        /**
         * The source filter ID of the `FilterDateTimePickerControl` .
         */
        sourceFilterId: pulumi.Input<string>;
        /**
         * The title of the `FilterDateTimePickerControl` .
         */
        title: pulumi.Input<string>;
        /**
         * The type of the `FilterDropDownControl` . Choose one of the following options:
         *
         * - `MULTI_SELECT` : The user can select multiple entries from a dropdown menu.
         * - `SINGLE_SELECT` : The user can select a single entry from a dropdown menu.
         */
        type?: pulumi.Input<enums.quicksight.DashboardSheetControlDateTimePickerType>;
    }
    interface DashboardFilterDropDownControlArgs {
        /**
         * The values that are displayed in a control can be configured to only show values that are valid based on what's selected in other controls.
         */
        cascadingControlConfiguration?: pulumi.Input<inputs.quicksight.DashboardCascadingControlConfigurationArgs>;
        /**
         * The visibility configuration of the Apply button on a `FilterDropDownControl` .
         */
        commitMode?: pulumi.Input<enums.quicksight.DashboardCommitMode>;
        /**
         * The display options of the `FilterDropDownControl` .
         */
        displayOptions?: pulumi.Input<inputs.quicksight.DashboardDropDownControlDisplayOptionsArgs>;
        /**
         * The ID of the `FilterDropDownControl` .
         */
        filterControlId: pulumi.Input<string>;
        /**
         * A list of selectable values that are used in a control.
         */
        selectableValues?: pulumi.Input<inputs.quicksight.DashboardFilterSelectableValuesArgs>;
        /**
         * The source filter ID of the `FilterDropDownControl` .
         */
        sourceFilterId: pulumi.Input<string>;
        /**
         * The title of the `FilterDropDownControl` .
         */
        title: pulumi.Input<string>;
        /**
         * The type of the `FilterDropDownControl` . Choose one of the following options:
         *
         * - `MULTI_SELECT` : The user can select multiple entries from a dropdown menu.
         * - `SINGLE_SELECT` : The user can select a single entry from a dropdown menu.
         */
        type?: pulumi.Input<enums.quicksight.DashboardSheetControlListType>;
    }
    interface DashboardFilterGroupArgs {
        /**
         * The filter new feature which can apply filter group to all data sets. Choose one of the following options:
         *
         * - `ALL_DATASETS`
         * - `SINGLE_DATASET`
         */
        crossDataset: pulumi.Input<enums.quicksight.DashboardCrossDatasetTypes>;
        /**
         * The value that uniquely identifies a `FilterGroup` within a dashboard, template, or analysis.
         */
        filterGroupId: pulumi.Input<string>;
        /**
         * The list of filters that are present in a `FilterGroup` .
         */
        filters: pulumi.Input<pulumi.Input<inputs.quicksight.DashboardFilterArgs>[]>;
        /**
         * The configuration that specifies what scope to apply to a `FilterGroup` .
         *
         * This is a union type structure. For this structure to be valid, only one of the attributes can be defined.
         */
        scopeConfiguration: pulumi.Input<inputs.quicksight.DashboardFilterScopeConfigurationArgs>;
        /**
         * The status of the `FilterGroup` .
         */
        status?: pulumi.Input<enums.quicksight.DashboardWidgetStatus>;
    }
    interface DashboardFilterListConfigurationArgs {
        /**
         * The list of category values for the filter.
         */
        categoryValues?: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * The match operator that is used to determine if a filter should be applied.
         */
        matchOperator: pulumi.Input<enums.quicksight.DashboardCategoryFilterMatchOperator>;
        /**
         * This option determines how null values should be treated when filtering data.
         *
         * - `ALL_VALUES` : Include null values in filtered results.
         * - `NULLS_ONLY` : Only include null values in filtered results.
         * - `NON_NULLS_ONLY` : Exclude null values from filtered results.
         */
        nullOption?: pulumi.Input<enums.quicksight.DashboardFilterNullOption>;
        /**
         * Select all of the values. Null is not the assigned value of select all.
         *
         * - `FILTER_ALL_VALUES`
         */
        selectAllOptions?: pulumi.Input<enums.quicksight.DashboardCategoryFilterSelectAllOptions>;
    }
    interface DashboardFilterListControlArgs {
        /**
         * The values that are displayed in a control can be configured to only show values that are valid based on what's selected in other controls.
         */
        cascadingControlConfiguration?: pulumi.Input<inputs.quicksight.DashboardCascadingControlConfigurationArgs>;
        /**
         * The display options of a control.
         */
        displayOptions?: pulumi.Input<inputs.quicksight.DashboardListControlDisplayOptionsArgs>;
        /**
         * The ID of the `FilterListControl` .
         */
        filterControlId: pulumi.Input<string>;
        /**
         * A list of selectable values that are used in a control.
         */
        selectableValues?: pulumi.Input<inputs.quicksight.DashboardFilterSelectableValuesArgs>;
        /**
         * The source filter ID of the `FilterListControl` .
         */
        sourceFilterId: pulumi.Input<string>;
        /**
         * The title of the `FilterListControl` .
         */
        title: pulumi.Input<string>;
        /**
         * The type of the `FilterListControl` . Choose one of the following options:
         *
         * - `MULTI_SELECT` : The user can select multiple entries from the list.
         * - `SINGLE_SELECT` : The user can select a single entry from the list.
         */
        type?: pulumi.Input<enums.quicksight.DashboardSheetControlListType>;
    }
    interface DashboardFilterOperationSelectedFieldsConfigurationArgs {
        /**
         * <p>The selected columns of a dataset.</p>
         */
        selectedColumns?: pulumi.Input<pulumi.Input<inputs.quicksight.DashboardColumnIdentifierArgs>[]>;
        /**
         * A structure that contains the options that choose which fields are filtered in the `CustomActionFilterOperation` .
         *
         * Valid values are defined as follows:
         *
         * - `ALL_FIELDS` : Applies the filter operation to all fields.
         */
        selectedFieldOptions?: pulumi.Input<enums.quicksight.DashboardSelectedFieldOptions>;
        /**
         * Chooses the fields that are filtered in `CustomActionFilterOperation` .
         */
        selectedFields?: pulumi.Input<pulumi.Input<string>[]>;
    }
    interface DashboardFilterOperationTargetVisualsConfigurationArgs {
        /**
         * The configuration of the same-sheet target visuals that you want to be filtered.
         */
        sameSheetTargetVisualConfiguration?: pulumi.Input<inputs.quicksight.DashboardSameSheetTargetVisualConfigurationArgs>;
    }
    interface DashboardFilterRelativeDateTimeControlArgs {
        /**
         * The visibility configuration of the Apply button on a `FilterRelativeDateTimeControl` .
         */
        commitMode?: pulumi.Input<enums.quicksight.DashboardCommitMode>;
        /**
         * The display options of a control.
         */
        displayOptions?: pulumi.Input<inputs.quicksight.DashboardRelativeDateTimeControlDisplayOptionsArgs>;
        /**
         * The ID of the `FilterTextAreaControl` .
         */
        filterControlId: pulumi.Input<string>;
        /**
         * The source filter ID of the `FilterTextAreaControl` .
         */
        sourceFilterId: pulumi.Input<string>;
        /**
         * The title of the `FilterTextAreaControl` .
         */
        title: pulumi.Input<string>;
    }
    interface DashboardFilterScopeConfigurationArgs {
        /**
         * The configuration that applies a filter to all sheets. When you choose `AllSheets` as the value for a `FilterScopeConfiguration` , this filter is applied to all visuals of all sheets in an Analysis, Dashboard, or Template. The `AllSheetsFilterScopeConfiguration` is chosen.
         */
        allSheets?: pulumi.Input<inputs.quicksight.DashboardAllSheetsFilterScopeConfigurationArgs>;
        /**
         * The configuration for applying a filter to specific sheets.
         */
        selectedSheets?: pulumi.Input<inputs.quicksight.DashboardSelectedSheetsFilterScopeConfigurationArgs>;
    }
    interface DashboardFilterSelectableValuesArgs {
        /**
         * The values that are used in the `FilterSelectableValues` .
         */
        values?: pulumi.Input<pulumi.Input<string>[]>;
    }
    interface DashboardFilterSliderControlArgs {
        /**
         * The display options of a control.
         */
        displayOptions?: pulumi.Input<inputs.quicksight.DashboardSliderControlDisplayOptionsArgs>;
        /**
         * The ID of the `FilterSliderControl` .
         */
        filterControlId: pulumi.Input<string>;
        /**
         * The larger value that is displayed at the right of the slider.
         */
        maximumValue: pulumi.Input<number>;
        /**
         * The smaller value that is displayed at the left of the slider.
         */
        minimumValue: pulumi.Input<number>;
        /**
         * The source filter ID of the `FilterSliderControl` .
         */
        sourceFilterId: pulumi.Input<string>;
        /**
         * The number of increments that the slider bar is divided into.
         */
        stepSize: pulumi.Input<number>;
        /**
         * The title of the `FilterSliderControl` .
         */
        title: pulumi.Input<string>;
        /**
         * The type of the `FilterSliderControl` . Choose one of the following options:
         *
         * - `SINGLE_POINT` : Filter against(equals) a single data point.
         * - `RANGE` : Filter data that is in a specified range.
         */
        type?: pulumi.Input<enums.quicksight.DashboardSheetControlSliderType>;
    }
    interface DashboardFilterTextAreaControlArgs {
        /**
         * The delimiter that is used to separate the lines in text.
         */
        delimiter?: pulumi.Input<string>;
        /**
         * The display options of a control.
         */
        displayOptions?: pulumi.Input<inputs.quicksight.DashboardTextAreaControlDisplayOptionsArgs>;
        /**
         * The ID of the `FilterTextAreaControl` .
         */
        filterControlId: pulumi.Input<string>;
        /**
         * The source filter ID of the `FilterTextAreaControl` .
         */
        sourceFilterId: pulumi.Input<string>;
        /**
         * The title of the `FilterTextAreaControl` .
         */
        title: pulumi.Input<string>;
    }
    interface DashboardFilterTextFieldControlArgs {
        /**
         * The display options of a control.
         */
        displayOptions?: pulumi.Input<inputs.quicksight.DashboardTextFieldControlDisplayOptionsArgs>;
        /**
         * The ID of the `FilterTextFieldControl` .
         */
        filterControlId: pulumi.Input<string>;
        /**
         * The source filter ID of the `FilterTextFieldControl` .
         */
        sourceFilterId: pulumi.Input<string>;
        /**
         * The title of the `FilterTextFieldControl` .
         */
        title: pulumi.Input<string>;
    }
    interface DashboardFontConfigurationArgs {
        /**
         * Determines the color of the text.
         */
        fontColor?: pulumi.Input<string>;
        /**
         * Determines the appearance of decorative lines on the text.
         */
        fontDecoration?: pulumi.Input<enums.quicksight.DashboardFontDecoration>;
        /**
         * The font family that you want to use.
         */
        fontFamily?: pulumi.Input<string>;
        /**
         * The option that determines the text display size.
         */
        fontSize?: pulumi.Input<inputs.quicksight.DashboardFontSizeArgs>;
        /**
         * Determines the text display face that is inherited by the given font family.
         */
        fontStyle?: pulumi.Input<enums.quicksight.DashboardFontStyle>;
        /**
         * The option that determines the text display weight, or boldness.
         */
        fontWeight?: pulumi.Input<inputs.quicksight.DashboardFontWeightArgs>;
    }
    interface DashboardFontSizeArgs {
        /**
         * String based length that is composed of value and unit in px
         */
        absolute?: pulumi.Input<string>;
        /**
         * The lexical name for the text size, proportional to its surrounding context.
         */
        relative?: pulumi.Input<enums.quicksight.DashboardRelativeFontSize>;
    }
    interface DashboardFontWeightArgs {
        /**
         * The lexical name for the level of boldness of the text display.
         */
        name?: pulumi.Input<enums.quicksight.DashboardFontWeightName>;
    }
    interface DashboardForecastComputationArgs {
        /**
         * The ID for a computation.
         */
        computationId: pulumi.Input<string>;
        /**
         * The custom seasonality value setup of a forecast computation.
         */
        customSeasonalityValue?: pulumi.Input<number>;
        /**
         * The lower boundary setup of a forecast computation.
         */
        lowerBoundary?: pulumi.Input<number>;
        /**
         * The name of a computation.
         */
        name?: pulumi.Input<string>;
        /**
         * The periods backward setup of a forecast computation.
         */
        periodsBackward?: pulumi.Input<number>;
        /**
         * The periods forward setup of a forecast computation.
         */
        periodsForward?: pulumi.Input<number>;
        /**
         * The prediction interval setup of a forecast computation.
         */
        predictionInterval?: pulumi.Input<number>;
        /**
         * The seasonality setup of a forecast computation. Choose one of the following options:
         *
         * - `AUTOMATIC`
         * - `CUSTOM` : Checks the custom seasonality value.
         */
        seasonality?: pulumi.Input<enums.quicksight.DashboardForecastComputationSeasonality>;
        /**
         * The time field that is used in a computation.
         */
        time?: pulumi.Input<inputs.quicksight.DashboardDimensionFieldArgs>;
        /**
         * The upper boundary setup of a forecast computation.
         */
        upperBoundary?: pulumi.Input<number>;
        /**
         * The value field that is used in a computation.
         */
        value?: pulumi.Input<inputs.quicksight.DashboardMeasureFieldArgs>;
    }
    interface DashboardForecastConfigurationArgs {
        /**
         * The forecast properties setup of a forecast in the line chart.
         */
        forecastProperties?: pulumi.Input<inputs.quicksight.DashboardTimeBasedForecastPropertiesArgs>;
        /**
         * The forecast scenario of a forecast in the line chart.
         */
        scenario?: pulumi.Input<inputs.quicksight.DashboardForecastScenarioArgs>;
    }
    interface DashboardForecastScenarioArgs {
        /**
         * The what-if analysis forecast setup with the target date.
         */
        whatIfPointScenario?: pulumi.Input<inputs.quicksight.DashboardWhatIfPointScenarioArgs>;
        /**
         * The what-if analysis forecast setup with the date range.
         */
        whatIfRangeScenario?: pulumi.Input<inputs.quicksight.DashboardWhatIfRangeScenarioArgs>;
    }
    interface DashboardFormatConfigurationArgs {
        /**
         * Formatting configuration for `DateTime` fields.
         */
        dateTimeFormatConfiguration?: pulumi.Input<inputs.quicksight.DashboardDateTimeFormatConfigurationArgs>;
        /**
         * Formatting configuration for number fields.
         */
        numberFormatConfiguration?: pulumi.Input<inputs.quicksight.DashboardNumberFormatConfigurationArgs>;
        /**
         * Formatting configuration for string fields.
         */
        stringFormatConfiguration?: pulumi.Input<inputs.quicksight.DashboardStringFormatConfigurationArgs>;
    }
    interface DashboardFreeFormLayoutCanvasSizeOptionsArgs {
        /**
         * The options that determine the sizing of the canvas used in a free-form layout.
         */
        screenCanvasSizeOptions?: pulumi.Input<inputs.quicksight.DashboardFreeFormLayoutScreenCanvasSizeOptionsArgs>;
    }
    interface DashboardFreeFormLayoutConfigurationArgs {
        canvasSizeOptions?: pulumi.Input<inputs.quicksight.DashboardFreeFormLayoutCanvasSizeOptionsArgs>;
        /**
         * The elements that are included in a free-form layout.
         */
        elements: pulumi.Input<pulumi.Input<inputs.quicksight.DashboardFreeFormLayoutElementArgs>[]>;
    }
    interface DashboardFreeFormLayoutElementArgs {
        /**
         * The background style configuration of a free-form layout element.
         */
        backgroundStyle?: pulumi.Input<inputs.quicksight.DashboardFreeFormLayoutElementBackgroundStyleArgs>;
        /**
         * The border style configuration of a free-form layout element.
         */
        borderStyle?: pulumi.Input<inputs.quicksight.DashboardFreeFormLayoutElementBorderStyleArgs>;
        /**
         * A unique identifier for an element within a free-form layout.
         */
        elementId: pulumi.Input<string>;
        /**
         * The type of element.
         */
        elementType: pulumi.Input<enums.quicksight.DashboardLayoutElementType>;
        /**
         * String based length that is composed of value and unit in px
         */
        height: pulumi.Input<string>;
        /**
         * The loading animation configuration of a free-form layout element.
         */
        loadingAnimation?: pulumi.Input<inputs.quicksight.DashboardLoadingAnimationArgs>;
        /**
         * The rendering rules that determine when an element should be displayed within a free-form layout.
         */
        renderingRules?: pulumi.Input<pulumi.Input<inputs.quicksight.DashboardSheetElementRenderingRuleArgs>[]>;
        /**
         * The border style configuration of a free-form layout element. This border style is used when the element is selected.
         */
        selectedBorderStyle?: pulumi.Input<inputs.quicksight.DashboardFreeFormLayoutElementBorderStyleArgs>;
        /**
         * The visibility of an element within a free-form layout.
         */
        visibility?: pulumi.Input<enums.quicksight.DashboardVisibility>;
        /**
         * String based length that is composed of value and unit in px
         */
        width: pulumi.Input<string>;
        /**
         * String based length that is composed of value and unit in px
         */
        xAxisLocation: pulumi.Input<string>;
        /**
         * String based length that is composed of value and unit in px with Integer.MAX_VALUE as maximum value
         */
        yAxisLocation: pulumi.Input<string>;
    }
    interface DashboardFreeFormLayoutElementBackgroundStyleArgs {
        /**
         * The background color of a free-form layout element.
         */
        color?: pulumi.Input<string>;
        /**
         * The background visibility of a free-form layout element.
         */
        visibility?: pulumi.Input<enums.quicksight.DashboardVisibility>;
    }
    interface DashboardFreeFormLayoutElementBorderStyleArgs {
        /**
         * The border color of a free-form layout element.
         */
        color?: pulumi.Input<string>;
        /**
         * The border visibility of a free-form layout element.
         */
        visibility?: pulumi.Input<enums.quicksight.DashboardVisibility>;
    }
    interface DashboardFreeFormLayoutScreenCanvasSizeOptionsArgs {
        /**
         * String based length that is composed of value and unit in px
         */
        optimizedViewPortWidth: pulumi.Input<string>;
    }
    interface DashboardFreeFormSectionLayoutConfigurationArgs {
        /**
         * The elements that are included in the free-form layout.
         */
        elements: pulumi.Input<pulumi.Input<inputs.quicksight.DashboardFreeFormLayoutElementArgs>[]>;
    }
    interface DashboardFunnelChartAggregatedFieldWellsArgs {
        /**
         * The category field wells of a funnel chart. Values are grouped by category fields.
         */
        category?: pulumi.Input<pulumi.Input<inputs.quicksight.DashboardDimensionFieldArgs>[]>;
        /**
         * The value field wells of a funnel chart. Values are aggregated based on categories.
         */
        values?: pulumi.Input<pulumi.Input<inputs.quicksight.DashboardMeasureFieldArgs>[]>;
    }
    interface DashboardFunnelChartConfigurationArgs {
        /**
         * The label options of the categories that are displayed in a `FunnelChartVisual` .
         */
        categoryLabelOptions?: pulumi.Input<inputs.quicksight.DashboardChartAxisLabelOptionsArgs>;
        /**
         * The options that determine the presentation of the data labels.
         */
        dataLabelOptions?: pulumi.Input<inputs.quicksight.DashboardFunnelChartDataLabelOptionsArgs>;
        /**
         * The field well configuration of a `FunnelChartVisual` .
         */
        fieldWells?: pulumi.Input<inputs.quicksight.DashboardFunnelChartFieldWellsArgs>;
        /**
         * The general visual interactions setup for a visual.
         */
        interactions?: pulumi.Input<inputs.quicksight.DashboardVisualInteractionOptionsArgs>;
        /**
         * The sort configuration of a `FunnelChartVisual` .
         */
        sortConfiguration?: pulumi.Input<inputs.quicksight.DashboardFunnelChartSortConfigurationArgs>;
        /**
         * The tooltip configuration of a `FunnelChartVisual` .
         */
        tooltip?: pulumi.Input<inputs.quicksight.DashboardTooltipOptionsArgs>;
        /**
         * The label options for the values that are displayed in a `FunnelChartVisual` .
         */
        valueLabelOptions?: pulumi.Input<inputs.quicksight.DashboardChartAxisLabelOptionsArgs>;
        /**
         * The visual palette configuration of a `FunnelChartVisual` .
         */
        visualPalette?: pulumi.Input<inputs.quicksight.DashboardVisualPaletteArgs>;
    }
    interface DashboardFunnelChartDataLabelOptionsArgs {
        /**
         * The visibility of the category labels within the data labels.
         */
        categoryLabelVisibility?: pulumi.Input<enums.quicksight.DashboardVisibility>;
        /**
         * The color of the data label text.
         */
        labelColor?: pulumi.Input<string>;
        /**
         * The font configuration for the data labels.
         *
         * Only the `FontSize` attribute of the font configuration is used for data labels.
         */
        labelFontConfiguration?: pulumi.Input<inputs.quicksight.DashboardFontConfigurationArgs>;
        /**
         * Determines the style of the metric labels.
         */
        measureDataLabelStyle?: pulumi.Input<enums.quicksight.DashboardFunnelChartMeasureDataLabelStyle>;
        /**
         * The visibility of the measure labels within the data labels.
         */
        measureLabelVisibility?: pulumi.Input<enums.quicksight.DashboardVisibility>;
        /**
         * Determines the positioning of the data label relative to a section of the funnel.
         */
        position?: pulumi.Input<enums.quicksight.DashboardDataLabelPosition>;
        /**
         * The visibility option that determines if data labels are displayed.
         */
        visibility?: pulumi.Input<enums.quicksight.DashboardVisibility>;
    }
    interface DashboardFunnelChartFieldWellsArgs {
        /**
         * The field well configuration of a `FunnelChartVisual` .
         */
        funnelChartAggregatedFieldWells?: pulumi.Input<inputs.quicksight.DashboardFunnelChartAggregatedFieldWellsArgs>;
    }
    interface DashboardFunnelChartSortConfigurationArgs {
        /**
         * The limit on the number of categories displayed.
         */
        categoryItemsLimit?: pulumi.Input<inputs.quicksight.DashboardItemsLimitConfigurationArgs>;
        /**
         * The sort configuration of the category fields.
         */
        categorySort?: pulumi.Input<pulumi.Input<inputs.quicksight.DashboardFieldSortOptionsArgs>[]>;
    }
    interface DashboardFunnelChartVisualArgs {
        /**
         * The list of custom actions that are configured for a visual.
         */
        actions?: pulumi.Input<pulumi.Input<inputs.quicksight.DashboardVisualCustomActionArgs>[]>;
        /**
         * The configuration of a `FunnelChartVisual` .
         */
        chartConfiguration?: pulumi.Input<inputs.quicksight.DashboardFunnelChartConfigurationArgs>;
        /**
         * The column hierarchy that is used during drill-downs and drill-ups.
         */
        columnHierarchies?: pulumi.Input<pulumi.Input<inputs.quicksight.DashboardColumnHierarchyArgs>[]>;
        /**
         * The subtitle that is displayed on the visual.
         */
        subtitle?: pulumi.Input<inputs.quicksight.DashboardVisualSubtitleLabelOptionsArgs>;
        /**
         * The title that is displayed on the visual.
         */
        title?: pulumi.Input<inputs.quicksight.DashboardVisualTitleLabelOptionsArgs>;
        /**
         * The alt text for the visual.
         */
        visualContentAltText?: pulumi.Input<string>;
        /**
         * The unique identifier of a visual. This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers..
         */
        visualId: pulumi.Input<string>;
    }
    interface DashboardGaugeChartArcConditionalFormattingArgs {
        /**
         * The conditional formatting of the arc foreground color.
         */
        foregroundColor?: pulumi.Input<inputs.quicksight.DashboardConditionalFormattingColorArgs>;
    }
    interface DashboardGaugeChartColorConfigurationArgs {
        /**
         * The background color configuration of a `GaugeChartVisual` .
         */
        backgroundColor?: pulumi.Input<string>;
        /**
         * The foreground color configuration of a `GaugeChartVisual` .
         */
        foregroundColor?: pulumi.Input<string>;
    }
    interface DashboardGaugeChartConditionalFormattingArgs {
        /**
         * Conditional formatting options of a `GaugeChartVisual` .
         */
        conditionalFormattingOptions?: pulumi.Input<pulumi.Input<inputs.quicksight.DashboardGaugeChartConditionalFormattingOptionArgs>[]>;
    }
    interface DashboardGaugeChartConditionalFormattingOptionArgs {
        /**
         * The options that determine the presentation of the arc of a `GaugeChartVisual` .
         */
        arc?: pulumi.Input<inputs.quicksight.DashboardGaugeChartArcConditionalFormattingArgs>;
        /**
         * The conditional formatting for the primary value of a `GaugeChartVisual` .
         */
        primaryValue?: pulumi.Input<inputs.quicksight.DashboardGaugeChartPrimaryValueConditionalFormattingArgs>;
    }
    interface DashboardGaugeChartConfigurationArgs {
        /**
         * The color configuration of a `GaugeChartVisual` .
         */
        colorConfiguration?: pulumi.Input<inputs.quicksight.DashboardGaugeChartColorConfigurationArgs>;
        /**
         * The data label configuration of a `GaugeChartVisual` .
         */
        dataLabels?: pulumi.Input<inputs.quicksight.DashboardDataLabelOptionsArgs>;
        /**
         * The field well configuration of a `GaugeChartVisual` .
         */
        fieldWells?: pulumi.Input<inputs.quicksight.DashboardGaugeChartFieldWellsArgs>;
        /**
         * The options that determine the presentation of the `GaugeChartVisual` .
         */
        gaugeChartOptions?: pulumi.Input<inputs.quicksight.DashboardGaugeChartOptionsArgs>;
        /**
         * The general visual interactions setup for a visual.
         */
        interactions?: pulumi.Input<inputs.quicksight.DashboardVisualInteractionOptionsArgs>;
        /**
         * The tooltip configuration of a `GaugeChartVisual` .
         */
        tooltipOptions?: pulumi.Input<inputs.quicksight.DashboardTooltipOptionsArgs>;
        /**
         * The visual palette configuration of a `GaugeChartVisual` .
         */
        visualPalette?: pulumi.Input<inputs.quicksight.DashboardVisualPaletteArgs>;
    }
    interface DashboardGaugeChartFieldWellsArgs {
        /**
         * The target value field wells of a `GaugeChartVisual` .
         */
        targetValues?: pulumi.Input<pulumi.Input<inputs.quicksight.DashboardMeasureFieldArgs>[]>;
        /**
         * The value field wells of a `GaugeChartVisual` .
         */
        values?: pulumi.Input<pulumi.Input<inputs.quicksight.DashboardMeasureFieldArgs>[]>;
    }
    interface DashboardGaugeChartOptionsArgs {
        /**
         * The arc configuration of a `GaugeChartVisual` .
         */
        arc?: pulumi.Input<inputs.quicksight.DashboardArcConfigurationArgs>;
        /**
         * The arc axis configuration of a `GaugeChartVisual` .
         */
        arcAxis?: pulumi.Input<inputs.quicksight.DashboardArcAxisConfigurationArgs>;
        /**
         * The comparison configuration of a `GaugeChartVisual` .
         */
        comparison?: pulumi.Input<inputs.quicksight.DashboardComparisonConfigurationArgs>;
        /**
         * The options that determine the primary value display type.
         */
        primaryValueDisplayType?: pulumi.Input<enums.quicksight.DashboardPrimaryValueDisplayType>;
        /**
         * The options that determine the primary value font configuration.
         */
        primaryValueFontConfiguration?: pulumi.Input<inputs.quicksight.DashboardFontConfigurationArgs>;
    }
    interface DashboardGaugeChartPrimaryValueConditionalFormattingArgs {
        /**
         * The conditional formatting of the primary value icon.
         */
        icon?: pulumi.Input<inputs.quicksight.DashboardConditionalFormattingIconArgs>;
        /**
         * The conditional formatting of the primary value text color.
         */
        textColor?: pulumi.Input<inputs.quicksight.DashboardConditionalFormattingColorArgs>;
    }
    interface DashboardGaugeChartVisualArgs {
        /**
         * The list of custom actions that are configured for a visual.
         */
        actions?: pulumi.Input<pulumi.Input<inputs.quicksight.DashboardVisualCustomActionArgs>[]>;
        /**
         * The configuration of a `GaugeChartVisual` .
         */
        chartConfiguration?: pulumi.Input<inputs.quicksight.DashboardGaugeChartConfigurationArgs>;
        /**
         * The conditional formatting of a `GaugeChartVisual` .
         */
        conditionalFormatting?: pulumi.Input<inputs.quicksight.DashboardGaugeChartConditionalFormattingArgs>;
        /**
         * The subtitle that is displayed on the visual.
         */
        subtitle?: pulumi.Input<inputs.quicksight.DashboardVisualSubtitleLabelOptionsArgs>;
        /**
         * The title that is displayed on the visual.
         */
        title?: pulumi.Input<inputs.quicksight.DashboardVisualTitleLabelOptionsArgs>;
        /**
         * The alt text for the visual.
         */
        visualContentAltText?: pulumi.Input<string>;
        /**
         * The unique identifier of a visual. This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers.
         */
        visualId: pulumi.Input<string>;
    }
    interface DashboardGeospatialCategoricalColorArgs {
        /**
         * A list of categorical data colors for each category.
         */
        categoryDataColors: pulumi.Input<pulumi.Input<inputs.quicksight.DashboardGeospatialCategoricalDataColorArgs>[]>;
        /**
         * The default opacity of a categorical color.
         */
        defaultOpacity?: pulumi.Input<number>;
        /**
         * The null data visualization settings.
         */
        nullDataSettings?: pulumi.Input<inputs.quicksight.DashboardGeospatialNullDataSettingsArgs>;
        /**
         * The state of visibility for null data.
         */
        nullDataVisibility?: pulumi.Input<enums.quicksight.DashboardVisibility>;
    }
    interface DashboardGeospatialCategoricalDataColorArgs {
        /**
         * The color and opacity values for the category data color.
         */
        color: pulumi.Input<string>;
        /**
         * The data value for the category data color.
         */
        dataValue: pulumi.Input<string>;
    }
    interface DashboardGeospatialCircleRadiusArgs {
        /**
         * The positive value for the radius of a circle.
         */
        radius?: pulumi.Input<number>;
    }
    interface DashboardGeospatialCircleSymbolStyleArgs {
        /**
         * The radius of the circle.
         */
        circleRadius?: pulumi.Input<inputs.quicksight.DashboardGeospatialCircleRadiusArgs>;
        /**
         * The color and opacity values for the fill color.
         */
        fillColor?: pulumi.Input<inputs.quicksight.DashboardGeospatialColorArgs>;
        /**
         * The color and opacity values for the stroke color.
         */
        strokeColor?: pulumi.Input<inputs.quicksight.DashboardGeospatialColorArgs>;
        /**
         * The width of the stroke (border).
         */
        strokeWidth?: pulumi.Input<inputs.quicksight.DashboardGeospatialLineWidthArgs>;
    }
    interface DashboardGeospatialColorArgs {
        /**
         * The visualization properties for the categorical color.
         */
        categorical?: pulumi.Input<inputs.quicksight.DashboardGeospatialCategoricalColorArgs>;
        /**
         * The visualization properties for the gradient color.
         */
        gradient?: pulumi.Input<inputs.quicksight.DashboardGeospatialGradientColorArgs>;
        /**
         * The visualization properties for the solid color.
         */
        solid?: pulumi.Input<inputs.quicksight.DashboardGeospatialSolidColorArgs>;
    }
    interface DashboardGeospatialCoordinateBoundsArgs {
        /**
         * The longitude of the east bound of the geospatial coordinate bounds.
         */
        east: pulumi.Input<number>;
        /**
         * The latitude of the north bound of the geospatial coordinate bounds.
         */
        north: pulumi.Input<number>;
        /**
         * The latitude of the south bound of the geospatial coordinate bounds.
         */
        south: pulumi.Input<number>;
        /**
         * The longitude of the west bound of the geospatial coordinate bounds.
         */
        west: pulumi.Input<number>;
    }
    interface DashboardGeospatialDataSourceItemArgs {
        /**
         * The static file data source properties for the geospatial data.
         */
        staticFileDataSource?: pulumi.Input<inputs.quicksight.DashboardGeospatialStaticFileSourceArgs>;
    }
    interface DashboardGeospatialGradientColorArgs {
        /**
         * The default opacity for the gradient color.
         */
        defaultOpacity?: pulumi.Input<number>;
        /**
         * The null data visualization settings.
         */
        nullDataSettings?: pulumi.Input<inputs.quicksight.DashboardGeospatialNullDataSettingsArgs>;
        /**
         * The state of visibility for null data.
         */
        nullDataVisibility?: pulumi.Input<enums.quicksight.DashboardVisibility>;
        /**
         * A list of gradient step colors for the gradient.
         */
        stepColors: pulumi.Input<pulumi.Input<inputs.quicksight.DashboardGeospatialGradientStepColorArgs>[]>;
    }
    interface DashboardGeospatialGradientStepColorArgs {
        /**
         * The color and opacity values for the gradient step color.
         */
        color: pulumi.Input<string>;
        /**
         * The data value for the gradient step color.
         */
        dataValue: pulumi.Input<number>;
    }
    interface DashboardGeospatialHeatmapColorScaleArgs {
        /**
         * The list of colors to be used in heatmap point style.
         */
        colors?: pulumi.Input<pulumi.Input<inputs.quicksight.DashboardGeospatialHeatmapDataColorArgs>[]>;
    }
    interface DashboardGeospatialHeatmapConfigurationArgs {
        /**
         * The color scale specification for the heatmap point style.
         */
        heatmapColor?: pulumi.Input<inputs.quicksight.DashboardGeospatialHeatmapColorScaleArgs>;
    }
    interface DashboardGeospatialHeatmapDataColorArgs {
        /**
         * The hex color to be used in the heatmap point style.
         */
        color: pulumi.Input<string>;
    }
    interface DashboardGeospatialLayerColorFieldArgs {
        /**
         * A list of color dimension fields.
         */
        colorDimensionsFields?: pulumi.Input<pulumi.Input<inputs.quicksight.DashboardDimensionFieldArgs>[]>;
        /**
         * A list of color measure fields.
         */
        colorValuesFields?: pulumi.Input<pulumi.Input<inputs.quicksight.DashboardMeasureFieldArgs>[]>;
    }
    interface DashboardGeospatialLayerDefinitionArgs {
        /**
         * The definition for a line layer.
         */
        lineLayer?: pulumi.Input<inputs.quicksight.DashboardGeospatialLineLayerArgs>;
        /**
         * The definition for a point layer.
         */
        pointLayer?: pulumi.Input<inputs.quicksight.DashboardGeospatialPointLayerArgs>;
        /**
         * The definition for a polygon layer.
         */
        polygonLayer?: pulumi.Input<inputs.quicksight.DashboardGeospatialPolygonLayerArgs>;
    }
    interface DashboardGeospatialLayerItemArgs {
        /**
         * A list of custom actions for a layer.
         */
        actions?: pulumi.Input<pulumi.Input<inputs.quicksight.DashboardLayerCustomActionArgs>[]>;
        /**
         * The data source for the layer.
         */
        dataSource?: pulumi.Input<inputs.quicksight.DashboardGeospatialDataSourceItemArgs>;
        /**
         * The join definition properties for a layer.
         */
        joinDefinition?: pulumi.Input<inputs.quicksight.DashboardGeospatialLayerJoinDefinitionArgs>;
        /**
         * The label that is displayed for the layer.
         */
        label?: pulumi.Input<string>;
        /**
         * The definition properties for a layer.
         */
        layerDefinition?: pulumi.Input<inputs.quicksight.DashboardGeospatialLayerDefinitionArgs>;
        /**
         * The ID of the layer.
         */
        layerId: pulumi.Input<string>;
        /**
         * The layer type.
         */
        layerType?: pulumi.Input<enums.quicksight.DashboardGeospatialLayerType>;
        tooltip?: pulumi.Input<inputs.quicksight.DashboardTooltipOptionsArgs>;
        /**
         * The state of visibility for the layer.
         */
        visibility?: pulumi.Input<enums.quicksight.DashboardVisibility>;
    }
    interface DashboardGeospatialLayerJoinDefinitionArgs {
        /**
         * The geospatial color field for the join definition.
         */
        colorField?: pulumi.Input<inputs.quicksight.DashboardGeospatialLayerColorFieldArgs>;
        datasetKeyField?: pulumi.Input<inputs.quicksight.DashboardUnaggregatedFieldArgs>;
        /**
         * The name of the field or property in the geospatial data source.
         */
        shapeKeyField?: pulumi.Input<string>;
    }
    interface DashboardGeospatialLayerMapConfigurationArgs {
        interactions?: pulumi.Input<inputs.quicksight.DashboardVisualInteractionOptionsArgs>;
        legend?: pulumi.Input<inputs.quicksight.DashboardLegendOptionsArgs>;
        /**
         * The geospatial layers to visualize on the map.
         */
        mapLayers?: pulumi.Input<pulumi.Input<inputs.quicksight.DashboardGeospatialLayerItemArgs>[]>;
        /**
         * The map state properties for the map.
         */
        mapState?: pulumi.Input<inputs.quicksight.DashboardGeospatialMapStateArgs>;
        /**
         * The map style properties for the map.
         */
        mapStyle?: pulumi.Input<inputs.quicksight.DashboardGeospatialMapStyleArgs>;
    }
    interface DashboardGeospatialLineLayerArgs {
        /**
         * The visualization style for a line layer.
         */
        style: pulumi.Input<inputs.quicksight.DashboardGeospatialLineStyleArgs>;
    }
    interface DashboardGeospatialLineStyleArgs {
        /**
         * The symbol style for a line style.
         */
        lineSymbolStyle?: pulumi.Input<inputs.quicksight.DashboardGeospatialLineSymbolStyleArgs>;
    }
    interface DashboardGeospatialLineSymbolStyleArgs {
        /**
         * The color and opacity values for the fill color.
         */
        fillColor?: pulumi.Input<inputs.quicksight.DashboardGeospatialColorArgs>;
        /**
         * The width value for a line.
         */
        lineWidth?: pulumi.Input<inputs.quicksight.DashboardGeospatialLineWidthArgs>;
    }
    interface DashboardGeospatialLineWidthArgs {
        /**
         * The positive value for the width of a line.
         */
        lineWidth?: pulumi.Input<number>;
    }
    interface DashboardGeospatialMapAggregatedFieldWellsArgs {
        /**
         * The color field wells of a geospatial map.
         */
        colors?: pulumi.Input<pulumi.Input<inputs.quicksight.DashboardDimensionFieldArgs>[]>;
        /**
         * The geospatial field wells of a geospatial map. Values are grouped by geospatial fields.
         */
        geospatial?: pulumi.Input<pulumi.Input<inputs.quicksight.DashboardDimensionFieldArgs>[]>;
        /**
         * The size field wells of a geospatial map. Values are aggregated based on geospatial fields.
         */
        values?: pulumi.Input<pulumi.Input<inputs.quicksight.DashboardMeasureFieldArgs>[]>;
    }
    interface DashboardGeospatialMapConfigurationArgs {
        /**
         * The field wells of the visual.
         */
        fieldWells?: pulumi.Input<inputs.quicksight.DashboardGeospatialMapFieldWellsArgs>;
        /**
         * The general visual interactions setup for a visual.
         */
        interactions?: pulumi.Input<inputs.quicksight.DashboardVisualInteractionOptionsArgs>;
        /**
         * The legend display setup of the visual.
         */
        legend?: pulumi.Input<inputs.quicksight.DashboardLegendOptionsArgs>;
        /**
         * The map style options of the geospatial map.
         */
        mapStyleOptions?: pulumi.Input<inputs.quicksight.DashboardGeospatialMapStyleOptionsArgs>;
        /**
         * The point style options of the geospatial map.
         */
        pointStyleOptions?: pulumi.Input<inputs.quicksight.DashboardGeospatialPointStyleOptionsArgs>;
        /**
         * The tooltip display setup of the visual.
         */
        tooltip?: pulumi.Input<inputs.quicksight.DashboardTooltipOptionsArgs>;
        visualPalette?: pulumi.Input<inputs.quicksight.DashboardVisualPaletteArgs>;
        /**
         * The window options of the geospatial map.
         */
        windowOptions?: pulumi.Input<inputs.quicksight.DashboardGeospatialWindowOptionsArgs>;
    }
    interface DashboardGeospatialMapFieldWellsArgs {
        /**
         * The aggregated field well for a geospatial map.
         */
        geospatialMapAggregatedFieldWells?: pulumi.Input<inputs.quicksight.DashboardGeospatialMapAggregatedFieldWellsArgs>;
    }
    interface DashboardGeospatialMapStateArgs {
        bounds?: pulumi.Input<inputs.quicksight.DashboardGeospatialCoordinateBoundsArgs>;
        /**
         * Enables or disables map navigation for a map.
         */
        mapNavigation?: pulumi.Input<enums.quicksight.DashboardGeospatialMapNavigation>;
    }
    interface DashboardGeospatialMapStyleArgs {
        /**
         * The background color and opacity values for a map.
         */
        backgroundColor?: pulumi.Input<string>;
        /**
         * The selected base map style.
         */
        baseMapStyle?: pulumi.Input<enums.quicksight.DashboardBaseMapStyleType>;
        /**
         * The state of visibility for the base map.
         */
        baseMapVisibility?: pulumi.Input<enums.quicksight.DashboardVisibility>;
    }
    interface DashboardGeospatialMapStyleOptionsArgs {
        /**
         * The base map style of the geospatial map.
         */
        baseMapStyle?: pulumi.Input<enums.quicksight.DashboardBaseMapStyleType>;
    }
    interface DashboardGeospatialMapVisualArgs {
        /**
         * The list of custom actions that are configured for a visual.
         */
        actions?: pulumi.Input<pulumi.Input<inputs.quicksight.DashboardVisualCustomActionArgs>[]>;
        /**
         * The configuration settings of the visual.
         */
        chartConfiguration?: pulumi.Input<inputs.quicksight.DashboardGeospatialMapConfigurationArgs>;
        /**
         * The column hierarchy that is used during drill-downs and drill-ups.
         */
        columnHierarchies?: pulumi.Input<pulumi.Input<inputs.quicksight.DashboardColumnHierarchyArgs>[]>;
        /**
         * The subtitle that is displayed on the visual.
         */
        subtitle?: pulumi.Input<inputs.quicksight.DashboardVisualSubtitleLabelOptionsArgs>;
        /**
         * The title that is displayed on the visual.
         */
        title?: pulumi.Input<inputs.quicksight.DashboardVisualTitleLabelOptionsArgs>;
        /**
         * The alt text for the visual.
         */
        visualContentAltText?: pulumi.Input<string>;
        /**
         * The unique identifier of a visual. This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers..
         */
        visualId: pulumi.Input<string>;
    }
    interface DashboardGeospatialNullDataSettingsArgs {
        /**
         * The symbol style for null data.
         */
        symbolStyle: pulumi.Input<inputs.quicksight.DashboardGeospatialNullSymbolStyleArgs>;
    }
    interface DashboardGeospatialNullSymbolStyleArgs {
        /**
         * The color and opacity values for the fill color.
         */
        fillColor?: pulumi.Input<string>;
        /**
         * The color and opacity values for the stroke color.
         */
        strokeColor?: pulumi.Input<string>;
        /**
         * The width of the border stroke.
         */
        strokeWidth?: pulumi.Input<number>;
    }
    interface DashboardGeospatialPointLayerArgs {
        /**
         * The visualization style for a point layer.
         */
        style: pulumi.Input<inputs.quicksight.DashboardGeospatialPointStyleArgs>;
    }
    interface DashboardGeospatialPointStyleArgs {
        /**
         * The circle symbol style for a point layer.
         */
        circleSymbolStyle?: pulumi.Input<inputs.quicksight.DashboardGeospatialCircleSymbolStyleArgs>;
    }
    interface DashboardGeospatialPointStyleOptionsArgs {
        /**
         * The cluster marker configuration of the geospatial point style.
         */
        clusterMarkerConfiguration?: pulumi.Input<inputs.quicksight.DashboardClusterMarkerConfigurationArgs>;
        /**
         * The heatmap configuration of the geospatial point style.
         */
        heatmapConfiguration?: pulumi.Input<inputs.quicksight.DashboardGeospatialHeatmapConfigurationArgs>;
        /**
         * The selected point styles (point, cluster) of the geospatial map.
         */
        selectedPointStyle?: pulumi.Input<enums.quicksight.DashboardGeospatialSelectedPointStyle>;
    }
    interface DashboardGeospatialPolygonLayerArgs {
        /**
         * The visualization style for a polygon layer.
         */
        style: pulumi.Input<inputs.quicksight.DashboardGeospatialPolygonStyleArgs>;
    }
    interface DashboardGeospatialPolygonStyleArgs {
        /**
         * The polygon symbol style for a polygon layer.
         */
        polygonSymbolStyle?: pulumi.Input<inputs.quicksight.DashboardGeospatialPolygonSymbolStyleArgs>;
    }
    interface DashboardGeospatialPolygonSymbolStyleArgs {
        /**
         * The color and opacity values for the fill color.
         */
        fillColor?: pulumi.Input<inputs.quicksight.DashboardGeospatialColorArgs>;
        /**
         * The color and opacity values for the stroke color.
         */
        strokeColor?: pulumi.Input<inputs.quicksight.DashboardGeospatialColorArgs>;
        /**
         * The width of the border stroke.
         */
        strokeWidth?: pulumi.Input<inputs.quicksight.DashboardGeospatialLineWidthArgs>;
    }
    /**
     * Describes the properties for a solid color
     */
    interface DashboardGeospatialSolidColorArgs {
        /**
         * The color and opacity values for the color.
         */
        color: pulumi.Input<string>;
        /**
         * Enables and disables the view state of the color.
         */
        state?: pulumi.Input<enums.quicksight.DashboardGeospatialColorState>;
    }
    interface DashboardGeospatialStaticFileSourceArgs {
        /**
         * The ID of the static file.
         */
        staticFileId: pulumi.Input<string>;
    }
    interface DashboardGeospatialWindowOptionsArgs {
        /**
         * The bounds options (north, south, west, east) of the geospatial window options.
         */
        bounds?: pulumi.Input<inputs.quicksight.DashboardGeospatialCoordinateBoundsArgs>;
        /**
         * The map zoom modes (manual, auto) of the geospatial window options.
         */
        mapZoomMode?: pulumi.Input<enums.quicksight.DashboardMapZoomMode>;
    }
    interface DashboardGlobalTableBorderOptionsArgs {
        /**
         * Determines the options for side specific border.
         */
        sideSpecificBorder?: pulumi.Input<inputs.quicksight.DashboardTableSideBorderOptionsArgs>;
        /**
         * Determines the options for uniform border.
         */
        uniformBorder?: pulumi.Input<inputs.quicksight.DashboardTableBorderOptionsArgs>;
    }
    interface DashboardGradientColorArgs {
        /**
         * The list of gradient color stops.
         */
        stops?: pulumi.Input<pulumi.Input<inputs.quicksight.DashboardGradientStopArgs>[]>;
    }
    interface DashboardGradientStopArgs {
        /**
         * Determines the color.
         */
        color?: pulumi.Input<string>;
        /**
         * Determines the data value.
         */
        dataValue?: pulumi.Input<number>;
        /**
         * Determines gradient offset value.
         */
        gradientOffset: pulumi.Input<number>;
    }
    interface DashboardGridLayoutCanvasSizeOptionsArgs {
        /**
         * The options that determine the sizing of the canvas used in a grid layout.
         */
        screenCanvasSizeOptions?: pulumi.Input<inputs.quicksight.DashboardGridLayoutScreenCanvasSizeOptionsArgs>;
    }
    interface DashboardGridLayoutConfigurationArgs {
        canvasSizeOptions?: pulumi.Input<inputs.quicksight.DashboardGridLayoutCanvasSizeOptionsArgs>;
        /**
         * The elements that are included in a grid layout.
         */
        elements: pulumi.Input<pulumi.Input<inputs.quicksight.DashboardGridLayoutElementArgs>[]>;
    }
    interface DashboardGridLayoutElementArgs {
        /**
         * The column index for the upper left corner of an element.
         */
        columnIndex?: pulumi.Input<number>;
        /**
         * The width of a grid element expressed as a number of grid columns.
         */
        columnSpan: pulumi.Input<number>;
        /**
         * A unique identifier for an element within a grid layout.
         */
        elementId: pulumi.Input<string>;
        /**
         * The type of element.
         */
        elementType: pulumi.Input<enums.quicksight.DashboardLayoutElementType>;
        /**
         * The row index for the upper left corner of an element.
         */
        rowIndex?: pulumi.Input<number>;
        /**
         * The height of a grid element expressed as a number of grid rows.
         */
        rowSpan: pulumi.Input<number>;
    }
    interface DashboardGridLayoutScreenCanvasSizeOptionsArgs {
        /**
         * String based length that is composed of value and unit in px
         */
        optimizedViewPortWidth?: pulumi.Input<string>;
        /**
         * This value determines the layout behavior when the viewport is resized.
         *
         * - `FIXED` : A fixed width will be used when optimizing the layout. In the Amazon QuickSight console, this option is called `Classic` .
         * - `RESPONSIVE` : The width of the canvas will be responsive and optimized to the view port. In the Amazon QuickSight console, this option is called `Tiled` .
         */
        resizeOption: pulumi.Input<enums.quicksight.DashboardResizeOption>;
    }
    interface DashboardGrowthRateComputationArgs {
        /**
         * The ID for a computation.
         */
        computationId: pulumi.Input<string>;
        /**
         * The name of a computation.
         */
        name?: pulumi.Input<string>;
        /**
         * The period size setup of a growth rate computation.
         */
        periodSize?: pulumi.Input<number>;
        /**
         * The time field that is used in a computation.
         */
        time?: pulumi.Input<inputs.quicksight.DashboardDimensionFieldArgs>;
        /**
         * The value field that is used in a computation.
         */
        value?: pulumi.Input<inputs.quicksight.DashboardMeasureFieldArgs>;
    }
    interface DashboardHeaderFooterSectionConfigurationArgs {
        /**
         * The layout configuration of the header or footer section.
         */
        layout: pulumi.Input<inputs.quicksight.DashboardSectionLayoutConfigurationArgs>;
        /**
         * The unique identifier of the header or footer section.
         */
        sectionId: pulumi.Input<string>;
        /**
         * The style options of a header or footer section.
         */
        style?: pulumi.Input<inputs.quicksight.DashboardSectionStyleArgs>;
    }
    interface DashboardHeatMapAggregatedFieldWellsArgs {
        /**
         * The columns field well of a heat map.
         */
        columns?: pulumi.Input<pulumi.Input<inputs.quicksight.DashboardDimensionFieldArgs>[]>;
        /**
         * The rows field well of a heat map.
         */
        rows?: pulumi.Input<pulumi.Input<inputs.quicksight.DashboardDimensionFieldArgs>[]>;
        /**
         * The values field well of a heat map.
         */
        values?: pulumi.Input<pulumi.Input<inputs.quicksight.DashboardMeasureFieldArgs>[]>;
    }
    interface DashboardHeatMapConfigurationArgs {
        /**
         * The color options (gradient color, point of divergence) in a heat map.
         */
        colorScale?: pulumi.Input<inputs.quicksight.DashboardColorScaleArgs>;
        /**
         * The label options of the column that is displayed in a heat map.
         */
        columnLabelOptions?: pulumi.Input<inputs.quicksight.DashboardChartAxisLabelOptionsArgs>;
        /**
         * The options that determine if visual data labels are displayed.
         */
        dataLabels?: pulumi.Input<inputs.quicksight.DashboardDataLabelOptionsArgs>;
        /**
         * The field wells of the visual.
         */
        fieldWells?: pulumi.Input<inputs.quicksight.DashboardHeatMapFieldWellsArgs>;
        /**
         * The general visual interactions setup for a visual.
         */
        interactions?: pulumi.Input<inputs.quicksight.DashboardVisualInteractionOptionsArgs>;
        /**
         * The legend display setup of the visual.
         */
        legend?: pulumi.Input<inputs.quicksight.DashboardLegendOptionsArgs>;
        /**
         * The label options of the row that is displayed in a `heat map` .
         */
        rowLabelOptions?: pulumi.Input<inputs.quicksight.DashboardChartAxisLabelOptionsArgs>;
        /**
         * The sort configuration of a heat map.
         */
        sortConfiguration?: pulumi.Input<inputs.quicksight.DashboardHeatMapSortConfigurationArgs>;
        /**
         * The tooltip display setup of the visual.
         */
        tooltip?: pulumi.Input<inputs.quicksight.DashboardTooltipOptionsArgs>;
    }
    interface DashboardHeatMapFieldWellsArgs {
        /**
         * The aggregated field wells of a heat map.
         */
        heatMapAggregatedFieldWells?: pulumi.Input<inputs.quicksight.DashboardHeatMapAggregatedFieldWellsArgs>;
    }
    interface DashboardHeatMapSortConfigurationArgs {
        /**
         * The limit on the number of columns that are displayed in a heat map.
         */
        heatMapColumnItemsLimitConfiguration?: pulumi.Input<inputs.quicksight.DashboardItemsLimitConfigurationArgs>;
        /**
         * The column sort configuration for heat map for columns that aren't a part of a field well.
         */
        heatMapColumnSort?: pulumi.Input<pulumi.Input<inputs.quicksight.DashboardFieldSortOptionsArgs>[]>;
        /**
         * The limit on the number of rows that are displayed in a heat map.
         */
        heatMapRowItemsLimitConfiguration?: pulumi.Input<inputs.quicksight.DashboardItemsLimitConfigurationArgs>;
        /**
         * The field sort configuration of the rows fields.
         */
        heatMapRowSort?: pulumi.Input<pulumi.Input<inputs.quicksight.DashboardFieldSortOptionsArgs>[]>;
    }
    interface DashboardHeatMapVisualArgs {
        /**
         * The list of custom actions that are configured for a visual.
         */
        actions?: pulumi.Input<pulumi.Input<inputs.quicksight.DashboardVisualCustomActionArgs>[]>;
        /**
         * The configuration of a heat map.
         */
        chartConfiguration?: pulumi.Input<inputs.quicksight.DashboardHeatMapConfigurationArgs>;
        /**
         * The column hierarchy that is used during drill-downs and drill-ups.
         */
        columnHierarchies?: pulumi.Input<pulumi.Input<inputs.quicksight.DashboardColumnHierarchyArgs>[]>;
        /**
         * The subtitle that is displayed on the visual.
         */
        subtitle?: pulumi.Input<inputs.quicksight.DashboardVisualSubtitleLabelOptionsArgs>;
        /**
         * The title that is displayed on the visual.
         */
        title?: pulumi.Input<inputs.quicksight.DashboardVisualTitleLabelOptionsArgs>;
        /**
         * The alt text for the visual.
         */
        visualContentAltText?: pulumi.Input<string>;
        /**
         * The unique identifier of a visual. This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers.
         */
        visualId: pulumi.Input<string>;
    }
    interface DashboardHistogramAggregatedFieldWellsArgs {
        /**
         * The value field wells of a histogram. Values are aggregated by `COUNT` or `DISTINCT_COUNT` .
         */
        values?: pulumi.Input<pulumi.Input<inputs.quicksight.DashboardMeasureFieldArgs>[]>;
    }
    interface DashboardHistogramBinOptionsArgs {
        /**
         * The options that determine the bin count of a histogram.
         */
        binCount?: pulumi.Input<inputs.quicksight.DashboardBinCountOptionsArgs>;
        /**
         * The options that determine the bin width of a histogram.
         */
        binWidth?: pulumi.Input<inputs.quicksight.DashboardBinWidthOptionsArgs>;
        /**
         * The options that determine the selected bin type.
         */
        selectedBinType?: pulumi.Input<enums.quicksight.DashboardHistogramBinType>;
        /**
         * The options that determine the bin start value.
         */
        startValue?: pulumi.Input<number>;
    }
    interface DashboardHistogramConfigurationArgs {
        /**
         * The options that determine the presentation of histogram bins.
         */
        binOptions?: pulumi.Input<inputs.quicksight.DashboardHistogramBinOptionsArgs>;
        /**
         * The data label configuration of a histogram.
         */
        dataLabels?: pulumi.Input<inputs.quicksight.DashboardDataLabelOptionsArgs>;
        /**
         * The field well configuration of a histogram.
         */
        fieldWells?: pulumi.Input<inputs.quicksight.DashboardHistogramFieldWellsArgs>;
        /**
         * The general visual interactions setup for a visual.
         */
        interactions?: pulumi.Input<inputs.quicksight.DashboardVisualInteractionOptionsArgs>;
        /**
         * The tooltip configuration of a histogram.
         */
        tooltip?: pulumi.Input<inputs.quicksight.DashboardTooltipOptionsArgs>;
        /**
         * The visual palette configuration of a histogram.
         */
        visualPalette?: pulumi.Input<inputs.quicksight.DashboardVisualPaletteArgs>;
        /**
         * The options that determine the presentation of the x-axis.
         */
        xAxisDisplayOptions?: pulumi.Input<inputs.quicksight.DashboardAxisDisplayOptionsArgs>;
        /**
         * The options that determine the presentation of the x-axis label.
         */
        xAxisLabelOptions?: pulumi.Input<inputs.quicksight.DashboardChartAxisLabelOptionsArgs>;
        /**
         * The options that determine the presentation of the y-axis.
         */
        yAxisDisplayOptions?: pulumi.Input<inputs.quicksight.DashboardAxisDisplayOptionsArgs>;
    }
    interface DashboardHistogramFieldWellsArgs {
        /**
         * The field well configuration of a histogram.
         */
        histogramAggregatedFieldWells?: pulumi.Input<inputs.quicksight.DashboardHistogramAggregatedFieldWellsArgs>;
    }
    interface DashboardHistogramVisualArgs {
        /**
         * The list of custom actions that are configured for a visual.
         */
        actions?: pulumi.Input<pulumi.Input<inputs.quicksight.DashboardVisualCustomActionArgs>[]>;
        /**
         * The configuration for a `HistogramVisual` .
         */
        chartConfiguration?: pulumi.Input<inputs.quicksight.DashboardHistogramConfigurationArgs>;
        /**
         * The subtitle that is displayed on the visual.
         */
        subtitle?: pulumi.Input<inputs.quicksight.DashboardVisualSubtitleLabelOptionsArgs>;
        /**
         * The title that is displayed on the visual.
         */
        title?: pulumi.Input<inputs.quicksight.DashboardVisualTitleLabelOptionsArgs>;
        /**
         * The alt text for the visual.
         */
        visualContentAltText?: pulumi.Input<string>;
        /**
         * The unique identifier of a visual. This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers.
         */
        visualId: pulumi.Input<string>;
    }
    interface DashboardImageCustomActionArgs {
        /**
         * A list of `ImageCustomActionOperations` .
         *
         * This is a union type structure. For this structure to be valid, only one of the attributes can be defined.
         */
        actionOperations: pulumi.Input<pulumi.Input<inputs.quicksight.DashboardImageCustomActionOperationArgs>[]>;
        /**
         * The ID of the custom action.
         */
        customActionId: pulumi.Input<string>;
        /**
         * The name of the custom action.
         */
        name: pulumi.Input<string>;
        /**
         * The status of the custom action.
         */
        status?: pulumi.Input<enums.quicksight.DashboardWidgetStatus>;
        /**
         * The trigger of the `VisualCustomAction` .
         *
         * Valid values are defined as follows:
         *
         * - `CLICK` : Initiates a custom action by a left pointer click on a data point.
         * - `MENU` : Initiates a custom action by right pointer click from the menu.
         */
        trigger: pulumi.Input<enums.quicksight.DashboardImageCustomActionTrigger>;
    }
    interface DashboardImageCustomActionOperationArgs {
        navigationOperation?: pulumi.Input<inputs.quicksight.DashboardCustomActionNavigationOperationArgs>;
        setParametersOperation?: pulumi.Input<inputs.quicksight.DashboardCustomActionSetParametersOperationArgs>;
        urlOperation?: pulumi.Input<inputs.quicksight.DashboardCustomActionUrlOperationArgs>;
    }
    interface DashboardImageInteractionOptionsArgs {
        /**
         * The menu options for the image.
         */
        imageMenuOption?: pulumi.Input<inputs.quicksight.DashboardImageMenuOptionArgs>;
    }
    interface DashboardImageMenuOptionArgs {
        /**
         * The availability status of the image menu. If the value of this property is set to `ENABLED` , dashboard readers can interact with the image menu.
         */
        availabilityStatus?: pulumi.Input<enums.quicksight.DashboardBehavior>;
    }
    interface DashboardImageStaticFileArgs {
        /**
         * The source of the image static file.
         */
        source?: pulumi.Input<inputs.quicksight.DashboardStaticFileSourceArgs>;
        /**
         * The ID of the static file that contains an image.
         */
        staticFileId: pulumi.Input<string>;
    }
    interface DashboardInnerFilterArgs {
        /**
         * A `CategoryInnerFilter` filters text values for the `NestedFilter` .
         */
        categoryInnerFilter?: pulumi.Input<inputs.quicksight.DashboardCategoryInnerFilterArgs>;
    }
    interface DashboardInsightConfigurationArgs {
        /**
         * The computations configurations of the insight visual
         */
        computations?: pulumi.Input<pulumi.Input<inputs.quicksight.DashboardComputationArgs>[]>;
        /**
         * The custom narrative of the insight visual.
         */
        customNarrative?: pulumi.Input<inputs.quicksight.DashboardCustomNarrativeOptionsArgs>;
        /**
         * The general visual interactions setup for a visual.
         */
        interactions?: pulumi.Input<inputs.quicksight.DashboardVisualInteractionOptionsArgs>;
    }
    interface DashboardInsightVisualArgs {
        /**
         * The list of custom actions that are configured for a visual.
         */
        actions?: pulumi.Input<pulumi.Input<inputs.quicksight.DashboardVisualCustomActionArgs>[]>;
        /**
         * The dataset that is used in the insight visual.
         */
        dataSetIdentifier: pulumi.Input<string>;
        /**
         * The configuration of an insight visual.
         */
        insightConfiguration?: pulumi.Input<inputs.quicksight.DashboardInsightConfigurationArgs>;
        /**
         * The subtitle that is displayed on the visual.
         */
        subtitle?: pulumi.Input<inputs.quicksight.DashboardVisualSubtitleLabelOptionsArgs>;
        /**
         * The title that is displayed on the visual.
         */
        title?: pulumi.Input<inputs.quicksight.DashboardVisualTitleLabelOptionsArgs>;
        /**
         * The alt text for the visual.
         */
        visualContentAltText?: pulumi.Input<string>;
        /**
         * The unique identifier of a visual. This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers.
         */
        visualId: pulumi.Input<string>;
    }
    interface DashboardIntegerDefaultValuesArgs {
        /**
         * The dynamic value of the `IntegerDefaultValues` . Different defaults are displayed according to users, groups, and values mapping.
         */
        dynamicValue?: pulumi.Input<inputs.quicksight.DashboardDynamicDefaultValueArgs>;
        /**
         * The static values of the `IntegerDefaultValues` .
         */
        staticValues?: pulumi.Input<pulumi.Input<number>[]>;
    }
    /**
     * <p>An integer parameter.</p>
     */
    interface DashboardIntegerParameterArgs {
        /**
         * <p>The name of the integer parameter.</p>
         */
        name: pulumi.Input<string>;
        /**
         * <p>The values for the integer parameter.</p>
         */
        values: pulumi.Input<pulumi.Input<number>[]>;
    }
    interface DashboardIntegerParameterDeclarationArgs {
        /**
         * The default values of a parameter. If the parameter is a single-value parameter, a maximum of one default value can be provided.
         */
        defaultValues?: pulumi.Input<inputs.quicksight.DashboardIntegerDefaultValuesArgs>;
        mappedDataSetParameters?: pulumi.Input<pulumi.Input<inputs.quicksight.DashboardMappedDataSetParameterArgs>[]>;
        /**
         * The name of the parameter that is being declared.
         */
        name: pulumi.Input<string>;
        /**
         * The value type determines whether the parameter is a single-value or multi-value parameter.
         */
        parameterValueType: pulumi.Input<enums.quicksight.DashboardParameterValueType>;
        /**
         * A parameter declaration for the `Integer` data type.
         */
        valueWhenUnset?: pulumi.Input<inputs.quicksight.DashboardIntegerValueWhenUnsetConfigurationArgs>;
    }
    interface DashboardIntegerValueWhenUnsetConfigurationArgs {
        /**
         * A custom value that's used when the value of a parameter isn't set.
         */
        customValue?: pulumi.Input<number>;
        /**
         * The built-in options for default values. The value can be one of the following:
         *
         * - `RECOMMENDED` : The recommended value.
         * - `NULL` : The `NULL` value.
         */
        valueWhenUnsetOption?: pulumi.Input<enums.quicksight.DashboardValueWhenUnsetOption>;
    }
    interface DashboardItemsLimitConfigurationArgs {
        /**
         * The limit on how many items of a field are showed in the chart. For example, the number of slices that are displayed in a pie chart.
         */
        itemsLimit?: pulumi.Input<number>;
        /**
         * The `Show other` of an axis in the chart. Choose one of the following options:
         *
         * - `INCLUDE`
         * - `EXCLUDE`
         */
        otherCategories?: pulumi.Input<enums.quicksight.DashboardOtherCategories>;
    }
    interface DashboardKpiActualValueConditionalFormattingArgs {
        /**
         * The conditional formatting of the actual value's icon.
         */
        icon?: pulumi.Input<inputs.quicksight.DashboardConditionalFormattingIconArgs>;
        /**
         * The conditional formatting of the actual value's text color.
         */
        textColor?: pulumi.Input<inputs.quicksight.DashboardConditionalFormattingColorArgs>;
    }
    interface DashboardKpiComparisonValueConditionalFormattingArgs {
        /**
         * The conditional formatting of the comparison value's icon.
         */
        icon?: pulumi.Input<inputs.quicksight.DashboardConditionalFormattingIconArgs>;
        /**
         * The conditional formatting of the comparison value's text color.
         */
        textColor?: pulumi.Input<inputs.quicksight.DashboardConditionalFormattingColorArgs>;
    }
    interface DashboardKpiConditionalFormattingArgs {
        /**
         * The conditional formatting options of a KPI visual.
         */
        conditionalFormattingOptions?: pulumi.Input<pulumi.Input<inputs.quicksight.DashboardKpiConditionalFormattingOptionArgs>[]>;
    }
    interface DashboardKpiConditionalFormattingOptionArgs {
        /**
         * The conditional formatting for the actual value of a KPI visual.
         */
        actualValue?: pulumi.Input<inputs.quicksight.DashboardKpiActualValueConditionalFormattingArgs>;
        /**
         * The conditional formatting for the comparison value of a KPI visual.
         */
        comparisonValue?: pulumi.Input<inputs.quicksight.DashboardKpiComparisonValueConditionalFormattingArgs>;
        /**
         * The conditional formatting for the primary value of a KPI visual.
         */
        primaryValue?: pulumi.Input<inputs.quicksight.DashboardKpiPrimaryValueConditionalFormattingArgs>;
        /**
         * The conditional formatting for the progress bar of a KPI visual.
         */
        progressBar?: pulumi.Input<inputs.quicksight.DashboardKpiProgressBarConditionalFormattingArgs>;
    }
    interface DashboardKpiConfigurationArgs {
        /**
         * The field well configuration of a KPI visual.
         */
        fieldWells?: pulumi.Input<inputs.quicksight.DashboardKpiFieldWellsArgs>;
        /**
         * The general visual interactions setup for a visual.
         */
        interactions?: pulumi.Input<inputs.quicksight.DashboardVisualInteractionOptionsArgs>;
        /**
         * The options that determine the presentation of a KPI visual.
         */
        kpiOptions?: pulumi.Input<inputs.quicksight.DashboardKpiOptionsArgs>;
        /**
         * The sort configuration of a KPI visual.
         */
        sortConfiguration?: pulumi.Input<inputs.quicksight.DashboardKpiSortConfigurationArgs>;
    }
    interface DashboardKpiFieldWellsArgs {
        /**
         * The target value field wells of a KPI visual.
         */
        targetValues?: pulumi.Input<pulumi.Input<inputs.quicksight.DashboardMeasureFieldArgs>[]>;
        /**
         * The trend group field wells of a KPI visual.
         */
        trendGroups?: pulumi.Input<pulumi.Input<inputs.quicksight.DashboardDimensionFieldArgs>[]>;
        /**
         * The value field wells of a KPI visual.
         */
        values?: pulumi.Input<pulumi.Input<inputs.quicksight.DashboardMeasureFieldArgs>[]>;
    }
    interface DashboardKpiOptionsArgs {
        /**
         * The comparison configuration of a KPI visual.
         */
        comparison?: pulumi.Input<inputs.quicksight.DashboardComparisonConfigurationArgs>;
        /**
         * The options that determine the primary value display type.
         */
        primaryValueDisplayType?: pulumi.Input<enums.quicksight.DashboardPrimaryValueDisplayType>;
        /**
         * The options that determine the primary value font configuration.
         */
        primaryValueFontConfiguration?: pulumi.Input<inputs.quicksight.DashboardFontConfigurationArgs>;
        /**
         * The options that determine the presentation of the progress bar of a KPI visual.
         */
        progressBar?: pulumi.Input<inputs.quicksight.DashboardProgressBarOptionsArgs>;
        /**
         * The options that determine the presentation of the secondary value of a KPI visual.
         */
        secondaryValue?: pulumi.Input<inputs.quicksight.DashboardSecondaryValueOptionsArgs>;
        /**
         * The options that determine the secondary value font configuration.
         */
        secondaryValueFontConfiguration?: pulumi.Input<inputs.quicksight.DashboardFontConfigurationArgs>;
        /**
         * The options that determine the visibility, color, type, and tooltip visibility of the sparkline of a KPI visual.
         */
        sparkline?: pulumi.Input<inputs.quicksight.DashboardKpiSparklineOptionsArgs>;
        /**
         * The options that determine the presentation of trend arrows in a KPI visual.
         */
        trendArrows?: pulumi.Input<inputs.quicksight.DashboardTrendArrowOptionsArgs>;
        /**
         * The options that determine the layout a KPI visual.
         */
        visualLayoutOptions?: pulumi.Input<inputs.quicksight.DashboardKpiVisualLayoutOptionsArgs>;
    }
    interface DashboardKpiPrimaryValueConditionalFormattingArgs {
        /**
         * The conditional formatting of the primary value's icon.
         */
        icon?: pulumi.Input<inputs.quicksight.DashboardConditionalFormattingIconArgs>;
        /**
         * The conditional formatting of the primary value's text color.
         */
        textColor?: pulumi.Input<inputs.quicksight.DashboardConditionalFormattingColorArgs>;
    }
    interface DashboardKpiProgressBarConditionalFormattingArgs {
        /**
         * The conditional formatting of the progress bar's foreground color.
         */
        foregroundColor?: pulumi.Input<inputs.quicksight.DashboardConditionalFormattingColorArgs>;
    }
    interface DashboardKpiSortConfigurationArgs {
        /**
         * The sort configuration of the trend group fields.
         */
        trendGroupSort?: pulumi.Input<pulumi.Input<inputs.quicksight.DashboardFieldSortOptionsArgs>[]>;
    }
    interface DashboardKpiSparklineOptionsArgs {
        /**
         * The color of the sparkline.
         */
        color?: pulumi.Input<string>;
        /**
         * The tooltip visibility of the sparkline.
         */
        tooltipVisibility?: pulumi.Input<enums.quicksight.DashboardVisibility>;
        /**
         * The type of the sparkline.
         */
        type: pulumi.Input<enums.quicksight.DashboardKpiSparklineType>;
        /**
         * The visibility of the sparkline.
         */
        visibility?: pulumi.Input<enums.quicksight.DashboardVisibility>;
    }
    interface DashboardKpiVisualArgs {
        /**
         * The list of custom actions that are configured for a visual.
         */
        actions?: pulumi.Input<pulumi.Input<inputs.quicksight.DashboardVisualCustomActionArgs>[]>;
        /**
         * The configuration of a KPI visual.
         */
        chartConfiguration?: pulumi.Input<inputs.quicksight.DashboardKpiConfigurationArgs>;
        /**
         * The column hierarchy that is used during drill-downs and drill-ups.
         */
        columnHierarchies?: pulumi.Input<pulumi.Input<inputs.quicksight.DashboardColumnHierarchyArgs>[]>;
        /**
         * The conditional formatting of a KPI visual.
         */
        conditionalFormatting?: pulumi.Input<inputs.quicksight.DashboardKpiConditionalFormattingArgs>;
        /**
         * The subtitle that is displayed on the visual.
         */
        subtitle?: pulumi.Input<inputs.quicksight.DashboardVisualSubtitleLabelOptionsArgs>;
        /**
         * The title that is displayed on the visual.
         */
        title?: pulumi.Input<inputs.quicksight.DashboardVisualTitleLabelOptionsArgs>;
        /**
         * The alt text for the visual.
         */
        visualContentAltText?: pulumi.Input<string>;
        /**
         * The unique identifier of a visual. This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers.
         */
        visualId: pulumi.Input<string>;
    }
    interface DashboardKpiVisualLayoutOptionsArgs {
        /**
         * The standard layout of the KPI visual.
         */
        standardLayout?: pulumi.Input<inputs.quicksight.DashboardKpiVisualStandardLayoutArgs>;
    }
    interface DashboardKpiVisualStandardLayoutArgs {
        /**
         * The standard layout type.
         */
        type: pulumi.Input<enums.quicksight.DashboardKpiVisualStandardLayoutType>;
    }
    interface DashboardLabelOptionsArgs {
        /**
         * The text for the label.
         */
        customLabel?: pulumi.Input<string>;
        /**
         * The font configuration of the label.
         */
        fontConfiguration?: pulumi.Input<inputs.quicksight.DashboardFontConfigurationArgs>;
        /**
         * Determines whether or not the label is visible.
         */
        visibility?: pulumi.Input<enums.quicksight.DashboardVisibility>;
    }
    interface DashboardLayerCustomActionArgs {
        /**
         * A list of `LayerCustomActionOperations` .
         *
         * This is a union type structure. For this structure to be valid, only one of the attributes can be defined.
         */
        actionOperations: pulumi.Input<pulumi.Input<inputs.quicksight.DashboardLayerCustomActionOperationArgs>[]>;
        /**
         * The ID of the custom action.
         */
        customActionId: pulumi.Input<string>;
        /**
         * The name of the custom action.
         */
        name: pulumi.Input<string>;
        /**
         * The status of the `LayerCustomAction` .
         */
        status?: pulumi.Input<enums.quicksight.DashboardWidgetStatus>;
        /**
         * The trigger of the `LayerCustomAction` .
         *
         * Valid values are defined as follows:
         *
         * - `DATA_POINT_CLICK` : Initiates a custom action by a left pointer click on a data point.
         * - `DATA_POINT_MENU` : Initiates a custom action by right pointer click from the menu.
         */
        trigger: pulumi.Input<enums.quicksight.DashboardLayerCustomActionTrigger>;
    }
    interface DashboardLayerCustomActionOperationArgs {
        filterOperation?: pulumi.Input<inputs.quicksight.DashboardCustomActionFilterOperationArgs>;
        navigationOperation?: pulumi.Input<inputs.quicksight.DashboardCustomActionNavigationOperationArgs>;
        setParametersOperation?: pulumi.Input<inputs.quicksight.DashboardCustomActionSetParametersOperationArgs>;
        urlOperation?: pulumi.Input<inputs.quicksight.DashboardCustomActionUrlOperationArgs>;
    }
    interface DashboardLayerMapVisualArgs {
        /**
         * The configuration settings of the visual.
         */
        chartConfiguration?: pulumi.Input<inputs.quicksight.DashboardGeospatialLayerMapConfigurationArgs>;
        /**
         * The dataset that is used to create the layer map visual. You can't create a visual without a dataset.
         */
        dataSetIdentifier: pulumi.Input<string>;
        subtitle?: pulumi.Input<inputs.quicksight.DashboardVisualSubtitleLabelOptionsArgs>;
        title?: pulumi.Input<inputs.quicksight.DashboardVisualTitleLabelOptionsArgs>;
        /**
         * The alt text for the visual.
         */
        visualContentAltText?: pulumi.Input<string>;
        /**
         * The ID of the visual.
         */
        visualId: pulumi.Input<string>;
    }
    interface DashboardLayoutArgs {
        /**
         * The configuration that determines what the type of layout for a sheet.
         */
        configuration: pulumi.Input<inputs.quicksight.DashboardLayoutConfigurationArgs>;
    }
    interface DashboardLayoutConfigurationArgs {
        /**
         * A free-form is optimized for a fixed width and has more control over the exact placement of layout elements.
         */
        freeFormLayout?: pulumi.Input<inputs.quicksight.DashboardFreeFormLayoutConfigurationArgs>;
        /**
         * A type of layout that can be used on a sheet. In a grid layout, visuals snap to a grid with standard spacing and alignment. Dashboards are displayed as designed, with options to fit to screen or view at actual size. A grid layout can be configured to behave in one of two ways when the viewport is resized: `FIXED` or `RESPONSIVE` .
         */
        gridLayout?: pulumi.Input<inputs.quicksight.DashboardGridLayoutConfigurationArgs>;
        /**
         * A section based layout organizes visuals into multiple sections and has customized header, footer and page break.
         */
        sectionBasedLayout?: pulumi.Input<inputs.quicksight.DashboardSectionBasedLayoutConfigurationArgs>;
    }
    interface DashboardLegendOptionsArgs {
        /**
         * String based length that is composed of value and unit in px
         */
        height?: pulumi.Input<string>;
        /**
         * The positions for the legend. Choose one of the following options:
         *
         * - `AUTO`
         * - `RIGHT`
         * - `BOTTOM`
         * - `LEFT`
         */
        position?: pulumi.Input<enums.quicksight.DashboardLegendPosition>;
        /**
         * The custom title for the legend.
         */
        title?: pulumi.Input<inputs.quicksight.DashboardLabelOptionsArgs>;
        valueFontConfiguration?: pulumi.Input<inputs.quicksight.DashboardFontConfigurationArgs>;
        /**
         * Determines whether or not the legend is visible.
         */
        visibility?: pulumi.Input<enums.quicksight.DashboardVisibility>;
        /**
         * String based length that is composed of value and unit in px
         */
        width?: pulumi.Input<string>;
    }
    interface DashboardLineChartAggregatedFieldWellsArgs {
        /**
         * The category field wells of a line chart. Values are grouped by category fields.
         */
        category?: pulumi.Input<pulumi.Input<inputs.quicksight.DashboardDimensionFieldArgs>[]>;
        /**
         * The color field wells of a line chart. Values are grouped by category fields.
         */
        colors?: pulumi.Input<pulumi.Input<inputs.quicksight.DashboardDimensionFieldArgs>[]>;
        /**
         * The small multiples field well of a line chart.
         */
        smallMultiples?: pulumi.Input<pulumi.Input<inputs.quicksight.DashboardDimensionFieldArgs>[]>;
        /**
         * The value field wells of a line chart. Values are aggregated based on categories.
         */
        values?: pulumi.Input<pulumi.Input<inputs.quicksight.DashboardMeasureFieldArgs>[]>;
    }
    interface DashboardLineChartConfigurationArgs {
        /**
         * The default configuration of a line chart's contribution analysis.
         */
        contributionAnalysisDefaults?: pulumi.Input<pulumi.Input<inputs.quicksight.DashboardContributionAnalysisDefaultArgs>[]>;
        /**
         * The data label configuration of a line chart.
         */
        dataLabels?: pulumi.Input<inputs.quicksight.DashboardDataLabelOptionsArgs>;
        /**
         * The options that determine the default presentation of all line series in `LineChartVisual` .
         */
        defaultSeriesSettings?: pulumi.Input<inputs.quicksight.DashboardLineChartDefaultSeriesSettingsArgs>;
        /**
         * The field well configuration of a line chart.
         */
        fieldWells?: pulumi.Input<inputs.quicksight.DashboardLineChartFieldWellsArgs>;
        /**
         * The forecast configuration of a line chart.
         */
        forecastConfigurations?: pulumi.Input<pulumi.Input<inputs.quicksight.DashboardForecastConfigurationArgs>[]>;
        /**
         * The general visual interactions setup for a visual.
         */
        interactions?: pulumi.Input<inputs.quicksight.DashboardVisualInteractionOptionsArgs>;
        /**
         * The legend configuration of a line chart.
         */
        legend?: pulumi.Input<inputs.quicksight.DashboardLegendOptionsArgs>;
        /**
         * The series axis configuration of a line chart.
         */
        primaryYAxisDisplayOptions?: pulumi.Input<inputs.quicksight.DashboardLineSeriesAxisDisplayOptionsArgs>;
        /**
         * The options that determine the presentation of the y-axis label.
         */
        primaryYAxisLabelOptions?: pulumi.Input<inputs.quicksight.DashboardChartAxisLabelOptionsArgs>;
        /**
         * The reference lines configuration of a line chart.
         */
        referenceLines?: pulumi.Input<pulumi.Input<inputs.quicksight.DashboardReferenceLineArgs>[]>;
        /**
         * The series axis configuration of a line chart.
         */
        secondaryYAxisDisplayOptions?: pulumi.Input<inputs.quicksight.DashboardLineSeriesAxisDisplayOptionsArgs>;
        /**
         * The options that determine the presentation of the secondary y-axis label.
         */
        secondaryYAxisLabelOptions?: pulumi.Input<inputs.quicksight.DashboardChartAxisLabelOptionsArgs>;
        /**
         * The series item configuration of a line chart.
         */
        series?: pulumi.Input<pulumi.Input<inputs.quicksight.DashboardSeriesItemArgs>[]>;
        singleAxisOptions?: pulumi.Input<inputs.quicksight.DashboardSingleAxisOptionsArgs>;
        /**
         * The small multiples setup for the visual.
         */
        smallMultiplesOptions?: pulumi.Input<inputs.quicksight.DashboardSmallMultiplesOptionsArgs>;
        /**
         * The sort configuration of a line chart.
         */
        sortConfiguration?: pulumi.Input<inputs.quicksight.DashboardLineChartSortConfigurationArgs>;
        /**
         * The tooltip configuration of a line chart.
         */
        tooltip?: pulumi.Input<inputs.quicksight.DashboardTooltipOptionsArgs>;
        /**
         * Determines the type of the line chart.
         */
        type?: pulumi.Input<enums.quicksight.DashboardLineChartType>;
        /**
         * The visual palette configuration of a line chart.
         */
        visualPalette?: pulumi.Input<inputs.quicksight.DashboardVisualPaletteArgs>;
        /**
         * The options that determine the presentation of the x-axis.
         */
        xAxisDisplayOptions?: pulumi.Input<inputs.quicksight.DashboardAxisDisplayOptionsArgs>;
        /**
         * The options that determine the presentation of the x-axis label.
         */
        xAxisLabelOptions?: pulumi.Input<inputs.quicksight.DashboardChartAxisLabelOptionsArgs>;
    }
    interface DashboardLineChartDefaultSeriesSettingsArgs {
        /**
         * The axis to which you are binding all line series to.
         */
        axisBinding?: pulumi.Input<enums.quicksight.DashboardAxisBinding>;
        /**
         * Line styles options for all line series in the visual.
         */
        lineStyleSettings?: pulumi.Input<inputs.quicksight.DashboardLineChartLineStyleSettingsArgs>;
        /**
         * Marker styles options for all line series in the visual.
         */
        markerStyleSettings?: pulumi.Input<inputs.quicksight.DashboardLineChartMarkerStyleSettingsArgs>;
    }
    interface DashboardLineChartFieldWellsArgs {
        /**
         * The field well configuration of a line chart.
         */
        lineChartAggregatedFieldWells?: pulumi.Input<inputs.quicksight.DashboardLineChartAggregatedFieldWellsArgs>;
    }
    interface DashboardLineChartLineStyleSettingsArgs {
        /**
         * Interpolation style for line series.
         *
         * - `LINEAR` : Show as default, linear style.
         * - `SMOOTH` : Show as a smooth curve.
         * - `STEPPED` : Show steps in line.
         */
        lineInterpolation?: pulumi.Input<enums.quicksight.DashboardLineInterpolation>;
        /**
         * Line style for line series.
         *
         * - `SOLID` : Show as a solid line.
         * - `DOTTED` : Show as a dotted line.
         * - `DASHED` : Show as a dashed line.
         */
        lineStyle?: pulumi.Input<enums.quicksight.DashboardLineChartLineStyle>;
        /**
         * Configuration option that determines whether to show the line for the series.
         */
        lineVisibility?: pulumi.Input<enums.quicksight.DashboardVisibility>;
        /**
         * String based length that is composed of value and unit in px
         */
        lineWidth?: pulumi.Input<string>;
    }
    interface DashboardLineChartMarkerStyleSettingsArgs {
        /**
         * Color of marker in the series.
         */
        markerColor?: pulumi.Input<string>;
        /**
         * Shape option for markers in the series.
         *
         * - `CIRCLE` : Show marker as a circle.
         * - `TRIANGLE` : Show marker as a triangle.
         * - `SQUARE` : Show marker as a square.
         * - `DIAMOND` : Show marker as a diamond.
         * - `ROUNDED_SQUARE` : Show marker as a rounded square.
         */
        markerShape?: pulumi.Input<enums.quicksight.DashboardLineChartMarkerShape>;
        /**
         * String based length that is composed of value and unit in px
         */
        markerSize?: pulumi.Input<string>;
        /**
         * Configuration option that determines whether to show the markers in the series.
         */
        markerVisibility?: pulumi.Input<enums.quicksight.DashboardVisibility>;
    }
    interface DashboardLineChartSeriesSettingsArgs {
        /**
         * Line styles options for a line series in `LineChartVisual` .
         */
        lineStyleSettings?: pulumi.Input<inputs.quicksight.DashboardLineChartLineStyleSettingsArgs>;
        /**
         * Marker styles options for a line series in `LineChartVisual` .
         */
        markerStyleSettings?: pulumi.Input<inputs.quicksight.DashboardLineChartMarkerStyleSettingsArgs>;
    }
    interface DashboardLineChartSortConfigurationArgs {
        /**
         * The limit on the number of categories that are displayed in a line chart.
         */
        categoryItemsLimitConfiguration?: pulumi.Input<inputs.quicksight.DashboardItemsLimitConfigurationArgs>;
        /**
         * The sort configuration of the category fields.
         */
        categorySort?: pulumi.Input<pulumi.Input<inputs.quicksight.DashboardFieldSortOptionsArgs>[]>;
        /**
         * The limit on the number of lines that are displayed in a line chart.
         */
        colorItemsLimitConfiguration?: pulumi.Input<inputs.quicksight.DashboardItemsLimitConfigurationArgs>;
        /**
         * The limit on the number of small multiples panels that are displayed.
         */
        smallMultiplesLimitConfiguration?: pulumi.Input<inputs.quicksight.DashboardItemsLimitConfigurationArgs>;
        /**
         * The sort configuration of the small multiples field.
         */
        smallMultiplesSort?: pulumi.Input<pulumi.Input<inputs.quicksight.DashboardFieldSortOptionsArgs>[]>;
    }
    interface DashboardLineChartVisualArgs {
        /**
         * The list of custom actions that are configured for a visual.
         */
        actions?: pulumi.Input<pulumi.Input<inputs.quicksight.DashboardVisualCustomActionArgs>[]>;
        /**
         * The configuration of a line chart.
         */
        chartConfiguration?: pulumi.Input<inputs.quicksight.DashboardLineChartConfigurationArgs>;
        /**
         * The column hierarchy that is used during drill-downs and drill-ups.
         */
        columnHierarchies?: pulumi.Input<pulumi.Input<inputs.quicksight.DashboardColumnHierarchyArgs>[]>;
        /**
         * The subtitle that is displayed on the visual.
         */
        subtitle?: pulumi.Input<inputs.quicksight.DashboardVisualSubtitleLabelOptionsArgs>;
        /**
         * The title that is displayed on the visual.
         */
        title?: pulumi.Input<inputs.quicksight.DashboardVisualTitleLabelOptionsArgs>;
        /**
         * The alt text for the visual.
         */
        visualContentAltText?: pulumi.Input<string>;
        /**
         * The unique identifier of a visual. This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers.
         */
        visualId: pulumi.Input<string>;
    }
    interface DashboardLineSeriesAxisDisplayOptionsArgs {
        /**
         * The options that determine the presentation of the line series axis.
         */
        axisOptions?: pulumi.Input<inputs.quicksight.DashboardAxisDisplayOptionsArgs>;
        /**
         * The configuration options that determine how missing data is treated during the rendering of a line chart.
         */
        missingDataConfigurations?: pulumi.Input<pulumi.Input<inputs.quicksight.DashboardMissingDataConfigurationArgs>[]>;
    }
    interface DashboardLinkSharingConfigurationArgs {
        /**
         * A structure that contains the permissions of a shareable link.
         */
        permissions?: pulumi.Input<pulumi.Input<inputs.quicksight.DashboardResourcePermissionArgs>[]>;
    }
    interface DashboardListControlDisplayOptionsArgs {
        /**
         * The configuration of info icon label options.
         */
        infoIconLabelOptions?: pulumi.Input<inputs.quicksight.DashboardSheetControlInfoIconLabelOptionsArgs>;
        /**
         * The configuration of the search options in a list control.
         */
        searchOptions?: pulumi.Input<inputs.quicksight.DashboardListControlSearchOptionsArgs>;
        /**
         * The configuration of the `Select all` options in a list control.
         */
        selectAllOptions?: pulumi.Input<inputs.quicksight.DashboardListControlSelectAllOptionsArgs>;
        /**
         * The options to configure the title visibility, name, and font size.
         */
        titleOptions?: pulumi.Input<inputs.quicksight.DashboardLabelOptionsArgs>;
    }
    interface DashboardListControlSearchOptionsArgs {
        /**
         * The visibility configuration of the search options in a list control.
         */
        visibility?: pulumi.Input<enums.quicksight.DashboardVisibility>;
    }
    interface DashboardListControlSelectAllOptionsArgs {
        /**
         * The visibility configuration of the `Select all` options in a list control.
         */
        visibility?: pulumi.Input<enums.quicksight.DashboardVisibility>;
    }
    interface DashboardLoadingAnimationArgs {
        /**
         * The visibility configuration of `LoadingAnimation` .
         */
        visibility?: pulumi.Input<enums.quicksight.DashboardVisibility>;
    }
    interface DashboardLocalNavigationConfigurationArgs {
        /**
         * The sheet that is targeted for navigation in the same analysis.
         */
        targetSheetId: pulumi.Input<string>;
    }
    interface DashboardLongFormatTextArgs {
        /**
         * Plain text format.
         */
        plainText?: pulumi.Input<string>;
        /**
         * Rich text. Examples of rich text include bold, underline, and italics.
         */
        richText?: pulumi.Input<string>;
    }
    interface DashboardMappedDataSetParameterArgs {
        /**
         * A unique name that identifies a dataset within the analysis or dashboard.
         */
        dataSetIdentifier: pulumi.Input<string>;
        /**
         * The name of the dataset parameter.
         */
        dataSetParameterName: pulumi.Input<string>;
    }
    interface DashboardMaximumLabelTypeArgs {
        /**
         * The visibility of the maximum label.
         */
        visibility?: pulumi.Input<enums.quicksight.DashboardVisibility>;
    }
    interface DashboardMaximumMinimumComputationArgs {
        /**
         * The ID for a computation.
         */
        computationId: pulumi.Input<string>;
        /**
         * The name of a computation.
         */
        name?: pulumi.Input<string>;
        /**
         * The time field that is used in a computation.
         */
        time?: pulumi.Input<inputs.quicksight.DashboardDimensionFieldArgs>;
        /**
         * The type of computation. Choose one of the following options:
         *
         * - MAXIMUM: A maximum computation.
         * - MINIMUM: A minimum computation.
         */
        type: pulumi.Input<enums.quicksight.DashboardMaximumMinimumComputationType>;
        /**
         * The value field that is used in a computation.
         */
        value?: pulumi.Input<inputs.quicksight.DashboardMeasureFieldArgs>;
    }
    interface DashboardMeasureFieldArgs {
        /**
         * The calculated measure field only used in pivot tables.
         */
        calculatedMeasureField?: pulumi.Input<inputs.quicksight.DashboardCalculatedMeasureFieldArgs>;
        /**
         * The measure type field with categorical type columns.
         */
        categoricalMeasureField?: pulumi.Input<inputs.quicksight.DashboardCategoricalMeasureFieldArgs>;
        /**
         * The measure type field with date type columns.
         */
        dateMeasureField?: pulumi.Input<inputs.quicksight.DashboardDateMeasureFieldArgs>;
        /**
         * The measure type field with numerical type columns.
         */
        numericalMeasureField?: pulumi.Input<inputs.quicksight.DashboardNumericalMeasureFieldArgs>;
    }
    interface DashboardMetricComparisonComputationArgs {
        /**
         * The ID for a computation.
         */
        computationId: pulumi.Input<string>;
        /**
         * The field that is used in a metric comparison from value setup.
         */
        fromValue?: pulumi.Input<inputs.quicksight.DashboardMeasureFieldArgs>;
        /**
         * The name of a computation.
         */
        name?: pulumi.Input<string>;
        /**
         * The field that is used in a metric comparison to value setup.
         */
        targetValue?: pulumi.Input<inputs.quicksight.DashboardMeasureFieldArgs>;
        /**
         * The time field that is used in a computation.
         */
        time?: pulumi.Input<inputs.quicksight.DashboardDimensionFieldArgs>;
    }
    interface DashboardMinimumLabelTypeArgs {
        /**
         * The visibility of the minimum label.
         */
        visibility?: pulumi.Input<enums.quicksight.DashboardVisibility>;
    }
    interface DashboardMissingDataConfigurationArgs {
        /**
         * The treatment option that determines how missing data should be rendered. Choose from the following options:
         *
         * - `INTERPOLATE` : Interpolate missing values between the prior and the next known value.
         * - `SHOW_AS_ZERO` : Show missing values as the value `0` .
         * - `SHOW_AS_BLANK` : Display a blank space when rendering missing data.
         */
        treatmentOption?: pulumi.Input<enums.quicksight.DashboardMissingDataTreatmentOption>;
    }
    interface DashboardNegativeValueConfigurationArgs {
        /**
         * Determines the display mode of the negative value configuration.
         */
        displayMode: pulumi.Input<enums.quicksight.DashboardNegativeValueDisplayMode>;
    }
    interface DashboardNestedFilterArgs {
        /**
         * The column that the filter is applied to.
         */
        column: pulumi.Input<inputs.quicksight.DashboardColumnIdentifierArgs>;
        /**
         * An identifier that uniquely identifies a filter within a dashboard, analysis, or template.
         */
        filterId: pulumi.Input<string>;
        /**
         * A boolean condition to include or exclude the subset that is defined by the values of the nested inner filter.
         */
        includeInnerSet: pulumi.Input<boolean>;
        /**
         * The `InnerFilter` defines the subset of data to be used with the `NestedFilter` .
         */
        innerFilter: pulumi.Input<inputs.quicksight.DashboardInnerFilterArgs>;
    }
    interface DashboardNullValueFormatConfigurationArgs {
        /**
         * Determines the null string of null values.
         */
        nullString: pulumi.Input<string>;
    }
    interface DashboardNumberDisplayFormatConfigurationArgs {
        /**
         * The option that determines the decimal places configuration.
         */
        decimalPlacesConfiguration?: pulumi.Input<inputs.quicksight.DashboardDecimalPlacesConfigurationArgs>;
        /**
         * The options that determine the negative value configuration.
         */
        negativeValueConfiguration?: pulumi.Input<inputs.quicksight.DashboardNegativeValueConfigurationArgs>;
        /**
         * The options that determine the null value format configuration.
         */
        nullValueFormatConfiguration?: pulumi.Input<inputs.quicksight.DashboardNullValueFormatConfigurationArgs>;
        /**
         * Determines the number scale value of the number format.
         */
        numberScale?: pulumi.Input<enums.quicksight.DashboardNumberScale>;
        /**
         * Determines the prefix value of the number format.
         */
        prefix?: pulumi.Input<string>;
        /**
         * The options that determine the numeric separator configuration.
         */
        separatorConfiguration?: pulumi.Input<inputs.quicksight.DashboardNumericSeparatorConfigurationArgs>;
        /**
         * Determines the suffix value of the number format.
         */
        suffix?: pulumi.Input<string>;
    }
    interface DashboardNumberFormatConfigurationArgs {
        /**
         * The options that determine the numeric format configuration.
         */
        formatConfiguration?: pulumi.Input<inputs.quicksight.DashboardNumericFormatConfigurationArgs>;
    }
    interface DashboardNumericAxisOptionsArgs {
        /**
         * The range setup of a numeric axis.
         */
        range?: pulumi.Input<inputs.quicksight.DashboardAxisDisplayRangeArgs>;
        /**
         * The scale setup of a numeric axis.
         */
        scale?: pulumi.Input<inputs.quicksight.DashboardAxisScaleArgs>;
    }
    interface DashboardNumericEqualityDrillDownFilterArgs {
        /**
         * The column that the filter is applied to.
         */
        column: pulumi.Input<inputs.quicksight.DashboardColumnIdentifierArgs>;
        /**
         * The value of the double input numeric drill down filter.
         */
        value: pulumi.Input<number>;
    }
    interface DashboardNumericEqualityFilterArgs {
        /**
         * The aggregation function of the filter.
         */
        aggregationFunction?: pulumi.Input<inputs.quicksight.DashboardAggregationFunctionArgs>;
        /**
         * The column that the filter is applied to.
         */
        column: pulumi.Input<inputs.quicksight.DashboardColumnIdentifierArgs>;
        /**
         * The default configurations for the associated controls. This applies only for filters that are scoped to multiple sheets.
         */
        defaultFilterControlConfiguration?: pulumi.Input<inputs.quicksight.DashboardDefaultFilterControlConfigurationArgs>;
        /**
         * An identifier that uniquely identifies a filter within a dashboard, analysis, or template.
         */
        filterId: pulumi.Input<string>;
        /**
         * The match operator that is used to determine if a filter should be applied.
         */
        matchOperator: pulumi.Input<enums.quicksight.DashboardNumericEqualityMatchOperator>;
        /**
         * This option determines how null values should be treated when filtering data.
         *
         * - `ALL_VALUES` : Include null values in filtered results.
         * - `NULLS_ONLY` : Only include null values in filtered results.
         * - `NON_NULLS_ONLY` : Exclude null values from filtered results.
         */
        nullOption: pulumi.Input<enums.quicksight.DashboardFilterNullOption>;
        /**
         * The parameter whose value should be used for the filter value.
         */
        parameterName?: pulumi.Input<string>;
        /**
         * Select all of the values. Null is not the assigned value of select all.
         *
         * - `FILTER_ALL_VALUES`
         */
        selectAllOptions?: pulumi.Input<enums.quicksight.DashboardNumericFilterSelectAllOptions>;
        /**
         * The input value.
         */
        value?: pulumi.Input<number>;
    }
    interface DashboardNumericFormatConfigurationArgs {
        /**
         * The options that determine the currency display format configuration.
         */
        currencyDisplayFormatConfiguration?: pulumi.Input<inputs.quicksight.DashboardCurrencyDisplayFormatConfigurationArgs>;
        /**
         * The options that determine the number display format configuration.
         */
        numberDisplayFormatConfiguration?: pulumi.Input<inputs.quicksight.DashboardNumberDisplayFormatConfigurationArgs>;
        /**
         * The options that determine the percentage display format configuration.
         */
        percentageDisplayFormatConfiguration?: pulumi.Input<inputs.quicksight.DashboardPercentageDisplayFormatConfigurationArgs>;
    }
    interface DashboardNumericRangeFilterArgs {
        /**
         * The aggregation function of the filter.
         */
        aggregationFunction?: pulumi.Input<inputs.quicksight.DashboardAggregationFunctionArgs>;
        /**
         * The column that the filter is applied to.
         */
        column: pulumi.Input<inputs.quicksight.DashboardColumnIdentifierArgs>;
        /**
         * The default configurations for the associated controls. This applies only for filters that are scoped to multiple sheets.
         */
        defaultFilterControlConfiguration?: pulumi.Input<inputs.quicksight.DashboardDefaultFilterControlConfigurationArgs>;
        /**
         * An identifier that uniquely identifies a filter within a dashboard, analysis, or template.
         */
        filterId: pulumi.Input<string>;
        /**
         * Determines whether the maximum value in the filter value range should be included in the filtered results.
         */
        includeMaximum?: pulumi.Input<boolean>;
        /**
         * Determines whether the minimum value in the filter value range should be included in the filtered results.
         */
        includeMinimum?: pulumi.Input<boolean>;
        /**
         * This option determines how null values should be treated when filtering data.
         *
         * - `ALL_VALUES` : Include null values in filtered results.
         * - `NULLS_ONLY` : Only include null values in filtered results.
         * - `NON_NULLS_ONLY` : Exclude null values from filtered results.
         */
        nullOption: pulumi.Input<enums.quicksight.DashboardFilterNullOption>;
        /**
         * The maximum value for the filter value range.
         */
        rangeMaximum?: pulumi.Input<inputs.quicksight.DashboardNumericRangeFilterValueArgs>;
        /**
         * The minimum value for the filter value range.
         */
        rangeMinimum?: pulumi.Input<inputs.quicksight.DashboardNumericRangeFilterValueArgs>;
        /**
         * Select all of the values. Null is not the assigned value of select all.
         *
         * - `FILTER_ALL_VALUES`
         */
        selectAllOptions?: pulumi.Input<enums.quicksight.DashboardNumericFilterSelectAllOptions>;
    }
    interface DashboardNumericRangeFilterValueArgs {
        /**
         * The parameter that is used in the numeric range.
         */
        parameter?: pulumi.Input<string>;
        /**
         * The static value of the numeric range filter.
         */
        staticValue?: pulumi.Input<number>;
    }
    interface DashboardNumericSeparatorConfigurationArgs {
        /**
         * Determines the decimal separator.
         */
        decimalSeparator?: pulumi.Input<enums.quicksight.DashboardNumericSeparatorSymbol>;
        /**
         * The options that determine the thousands separator configuration.
         */
        thousandsSeparator?: pulumi.Input<inputs.quicksight.DashboardThousandSeparatorOptionsArgs>;
    }
    interface DashboardNumericalAggregationFunctionArgs {
        /**
         * An aggregation based on the percentile of values in a dimension or measure.
         */
        percentileAggregation?: pulumi.Input<inputs.quicksight.DashboardPercentileAggregationArgs>;
        /**
         * Built-in aggregation functions for numerical values.
         *
         * - `SUM` : The sum of a dimension or measure.
         * - `AVERAGE` : The average of a dimension or measure.
         * - `MIN` : The minimum value of a dimension or measure.
         * - `MAX` : The maximum value of a dimension or measure.
         * - `COUNT` : The count of a dimension or measure.
         * - `DISTINCT_COUNT` : The count of distinct values in a dimension or measure.
         * - `VAR` : The variance of a dimension or measure.
         * - `VARP` : The partitioned variance of a dimension or measure.
         * - `STDEV` : The standard deviation of a dimension or measure.
         * - `STDEVP` : The partitioned standard deviation of a dimension or measure.
         * - `MEDIAN` : The median value of a dimension or measure.
         */
        simpleNumericalAggregation?: pulumi.Input<enums.quicksight.DashboardSimpleNumericalAggregationFunction>;
    }
    interface DashboardNumericalDimensionFieldArgs {
        /**
         * The column that is used in the `NumericalDimensionField` .
         */
        column: pulumi.Input<inputs.quicksight.DashboardColumnIdentifierArgs>;
        /**
         * The custom field ID.
         */
        fieldId: pulumi.Input<string>;
        /**
         * The format configuration of the field.
         */
        formatConfiguration?: pulumi.Input<inputs.quicksight.DashboardNumberFormatConfigurationArgs>;
        /**
         * The custom hierarchy ID.
         */
        hierarchyId?: pulumi.Input<string>;
    }
    interface DashboardNumericalMeasureFieldArgs {
        /**
         * The aggregation function of the measure field.
         */
        aggregationFunction?: pulumi.Input<inputs.quicksight.DashboardNumericalAggregationFunctionArgs>;
        /**
         * The column that is used in the `NumericalMeasureField` .
         */
        column: pulumi.Input<inputs.quicksight.DashboardColumnIdentifierArgs>;
        /**
         * The custom field ID.
         */
        fieldId: pulumi.Input<string>;
        /**
         * The format configuration of the field.
         */
        formatConfiguration?: pulumi.Input<inputs.quicksight.DashboardNumberFormatConfigurationArgs>;
    }
    interface DashboardPaginationConfigurationArgs {
        /**
         * Indicates the page number.
         */
        pageNumber: pulumi.Input<number>;
        /**
         * Indicates how many items render in one page.
         */
        pageSize: pulumi.Input<number>;
    }
    interface DashboardPanelConfigurationArgs {
        /**
         * Sets the background color for each panel.
         */
        backgroundColor?: pulumi.Input<string>;
        /**
         * Determines whether or not a background for each small multiples panel is rendered.
         */
        backgroundVisibility?: pulumi.Input<enums.quicksight.DashboardVisibility>;
        /**
         * Sets the line color of panel borders.
         */
        borderColor?: pulumi.Input<string>;
        /**
         * Sets the line style of panel borders.
         */
        borderStyle?: pulumi.Input<enums.quicksight.DashboardPanelBorderStyle>;
        /**
         * String based length that is composed of value and unit in px
         */
        borderThickness?: pulumi.Input<string>;
        /**
         * Determines whether or not each panel displays a border.
         */
        borderVisibility?: pulumi.Input<enums.quicksight.DashboardVisibility>;
        /**
         * String based length that is composed of value and unit in px
         */
        gutterSpacing?: pulumi.Input<string>;
        /**
         * Determines whether or not negative space between sibling panels is rendered.
         */
        gutterVisibility?: pulumi.Input<enums.quicksight.DashboardVisibility>;
        /**
         * Configures the title display within each small multiples panel.
         */
        title?: pulumi.Input<inputs.quicksight.DashboardPanelTitleOptionsArgs>;
    }
    interface DashboardPanelTitleOptionsArgs {
        fontConfiguration?: pulumi.Input<inputs.quicksight.DashboardFontConfigurationArgs>;
        /**
         * Sets the horizontal text alignment of the title within each panel.
         */
        horizontalTextAlignment?: pulumi.Input<enums.quicksight.DashboardHorizontalTextAlignment>;
        /**
         * Determines whether or not panel titles are displayed.
         */
        visibility?: pulumi.Input<enums.quicksight.DashboardVisibility>;
    }
    interface DashboardParameterControlArgs {
        /**
         * A control from a date parameter that specifies date and time.
         */
        dateTimePicker?: pulumi.Input<inputs.quicksight.DashboardParameterDateTimePickerControlArgs>;
        /**
         * A control to display a dropdown list with buttons that are used to select a single value.
         */
        dropdown?: pulumi.Input<inputs.quicksight.DashboardParameterDropDownControlArgs>;
        /**
         * A control to display a list with buttons or boxes that are used to select either a single value or multiple values.
         */
        list?: pulumi.Input<inputs.quicksight.DashboardParameterListControlArgs>;
        /**
         * A control to display a horizontal toggle bar. This is used to change a value by sliding the toggle.
         */
        slider?: pulumi.Input<inputs.quicksight.DashboardParameterSliderControlArgs>;
        /**
         * A control to display a text box that is used to enter multiple entries.
         */
        textArea?: pulumi.Input<inputs.quicksight.DashboardParameterTextAreaControlArgs>;
        /**
         * A control to display a text box that is used to enter a single entry.
         */
        textField?: pulumi.Input<inputs.quicksight.DashboardParameterTextFieldControlArgs>;
    }
    interface DashboardParameterDateTimePickerControlArgs {
        /**
         * The display options of a control.
         */
        displayOptions?: pulumi.Input<inputs.quicksight.DashboardDateTimePickerControlDisplayOptionsArgs>;
        /**
         * The ID of the `ParameterDateTimePickerControl` .
         */
        parameterControlId: pulumi.Input<string>;
        /**
         * The name of the `ParameterDateTimePickerControl` .
         */
        sourceParameterName: pulumi.Input<string>;
        /**
         * The title of the `ParameterDateTimePickerControl` .
         */
        title: pulumi.Input<string>;
    }
    interface DashboardParameterDeclarationArgs {
        /**
         * A parameter declaration for the `DateTime` data type.
         */
        dateTimeParameterDeclaration?: pulumi.Input<inputs.quicksight.DashboardDateTimeParameterDeclarationArgs>;
        /**
         * A parameter declaration for the `Decimal` data type.
         */
        decimalParameterDeclaration?: pulumi.Input<inputs.quicksight.DashboardDecimalParameterDeclarationArgs>;
        /**
         * A parameter declaration for the `Integer` data type.
         */
        integerParameterDeclaration?: pulumi.Input<inputs.quicksight.DashboardIntegerParameterDeclarationArgs>;
        /**
         * A parameter declaration for the `String` data type.
         */
        stringParameterDeclaration?: pulumi.Input<inputs.quicksight.DashboardStringParameterDeclarationArgs>;
    }
    interface DashboardParameterDropDownControlArgs {
        /**
         * The values that are displayed in a control can be configured to only show values that are valid based on what's selected in other controls.
         */
        cascadingControlConfiguration?: pulumi.Input<inputs.quicksight.DashboardCascadingControlConfigurationArgs>;
        /**
         * The visibility configuration of the Apply button on a `ParameterDropDownControl` .
         */
        commitMode?: pulumi.Input<enums.quicksight.DashboardCommitMode>;
        /**
         * The display options of a control.
         */
        displayOptions?: pulumi.Input<inputs.quicksight.DashboardDropDownControlDisplayOptionsArgs>;
        /**
         * The ID of the `ParameterDropDownControl` .
         */
        parameterControlId: pulumi.Input<string>;
        /**
         * A list of selectable values that are used in a control.
         */
        selectableValues?: pulumi.Input<inputs.quicksight.DashboardParameterSelectableValuesArgs>;
        /**
         * The source parameter name of the `ParameterDropDownControl` .
         */
        sourceParameterName: pulumi.Input<string>;
        /**
         * The title of the `ParameterDropDownControl` .
         */
        title: pulumi.Input<string>;
        /**
         * The type parameter name of the `ParameterDropDownControl` .
         */
        type?: pulumi.Input<enums.quicksight.DashboardSheetControlListType>;
    }
    interface DashboardParameterListControlArgs {
        /**
         * The values that are displayed in a control can be configured to only show values that are valid based on what's selected in other controls.
         */
        cascadingControlConfiguration?: pulumi.Input<inputs.quicksight.DashboardCascadingControlConfigurationArgs>;
        /**
         * The display options of a control.
         */
        displayOptions?: pulumi.Input<inputs.quicksight.DashboardListControlDisplayOptionsArgs>;
        /**
         * The ID of the `ParameterListControl` .
         */
        parameterControlId: pulumi.Input<string>;
        /**
         * A list of selectable values that are used in a control.
         */
        selectableValues?: pulumi.Input<inputs.quicksight.DashboardParameterSelectableValuesArgs>;
        /**
         * The source parameter name of the `ParameterListControl` .
         */
        sourceParameterName: pulumi.Input<string>;
        /**
         * The title of the `ParameterListControl` .
         */
        title: pulumi.Input<string>;
        /**
         * The type of `ParameterListControl` .
         */
        type?: pulumi.Input<enums.quicksight.DashboardSheetControlListType>;
    }
    interface DashboardParameterSelectableValuesArgs {
        /**
         * The column identifier that fetches values from the data set.
         */
        linkToDataSetColumn?: pulumi.Input<inputs.quicksight.DashboardColumnIdentifierArgs>;
        /**
         * The values that are used in `ParameterSelectableValues` .
         */
        values?: pulumi.Input<pulumi.Input<string>[]>;
    }
    interface DashboardParameterSliderControlArgs {
        /**
         * The display options of a control.
         */
        displayOptions?: pulumi.Input<inputs.quicksight.DashboardSliderControlDisplayOptionsArgs>;
        /**
         * The larger value that is displayed at the right of the slider.
         */
        maximumValue: pulumi.Input<number>;
        /**
         * The smaller value that is displayed at the left of the slider.
         */
        minimumValue: pulumi.Input<number>;
        /**
         * The ID of the `ParameterSliderControl` .
         */
        parameterControlId: pulumi.Input<string>;
        /**
         * The source parameter name of the `ParameterSliderControl` .
         */
        sourceParameterName: pulumi.Input<string>;
        /**
         * The number of increments that the slider bar is divided into.
         */
        stepSize: pulumi.Input<number>;
        /**
         * The title of the `ParameterSliderControl` .
         */
        title: pulumi.Input<string>;
    }
    interface DashboardParameterTextAreaControlArgs {
        /**
         * The delimiter that is used to separate the lines in text.
         */
        delimiter?: pulumi.Input<string>;
        /**
         * The display options of a control.
         */
        displayOptions?: pulumi.Input<inputs.quicksight.DashboardTextAreaControlDisplayOptionsArgs>;
        /**
         * The ID of the `ParameterTextAreaControl` .
         */
        parameterControlId: pulumi.Input<string>;
        /**
         * The source parameter name of the `ParameterTextAreaControl` .
         */
        sourceParameterName: pulumi.Input<string>;
        /**
         * The title of the `ParameterTextAreaControl` .
         */
        title: pulumi.Input<string>;
    }
    interface DashboardParameterTextFieldControlArgs {
        /**
         * The display options of a control.
         */
        displayOptions?: pulumi.Input<inputs.quicksight.DashboardTextFieldControlDisplayOptionsArgs>;
        /**
         * The ID of the `ParameterTextFieldControl` .
         */
        parameterControlId: pulumi.Input<string>;
        /**
         * The source parameter name of the `ParameterTextFieldControl` .
         */
        sourceParameterName: pulumi.Input<string>;
        /**
         * The title of the `ParameterTextFieldControl` .
         */
        title: pulumi.Input<string>;
    }
    /**
     * <p>A list of Amazon QuickSight parameters and the list's override values.</p>
     */
    interface DashboardParametersArgs {
        /**
         * <p>The parameters that have a data type of date-time.</p>
         */
        dateTimeParameters?: pulumi.Input<pulumi.Input<inputs.quicksight.DashboardDateTimeParameterArgs>[]>;
        /**
         * <p>The parameters that have a data type of decimal.</p>
         */
        decimalParameters?: pulumi.Input<pulumi.Input<inputs.quicksight.DashboardDecimalParameterArgs>[]>;
        /**
         * <p>The parameters that have a data type of integer.</p>
         */
        integerParameters?: pulumi.Input<pulumi.Input<inputs.quicksight.DashboardIntegerParameterArgs>[]>;
        /**
         * <p>The parameters that have a data type of string.</p>
         */
        stringParameters?: pulumi.Input<pulumi.Input<inputs.quicksight.DashboardStringParameterArgs>[]>;
    }
    interface DashboardPercentVisibleRangeArgs {
        /**
         * The lower bound of the range.
         */
        from?: pulumi.Input<number>;
        /**
         * The top bound of the range.
         */
        to?: pulumi.Input<number>;
    }
    interface DashboardPercentageDisplayFormatConfigurationArgs {
        /**
         * The option that determines the decimal places configuration.
         */
        decimalPlacesConfiguration?: pulumi.Input<inputs.quicksight.DashboardDecimalPlacesConfigurationArgs>;
        /**
         * The options that determine the negative value configuration.
         */
        negativeValueConfiguration?: pulumi.Input<inputs.quicksight.DashboardNegativeValueConfigurationArgs>;
        /**
         * The options that determine the null value format configuration.
         */
        nullValueFormatConfiguration?: pulumi.Input<inputs.quicksight.DashboardNullValueFormatConfigurationArgs>;
        /**
         * Determines the prefix value of the percentage format.
         */
        prefix?: pulumi.Input<string>;
        /**
         * The options that determine the numeric separator configuration.
         */
        separatorConfiguration?: pulumi.Input<inputs.quicksight.DashboardNumericSeparatorConfigurationArgs>;
        /**
         * Determines the suffix value of the percentage format.
         */
        suffix?: pulumi.Input<string>;
    }
    interface DashboardPercentileAggregationArgs {
        /**
         * The percentile value. This value can be any numeric constant 0–100. A percentile value of 50 computes the median value of the measure.
         */
        percentileValue?: pulumi.Input<number>;
    }
    interface DashboardPeriodOverPeriodComputationArgs {
        /**
         * The ID for a computation.
         */
        computationId: pulumi.Input<string>;
        /**
         * The name of a computation.
         */
        name?: pulumi.Input<string>;
        /**
         * The time field that is used in a computation.
         */
        time?: pulumi.Input<inputs.quicksight.DashboardDimensionFieldArgs>;
        /**
         * The value field that is used in a computation.
         */
        value?: pulumi.Input<inputs.quicksight.DashboardMeasureFieldArgs>;
    }
    interface DashboardPeriodToDateComputationArgs {
        /**
         * The ID for a computation.
         */
        computationId: pulumi.Input<string>;
        /**
         * The name of a computation.
         */
        name?: pulumi.Input<string>;
        /**
         * The time granularity setup of period to date computation. Choose from the following options:
         *
         * - YEAR: Year to date.
         * - MONTH: Month to date.
         */
        periodTimeGranularity?: pulumi.Input<enums.quicksight.DashboardTimeGranularity>;
        /**
         * The time field that is used in a computation.
         */
        time?: pulumi.Input<inputs.quicksight.DashboardDimensionFieldArgs>;
        /**
         * The value field that is used in a computation.
         */
        value?: pulumi.Input<inputs.quicksight.DashboardMeasureFieldArgs>;
    }
    interface DashboardPieChartAggregatedFieldWellsArgs {
        /**
         * The category (group/color) field wells of a pie chart.
         */
        category?: pulumi.Input<pulumi.Input<inputs.quicksight.DashboardDimensionFieldArgs>[]>;
        /**
         * The small multiples field well of a pie chart.
         */
        smallMultiples?: pulumi.Input<pulumi.Input<inputs.quicksight.DashboardDimensionFieldArgs>[]>;
        /**
         * The value field wells of a pie chart. Values are aggregated based on categories.
         */
        values?: pulumi.Input<pulumi.Input<inputs.quicksight.DashboardMeasureFieldArgs>[]>;
    }
    interface DashboardPieChartConfigurationArgs {
        /**
         * The label options of the group/color that is displayed in a pie chart.
         */
        categoryLabelOptions?: pulumi.Input<inputs.quicksight.DashboardChartAxisLabelOptionsArgs>;
        /**
         * The contribution analysis (anomaly configuration) setup of the visual.
         */
        contributionAnalysisDefaults?: pulumi.Input<pulumi.Input<inputs.quicksight.DashboardContributionAnalysisDefaultArgs>[]>;
        /**
         * The options that determine if visual data labels are displayed.
         */
        dataLabels?: pulumi.Input<inputs.quicksight.DashboardDataLabelOptionsArgs>;
        /**
         * The options that determine the shape of the chart. This option determines whether the chart is a pie chart or a donut chart.
         */
        donutOptions?: pulumi.Input<inputs.quicksight.DashboardDonutOptionsArgs>;
        /**
         * The field wells of the visual.
         */
        fieldWells?: pulumi.Input<inputs.quicksight.DashboardPieChartFieldWellsArgs>;
        /**
         * The general visual interactions setup for a visual.
         */
        interactions?: pulumi.Input<inputs.quicksight.DashboardVisualInteractionOptionsArgs>;
        /**
         * The legend display setup of the visual.
         */
        legend?: pulumi.Input<inputs.quicksight.DashboardLegendOptionsArgs>;
        /**
         * The small multiples setup for the visual.
         */
        smallMultiplesOptions?: pulumi.Input<inputs.quicksight.DashboardSmallMultiplesOptionsArgs>;
        /**
         * The sort configuration of a pie chart.
         */
        sortConfiguration?: pulumi.Input<inputs.quicksight.DashboardPieChartSortConfigurationArgs>;
        /**
         * The tooltip display setup of the visual.
         */
        tooltip?: pulumi.Input<inputs.quicksight.DashboardTooltipOptionsArgs>;
        /**
         * The label options for the value that is displayed in a pie chart.
         */
        valueLabelOptions?: pulumi.Input<inputs.quicksight.DashboardChartAxisLabelOptionsArgs>;
        /**
         * The palette (chart color) display setup of the visual.
         */
        visualPalette?: pulumi.Input<inputs.quicksight.DashboardVisualPaletteArgs>;
    }
    interface DashboardPieChartFieldWellsArgs {
        /**
         * The field well configuration of a pie chart.
         */
        pieChartAggregatedFieldWells?: pulumi.Input<inputs.quicksight.DashboardPieChartAggregatedFieldWellsArgs>;
    }
    interface DashboardPieChartSortConfigurationArgs {
        /**
         * The limit on the number of categories that are displayed in a pie chart.
         */
        categoryItemsLimit?: pulumi.Input<inputs.quicksight.DashboardItemsLimitConfigurationArgs>;
        /**
         * The sort configuration of the category fields.
         */
        categorySort?: pulumi.Input<pulumi.Input<inputs.quicksight.DashboardFieldSortOptionsArgs>[]>;
        /**
         * The limit on the number of small multiples panels that are displayed.
         */
        smallMultiplesLimitConfiguration?: pulumi.Input<inputs.quicksight.DashboardItemsLimitConfigurationArgs>;
        /**
         * The sort configuration of the small multiples field.
         */
        smallMultiplesSort?: pulumi.Input<pulumi.Input<inputs.quicksight.DashboardFieldSortOptionsArgs>[]>;
    }
    interface DashboardPieChartVisualArgs {
        /**
         * The list of custom actions that are configured for a visual.
         */
        actions?: pulumi.Input<pulumi.Input<inputs.quicksight.DashboardVisualCustomActionArgs>[]>;
        /**
         * The configuration of a pie chart.
         */
        chartConfiguration?: pulumi.Input<inputs.quicksight.DashboardPieChartConfigurationArgs>;
        /**
         * The column hierarchy that is used during drill-downs and drill-ups.
         */
        columnHierarchies?: pulumi.Input<pulumi.Input<inputs.quicksight.DashboardColumnHierarchyArgs>[]>;
        /**
         * The subtitle that is displayed on the visual.
         */
        subtitle?: pulumi.Input<inputs.quicksight.DashboardVisualSubtitleLabelOptionsArgs>;
        /**
         * The title that is displayed on the visual.
         */
        title?: pulumi.Input<inputs.quicksight.DashboardVisualTitleLabelOptionsArgs>;
        /**
         * The alt text for the visual.
         */
        visualContentAltText?: pulumi.Input<string>;
        /**
         * The unique identifier of a visual. This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers.
         */
        visualId: pulumi.Input<string>;
    }
    interface DashboardPivotFieldSortOptionsArgs {
        /**
         * The field ID for the field sort options.
         */
        fieldId: pulumi.Input<string>;
        /**
         * The sort by field for the field sort options.
         */
        sortBy: pulumi.Input<inputs.quicksight.DashboardPivotTableSortByArgs>;
    }
    interface DashboardPivotTableAggregatedFieldWellsArgs {
        /**
         * The columns field well for a pivot table. Values are grouped by columns fields.
         */
        columns?: pulumi.Input<pulumi.Input<inputs.quicksight.DashboardDimensionFieldArgs>[]>;
        /**
         * The rows field well for a pivot table. Values are grouped by rows fields.
         */
        rows?: pulumi.Input<pulumi.Input<inputs.quicksight.DashboardDimensionFieldArgs>[]>;
        /**
         * The values field well for a pivot table. Values are aggregated based on rows and columns fields.
         */
        values?: pulumi.Input<pulumi.Input<inputs.quicksight.DashboardMeasureFieldArgs>[]>;
    }
    interface DashboardPivotTableCellConditionalFormattingArgs {
        /**
         * The field ID of the cell for conditional formatting.
         */
        fieldId: pulumi.Input<string>;
        /**
         * The scope of the cell for conditional formatting.
         */
        scope?: pulumi.Input<inputs.quicksight.DashboardPivotTableConditionalFormattingScopeArgs>;
        /**
         * A list of cell scopes for conditional formatting.
         */
        scopes?: pulumi.Input<pulumi.Input<inputs.quicksight.DashboardPivotTableConditionalFormattingScopeArgs>[]>;
        /**
         * The text format of the cell for conditional formatting.
         */
        textFormat?: pulumi.Input<inputs.quicksight.DashboardTextConditionalFormatArgs>;
    }
    interface DashboardPivotTableConditionalFormattingArgs {
        /**
         * Conditional formatting options for a `PivotTableVisual` .
         */
        conditionalFormattingOptions?: pulumi.Input<pulumi.Input<inputs.quicksight.DashboardPivotTableConditionalFormattingOptionArgs>[]>;
    }
    interface DashboardPivotTableConditionalFormattingOptionArgs {
        /**
         * The cell conditional formatting option for a pivot table.
         */
        cell?: pulumi.Input<inputs.quicksight.DashboardPivotTableCellConditionalFormattingArgs>;
    }
    interface DashboardPivotTableConditionalFormattingScopeArgs {
        /**
         * The role (field, field total, grand total) of the cell for conditional formatting.
         */
        role?: pulumi.Input<enums.quicksight.DashboardPivotTableConditionalFormattingScopeRole>;
    }
    interface DashboardPivotTableConfigurationArgs {
        /**
         * The field options for a pivot table visual.
         */
        fieldOptions?: pulumi.Input<inputs.quicksight.DashboardPivotTableFieldOptionsArgs>;
        /**
         * The field wells of the visual.
         */
        fieldWells?: pulumi.Input<inputs.quicksight.DashboardPivotTableFieldWellsArgs>;
        /**
         * The general visual interactions setup for a visual.
         */
        interactions?: pulumi.Input<inputs.quicksight.DashboardVisualInteractionOptionsArgs>;
        /**
         * The paginated report options for a pivot table visual.
         */
        paginatedReportOptions?: pulumi.Input<inputs.quicksight.DashboardPivotTablePaginatedReportOptionsArgs>;
        /**
         * The sort configuration for a `PivotTableVisual` .
         */
        sortConfiguration?: pulumi.Input<inputs.quicksight.DashboardPivotTableSortConfigurationArgs>;
        /**
         * The table options for a pivot table visual.
         */
        tableOptions?: pulumi.Input<inputs.quicksight.DashboardPivotTableOptionsArgs>;
        /**
         * The total options for a pivot table visual.
         */
        totalOptions?: pulumi.Input<inputs.quicksight.DashboardPivotTableTotalOptionsArgs>;
    }
    interface DashboardPivotTableDataPathOptionArgs {
        /**
         * The list of data path values for the data path options.
         */
        dataPathList: pulumi.Input<pulumi.Input<inputs.quicksight.DashboardDataPathValueArgs>[]>;
        /**
         * String based length that is composed of value and unit in px
         */
        width?: pulumi.Input<string>;
    }
    interface DashboardPivotTableFieldCollapseStateOptionArgs {
        /**
         * The state of the field target of a pivot table. Choose one of the following options:
         *
         * - `COLLAPSED`
         * - `EXPANDED`
         */
        state?: pulumi.Input<enums.quicksight.DashboardPivotTableFieldCollapseState>;
        /**
         * A tagged-union object that sets the collapse state.
         */
        target: pulumi.Input<inputs.quicksight.DashboardPivotTableFieldCollapseStateTargetArgs>;
    }
    interface DashboardPivotTableFieldCollapseStateTargetArgs {
        /**
         * The data path of the pivot table's header. Used to set the collapse state.
         */
        fieldDataPathValues?: pulumi.Input<pulumi.Input<inputs.quicksight.DashboardDataPathValueArgs>[]>;
        /**
         * The field ID of the pivot table that the collapse state needs to be set to.
         */
        fieldId?: pulumi.Input<string>;
    }
    interface DashboardPivotTableFieldOptionArgs {
        /**
         * The custom label of the pivot table field.
         */
        customLabel?: pulumi.Input<string>;
        /**
         * The field ID of the pivot table field.
         */
        fieldId: pulumi.Input<string>;
        /**
         * The visibility of the pivot table field.
         */
        visibility?: pulumi.Input<enums.quicksight.DashboardVisibility>;
    }
    interface DashboardPivotTableFieldOptionsArgs {
        /**
         * The collapse state options for the pivot table field options.
         */
        collapseStateOptions?: pulumi.Input<pulumi.Input<inputs.quicksight.DashboardPivotTableFieldCollapseStateOptionArgs>[]>;
        /**
         * The data path options for the pivot table field options.
         */
        dataPathOptions?: pulumi.Input<pulumi.Input<inputs.quicksight.DashboardPivotTableDataPathOptionArgs>[]>;
        /**
         * The selected field options for the pivot table field options.
         */
        selectedFieldOptions?: pulumi.Input<pulumi.Input<inputs.quicksight.DashboardPivotTableFieldOptionArgs>[]>;
    }
    interface DashboardPivotTableFieldSubtotalOptionsArgs {
        /**
         * The field ID of the subtotal options.
         */
        fieldId?: pulumi.Input<string>;
    }
    interface DashboardPivotTableFieldWellsArgs {
        /**
         * The aggregated field well for the pivot table.
         */
        pivotTableAggregatedFieldWells?: pulumi.Input<inputs.quicksight.DashboardPivotTableAggregatedFieldWellsArgs>;
    }
    interface DashboardPivotTableOptionsArgs {
        /**
         * The table cell style of cells.
         */
        cellStyle?: pulumi.Input<inputs.quicksight.DashboardTableCellStyleArgs>;
        /**
         * The visibility setting of a pivot table's collapsed row dimension fields. If the value of this structure is `HIDDEN` , all collapsed columns in a pivot table are automatically hidden. The default value is `VISIBLE` .
         */
        collapsedRowDimensionsVisibility?: pulumi.Input<enums.quicksight.DashboardVisibility>;
        /**
         * The table cell style of the column header.
         */
        columnHeaderStyle?: pulumi.Input<inputs.quicksight.DashboardTableCellStyleArgs>;
        /**
         * The visibility of the column names.
         */
        columnNamesVisibility?: pulumi.Input<enums.quicksight.DashboardVisibility>;
        /**
         * String based length that is composed of value and unit in px
         */
        defaultCellWidth?: pulumi.Input<string>;
        /**
         * The metric placement (row, column) options.
         */
        metricPlacement?: pulumi.Input<enums.quicksight.DashboardPivotTableMetricPlacement>;
        /**
         * The row alternate color options (widget status, row alternate colors).
         */
        rowAlternateColorOptions?: pulumi.Input<inputs.quicksight.DashboardRowAlternateColorOptionsArgs>;
        /**
         * The table cell style of row field names.
         */
        rowFieldNamesStyle?: pulumi.Input<inputs.quicksight.DashboardTableCellStyleArgs>;
        /**
         * The table cell style of the row headers.
         */
        rowHeaderStyle?: pulumi.Input<inputs.quicksight.DashboardTableCellStyleArgs>;
        /**
         * The options for the label that is located above the row headers. This option is only applicable when `RowsLayout` is set to `HIERARCHY` .
         */
        rowsLabelOptions?: pulumi.Input<inputs.quicksight.DashboardPivotTableRowsLabelOptionsArgs>;
        /**
         * The layout for the row dimension headers of a pivot table. Choose one of the following options.
         *
         * - `TABULAR` : (Default) Each row field is displayed in a separate column.
         * - `HIERARCHY` : All row fields are displayed in a single column. Indentation is used to differentiate row headers of different fields.
         */
        rowsLayout?: pulumi.Input<enums.quicksight.DashboardPivotTableRowsLayout>;
        /**
         * The visibility of the single metric options.
         */
        singleMetricVisibility?: pulumi.Input<enums.quicksight.DashboardVisibility>;
        /**
         * Determines the visibility of the pivot table.
         */
        toggleButtonsVisibility?: pulumi.Input<enums.quicksight.DashboardVisibility>;
    }
    interface DashboardPivotTablePaginatedReportOptionsArgs {
        /**
         * The visibility of the repeating header rows on each page.
         */
        overflowColumnHeaderVisibility?: pulumi.Input<enums.quicksight.DashboardVisibility>;
        /**
         * The visibility of the printing table overflow across pages.
         */
        verticalOverflowVisibility?: pulumi.Input<enums.quicksight.DashboardVisibility>;
    }
    interface DashboardPivotTableRowsLabelOptionsArgs {
        /**
         * The custom label string for the rows label.
         */
        customLabel?: pulumi.Input<string>;
        /**
         * The visibility of the rows label.
         */
        visibility?: pulumi.Input<enums.quicksight.DashboardVisibility>;
    }
    interface DashboardPivotTableSortByArgs {
        /**
         * The column sort (field id, direction) for the pivot table sort by options.
         */
        column?: pulumi.Input<inputs.quicksight.DashboardColumnSortArgs>;
        /**
         * The data path sort (data path value, direction) for the pivot table sort by options.
         */
        dataPath?: pulumi.Input<inputs.quicksight.DashboardDataPathSortArgs>;
        /**
         * The field sort (field id, direction) for the pivot table sort by options.
         */
        field?: pulumi.Input<inputs.quicksight.DashboardFieldSortArgs>;
    }
    interface DashboardPivotTableSortConfigurationArgs {
        /**
         * The field sort options for a pivot table sort configuration.
         */
        fieldSortOptions?: pulumi.Input<pulumi.Input<inputs.quicksight.DashboardPivotFieldSortOptionsArgs>[]>;
    }
    interface DashboardPivotTableTotalOptionsArgs {
        /**
         * The column subtotal options.
         */
        columnSubtotalOptions?: pulumi.Input<inputs.quicksight.DashboardSubtotalOptionsArgs>;
        /**
         * The column total options.
         */
        columnTotalOptions?: pulumi.Input<inputs.quicksight.DashboardPivotTotalOptionsArgs>;
        /**
         * The row subtotal options.
         */
        rowSubtotalOptions?: pulumi.Input<inputs.quicksight.DashboardSubtotalOptionsArgs>;
        /**
         * The row total options.
         */
        rowTotalOptions?: pulumi.Input<inputs.quicksight.DashboardPivotTotalOptionsArgs>;
    }
    interface DashboardPivotTableVisualArgs {
        /**
         * The list of custom actions that are configured for a visual.
         */
        actions?: pulumi.Input<pulumi.Input<inputs.quicksight.DashboardVisualCustomActionArgs>[]>;
        /**
         * The configuration settings of the visual.
         */
        chartConfiguration?: pulumi.Input<inputs.quicksight.DashboardPivotTableConfigurationArgs>;
        /**
         * The conditional formatting for a `PivotTableVisual` .
         */
        conditionalFormatting?: pulumi.Input<inputs.quicksight.DashboardPivotTableConditionalFormattingArgs>;
        /**
         * The subtitle that is displayed on the visual.
         */
        subtitle?: pulumi.Input<inputs.quicksight.DashboardVisualSubtitleLabelOptionsArgs>;
        /**
         * The title that is displayed on the visual.
         */
        title?: pulumi.Input<inputs.quicksight.DashboardVisualTitleLabelOptionsArgs>;
        /**
         * The alt text for the visual.
         */
        visualContentAltText?: pulumi.Input<string>;
        /**
         * The unique identifier of a visual. This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers..
         */
        visualId: pulumi.Input<string>;
    }
    interface DashboardPivotTotalOptionsArgs {
        /**
         * The custom label string for the total cells.
         */
        customLabel?: pulumi.Input<string>;
        /**
         * The cell styling options for the total of header cells.
         */
        metricHeaderCellStyle?: pulumi.Input<inputs.quicksight.DashboardTableCellStyleArgs>;
        /**
         * The placement (start, end) for the total cells.
         */
        placement?: pulumi.Input<enums.quicksight.DashboardTableTotalsPlacement>;
        /**
         * The scroll status (pinned, scrolled) for the total cells.
         */
        scrollStatus?: pulumi.Input<enums.quicksight.DashboardTableTotalsScrollStatus>;
        /**
         * The total aggregation options for each value field.
         */
        totalAggregationOptions?: pulumi.Input<pulumi.Input<inputs.quicksight.DashboardTotalAggregationOptionArgs>[]>;
        /**
         * The cell styling options for the total cells.
         */
        totalCellStyle?: pulumi.Input<inputs.quicksight.DashboardTableCellStyleArgs>;
        /**
         * The visibility configuration for the total cells.
         */
        totalsVisibility?: pulumi.Input<enums.quicksight.DashboardVisibility>;
        /**
         * The cell styling options for the totals of value cells.
         */
        valueCellStyle?: pulumi.Input<inputs.quicksight.DashboardTableCellStyleArgs>;
    }
    interface DashboardPluginVisualArgs {
        /**
         * A description of the plugin field wells and their persisted properties.
         */
        chartConfiguration?: pulumi.Input<inputs.quicksight.DashboardPluginVisualConfigurationArgs>;
        /**
         * The Amazon Resource Name (ARN) that reflects the plugin and version.
         */
        pluginArn: pulumi.Input<string>;
        subtitle?: pulumi.Input<inputs.quicksight.DashboardVisualSubtitleLabelOptionsArgs>;
        title?: pulumi.Input<inputs.quicksight.DashboardVisualTitleLabelOptionsArgs>;
        /**
         * The alt text for the visual.
         */
        visualContentAltText?: pulumi.Input<string>;
        /**
         * The ID of the visual that you want to use.
         */
        visualId: pulumi.Input<string>;
    }
    interface DashboardPluginVisualConfigurationArgs {
        /**
         * The field wells configuration of the plugin visual.
         */
        fieldWells?: pulumi.Input<pulumi.Input<inputs.quicksight.DashboardPluginVisualFieldWellArgs>[]>;
        /**
         * The sort configuration of the plugin visual.
         */
        sortConfiguration?: pulumi.Input<inputs.quicksight.DashboardPluginVisualSortConfigurationArgs>;
        /**
         * The persisted properties of the plugin visual.
         */
        visualOptions?: pulumi.Input<inputs.quicksight.DashboardPluginVisualOptionsArgs>;
    }
    interface DashboardPluginVisualFieldWellArgs {
        /**
         * The semantic axis name for the field well.
         */
        axisName?: pulumi.Input<enums.quicksight.DashboardPluginVisualAxisName>;
        /**
         * A list of dimensions for the field well.
         */
        dimensions?: pulumi.Input<pulumi.Input<inputs.quicksight.DashboardDimensionFieldArgs>[]>;
        /**
         * A list of measures that exist in the field well.
         */
        measures?: pulumi.Input<pulumi.Input<inputs.quicksight.DashboardMeasureFieldArgs>[]>;
        /**
         * A list of unaggregated fields that exist in the field well.
         */
        unaggregated?: pulumi.Input<pulumi.Input<inputs.quicksight.DashboardUnaggregatedFieldArgs>[]>;
    }
    interface DashboardPluginVisualItemsLimitConfigurationArgs {
        /**
         * Determines how many values are be fetched at once.
         */
        itemsLimit?: pulumi.Input<number>;
    }
    interface DashboardPluginVisualOptionsArgs {
        /**
         * The persisted properties and their values.
         */
        visualProperties?: pulumi.Input<pulumi.Input<inputs.quicksight.DashboardPluginVisualPropertyArgs>[]>;
    }
    interface DashboardPluginVisualPropertyArgs {
        /**
         * The name of the plugin visual property.
         */
        name?: pulumi.Input<string>;
        /**
         * The value of the plugin visual property.
         */
        value?: pulumi.Input<string>;
    }
    interface DashboardPluginVisualSortConfigurationArgs {
        /**
         * The table query sorting options for the plugin visual.
         */
        pluginVisualTableQuerySort?: pulumi.Input<inputs.quicksight.DashboardPluginVisualTableQuerySortArgs>;
    }
    interface DashboardPluginVisualTableQuerySortArgs {
        /**
         * The maximum amount of data to be returned by a query.
         */
        itemsLimitConfiguration?: pulumi.Input<inputs.quicksight.DashboardPluginVisualItemsLimitConfigurationArgs>;
        /**
         * Determines how data is sorted in the response.
         */
        rowSort?: pulumi.Input<pulumi.Input<inputs.quicksight.DashboardFieldSortOptionsArgs>[]>;
    }
    interface DashboardPredefinedHierarchyArgs {
        /**
         * The list of columns that define the predefined hierarchy.
         */
        columns: pulumi.Input<pulumi.Input<inputs.quicksight.DashboardColumnIdentifierArgs>[]>;
        /**
         * The option that determines the drill down filters for the predefined hierarchy.
         */
        drillDownFilters?: pulumi.Input<pulumi.Input<inputs.quicksight.DashboardDrillDownFilterArgs>[]>;
        /**
         * The hierarchy ID of the predefined hierarchy.
         */
        hierarchyId: pulumi.Input<string>;
    }
    interface DashboardProgressBarOptionsArgs {
        /**
         * The visibility of the progress bar.
         */
        visibility?: pulumi.Input<enums.quicksight.DashboardVisibility>;
    }
    /**
     * <p>Dashboard publish options.</p>
     */
    interface DashboardPublishOptionsArgs {
        /**
         * Ad hoc (one-time) filtering option.
         */
        adHocFilteringOption?: pulumi.Input<inputs.quicksight.DashboardAdHocFilteringOptionArgs>;
        /**
         * The drill-down options of data points in a dashboard.
         */
        dataPointDrillUpDownOption?: pulumi.Input<inputs.quicksight.DashboardDataPointDrillUpDownOptionArgs>;
        /**
         * The data point menu label options of a dashboard.
         */
        dataPointMenuLabelOption?: pulumi.Input<inputs.quicksight.DashboardDataPointMenuLabelOptionArgs>;
        /**
         * The data point tool tip options of a dashboard.
         */
        dataPointTooltipOption?: pulumi.Input<inputs.quicksight.DashboardDataPointTooltipOptionArgs>;
        /**
         * Export to .csv option.
         */
        exportToCsvOption?: pulumi.Input<inputs.quicksight.DashboardExportToCsvOptionArgs>;
        /**
         * Determines if hidden fields are exported with a dashboard.
         */
        exportWithHiddenFieldsOption?: pulumi.Input<inputs.quicksight.DashboardExportWithHiddenFieldsOptionArgs>;
        /**
         * Sheet controls option.
         */
        sheetControlsOption?: pulumi.Input<inputs.quicksight.DashboardSheetControlsOptionArgs>;
        /**
         * The sheet layout maximization options of a dashbaord.
         */
        sheetLayoutElementMaximizationOption?: pulumi.Input<inputs.quicksight.DashboardSheetLayoutElementMaximizationOptionArgs>;
        /**
         * The axis sort options of a dashboard.
         */
        visualAxisSortOption?: pulumi.Input<inputs.quicksight.DashboardVisualAxisSortOptionArgs>;
        /**
         * The menu options of a visual in a dashboard.
         */
        visualMenuOption?: pulumi.Input<inputs.quicksight.DashboardVisualMenuOptionArgs>;
        /**
         * The visual publish options of a visual in a dashboard.
         */
        visualPublishOptions?: pulumi.Input<inputs.quicksight.DashboardVisualPublishOptionsArgs>;
    }
    interface DashboardRadarChartAggregatedFieldWellsArgs {
        /**
         * The aggregated field well categories of a radar chart.
         */
        category?: pulumi.Input<pulumi.Input<inputs.quicksight.DashboardDimensionFieldArgs>[]>;
        /**
         * The color that are assigned to the aggregated field wells of a radar chart.
         */
        color?: pulumi.Input<pulumi.Input<inputs.quicksight.DashboardDimensionFieldArgs>[]>;
        /**
         * The values that are assigned to the aggregated field wells of a radar chart.
         */
        values?: pulumi.Input<pulumi.Input<inputs.quicksight.DashboardMeasureFieldArgs>[]>;
    }
    interface DashboardRadarChartAreaStyleSettingsArgs {
        /**
         * The visibility settings of a radar chart.
         */
        visibility?: pulumi.Input<enums.quicksight.DashboardVisibility>;
    }
    interface DashboardRadarChartConfigurationArgs {
        /**
         * Determines the visibility of the colors of alternatign bands in a radar chart.
         */
        alternateBandColorsVisibility?: pulumi.Input<enums.quicksight.DashboardVisibility>;
        /**
         * The color of the even-numbered alternate bands of a radar chart.
         */
        alternateBandEvenColor?: pulumi.Input<string>;
        /**
         * The color of the odd-numbered alternate bands of a radar chart.
         */
        alternateBandOddColor?: pulumi.Input<string>;
        /**
         * The axis behavior options of a radar chart.
         */
        axesRangeScale?: pulumi.Input<enums.quicksight.DashboardRadarChartAxesRangeScale>;
        /**
         * The base sreies settings of a radar chart.
         */
        baseSeriesSettings?: pulumi.Input<inputs.quicksight.DashboardRadarChartSeriesSettingsArgs>;
        /**
         * The category axis of a radar chart.
         */
        categoryAxis?: pulumi.Input<inputs.quicksight.DashboardAxisDisplayOptionsArgs>;
        /**
         * The category label options of a radar chart.
         */
        categoryLabelOptions?: pulumi.Input<inputs.quicksight.DashboardChartAxisLabelOptionsArgs>;
        /**
         * The color axis of a radar chart.
         */
        colorAxis?: pulumi.Input<inputs.quicksight.DashboardAxisDisplayOptionsArgs>;
        /**
         * The color label options of a radar chart.
         */
        colorLabelOptions?: pulumi.Input<inputs.quicksight.DashboardChartAxisLabelOptionsArgs>;
        /**
         * The field well configuration of a `RadarChartVisual` .
         */
        fieldWells?: pulumi.Input<inputs.quicksight.DashboardRadarChartFieldWellsArgs>;
        /**
         * The general visual interactions setup for a visual.
         */
        interactions?: pulumi.Input<inputs.quicksight.DashboardVisualInteractionOptionsArgs>;
        /**
         * The legend display setup of the visual.
         */
        legend?: pulumi.Input<inputs.quicksight.DashboardLegendOptionsArgs>;
        /**
         * The shape of the radar chart.
         */
        shape?: pulumi.Input<enums.quicksight.DashboardRadarChartShape>;
        /**
         * The sort configuration of a `RadarChartVisual` .
         */
        sortConfiguration?: pulumi.Input<inputs.quicksight.DashboardRadarChartSortConfigurationArgs>;
        /**
         * The start angle of a radar chart's axis.
         */
        startAngle?: pulumi.Input<number>;
        /**
         * The palette (chart color) display setup of the visual.
         */
        visualPalette?: pulumi.Input<inputs.quicksight.DashboardVisualPaletteArgs>;
    }
    interface DashboardRadarChartFieldWellsArgs {
        /**
         * The aggregated field wells of a radar chart visual.
         */
        radarChartAggregatedFieldWells?: pulumi.Input<inputs.quicksight.DashboardRadarChartAggregatedFieldWellsArgs>;
    }
    interface DashboardRadarChartSeriesSettingsArgs {
        /**
         * The area style settings of a radar chart.
         */
        areaStyleSettings?: pulumi.Input<inputs.quicksight.DashboardRadarChartAreaStyleSettingsArgs>;
    }
    interface DashboardRadarChartSortConfigurationArgs {
        /**
         * The category items limit for a radar chart.
         */
        categoryItemsLimit?: pulumi.Input<inputs.quicksight.DashboardItemsLimitConfigurationArgs>;
        /**
         * The category sort options of a radar chart.
         */
        categorySort?: pulumi.Input<pulumi.Input<inputs.quicksight.DashboardFieldSortOptionsArgs>[]>;
        /**
         * The color items limit of a radar chart.
         */
        colorItemsLimit?: pulumi.Input<inputs.quicksight.DashboardItemsLimitConfigurationArgs>;
        /**
         * The color sort configuration of a radar chart.
         */
        colorSort?: pulumi.Input<pulumi.Input<inputs.quicksight.DashboardFieldSortOptionsArgs>[]>;
    }
    interface DashboardRadarChartVisualArgs {
        /**
         * The list of custom actions that are configured for a visual.
         */
        actions?: pulumi.Input<pulumi.Input<inputs.quicksight.DashboardVisualCustomActionArgs>[]>;
        /**
         * The configuration settings of the visual.
         */
        chartConfiguration?: pulumi.Input<inputs.quicksight.DashboardRadarChartConfigurationArgs>;
        /**
         * The column hierarchy that is used during drill-downs and drill-ups.
         */
        columnHierarchies?: pulumi.Input<pulumi.Input<inputs.quicksight.DashboardColumnHierarchyArgs>[]>;
        /**
         * The subtitle that is displayed on the visual.
         */
        subtitle?: pulumi.Input<inputs.quicksight.DashboardVisualSubtitleLabelOptionsArgs>;
        /**
         * The title that is displayed on the visual.
         */
        title?: pulumi.Input<inputs.quicksight.DashboardVisualTitleLabelOptionsArgs>;
        /**
         * The alt text for the visual.
         */
        visualContentAltText?: pulumi.Input<string>;
        /**
         * The unique identifier of a visual. This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers.
         */
        visualId: pulumi.Input<string>;
    }
    interface DashboardRangeEndsLabelTypeArgs {
        /**
         * The visibility of the range ends label.
         */
        visibility?: pulumi.Input<enums.quicksight.DashboardVisibility>;
    }
    interface DashboardReferenceLineArgs {
        /**
         * The data configuration of the reference line.
         */
        dataConfiguration: pulumi.Input<inputs.quicksight.DashboardReferenceLineDataConfigurationArgs>;
        /**
         * The label configuration of the reference line.
         */
        labelConfiguration?: pulumi.Input<inputs.quicksight.DashboardReferenceLineLabelConfigurationArgs>;
        /**
         * The status of the reference line. Choose one of the following options:
         *
         * - `ENABLE`
         * - `DISABLE`
         */
        status?: pulumi.Input<enums.quicksight.DashboardWidgetStatus>;
        /**
         * The style configuration of the reference line.
         */
        styleConfiguration?: pulumi.Input<inputs.quicksight.DashboardReferenceLineStyleConfigurationArgs>;
    }
    interface DashboardReferenceLineCustomLabelConfigurationArgs {
        /**
         * The string text of the custom label.
         */
        customLabel: pulumi.Input<string>;
    }
    interface DashboardReferenceLineDataConfigurationArgs {
        /**
         * The axis binding type of the reference line. Choose one of the following options:
         *
         * - `PrimaryY`
         * - `SecondaryY`
         */
        axisBinding?: pulumi.Input<enums.quicksight.DashboardAxisBinding>;
        /**
         * The dynamic configuration of the reference line data configuration.
         */
        dynamicConfiguration?: pulumi.Input<inputs.quicksight.DashboardReferenceLineDynamicDataConfigurationArgs>;
        /**
         * The series type of the reference line data configuration. Choose one of the following options:
         *
         * - `BAR`
         * - `LINE`
         */
        seriesType?: pulumi.Input<enums.quicksight.DashboardReferenceLineSeriesType>;
        /**
         * The static data configuration of the reference line data configuration.
         */
        staticConfiguration?: pulumi.Input<inputs.quicksight.DashboardReferenceLineStaticDataConfigurationArgs>;
    }
    interface DashboardReferenceLineDynamicDataConfigurationArgs {
        /**
         * The calculation that is used in the dynamic data.
         */
        calculation: pulumi.Input<inputs.quicksight.DashboardNumericalAggregationFunctionArgs>;
        /**
         * The column that the dynamic data targets.
         */
        column: pulumi.Input<inputs.quicksight.DashboardColumnIdentifierArgs>;
        /**
         * The aggregation function that is used in the dynamic data.
         */
        measureAggregationFunction?: pulumi.Input<inputs.quicksight.DashboardAggregationFunctionArgs>;
    }
    interface DashboardReferenceLineLabelConfigurationArgs {
        /**
         * The custom label configuration of the label in a reference line.
         */
        customLabelConfiguration?: pulumi.Input<inputs.quicksight.DashboardReferenceLineCustomLabelConfigurationArgs>;
        /**
         * The font color configuration of the label in a reference line.
         */
        fontColor?: pulumi.Input<string>;
        /**
         * The font configuration of the label in a reference line.
         */
        fontConfiguration?: pulumi.Input<inputs.quicksight.DashboardFontConfigurationArgs>;
        /**
         * The horizontal position configuration of the label in a reference line. Choose one of the following options:
         *
         * - `LEFT`
         * - `CENTER`
         * - `RIGHT`
         */
        horizontalPosition?: pulumi.Input<enums.quicksight.DashboardReferenceLineLabelHorizontalPosition>;
        /**
         * The value label configuration of the label in a reference line.
         */
        valueLabelConfiguration?: pulumi.Input<inputs.quicksight.DashboardReferenceLineValueLabelConfigurationArgs>;
        /**
         * The vertical position configuration of the label in a reference line. Choose one of the following options:
         *
         * - `ABOVE`
         * - `BELOW`
         */
        verticalPosition?: pulumi.Input<enums.quicksight.DashboardReferenceLineLabelVerticalPosition>;
    }
    interface DashboardReferenceLineStaticDataConfigurationArgs {
        /**
         * The double input of the static data.
         */
        value: pulumi.Input<number>;
    }
    interface DashboardReferenceLineStyleConfigurationArgs {
        /**
         * The hex color of the reference line.
         */
        color?: pulumi.Input<string>;
        /**
         * The pattern type of the line style. Choose one of the following options:
         *
         * - `SOLID`
         * - `DASHED`
         * - `DOTTED`
         */
        pattern?: pulumi.Input<enums.quicksight.DashboardReferenceLinePatternType>;
    }
    interface DashboardReferenceLineValueLabelConfigurationArgs {
        /**
         * The format configuration of the value label.
         */
        formatConfiguration?: pulumi.Input<inputs.quicksight.DashboardNumericFormatConfigurationArgs>;
        /**
         * The relative position of the value label. Choose one of the following options:
         *
         * - `BEFORE_CUSTOM_LABEL`
         * - `AFTER_CUSTOM_LABEL`
         */
        relativePosition?: pulumi.Input<enums.quicksight.DashboardReferenceLineValueLabelRelativePosition>;
    }
    interface DashboardRelativeDateTimeControlDisplayOptionsArgs {
        /**
         * Customize how dates are formatted in controls.
         */
        dateTimeFormat?: pulumi.Input<string>;
        /**
         * The configuration of info icon label options.
         */
        infoIconLabelOptions?: pulumi.Input<inputs.quicksight.DashboardSheetControlInfoIconLabelOptionsArgs>;
        /**
         * The options to configure the title visibility, name, and font size.
         */
        titleOptions?: pulumi.Input<inputs.quicksight.DashboardLabelOptionsArgs>;
    }
    interface DashboardRelativeDatesFilterArgs {
        /**
         * The date configuration of the filter.
         */
        anchorDateConfiguration: pulumi.Input<inputs.quicksight.DashboardAnchorDateConfigurationArgs>;
        /**
         * The column that the filter is applied to.
         */
        column: pulumi.Input<inputs.quicksight.DashboardColumnIdentifierArgs>;
        /**
         * The default configurations for the associated controls. This applies only for filters that are scoped to multiple sheets.
         */
        defaultFilterControlConfiguration?: pulumi.Input<inputs.quicksight.DashboardDefaultFilterControlConfigurationArgs>;
        /**
         * The configuration for the exclude period of the filter.
         */
        excludePeriodConfiguration?: pulumi.Input<inputs.quicksight.DashboardExcludePeriodConfigurationArgs>;
        /**
         * An identifier that uniquely identifies a filter within a dashboard, analysis, or template.
         */
        filterId: pulumi.Input<string>;
        /**
         * The minimum granularity (period granularity) of the relative dates filter.
         */
        minimumGranularity?: pulumi.Input<enums.quicksight.DashboardTimeGranularity>;
        /**
         * This option determines how null values should be treated when filtering data.
         *
         * - `ALL_VALUES` : Include null values in filtered results.
         * - `NULLS_ONLY` : Only include null values in filtered results.
         * - `NON_NULLS_ONLY` : Exclude null values from filtered results.
         */
        nullOption: pulumi.Input<enums.quicksight.DashboardFilterNullOption>;
        /**
         * The parameter whose value should be used for the filter value.
         */
        parameterName?: pulumi.Input<string>;
        /**
         * The range date type of the filter. Choose one of the options below:
         *
         * - `PREVIOUS`
         * - `THIS`
         * - `LAST`
         * - `NOW`
         * - `NEXT`
         */
        relativeDateType: pulumi.Input<enums.quicksight.DashboardRelativeDateType>;
        /**
         * The date value of the filter.
         */
        relativeDateValue?: pulumi.Input<number>;
        /**
         * The level of time precision that is used to aggregate `DateTime` values.
         */
        timeGranularity: pulumi.Input<enums.quicksight.DashboardTimeGranularity>;
    }
    /**
     * <p>Permission for the resource.</p>
     */
    interface DashboardResourcePermissionArgs {
        /**
         * <p>The IAM action to grant or revoke permissions on.</p>
         */
        actions: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * <p>The Amazon Resource Name (ARN) of the principal. This can be one of the
         *             following:</p>
         *          <ul>
         *             <li>
         *                <p>The ARN of an Amazon QuickSight user or group associated with a data source or dataset. (This is common.)</p>
         *             </li>
         *             <li>
         *                <p>The ARN of an Amazon QuickSight user, group, or namespace associated with an analysis, dashboard, template, or theme. (This is common.)</p>
         *             </li>
         *             <li>
         *                <p>The ARN of an Amazon Web Services account root: This is an IAM ARN rather than a QuickSight
         *                     ARN. Use this option only to share resources (templates) across Amazon Web Services accounts.
         *                     (This is less common.) </p>
         *             </li>
         *          </ul>
         */
        principal: pulumi.Input<string>;
    }
    interface DashboardRollingDateConfigurationArgs {
        /**
         * The data set that is used in the rolling date configuration.
         */
        dataSetIdentifier?: pulumi.Input<string>;
        /**
         * The expression of the rolling date configuration.
         */
        expression: pulumi.Input<string>;
    }
    interface DashboardRowAlternateColorOptionsArgs {
        /**
         * Determines the list of row alternate colors.
         */
        rowAlternateColors?: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * Determines the widget status.
         */
        status?: pulumi.Input<enums.quicksight.DashboardWidgetStatus>;
        /**
         * The primary background color options for alternate rows.
         */
        usePrimaryBackgroundColor?: pulumi.Input<enums.quicksight.DashboardWidgetStatus>;
    }
    interface DashboardSameSheetTargetVisualConfigurationArgs {
        /**
         * The options that choose the target visual in the same sheet.
         *
         * Valid values are defined as follows:
         *
         * - `ALL_VISUALS` : Applies the filter operation to all visuals in the same sheet.
         */
        targetVisualOptions?: pulumi.Input<enums.quicksight.DashboardTargetVisualOptions>;
        /**
         * A list of the target visual IDs that are located in the same sheet of the analysis.
         */
        targetVisuals?: pulumi.Input<pulumi.Input<string>[]>;
    }
    interface DashboardSankeyDiagramAggregatedFieldWellsArgs {
        /**
         * The destination field wells of a sankey diagram.
         */
        destination?: pulumi.Input<pulumi.Input<inputs.quicksight.DashboardDimensionFieldArgs>[]>;
        /**
         * The source field wells of a sankey diagram.
         */
        source?: pulumi.Input<pulumi.Input<inputs.quicksight.DashboardDimensionFieldArgs>[]>;
        /**
         * The weight field wells of a sankey diagram.
         */
        weight?: pulumi.Input<pulumi.Input<inputs.quicksight.DashboardMeasureFieldArgs>[]>;
    }
    interface DashboardSankeyDiagramChartConfigurationArgs {
        /**
         * The data label configuration of a sankey diagram.
         */
        dataLabels?: pulumi.Input<inputs.quicksight.DashboardDataLabelOptionsArgs>;
        /**
         * The field well configuration of a sankey diagram.
         */
        fieldWells?: pulumi.Input<inputs.quicksight.DashboardSankeyDiagramFieldWellsArgs>;
        /**
         * The general visual interactions setup for a visual.
         */
        interactions?: pulumi.Input<inputs.quicksight.DashboardVisualInteractionOptionsArgs>;
        /**
         * The sort configuration of a sankey diagram.
         */
        sortConfiguration?: pulumi.Input<inputs.quicksight.DashboardSankeyDiagramSortConfigurationArgs>;
    }
    interface DashboardSankeyDiagramFieldWellsArgs {
        /**
         * The field well configuration of a sankey diagram.
         */
        sankeyDiagramAggregatedFieldWells?: pulumi.Input<inputs.quicksight.DashboardSankeyDiagramAggregatedFieldWellsArgs>;
    }
    interface DashboardSankeyDiagramSortConfigurationArgs {
        /**
         * The limit on the number of destination nodes that are displayed in a sankey diagram.
         */
        destinationItemsLimit?: pulumi.Input<inputs.quicksight.DashboardItemsLimitConfigurationArgs>;
        /**
         * The limit on the number of source nodes that are displayed in a sankey diagram.
         */
        sourceItemsLimit?: pulumi.Input<inputs.quicksight.DashboardItemsLimitConfigurationArgs>;
        /**
         * The sort configuration of the weight fields.
         */
        weightSort?: pulumi.Input<pulumi.Input<inputs.quicksight.DashboardFieldSortOptionsArgs>[]>;
    }
    interface DashboardSankeyDiagramVisualArgs {
        /**
         * The list of custom actions that are configured for a visual.
         */
        actions?: pulumi.Input<pulumi.Input<inputs.quicksight.DashboardVisualCustomActionArgs>[]>;
        /**
         * The configuration of a sankey diagram.
         */
        chartConfiguration?: pulumi.Input<inputs.quicksight.DashboardSankeyDiagramChartConfigurationArgs>;
        /**
         * The subtitle that is displayed on the visual.
         */
        subtitle?: pulumi.Input<inputs.quicksight.DashboardVisualSubtitleLabelOptionsArgs>;
        /**
         * The title that is displayed on the visual.
         */
        title?: pulumi.Input<inputs.quicksight.DashboardVisualTitleLabelOptionsArgs>;
        /**
         * The alt text for the visual.
         */
        visualContentAltText?: pulumi.Input<string>;
        /**
         * The unique identifier of a visual. This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers.
         */
        visualId: pulumi.Input<string>;
    }
    interface DashboardScatterPlotCategoricallyAggregatedFieldWellsArgs {
        /**
         * The category field well of a scatter plot.
         */
        category?: pulumi.Input<pulumi.Input<inputs.quicksight.DashboardDimensionFieldArgs>[]>;
        /**
         * The label field well of a scatter plot.
         */
        label?: pulumi.Input<pulumi.Input<inputs.quicksight.DashboardDimensionFieldArgs>[]>;
        /**
         * The size field well of a scatter plot.
         */
        size?: pulumi.Input<pulumi.Input<inputs.quicksight.DashboardMeasureFieldArgs>[]>;
        /**
         * The x-axis field well of a scatter plot.
         *
         * The x-axis is aggregated by category.
         */
        xAxis?: pulumi.Input<pulumi.Input<inputs.quicksight.DashboardMeasureFieldArgs>[]>;
        /**
         * The y-axis field well of a scatter plot.
         *
         * The y-axis is aggregated by category.
         */
        yAxis?: pulumi.Input<pulumi.Input<inputs.quicksight.DashboardMeasureFieldArgs>[]>;
    }
    interface DashboardScatterPlotConfigurationArgs {
        /**
         * The options that determine if visual data labels are displayed.
         */
        dataLabels?: pulumi.Input<inputs.quicksight.DashboardDataLabelOptionsArgs>;
        /**
         * The field wells of the visual.
         */
        fieldWells?: pulumi.Input<inputs.quicksight.DashboardScatterPlotFieldWellsArgs>;
        /**
         * The general visual interactions setup for a visual.
         */
        interactions?: pulumi.Input<inputs.quicksight.DashboardVisualInteractionOptionsArgs>;
        /**
         * The legend display setup of the visual.
         */
        legend?: pulumi.Input<inputs.quicksight.DashboardLegendOptionsArgs>;
        /**
         * The sort configuration of a scatter plot.
         */
        sortConfiguration?: pulumi.Input<inputs.quicksight.DashboardScatterPlotSortConfigurationArgs>;
        /**
         * The legend display setup of the visual.
         */
        tooltip?: pulumi.Input<inputs.quicksight.DashboardTooltipOptionsArgs>;
        /**
         * The palette (chart color) display setup of the visual.
         */
        visualPalette?: pulumi.Input<inputs.quicksight.DashboardVisualPaletteArgs>;
        /**
         * The label display options (grid line, range, scale, and axis step) of the scatter plot's x-axis.
         */
        xAxisDisplayOptions?: pulumi.Input<inputs.quicksight.DashboardAxisDisplayOptionsArgs>;
        /**
         * The label options (label text, label visibility, and sort icon visibility) of the scatter plot's x-axis.
         */
        xAxisLabelOptions?: pulumi.Input<inputs.quicksight.DashboardChartAxisLabelOptionsArgs>;
        /**
         * The label display options (grid line, range, scale, and axis step) of the scatter plot's y-axis.
         */
        yAxisDisplayOptions?: pulumi.Input<inputs.quicksight.DashboardAxisDisplayOptionsArgs>;
        /**
         * The label options (label text, label visibility, and sort icon visibility) of the scatter plot's y-axis.
         */
        yAxisLabelOptions?: pulumi.Input<inputs.quicksight.DashboardChartAxisLabelOptionsArgs>;
    }
    interface DashboardScatterPlotFieldWellsArgs {
        /**
         * The aggregated field wells of a scatter plot. The x and y-axes of scatter plots with aggregated field wells are aggregated by category, label, or both.
         */
        scatterPlotCategoricallyAggregatedFieldWells?: pulumi.Input<inputs.quicksight.DashboardScatterPlotCategoricallyAggregatedFieldWellsArgs>;
        /**
         * The unaggregated field wells of a scatter plot. The x and y-axes of these scatter plots are unaggregated.
         */
        scatterPlotUnaggregatedFieldWells?: pulumi.Input<inputs.quicksight.DashboardScatterPlotUnaggregatedFieldWellsArgs>;
    }
    interface DashboardScatterPlotSortConfigurationArgs {
        scatterPlotLimitConfiguration?: pulumi.Input<inputs.quicksight.DashboardItemsLimitConfigurationArgs>;
    }
    interface DashboardScatterPlotUnaggregatedFieldWellsArgs {
        /**
         * The category field well of a scatter plot.
         */
        category?: pulumi.Input<pulumi.Input<inputs.quicksight.DashboardDimensionFieldArgs>[]>;
        /**
         * The label field well of a scatter plot.
         */
        label?: pulumi.Input<pulumi.Input<inputs.quicksight.DashboardDimensionFieldArgs>[]>;
        /**
         * The size field well of a scatter plot.
         */
        size?: pulumi.Input<pulumi.Input<inputs.quicksight.DashboardMeasureFieldArgs>[]>;
        /**
         * The x-axis field well of a scatter plot.
         *
         * The x-axis is a dimension field and cannot be aggregated.
         */
        xAxis?: pulumi.Input<pulumi.Input<inputs.quicksight.DashboardDimensionFieldArgs>[]>;
        /**
         * The y-axis field well of a scatter plot.
         *
         * The y-axis is a dimension field and cannot be aggregated.
         */
        yAxis?: pulumi.Input<pulumi.Input<inputs.quicksight.DashboardDimensionFieldArgs>[]>;
    }
    interface DashboardScatterPlotVisualArgs {
        /**
         * The list of custom actions that are configured for a visual.
         */
        actions?: pulumi.Input<pulumi.Input<inputs.quicksight.DashboardVisualCustomActionArgs>[]>;
        /**
         * The configuration settings of the visual.
         */
        chartConfiguration?: pulumi.Input<inputs.quicksight.DashboardScatterPlotConfigurationArgs>;
        /**
         * The column hierarchy that is used during drill-downs and drill-ups.
         */
        columnHierarchies?: pulumi.Input<pulumi.Input<inputs.quicksight.DashboardColumnHierarchyArgs>[]>;
        /**
         * The subtitle that is displayed on the visual.
         */
        subtitle?: pulumi.Input<inputs.quicksight.DashboardVisualSubtitleLabelOptionsArgs>;
        /**
         * The title that is displayed on the visual.
         */
        title?: pulumi.Input<inputs.quicksight.DashboardVisualTitleLabelOptionsArgs>;
        /**
         * The alt text for the visual.
         */
        visualContentAltText?: pulumi.Input<string>;
        /**
         * The unique identifier of a visual. This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers.
         */
        visualId: pulumi.Input<string>;
    }
    interface DashboardScrollBarOptionsArgs {
        /**
         * The visibility of the data zoom scroll bar.
         */
        visibility?: pulumi.Input<enums.quicksight.DashboardVisibility>;
        /**
         * The visibility range for the data zoom scroll bar.
         */
        visibleRange?: pulumi.Input<inputs.quicksight.DashboardVisibleRangeOptionsArgs>;
    }
    interface DashboardSecondaryValueOptionsArgs {
        /**
         * Determines the visibility of the secondary value.
         */
        visibility?: pulumi.Input<enums.quicksight.DashboardVisibility>;
    }
    interface DashboardSectionAfterPageBreakArgs {
        /**
         * The option that enables or disables a page break at the end of a section.
         */
        status?: pulumi.Input<enums.quicksight.DashboardSectionPageBreakStatus>;
    }
    interface DashboardSectionBasedLayoutCanvasSizeOptionsArgs {
        /**
         * The options for a paper canvas of a section-based layout.
         */
        paperCanvasSizeOptions?: pulumi.Input<inputs.quicksight.DashboardSectionBasedLayoutPaperCanvasSizeOptionsArgs>;
    }
    interface DashboardSectionBasedLayoutConfigurationArgs {
        /**
         * A list of body section configurations.
         */
        bodySections: pulumi.Input<pulumi.Input<inputs.quicksight.DashboardBodySectionConfigurationArgs>[]>;
        /**
         * The options for the canvas of a section-based layout.
         */
        canvasSizeOptions: pulumi.Input<inputs.quicksight.DashboardSectionBasedLayoutCanvasSizeOptionsArgs>;
        /**
         * A list of footer section configurations.
         */
        footerSections: pulumi.Input<pulumi.Input<inputs.quicksight.DashboardHeaderFooterSectionConfigurationArgs>[]>;
        /**
         * A list of header section configurations.
         */
        headerSections: pulumi.Input<pulumi.Input<inputs.quicksight.DashboardHeaderFooterSectionConfigurationArgs>[]>;
    }
    interface DashboardSectionBasedLayoutPaperCanvasSizeOptionsArgs {
        /**
         * Defines the spacing between the canvas content and the top, bottom, left, and right edges.
         */
        paperMargin?: pulumi.Input<inputs.quicksight.DashboardSpacingArgs>;
        /**
         * The paper orientation that is used to define canvas dimensions. Choose one of the following options:
         *
         * - PORTRAIT
         * - LANDSCAPE
         */
        paperOrientation?: pulumi.Input<enums.quicksight.DashboardPaperOrientation>;
        /**
         * The paper size that is used to define canvas dimensions.
         */
        paperSize?: pulumi.Input<enums.quicksight.DashboardPaperSize>;
    }
    interface DashboardSectionLayoutConfigurationArgs {
        /**
         * The free-form layout configuration of a section.
         */
        freeFormLayout: pulumi.Input<inputs.quicksight.DashboardFreeFormSectionLayoutConfigurationArgs>;
    }
    interface DashboardSectionPageBreakConfigurationArgs {
        /**
         * The configuration of a page break after a section.
         */
        after?: pulumi.Input<inputs.quicksight.DashboardSectionAfterPageBreakArgs>;
    }
    interface DashboardSectionStyleArgs {
        /**
         * String based length that is composed of value and unit in px
         */
        height?: pulumi.Input<string>;
        /**
         * The spacing between section content and its top, bottom, left, and right edges.
         *
         * There is no padding by default.
         */
        padding?: pulumi.Input<inputs.quicksight.DashboardSpacingArgs>;
    }
    interface DashboardSelectedSheetsFilterScopeConfigurationArgs {
        /**
         * The sheet ID and visual IDs of the sheet and visuals that the filter is applied to.
         */
        sheetVisualScopingConfigurations?: pulumi.Input<pulumi.Input<inputs.quicksight.DashboardSheetVisualScopingConfigurationArgs>[]>;
    }
    interface DashboardSeriesItemArgs {
        /**
         * The data field series item configuration of a line chart.
         */
        dataFieldSeriesItem?: pulumi.Input<inputs.quicksight.DashboardDataFieldSeriesItemArgs>;
        /**
         * The field series item configuration of a line chart.
         */
        fieldSeriesItem?: pulumi.Input<inputs.quicksight.DashboardFieldSeriesItemArgs>;
    }
    interface DashboardSetParameterValueConfigurationArgs {
        /**
         * The destination parameter name of the `SetParameterValueConfiguration` .
         */
        destinationParameterName: pulumi.Input<string>;
        value: pulumi.Input<inputs.quicksight.DashboardDestinationParameterValueConfigurationArgs>;
    }
    interface DashboardShapeConditionalFormatArgs {
        /**
         * The conditional formatting for the shape background color of a filled map visual.
         */
        backgroundColor: pulumi.Input<inputs.quicksight.DashboardConditionalFormattingColorArgs>;
    }
    interface DashboardSheetControlInfoIconLabelOptionsArgs {
        /**
         * The text content of info icon.
         */
        infoIconText?: pulumi.Input<string>;
        /**
         * The visibility configuration of info icon label options.
         */
        visibility?: pulumi.Input<enums.quicksight.DashboardVisibility>;
    }
    interface DashboardSheetControlLayoutArgs {
        /**
         * The configuration that determines the elements and canvas size options of sheet control.
         */
        configuration: pulumi.Input<inputs.quicksight.DashboardSheetControlLayoutConfigurationArgs>;
    }
    interface DashboardSheetControlLayoutConfigurationArgs {
        /**
         * The configuration that determines the elements and canvas size options of sheet control.
         */
        gridLayout?: pulumi.Input<inputs.quicksight.DashboardGridLayoutConfigurationArgs>;
    }
    /**
     * <p>Sheet controls option.</p>
     */
    interface DashboardSheetControlsOptionArgs {
        /**
         * Visibility state.
         */
        visibilityState?: pulumi.Input<enums.quicksight.DashboardUiState>;
    }
    interface DashboardSheetDefinitionArgs {
        /**
         * The layout content type of the sheet. Choose one of the following options:
         *
         * - `PAGINATED` : Creates a sheet for a paginated report.
         * - `INTERACTIVE` : Creates a sheet for an interactive dashboard.
         */
        contentType?: pulumi.Input<enums.quicksight.DashboardSheetContentType>;
        /**
         * A description of the sheet.
         */
        description?: pulumi.Input<string>;
        /**
         * The list of filter controls that are on a sheet.
         *
         * For more information, see [Adding filter controls to analysis sheets](https://docs.aws.amazon.com/quicksight/latest/user/filter-controls.html) in the *Amazon QuickSight User Guide* .
         */
        filterControls?: pulumi.Input<pulumi.Input<inputs.quicksight.DashboardFilterControlArgs>[]>;
        /**
         * A list of images on a sheet.
         */
        images?: pulumi.Input<pulumi.Input<inputs.quicksight.DashboardSheetImageArgs>[]>;
        /**
         * Layouts define how the components of a sheet are arranged.
         *
         * For more information, see [Types of layout](https://docs.aws.amazon.com/quicksight/latest/user/types-of-layout.html) in the *Amazon QuickSight User Guide* .
         */
        layouts?: pulumi.Input<pulumi.Input<inputs.quicksight.DashboardLayoutArgs>[]>;
        /**
         * The name of the sheet. This name is displayed on the sheet's tab in the Amazon QuickSight console.
         */
        name?: pulumi.Input<string>;
        /**
         * The list of parameter controls that are on a sheet.
         *
         * For more information, see [Using a Control with a Parameter in Amazon QuickSight](https://docs.aws.amazon.com/quicksight/latest/user/parameters-controls.html) in the *Amazon QuickSight User Guide* .
         */
        parameterControls?: pulumi.Input<pulumi.Input<inputs.quicksight.DashboardParameterControlArgs>[]>;
        /**
         * The control layouts of the sheet.
         */
        sheetControlLayouts?: pulumi.Input<pulumi.Input<inputs.quicksight.DashboardSheetControlLayoutArgs>[]>;
        /**
         * The unique identifier of a sheet.
         */
        sheetId: pulumi.Input<string>;
        /**
         * The text boxes that are on a sheet.
         */
        textBoxes?: pulumi.Input<pulumi.Input<inputs.quicksight.DashboardSheetTextBoxArgs>[]>;
        /**
         * The title of the sheet.
         */
        title?: pulumi.Input<string>;
        /**
         * A list of the visuals that are on a sheet. Visual placement is determined by the layout of the sheet.
         */
        visuals?: pulumi.Input<pulumi.Input<inputs.quicksight.DashboardVisualArgs>[]>;
    }
    interface DashboardSheetElementConfigurationOverridesArgs {
        /**
         * Determines whether or not the overrides are visible. Choose one of the following options:
         *
         * - `VISIBLE`
         * - `HIDDEN`
         */
        visibility?: pulumi.Input<enums.quicksight.DashboardVisibility>;
    }
    interface DashboardSheetElementRenderingRuleArgs {
        /**
         * The override configuration of the rendering rules of a sheet.
         */
        configurationOverrides: pulumi.Input<inputs.quicksight.DashboardSheetElementConfigurationOverridesArgs>;
        /**
         * The expression of the rendering rules of a sheet.
         */
        expression: pulumi.Input<string>;
    }
    interface DashboardSheetImageArgs {
        /**
         * A list of custom actions that are configured for an image.
         */
        actions?: pulumi.Input<pulumi.Input<inputs.quicksight.DashboardImageCustomActionArgs>[]>;
        /**
         * The alt text for the image.
         */
        imageContentAltText?: pulumi.Input<string>;
        /**
         * The general image interactions setup for an image.
         */
        interactions?: pulumi.Input<inputs.quicksight.DashboardImageInteractionOptionsArgs>;
        /**
         * Determines how the image is scaled.
         */
        scaling?: pulumi.Input<inputs.quicksight.DashboardSheetImageScalingConfigurationArgs>;
        /**
         * The ID of the sheet image.
         */
        sheetImageId: pulumi.Input<string>;
        /**
         * The source of the image.
         */
        source: pulumi.Input<inputs.quicksight.DashboardSheetImageSourceArgs>;
        /**
         * The tooltip to be shown when hovering over the image.
         */
        tooltip?: pulumi.Input<inputs.quicksight.DashboardSheetImageTooltipConfigurationArgs>;
    }
    interface DashboardSheetImageScalingConfigurationArgs {
        /**
         * The scaling option to use when fitting the image inside the container.
         *
         * Valid values are defined as follows:
         *
         * - `SCALE_TO_WIDTH` : The image takes up the entire width of the container. The image aspect ratio is preserved.
         * - `SCALE_TO_HEIGHT` : The image takes up the entire height of the container. The image aspect ratio is preserved.
         * - `SCALE_TO_CONTAINER` : The image takes up the entire width and height of the container. The image aspect ratio is not preserved.
         * - `SCALE_NONE` : The image is displayed in its original size and is not scaled to the container.
         */
        scalingType?: pulumi.Input<enums.quicksight.DashboardSheetImageScalingType>;
    }
    interface DashboardSheetImageSourceArgs {
        /**
         * The source of the static file that contains the image.
         */
        sheetImageStaticFileSource?: pulumi.Input<inputs.quicksight.DashboardSheetImageStaticFileSourceArgs>;
    }
    interface DashboardSheetImageStaticFileSourceArgs {
        /**
         * The ID of the static file that contains the image.
         */
        staticFileId: pulumi.Input<string>;
    }
    interface DashboardSheetImageTooltipConfigurationArgs {
        /**
         * The text that appears in the tooltip.
         */
        tooltipText?: pulumi.Input<inputs.quicksight.DashboardSheetImageTooltipTextArgs>;
        /**
         * The visibility of the tooltip.
         */
        visibility?: pulumi.Input<enums.quicksight.DashboardVisibility>;
    }
    interface DashboardSheetImageTooltipTextArgs {
        /**
         * The plain text format.
         */
        plainText?: pulumi.Input<string>;
    }
    /**
     * <p>The sheet layout maximization options of a dashbaord.</p>
     */
    interface DashboardSheetLayoutElementMaximizationOptionArgs {
        /**
         * The status of the sheet layout maximization options of a dashbaord.
         */
        availabilityStatus?: pulumi.Input<enums.quicksight.DashboardBehavior>;
    }
    interface DashboardSheetTextBoxArgs {
        /**
         * The content that is displayed in the text box.
         */
        content?: pulumi.Input<string>;
        /**
         * The unique identifier for a text box. This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have text boxes that share identifiers.
         */
        sheetTextBoxId: pulumi.Input<string>;
    }
    interface DashboardSheetVisualScopingConfigurationArgs {
        /**
         * The scope of the applied entities. Choose one of the following options:
         *
         * - `ALL_VISUALS`
         * - `SELECTED_VISUALS`
         */
        scope: pulumi.Input<enums.quicksight.DashboardFilterVisualScope>;
        /**
         * The selected sheet that the filter is applied to.
         */
        sheetId: pulumi.Input<string>;
        /**
         * The selected visuals that the filter is applied to.
         */
        visualIds?: pulumi.Input<pulumi.Input<string>[]>;
    }
    interface DashboardShortFormatTextArgs {
        /**
         * Plain text format.
         */
        plainText?: pulumi.Input<string>;
        /**
         * Rich text. Examples of rich text include bold, underline, and italics.
         */
        richText?: pulumi.Input<string>;
    }
    interface DashboardSimpleClusterMarkerArgs {
        /**
         * The color of the simple cluster marker.
         */
        color?: pulumi.Input<string>;
    }
    interface DashboardSingleAxisOptionsArgs {
        /**
         * The Y axis options of a single axis configuration.
         */
        yAxisOptions?: pulumi.Input<inputs.quicksight.DashboardYAxisOptionsArgs>;
    }
    interface DashboardSliderControlDisplayOptionsArgs {
        /**
         * The configuration of info icon label options.
         */
        infoIconLabelOptions?: pulumi.Input<inputs.quicksight.DashboardSheetControlInfoIconLabelOptionsArgs>;
        /**
         * The options to configure the title visibility, name, and font size.
         */
        titleOptions?: pulumi.Input<inputs.quicksight.DashboardLabelOptionsArgs>;
    }
    interface DashboardSmallMultiplesAxisPropertiesArgs {
        /**
         * Defines the placement of the axis. By default, axes are rendered `OUTSIDE` of the panels. Axes with `INDEPENDENT` scale are rendered `INSIDE` the panels.
         */
        placement?: pulumi.Input<enums.quicksight.DashboardSmallMultiplesAxisPlacement>;
        /**
         * Determines whether scale of the axes are shared or independent. The default value is `SHARED` .
         */
        scale?: pulumi.Input<enums.quicksight.DashboardSmallMultiplesAxisScale>;
    }
    interface DashboardSmallMultiplesOptionsArgs {
        /**
         * Sets the maximum number of visible columns to display in the grid of small multiples panels.
         *
         * The default is `Auto` , which automatically adjusts the columns in the grid to fit the overall layout and size of the given chart.
         */
        maxVisibleColumns?: pulumi.Input<number>;
        /**
         * Sets the maximum number of visible rows to display in the grid of small multiples panels.
         *
         * The default value is `Auto` , which automatically adjusts the rows in the grid to fit the overall layout and size of the given chart.
         */
        maxVisibleRows?: pulumi.Input<number>;
        /**
         * Configures the display options for each small multiples panel.
         */
        panelConfiguration?: pulumi.Input<inputs.quicksight.DashboardPanelConfigurationArgs>;
        /**
         * The properties of a small multiples X axis.
         */
        xAxis?: pulumi.Input<inputs.quicksight.DashboardSmallMultiplesAxisPropertiesArgs>;
        /**
         * The properties of a small multiples Y axis.
         */
        yAxis?: pulumi.Input<inputs.quicksight.DashboardSmallMultiplesAxisPropertiesArgs>;
    }
    /**
     * <p>Dashboard source entity.</p>
     */
    interface DashboardSourceEntityArgs {
        /**
         * Source template.
         */
        sourceTemplate?: pulumi.Input<inputs.quicksight.DashboardSourceTemplateArgs>;
    }
    /**
     * <p>Dashboard source template.</p>
     */
    interface DashboardSourceTemplateArgs {
        /**
         * <p>The Amazon Resource Name (ARN) of the resource.</p>
         */
        arn: pulumi.Input<string>;
        /**
         * <p>Dataset references.</p>
         */
        dataSetReferences: pulumi.Input<pulumi.Input<inputs.quicksight.DashboardDataSetReferenceArgs>[]>;
    }
    interface DashboardSpacingArgs {
        /**
         * String based length that is composed of value and unit
         */
        bottom?: pulumi.Input<string>;
        /**
         * String based length that is composed of value and unit
         */
        left?: pulumi.Input<string>;
        /**
         * String based length that is composed of value and unit
         */
        right?: pulumi.Input<string>;
        /**
         * String based length that is composed of value and unit
         */
        top?: pulumi.Input<string>;
    }
    interface DashboardSpatialStaticFileArgs {
        /**
         * The source of the spatial static file.
         */
        source?: pulumi.Input<inputs.quicksight.DashboardStaticFileSourceArgs>;
        /**
         * The ID of the spatial static file.
         */
        staticFileId: pulumi.Input<string>;
    }
    interface DashboardStaticFileArgs {
        /**
         * The image static file.
         */
        imageStaticFile?: pulumi.Input<inputs.quicksight.DashboardImageStaticFileArgs>;
        /**
         * The spacial static file.
         */
        spatialStaticFile?: pulumi.Input<inputs.quicksight.DashboardSpatialStaticFileArgs>;
    }
    interface DashboardStaticFileS3SourceOptionsArgs {
        /**
         * The name of the Amazon S3 bucket.
         */
        bucketName: pulumi.Input<string>;
        /**
         * The identifier of the static file in the Amazon S3 bucket.
         */
        objectKey: pulumi.Input<string>;
        /**
         * The Region of the Amazon S3 account that contains the bucket.
         */
        region: pulumi.Input<string>;
    }
    interface DashboardStaticFileSourceArgs {
        /**
         * The structure that contains the Amazon S3 location to download the static file from.
         */
        s3Options?: pulumi.Input<inputs.quicksight.DashboardStaticFileS3SourceOptionsArgs>;
        /**
         * The structure that contains the URL to download the static file from.
         */
        urlOptions?: pulumi.Input<inputs.quicksight.DashboardStaticFileUrlSourceOptionsArgs>;
    }
    interface DashboardStaticFileUrlSourceOptionsArgs {
        /**
         * The URL to download the static file from.
         */
        url: pulumi.Input<string>;
    }
    interface DashboardStringDefaultValuesArgs {
        /**
         * The dynamic value of the `StringDefaultValues` . Different defaults displayed according to users, groups, and values mapping.
         */
        dynamicValue?: pulumi.Input<inputs.quicksight.DashboardDynamicDefaultValueArgs>;
        /**
         * The static values of the `DecimalDefaultValues` .
         */
        staticValues?: pulumi.Input<pulumi.Input<string>[]>;
    }
    interface DashboardStringFormatConfigurationArgs {
        /**
         * The options that determine the null value format configuration.
         */
        nullValueFormatConfiguration?: pulumi.Input<inputs.quicksight.DashboardNullValueFormatConfigurationArgs>;
        /**
         * The formatting configuration for numeric strings.
         */
        numericFormatConfiguration?: pulumi.Input<inputs.quicksight.DashboardNumericFormatConfigurationArgs>;
    }
    /**
     * <p>A string parameter.</p>
     */
    interface DashboardStringParameterArgs {
        /**
         * <p>A display name for a string parameter.</p>
         */
        name: pulumi.Input<string>;
        /**
         * <p>The values of a string parameter.</p>
         */
        values: pulumi.Input<pulumi.Input<string>[]>;
    }
    interface DashboardStringParameterDeclarationArgs {
        /**
         * The default values of a parameter. If the parameter is a single-value parameter, a maximum of one default value can be provided.
         */
        defaultValues?: pulumi.Input<inputs.quicksight.DashboardStringDefaultValuesArgs>;
        mappedDataSetParameters?: pulumi.Input<pulumi.Input<inputs.quicksight.DashboardMappedDataSetParameterArgs>[]>;
        /**
         * The name of the parameter that is being declared.
         */
        name: pulumi.Input<string>;
        /**
         * The value type determines whether the parameter is a single-value or multi-value parameter.
         */
        parameterValueType: pulumi.Input<enums.quicksight.DashboardParameterValueType>;
        /**
         * The configuration that defines the default value of a `String` parameter when a value has not been set.
         */
        valueWhenUnset?: pulumi.Input<inputs.quicksight.DashboardStringValueWhenUnsetConfigurationArgs>;
    }
    interface DashboardStringValueWhenUnsetConfigurationArgs {
        /**
         * A custom value that's used when the value of a parameter isn't set.
         */
        customValue?: pulumi.Input<string>;
        /**
         * The built-in options for default values. The value can be one of the following:
         *
         * - `RECOMMENDED` : The recommended value.
         * - `NULL` : The `NULL` value.
         */
        valueWhenUnsetOption?: pulumi.Input<enums.quicksight.DashboardValueWhenUnsetOption>;
    }
    interface DashboardSubtotalOptionsArgs {
        /**
         * The custom label string for the subtotal cells.
         */
        customLabel?: pulumi.Input<string>;
        /**
         * The field level (all, custom, last) for the subtotal cells.
         */
        fieldLevel?: pulumi.Input<enums.quicksight.DashboardPivotTableSubtotalLevel>;
        /**
         * The optional configuration of subtotal cells.
         */
        fieldLevelOptions?: pulumi.Input<pulumi.Input<inputs.quicksight.DashboardPivotTableFieldSubtotalOptionsArgs>[]>;
        /**
         * The cell styling options for the subtotals of header cells.
         */
        metricHeaderCellStyle?: pulumi.Input<inputs.quicksight.DashboardTableCellStyleArgs>;
        /**
         * The style targets options for subtotals.
         */
        styleTargets?: pulumi.Input<pulumi.Input<inputs.quicksight.DashboardTableStyleTargetArgs>[]>;
        /**
         * The cell styling options for the subtotal cells.
         */
        totalCellStyle?: pulumi.Input<inputs.quicksight.DashboardTableCellStyleArgs>;
        /**
         * The visibility configuration for the subtotal cells.
         */
        totalsVisibility?: pulumi.Input<enums.quicksight.DashboardVisibility>;
        /**
         * The cell styling options for the subtotals of value cells.
         */
        valueCellStyle?: pulumi.Input<inputs.quicksight.DashboardTableCellStyleArgs>;
    }
    interface DashboardTableAggregatedFieldWellsArgs {
        /**
         * The group by field well for a pivot table. Values are grouped by group by fields.
         */
        groupBy?: pulumi.Input<pulumi.Input<inputs.quicksight.DashboardDimensionFieldArgs>[]>;
        /**
         * The values field well for a pivot table. Values are aggregated based on group by fields.
         */
        values?: pulumi.Input<pulumi.Input<inputs.quicksight.DashboardMeasureFieldArgs>[]>;
    }
    interface DashboardTableBorderOptionsArgs {
        /**
         * The color of a table border.
         */
        color?: pulumi.Input<string>;
        /**
         * The style (none, solid) of a table border.
         */
        style?: pulumi.Input<enums.quicksight.DashboardTableBorderStyle>;
        /**
         * The thickness of a table border.
         */
        thickness?: pulumi.Input<number>;
    }
    interface DashboardTableCellConditionalFormattingArgs {
        /**
         * The field ID of the cell for conditional formatting.
         */
        fieldId: pulumi.Input<string>;
        /**
         * The text format of the cell for conditional formatting.
         */
        textFormat?: pulumi.Input<inputs.quicksight.DashboardTextConditionalFormatArgs>;
    }
    interface DashboardTableCellImageSizingConfigurationArgs {
        /**
         * The cell scaling configuration of the sizing options for the table image configuration.
         */
        tableCellImageScalingConfiguration?: pulumi.Input<enums.quicksight.DashboardTableCellImageScalingConfiguration>;
    }
    interface DashboardTableCellStyleArgs {
        /**
         * The background color for the table cells.
         */
        backgroundColor?: pulumi.Input<string>;
        /**
         * The borders for the table cells.
         */
        border?: pulumi.Input<inputs.quicksight.DashboardGlobalTableBorderOptionsArgs>;
        /**
         * The font configuration of the table cells.
         */
        fontConfiguration?: pulumi.Input<inputs.quicksight.DashboardFontConfigurationArgs>;
        /**
         * The height color for the table cells.
         */
        height?: pulumi.Input<number>;
        /**
         * The horizontal text alignment (left, center, right, auto) for the table cells.
         */
        horizontalTextAlignment?: pulumi.Input<enums.quicksight.DashboardHorizontalTextAlignment>;
        /**
         * The text wrap (none, wrap) for the table cells.
         */
        textWrap?: pulumi.Input<enums.quicksight.DashboardTextWrap>;
        /**
         * The vertical text alignment (top, middle, bottom) for the table cells.
         */
        verticalTextAlignment?: pulumi.Input<enums.quicksight.DashboardVerticalTextAlignment>;
        /**
         * The visibility of the table cells.
         */
        visibility?: pulumi.Input<enums.quicksight.DashboardVisibility>;
    }
    interface DashboardTableConditionalFormattingArgs {
        /**
         * Conditional formatting options for a `PivotTableVisual` .
         */
        conditionalFormattingOptions?: pulumi.Input<pulumi.Input<inputs.quicksight.DashboardTableConditionalFormattingOptionArgs>[]>;
    }
    interface DashboardTableConditionalFormattingOptionArgs {
        /**
         * The cell conditional formatting option for a table.
         */
        cell?: pulumi.Input<inputs.quicksight.DashboardTableCellConditionalFormattingArgs>;
        /**
         * The row conditional formatting option for a table.
         */
        row?: pulumi.Input<inputs.quicksight.DashboardTableRowConditionalFormattingArgs>;
    }
    interface DashboardTableConfigurationArgs {
        /**
         * The field options for a table visual.
         */
        fieldOptions?: pulumi.Input<inputs.quicksight.DashboardTableFieldOptionsArgs>;
        /**
         * The field wells of the visual.
         */
        fieldWells?: pulumi.Input<inputs.quicksight.DashboardTableFieldWellsArgs>;
        /**
         * The general visual interactions setup for a visual.
         */
        interactions?: pulumi.Input<inputs.quicksight.DashboardVisualInteractionOptionsArgs>;
        /**
         * The paginated report options for a table visual.
         */
        paginatedReportOptions?: pulumi.Input<inputs.quicksight.DashboardTablePaginatedReportOptionsArgs>;
        /**
         * The sort configuration for a `TableVisual` .
         */
        sortConfiguration?: pulumi.Input<inputs.quicksight.DashboardTableSortConfigurationArgs>;
        /**
         * A collection of inline visualizations to display within a chart.
         */
        tableInlineVisualizations?: pulumi.Input<pulumi.Input<inputs.quicksight.DashboardTableInlineVisualizationArgs>[]>;
        /**
         * The table options for a table visual.
         */
        tableOptions?: pulumi.Input<inputs.quicksight.DashboardTableOptionsArgs>;
        /**
         * The total options for a table visual.
         */
        totalOptions?: pulumi.Input<inputs.quicksight.DashboardTotalOptionsArgs>;
    }
    interface DashboardTableFieldCustomIconContentArgs {
        /**
         * The icon set type (link) of the custom icon content for table URL link content.
         */
        icon?: pulumi.Input<enums.quicksight.DashboardTableFieldIconSetType>;
    }
    interface DashboardTableFieldCustomTextContentArgs {
        /**
         * The font configuration of the custom text content for the table URL link content.
         */
        fontConfiguration: pulumi.Input<inputs.quicksight.DashboardFontConfigurationArgs>;
        /**
         * The string value of the custom text content for the table URL link content.
         */
        value?: pulumi.Input<string>;
    }
    interface DashboardTableFieldImageConfigurationArgs {
        /**
         * The sizing options for the table image configuration.
         */
        sizingOptions?: pulumi.Input<inputs.quicksight.DashboardTableCellImageSizingConfigurationArgs>;
    }
    interface DashboardTableFieldLinkConfigurationArgs {
        /**
         * The URL content (text, icon) for the table link configuration.
         */
        content: pulumi.Input<inputs.quicksight.DashboardTableFieldLinkContentConfigurationArgs>;
        /**
         * The URL target (new tab, new window, same tab) for the table link configuration.
         */
        target: pulumi.Input<enums.quicksight.DashboardUrlTargetConfiguration>;
    }
    interface DashboardTableFieldLinkContentConfigurationArgs {
        /**
         * The custom icon content for the table link content configuration.
         */
        customIconContent?: pulumi.Input<inputs.quicksight.DashboardTableFieldCustomIconContentArgs>;
        /**
         * The custom text content (value, font configuration) for the table link content configuration.
         */
        customTextContent?: pulumi.Input<inputs.quicksight.DashboardTableFieldCustomTextContentArgs>;
    }
    interface DashboardTableFieldOptionArgs {
        /**
         * The custom label for a table field.
         */
        customLabel?: pulumi.Input<string>;
        /**
         * The field ID for a table field.
         */
        fieldId: pulumi.Input<string>;
        /**
         * The URL configuration for a table field.
         */
        urlStyling?: pulumi.Input<inputs.quicksight.DashboardTableFieldUrlConfigurationArgs>;
        /**
         * The visibility of a table field.
         */
        visibility?: pulumi.Input<enums.quicksight.DashboardVisibility>;
        /**
         * String based length that is composed of value and unit in px
         */
        width?: pulumi.Input<string>;
    }
    interface DashboardTableFieldOptionsArgs {
        /**
         * The order of the field IDs that are configured as field options for a table visual.
         */
        order?: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * The settings for the pinned columns of a table visual.
         */
        pinnedFieldOptions?: pulumi.Input<inputs.quicksight.DashboardTablePinnedFieldOptionsArgs>;
        /**
         * The field options to be configured to a table.
         */
        selectedFieldOptions?: pulumi.Input<pulumi.Input<inputs.quicksight.DashboardTableFieldOptionArgs>[]>;
        /**
         * The `TableOptions` of a transposed table.
         */
        transposedTableOptions?: pulumi.Input<pulumi.Input<inputs.quicksight.DashboardTransposedTableOptionArgs>[]>;
    }
    interface DashboardTableFieldUrlConfigurationArgs {
        /**
         * The image configuration of a table field URL.
         */
        imageConfiguration?: pulumi.Input<inputs.quicksight.DashboardTableFieldImageConfigurationArgs>;
        /**
         * The link configuration of a table field URL.
         */
        linkConfiguration?: pulumi.Input<inputs.quicksight.DashboardTableFieldLinkConfigurationArgs>;
    }
    interface DashboardTableFieldWellsArgs {
        /**
         * The aggregated field well for the table.
         */
        tableAggregatedFieldWells?: pulumi.Input<inputs.quicksight.DashboardTableAggregatedFieldWellsArgs>;
        /**
         * The unaggregated field well for the table.
         */
        tableUnaggregatedFieldWells?: pulumi.Input<inputs.quicksight.DashboardTableUnaggregatedFieldWellsArgs>;
    }
    interface DashboardTableInlineVisualizationArgs {
        /**
         * The configuration of the inline visualization of the data bars within a chart.
         */
        dataBars?: pulumi.Input<inputs.quicksight.DashboardDataBarsOptionsArgs>;
    }
    interface DashboardTableOptionsArgs {
        /**
         * The table cell style of table cells.
         */
        cellStyle?: pulumi.Input<inputs.quicksight.DashboardTableCellStyleArgs>;
        /**
         * The table cell style of a table header.
         */
        headerStyle?: pulumi.Input<inputs.quicksight.DashboardTableCellStyleArgs>;
        /**
         * The orientation (vertical, horizontal) for a table.
         */
        orientation?: pulumi.Input<enums.quicksight.DashboardTableOrientation>;
        /**
         * The row alternate color options (widget status, row alternate colors) for a table.
         */
        rowAlternateColorOptions?: pulumi.Input<inputs.quicksight.DashboardRowAlternateColorOptionsArgs>;
    }
    interface DashboardTablePaginatedReportOptionsArgs {
        /**
         * The visibility of repeating header rows on each page.
         */
        overflowColumnHeaderVisibility?: pulumi.Input<enums.quicksight.DashboardVisibility>;
        /**
         * The visibility of printing table overflow across pages.
         */
        verticalOverflowVisibility?: pulumi.Input<enums.quicksight.DashboardVisibility>;
    }
    interface DashboardTablePinnedFieldOptionsArgs {
        /**
         * A list of columns to be pinned to the left of a table visual.
         */
        pinnedLeftFields?: pulumi.Input<pulumi.Input<string>[]>;
    }
    interface DashboardTableRowConditionalFormattingArgs {
        /**
         * The conditional formatting color (solid, gradient) of the background for a table row.
         */
        backgroundColor?: pulumi.Input<inputs.quicksight.DashboardConditionalFormattingColorArgs>;
        /**
         * The conditional formatting color (solid, gradient) of the text for a table row.
         */
        textColor?: pulumi.Input<inputs.quicksight.DashboardConditionalFormattingColorArgs>;
    }
    interface DashboardTableSideBorderOptionsArgs {
        /**
         * The table border options of the bottom border.
         */
        bottom?: pulumi.Input<inputs.quicksight.DashboardTableBorderOptionsArgs>;
        /**
         * The table border options of the inner horizontal border.
         */
        innerHorizontal?: pulumi.Input<inputs.quicksight.DashboardTableBorderOptionsArgs>;
        /**
         * The table border options of the inner vertical border.
         */
        innerVertical?: pulumi.Input<inputs.quicksight.DashboardTableBorderOptionsArgs>;
        /**
         * The table border options of the left border.
         */
        left?: pulumi.Input<inputs.quicksight.DashboardTableBorderOptionsArgs>;
        /**
         * The table border options of the right border.
         */
        right?: pulumi.Input<inputs.quicksight.DashboardTableBorderOptionsArgs>;
        /**
         * The table border options of the top border.
         */
        top?: pulumi.Input<inputs.quicksight.DashboardTableBorderOptionsArgs>;
    }
    interface DashboardTableSortConfigurationArgs {
        /**
         * The pagination configuration (page size, page number) for the table.
         */
        paginationConfiguration?: pulumi.Input<inputs.quicksight.DashboardPaginationConfigurationArgs>;
        /**
         * The field sort options for rows in the table.
         */
        rowSort?: pulumi.Input<pulumi.Input<inputs.quicksight.DashboardFieldSortOptionsArgs>[]>;
    }
    interface DashboardTableStyleTargetArgs {
        /**
         * The cell type of the table style target.
         */
        cellType: pulumi.Input<enums.quicksight.DashboardStyledCellType>;
    }
    interface DashboardTableUnaggregatedFieldWellsArgs {
        /**
         * The values field well for a pivot table. Values are unaggregated for an unaggregated table.
         */
        values?: pulumi.Input<pulumi.Input<inputs.quicksight.DashboardUnaggregatedFieldArgs>[]>;
    }
    interface DashboardTableVisualArgs {
        /**
         * The list of custom actions that are configured for a visual.
         */
        actions?: pulumi.Input<pulumi.Input<inputs.quicksight.DashboardVisualCustomActionArgs>[]>;
        /**
         * The configuration settings of the visual.
         */
        chartConfiguration?: pulumi.Input<inputs.quicksight.DashboardTableConfigurationArgs>;
        /**
         * The conditional formatting for a `PivotTableVisual` .
         */
        conditionalFormatting?: pulumi.Input<inputs.quicksight.DashboardTableConditionalFormattingArgs>;
        /**
         * The subtitle that is displayed on the visual.
         */
        subtitle?: pulumi.Input<inputs.quicksight.DashboardVisualSubtitleLabelOptionsArgs>;
        /**
         * The title that is displayed on the visual.
         */
        title?: pulumi.Input<inputs.quicksight.DashboardVisualTitleLabelOptionsArgs>;
        /**
         * The alt text for the visual.
         */
        visualContentAltText?: pulumi.Input<string>;
        /**
         * The unique identifier of a visual. This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers..
         */
        visualId: pulumi.Input<string>;
    }
    interface DashboardTextAreaControlDisplayOptionsArgs {
        /**
         * The configuration of info icon label options.
         */
        infoIconLabelOptions?: pulumi.Input<inputs.quicksight.DashboardSheetControlInfoIconLabelOptionsArgs>;
        /**
         * The configuration of the placeholder options in a text area control.
         */
        placeholderOptions?: pulumi.Input<inputs.quicksight.DashboardTextControlPlaceholderOptionsArgs>;
        /**
         * The options to configure the title visibility, name, and font size.
         */
        titleOptions?: pulumi.Input<inputs.quicksight.DashboardLabelOptionsArgs>;
    }
    interface DashboardTextConditionalFormatArgs {
        /**
         * The conditional formatting for the text background color.
         */
        backgroundColor?: pulumi.Input<inputs.quicksight.DashboardConditionalFormattingColorArgs>;
        /**
         * The conditional formatting for the icon.
         */
        icon?: pulumi.Input<inputs.quicksight.DashboardConditionalFormattingIconArgs>;
        /**
         * The conditional formatting for the text color.
         */
        textColor?: pulumi.Input<inputs.quicksight.DashboardConditionalFormattingColorArgs>;
    }
    interface DashboardTextControlPlaceholderOptionsArgs {
        /**
         * The visibility configuration of the placeholder options in a text control.
         */
        visibility?: pulumi.Input<enums.quicksight.DashboardVisibility>;
    }
    interface DashboardTextFieldControlDisplayOptionsArgs {
        /**
         * The configuration of info icon label options.
         */
        infoIconLabelOptions?: pulumi.Input<inputs.quicksight.DashboardSheetControlInfoIconLabelOptionsArgs>;
        /**
         * The configuration of the placeholder options in a text field control.
         */
        placeholderOptions?: pulumi.Input<inputs.quicksight.DashboardTextControlPlaceholderOptionsArgs>;
        /**
         * The options to configure the title visibility, name, and font size.
         */
        titleOptions?: pulumi.Input<inputs.quicksight.DashboardLabelOptionsArgs>;
    }
    interface DashboardThousandSeparatorOptionsArgs {
        /**
         * Determines the way numbers are styled to accommodate different readability standards. The `DEFAULT` value uses the standard international grouping system and groups numbers by the thousands. The `LAKHS` value uses the Indian numbering system and groups numbers by lakhs and crores.
         */
        groupingStyle?: pulumi.Input<enums.quicksight.DashboardDigitGroupingStyle>;
        /**
         * Determines the thousands separator symbol.
         */
        symbol?: pulumi.Input<enums.quicksight.DashboardNumericSeparatorSymbol>;
        /**
         * Determines the visibility of the thousands separator.
         */
        visibility?: pulumi.Input<enums.quicksight.DashboardVisibility>;
    }
    interface DashboardTimeBasedForecastPropertiesArgs {
        /**
         * The lower boundary setup of a forecast computation.
         */
        lowerBoundary?: pulumi.Input<number>;
        /**
         * The periods backward setup of a forecast computation.
         */
        periodsBackward?: pulumi.Input<number>;
        /**
         * The periods forward setup of a forecast computation.
         */
        periodsForward?: pulumi.Input<number>;
        /**
         * The prediction interval setup of a forecast computation.
         */
        predictionInterval?: pulumi.Input<number>;
        /**
         * The seasonality setup of a forecast computation. Choose one of the following options:
         *
         * - `NULL` : The input is set to `NULL` .
         * - `NON_NULL` : The input is set to a custom value.
         */
        seasonality?: pulumi.Input<number>;
        /**
         * The upper boundary setup of a forecast computation.
         */
        upperBoundary?: pulumi.Input<number>;
    }
    interface DashboardTimeEqualityFilterArgs {
        /**
         * The column that the filter is applied to.
         */
        column: pulumi.Input<inputs.quicksight.DashboardColumnIdentifierArgs>;
        /**
         * The default configurations for the associated controls. This applies only for filters that are scoped to multiple sheets.
         */
        defaultFilterControlConfiguration?: pulumi.Input<inputs.quicksight.DashboardDefaultFilterControlConfigurationArgs>;
        /**
         * An identifier that uniquely identifies a filter within a dashboard, analysis, or template.
         */
        filterId: pulumi.Input<string>;
        /**
         * The parameter whose value should be used for the filter value.
         *
         * This field is mutually exclusive to `Value` and `RollingDate` .
         */
        parameterName?: pulumi.Input<string>;
        /**
         * The rolling date input for the `TimeEquality` filter.
         *
         * This field is mutually exclusive to `Value` and `ParameterName` .
         */
        rollingDate?: pulumi.Input<inputs.quicksight.DashboardRollingDateConfigurationArgs>;
        /**
         * The level of time precision that is used to aggregate `DateTime` values.
         */
        timeGranularity?: pulumi.Input<enums.quicksight.DashboardTimeGranularity>;
        /**
         * The value of a `TimeEquality` filter.
         *
         * This field is mutually exclusive to `RollingDate` and `ParameterName` .
         */
        value?: pulumi.Input<string>;
    }
    interface DashboardTimeRangeDrillDownFilterArgs {
        /**
         * The column that the filter is applied to.
         */
        column: pulumi.Input<inputs.quicksight.DashboardColumnIdentifierArgs>;
        /**
         * The maximum value for the filter value range.
         */
        rangeMaximum: pulumi.Input<string>;
        /**
         * The minimum value for the filter value range.
         */
        rangeMinimum: pulumi.Input<string>;
        /**
         * The level of time precision that is used to aggregate `DateTime` values.
         */
        timeGranularity: pulumi.Input<enums.quicksight.DashboardTimeGranularity>;
    }
    interface DashboardTimeRangeFilterArgs {
        /**
         * The column that the filter is applied to.
         */
        column: pulumi.Input<inputs.quicksight.DashboardColumnIdentifierArgs>;
        /**
         * The default configurations for the associated controls. This applies only for filters that are scoped to multiple sheets.
         */
        defaultFilterControlConfiguration?: pulumi.Input<inputs.quicksight.DashboardDefaultFilterControlConfigurationArgs>;
        /**
         * The exclude period of the time range filter.
         */
        excludePeriodConfiguration?: pulumi.Input<inputs.quicksight.DashboardExcludePeriodConfigurationArgs>;
        /**
         * An identifier that uniquely identifies a filter within a dashboard, analysis, or template.
         */
        filterId: pulumi.Input<string>;
        /**
         * Determines whether the maximum value in the filter value range should be included in the filtered results.
         */
        includeMaximum?: pulumi.Input<boolean>;
        /**
         * Determines whether the minimum value in the filter value range should be included in the filtered results.
         */
        includeMinimum?: pulumi.Input<boolean>;
        /**
         * This option determines how null values should be treated when filtering data.
         *
         * - `ALL_VALUES` : Include null values in filtered results.
         * - `NULLS_ONLY` : Only include null values in filtered results.
         * - `NON_NULLS_ONLY` : Exclude null values from filtered results.
         */
        nullOption: pulumi.Input<enums.quicksight.DashboardFilterNullOption>;
        /**
         * The maximum value for the filter value range.
         */
        rangeMaximumValue?: pulumi.Input<inputs.quicksight.DashboardTimeRangeFilterValueArgs>;
        /**
         * The minimum value for the filter value range.
         */
        rangeMinimumValue?: pulumi.Input<inputs.quicksight.DashboardTimeRangeFilterValueArgs>;
        /**
         * The level of time precision that is used to aggregate `DateTime` values.
         */
        timeGranularity?: pulumi.Input<enums.quicksight.DashboardTimeGranularity>;
    }
    interface DashboardTimeRangeFilterValueArgs {
        /**
         * The parameter type input value.
         */
        parameter?: pulumi.Input<string>;
        /**
         * The rolling date input value.
         */
        rollingDate?: pulumi.Input<inputs.quicksight.DashboardRollingDateConfigurationArgs>;
        /**
         * The static input value.
         */
        staticValue?: pulumi.Input<string>;
    }
    interface DashboardTooltipItemArgs {
        /**
         * The tooltip item for the columns that are not part of a field well.
         */
        columnTooltipItem?: pulumi.Input<inputs.quicksight.DashboardColumnTooltipItemArgs>;
        /**
         * The tooltip item for the fields.
         */
        fieldTooltipItem?: pulumi.Input<inputs.quicksight.DashboardFieldTooltipItemArgs>;
    }
    interface DashboardTooltipOptionsArgs {
        /**
         * The setup for the detailed tooltip. The tooltip setup is always saved. The display type is decided based on the tooltip type.
         */
        fieldBasedTooltip?: pulumi.Input<inputs.quicksight.DashboardFieldBasedTooltipArgs>;
        /**
         * The selected type for the tooltip. Choose one of the following options:
         *
         * - `BASIC` : A basic tooltip.
         * - `DETAILED` : A detailed tooltip.
         */
        selectedTooltipType?: pulumi.Input<enums.quicksight.DashboardSelectedTooltipType>;
        /**
         * Determines whether or not the tooltip is visible.
         */
        tooltipVisibility?: pulumi.Input<enums.quicksight.DashboardVisibility>;
    }
    interface DashboardTopBottomFilterArgs {
        /**
         * The aggregation and sort configuration of the top bottom filter.
         */
        aggregationSortConfigurations: pulumi.Input<pulumi.Input<inputs.quicksight.DashboardAggregationSortConfigurationArgs>[]>;
        /**
         * The column that the filter is applied to.
         */
        column: pulumi.Input<inputs.quicksight.DashboardColumnIdentifierArgs>;
        /**
         * The default configurations for the associated controls. This applies only for filters that are scoped to multiple sheets.
         */
        defaultFilterControlConfiguration?: pulumi.Input<inputs.quicksight.DashboardDefaultFilterControlConfigurationArgs>;
        /**
         * An identifier that uniquely identifies a filter within a dashboard, analysis, or template.
         */
        filterId: pulumi.Input<string>;
        /**
         * The number of items to include in the top bottom filter results.
         */
        limit?: pulumi.Input<number>;
        /**
         * The parameter whose value should be used for the filter value.
         */
        parameterName?: pulumi.Input<string>;
        /**
         * The level of time precision that is used to aggregate `DateTime` values.
         */
        timeGranularity?: pulumi.Input<enums.quicksight.DashboardTimeGranularity>;
    }
    interface DashboardTopBottomMoversComputationArgs {
        /**
         * The category field that is used in a computation.
         */
        category?: pulumi.Input<inputs.quicksight.DashboardDimensionFieldArgs>;
        /**
         * The ID for a computation.
         */
        computationId: pulumi.Input<string>;
        /**
         * The mover size setup of the top and bottom movers computation.
         */
        moverSize?: pulumi.Input<number>;
        /**
         * The name of a computation.
         */
        name?: pulumi.Input<string>;
        /**
         * The sort order setup of the top and bottom movers computation.
         */
        sortOrder?: pulumi.Input<enums.quicksight.DashboardTopBottomSortOrder>;
        /**
         * The time field that is used in a computation.
         */
        time?: pulumi.Input<inputs.quicksight.DashboardDimensionFieldArgs>;
        /**
         * The computation type. Choose from the following options:
         *
         * - TOP: Top movers computation.
         * - BOTTOM: Bottom movers computation.
         */
        type: pulumi.Input<enums.quicksight.DashboardTopBottomComputationType>;
        /**
         * The value field that is used in a computation.
         */
        value?: pulumi.Input<inputs.quicksight.DashboardMeasureFieldArgs>;
    }
    interface DashboardTopBottomRankedComputationArgs {
        /**
         * The category field that is used in a computation.
         */
        category?: pulumi.Input<inputs.quicksight.DashboardDimensionFieldArgs>;
        /**
         * The ID for a computation.
         */
        computationId: pulumi.Input<string>;
        /**
         * The name of a computation.
         */
        name?: pulumi.Input<string>;
        /**
         * The result size of a top and bottom ranked computation.
         */
        resultSize?: pulumi.Input<number>;
        /**
         * The computation type. Choose one of the following options:
         *
         * - TOP: A top ranked computation.
         * - BOTTOM: A bottom ranked computation.
         */
        type: pulumi.Input<enums.quicksight.DashboardTopBottomComputationType>;
        /**
         * The value field that is used in a computation.
         */
        value?: pulumi.Input<inputs.quicksight.DashboardMeasureFieldArgs>;
    }
    interface DashboardTotalAggregationComputationArgs {
        /**
         * The ID for a computation.
         */
        computationId: pulumi.Input<string>;
        /**
         * The name of a computation.
         */
        name?: pulumi.Input<string>;
        /**
         * The value field that is used in a computation.
         */
        value?: pulumi.Input<inputs.quicksight.DashboardMeasureFieldArgs>;
    }
    interface DashboardTotalAggregationFunctionArgs {
        /**
         * A built in aggregation function for total values.
         */
        simpleTotalAggregationFunction?: pulumi.Input<enums.quicksight.DashboardSimpleTotalAggregationFunction>;
    }
    interface DashboardTotalAggregationOptionArgs {
        /**
         * The field id that's associated with the total aggregation option.
         */
        fieldId: pulumi.Input<string>;
        /**
         * The total aggregation function that you want to set for a specified field id.
         */
        totalAggregationFunction: pulumi.Input<inputs.quicksight.DashboardTotalAggregationFunctionArgs>;
    }
    interface DashboardTotalOptionsArgs {
        /**
         * The custom label string for the total cells.
         */
        customLabel?: pulumi.Input<string>;
        /**
         * The placement (start, end) for the total cells.
         */
        placement?: pulumi.Input<enums.quicksight.DashboardTableTotalsPlacement>;
        /**
         * The scroll status (pinned, scrolled) for the total cells.
         */
        scrollStatus?: pulumi.Input<enums.quicksight.DashboardTableTotalsScrollStatus>;
        /**
         * The total aggregation settings for each value field.
         */
        totalAggregationOptions?: pulumi.Input<pulumi.Input<inputs.quicksight.DashboardTotalAggregationOptionArgs>[]>;
        /**
         * Cell styling options for the total cells.
         */
        totalCellStyle?: pulumi.Input<inputs.quicksight.DashboardTableCellStyleArgs>;
        /**
         * The visibility configuration for the total cells.
         */
        totalsVisibility?: pulumi.Input<enums.quicksight.DashboardVisibility>;
    }
    interface DashboardTransposedTableOptionArgs {
        /**
         * The index of a columns in a transposed table. The index range is 0-9999.
         */
        columnIndex?: pulumi.Input<number>;
        /**
         * The column type of the column in a transposed table. Choose one of the following options:
         *
         * - `ROW_HEADER_COLUMN` : Refers to the leftmost column of the row header in the transposed table.
         * - `VALUE_COLUMN` : Refers to all value columns in the transposed table.
         */
        columnType: pulumi.Input<enums.quicksight.DashboardTransposedColumnType>;
        /**
         * String based length that is composed of value and unit in px
         */
        columnWidth?: pulumi.Input<string>;
    }
    interface DashboardTreeMapAggregatedFieldWellsArgs {
        /**
         * The color field well of a tree map. Values are grouped by aggregations based on group by fields.
         */
        colors?: pulumi.Input<pulumi.Input<inputs.quicksight.DashboardMeasureFieldArgs>[]>;
        /**
         * The group by field well of a tree map. Values are grouped based on group by fields.
         */
        groups?: pulumi.Input<pulumi.Input<inputs.quicksight.DashboardDimensionFieldArgs>[]>;
        /**
         * The size field well of a tree map. Values are aggregated based on group by fields.
         */
        sizes?: pulumi.Input<pulumi.Input<inputs.quicksight.DashboardMeasureFieldArgs>[]>;
    }
    interface DashboardTreeMapConfigurationArgs {
        /**
         * The label options (label text, label visibility) for the colors displayed in a tree map.
         */
        colorLabelOptions?: pulumi.Input<inputs.quicksight.DashboardChartAxisLabelOptionsArgs>;
        /**
         * The color options (gradient color, point of divergence) of a tree map.
         */
        colorScale?: pulumi.Input<inputs.quicksight.DashboardColorScaleArgs>;
        /**
         * The options that determine if visual data labels are displayed.
         */
        dataLabels?: pulumi.Input<inputs.quicksight.DashboardDataLabelOptionsArgs>;
        /**
         * The field wells of the visual.
         */
        fieldWells?: pulumi.Input<inputs.quicksight.DashboardTreeMapFieldWellsArgs>;
        /**
         * The label options (label text, label visibility) of the groups that are displayed in a tree map.
         */
        groupLabelOptions?: pulumi.Input<inputs.quicksight.DashboardChartAxisLabelOptionsArgs>;
        /**
         * The general visual interactions setup for a visual.
         */
        interactions?: pulumi.Input<inputs.quicksight.DashboardVisualInteractionOptionsArgs>;
        /**
         * The legend display setup of the visual.
         */
        legend?: pulumi.Input<inputs.quicksight.DashboardLegendOptionsArgs>;
        /**
         * The label options (label text, label visibility) of the sizes that are displayed in a tree map.
         */
        sizeLabelOptions?: pulumi.Input<inputs.quicksight.DashboardChartAxisLabelOptionsArgs>;
        /**
         * The sort configuration of a tree map.
         */
        sortConfiguration?: pulumi.Input<inputs.quicksight.DashboardTreeMapSortConfigurationArgs>;
        /**
         * The tooltip display setup of the visual.
         */
        tooltip?: pulumi.Input<inputs.quicksight.DashboardTooltipOptionsArgs>;
    }
    interface DashboardTreeMapFieldWellsArgs {
        /**
         * The aggregated field wells of a tree map.
         */
        treeMapAggregatedFieldWells?: pulumi.Input<inputs.quicksight.DashboardTreeMapAggregatedFieldWellsArgs>;
    }
    interface DashboardTreeMapSortConfigurationArgs {
        /**
         * The limit on the number of groups that are displayed.
         */
        treeMapGroupItemsLimitConfiguration?: pulumi.Input<inputs.quicksight.DashboardItemsLimitConfigurationArgs>;
        /**
         * The sort configuration of group by fields.
         */
        treeMapSort?: pulumi.Input<pulumi.Input<inputs.quicksight.DashboardFieldSortOptionsArgs>[]>;
    }
    interface DashboardTreeMapVisualArgs {
        /**
         * The list of custom actions that are configured for a visual.
         */
        actions?: pulumi.Input<pulumi.Input<inputs.quicksight.DashboardVisualCustomActionArgs>[]>;
        /**
         * The configuration settings of the visual.
         */
        chartConfiguration?: pulumi.Input<inputs.quicksight.DashboardTreeMapConfigurationArgs>;
        /**
         * The column hierarchy that is used during drill-downs and drill-ups.
         */
        columnHierarchies?: pulumi.Input<pulumi.Input<inputs.quicksight.DashboardColumnHierarchyArgs>[]>;
        /**
         * The subtitle that is displayed on the visual.
         */
        subtitle?: pulumi.Input<inputs.quicksight.DashboardVisualSubtitleLabelOptionsArgs>;
        /**
         * The title that is displayed on the visual.
         */
        title?: pulumi.Input<inputs.quicksight.DashboardVisualTitleLabelOptionsArgs>;
        /**
         * The alt text for the visual.
         */
        visualContentAltText?: pulumi.Input<string>;
        /**
         * The unique identifier of a visual. This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers..
         */
        visualId: pulumi.Input<string>;
    }
    interface DashboardTrendArrowOptionsArgs {
        /**
         * The visibility of the trend arrows.
         */
        visibility?: pulumi.Input<enums.quicksight.DashboardVisibility>;
    }
    interface DashboardUnaggregatedFieldArgs {
        /**
         * The column that is used in the `UnaggregatedField` .
         */
        column: pulumi.Input<inputs.quicksight.DashboardColumnIdentifierArgs>;
        /**
         * The custom field ID.
         */
        fieldId: pulumi.Input<string>;
        /**
         * The format configuration of the field.
         */
        formatConfiguration?: pulumi.Input<inputs.quicksight.DashboardFormatConfigurationArgs>;
    }
    interface DashboardUniqueValuesComputationArgs {
        /**
         * The category field that is used in a computation.
         */
        category?: pulumi.Input<inputs.quicksight.DashboardDimensionFieldArgs>;
        /**
         * The ID for a computation.
         */
        computationId: pulumi.Input<string>;
        /**
         * The name of a computation.
         */
        name?: pulumi.Input<string>;
    }
    /**
     * <p>The option to relax the validation that is required to create and update analyses, dashboards, and templates with definition objects. When you set this value to <code>LENIENT</code>, validation is skipped for specific errors.</p>
     */
    interface DashboardValidationStrategyArgs {
        /**
         * The mode of validation for the asset to be created or updated. When you set this value to `STRICT` , strict validation for every error is enforced. When you set this value to `LENIENT` , validation is skipped for specific UI errors.
         */
        mode: pulumi.Input<enums.quicksight.DashboardValidationStrategyMode>;
    }
    interface DashboardVersionDefinitionArgs {
        analysisDefaults?: pulumi.Input<inputs.quicksight.DashboardAnalysisDefaultsArgs>;
        /**
         * An array of calculated field definitions for the dashboard.
         */
        calculatedFields?: pulumi.Input<pulumi.Input<inputs.quicksight.DashboardCalculatedFieldArgs>[]>;
        /**
         * An array of dashboard-level column configurations. Column configurations are used to set the default formatting for a column that is used throughout a dashboard.
         */
        columnConfigurations?: pulumi.Input<pulumi.Input<inputs.quicksight.DashboardColumnConfigurationArgs>[]>;
        /**
         * An array of dataset identifier declarations. With this mapping,you can use dataset identifiers instead of dataset Amazon Resource Names (ARNs) throughout the dashboard's sub-structures.
         */
        dataSetIdentifierDeclarations: pulumi.Input<pulumi.Input<inputs.quicksight.DashboardDataSetIdentifierDeclarationArgs>[]>;
        /**
         * The filter definitions for a dashboard.
         *
         * For more information, see [Filtering Data in Amazon QuickSight](https://docs.aws.amazon.com/quicksight/latest/user/adding-a-filter.html) in the *Amazon QuickSight User Guide* .
         */
        filterGroups?: pulumi.Input<pulumi.Input<inputs.quicksight.DashboardFilterGroupArgs>[]>;
        /**
         * An array of option definitions for a dashboard.
         */
        options?: pulumi.Input<inputs.quicksight.DashboardAssetOptionsArgs>;
        /**
         * The parameter declarations for a dashboard. Parameters are named variables that can transfer a value for use by an action or an object.
         *
         * For more information, see [Parameters in Amazon QuickSight](https://docs.aws.amazon.com/quicksight/latest/user/parameters-in-quicksight.html) in the *Amazon QuickSight User Guide* .
         */
        parameterDeclarations?: pulumi.Input<pulumi.Input<inputs.quicksight.DashboardParameterDeclarationArgs>[]>;
        /**
         * An array of sheet definitions for a dashboard.
         */
        sheets?: pulumi.Input<pulumi.Input<inputs.quicksight.DashboardSheetDefinitionArgs>[]>;
        /**
         * The static files for the definition.
         */
        staticFiles?: pulumi.Input<pulumi.Input<inputs.quicksight.DashboardStaticFileArgs>[]>;
    }
    interface DashboardVisibleRangeOptionsArgs {
        /**
         * The percent range in the visible range.
         */
        percentRange?: pulumi.Input<inputs.quicksight.DashboardPercentVisibleRangeArgs>;
    }
    interface DashboardVisualArgs {
        /**
         * A bar chart.
         *
         * For more information, see [Using bar charts](https://docs.aws.amazon.com/quicksight/latest/user/bar-charts.html) in the *Amazon QuickSight User Guide* .
         */
        barChartVisual?: pulumi.Input<inputs.quicksight.DashboardBarChartVisualArgs>;
        /**
         * A box plot.
         *
         * For more information, see [Using box plots](https://docs.aws.amazon.com/quicksight/latest/user/box-plots.html) in the *Amazon QuickSight User Guide* .
         */
        boxPlotVisual?: pulumi.Input<inputs.quicksight.DashboardBoxPlotVisualArgs>;
        /**
         * A combo chart.
         *
         * For more information, see [Using combo charts](https://docs.aws.amazon.com/quicksight/latest/user/combo-charts.html) in the *Amazon QuickSight User Guide* .
         */
        comboChartVisual?: pulumi.Input<inputs.quicksight.DashboardComboChartVisualArgs>;
        /**
         * A visual that contains custom content.
         *
         * For more information, see [Using custom visual content](https://docs.aws.amazon.com/quicksight/latest/user/custom-visual-content.html) in the *Amazon QuickSight User Guide* .
         */
        customContentVisual?: pulumi.Input<inputs.quicksight.DashboardCustomContentVisualArgs>;
        /**
         * An empty visual.
         */
        emptyVisual?: pulumi.Input<inputs.quicksight.DashboardEmptyVisualArgs>;
        /**
         * A filled map.
         *
         * For more information, see [Creating filled maps](https://docs.aws.amazon.com/quicksight/latest/user/filled-maps.html) in the *Amazon QuickSight User Guide* .
         */
        filledMapVisual?: pulumi.Input<inputs.quicksight.DashboardFilledMapVisualArgs>;
        /**
         * A funnel chart.
         *
         * For more information, see [Using funnel charts](https://docs.aws.amazon.com/quicksight/latest/user/funnel-visual-content.html) in the *Amazon QuickSight User Guide* .
         */
        funnelChartVisual?: pulumi.Input<inputs.quicksight.DashboardFunnelChartVisualArgs>;
        /**
         * A gauge chart.
         *
         * For more information, see [Using gauge charts](https://docs.aws.amazon.com/quicksight/latest/user/gauge-chart.html) in the *Amazon QuickSight User Guide* .
         */
        gaugeChartVisual?: pulumi.Input<inputs.quicksight.DashboardGaugeChartVisualArgs>;
        /**
         * A geospatial map or a points on map visual.
         *
         * For more information, see [Creating point maps](https://docs.aws.amazon.com/quicksight/latest/user/point-maps.html) in the *Amazon QuickSight User Guide* .
         */
        geospatialMapVisual?: pulumi.Input<inputs.quicksight.DashboardGeospatialMapVisualArgs>;
        /**
         * A heat map.
         *
         * For more information, see [Using heat maps](https://docs.aws.amazon.com/quicksight/latest/user/heat-map.html) in the *Amazon QuickSight User Guide* .
         */
        heatMapVisual?: pulumi.Input<inputs.quicksight.DashboardHeatMapVisualArgs>;
        /**
         * A histogram.
         *
         * For more information, see [Using histograms](https://docs.aws.amazon.com/quicksight/latest/user/histogram-charts.html) in the *Amazon QuickSight User Guide* .
         */
        histogramVisual?: pulumi.Input<inputs.quicksight.DashboardHistogramVisualArgs>;
        /**
         * An insight visual.
         *
         * For more information, see [Working with insights](https://docs.aws.amazon.com/quicksight/latest/user/computational-insights.html) in the *Amazon QuickSight User Guide* .
         */
        insightVisual?: pulumi.Input<inputs.quicksight.DashboardInsightVisualArgs>;
        /**
         * A key performance indicator (KPI).
         *
         * For more information, see [Using KPIs](https://docs.aws.amazon.com/quicksight/latest/user/kpi.html) in the *Amazon QuickSight User Guide* .
         */
        kpiVisual?: pulumi.Input<inputs.quicksight.DashboardKpiVisualArgs>;
        /**
         * The properties for a layer map visual
         */
        layerMapVisual?: pulumi.Input<inputs.quicksight.DashboardLayerMapVisualArgs>;
        /**
         * A line chart.
         *
         * For more information, see [Using line charts](https://docs.aws.amazon.com/quicksight/latest/user/line-charts.html) in the *Amazon QuickSight User Guide* .
         */
        lineChartVisual?: pulumi.Input<inputs.quicksight.DashboardLineChartVisualArgs>;
        /**
         * A pie or donut chart.
         *
         * For more information, see [Using pie charts](https://docs.aws.amazon.com/quicksight/latest/user/pie-chart.html) in the *Amazon QuickSight User Guide* .
         */
        pieChartVisual?: pulumi.Input<inputs.quicksight.DashboardPieChartVisualArgs>;
        /**
         * A pivot table.
         *
         * For more information, see [Using pivot tables](https://docs.aws.amazon.com/quicksight/latest/user/pivot-table.html) in the *Amazon QuickSight User Guide* .
         */
        pivotTableVisual?: pulumi.Input<inputs.quicksight.DashboardPivotTableVisualArgs>;
        /**
         * The custom plugin visual type.
         */
        pluginVisual?: pulumi.Input<inputs.quicksight.DashboardPluginVisualArgs>;
        /**
         * A radar chart visual.
         *
         * For more information, see [Using radar charts](https://docs.aws.amazon.com/quicksight/latest/user/radar-chart.html) in the *Amazon QuickSight User Guide* .
         */
        radarChartVisual?: pulumi.Input<inputs.quicksight.DashboardRadarChartVisualArgs>;
        /**
         * A sankey diagram.
         *
         * For more information, see [Using Sankey diagrams](https://docs.aws.amazon.com/quicksight/latest/user/sankey-diagram.html) in the *Amazon QuickSight User Guide* .
         */
        sankeyDiagramVisual?: pulumi.Input<inputs.quicksight.DashboardSankeyDiagramVisualArgs>;
        /**
         * A scatter plot.
         *
         * For more information, see [Using scatter plots](https://docs.aws.amazon.com/quicksight/latest/user/scatter-plot.html) in the *Amazon QuickSight User Guide* .
         */
        scatterPlotVisual?: pulumi.Input<inputs.quicksight.DashboardScatterPlotVisualArgs>;
        /**
         * A table visual.
         *
         * For more information, see [Using tables as visuals](https://docs.aws.amazon.com/quicksight/latest/user/tabular.html) in the *Amazon QuickSight User Guide* .
         */
        tableVisual?: pulumi.Input<inputs.quicksight.DashboardTableVisualArgs>;
        /**
         * A tree map.
         *
         * For more information, see [Using tree maps](https://docs.aws.amazon.com/quicksight/latest/user/tree-map.html) in the *Amazon QuickSight User Guide* .
         */
        treeMapVisual?: pulumi.Input<inputs.quicksight.DashboardTreeMapVisualArgs>;
        /**
         * A waterfall chart.
         *
         * For more information, see [Using waterfall charts](https://docs.aws.amazon.com/quicksight/latest/user/waterfall-chart.html) in the *Amazon QuickSight User Guide* .
         */
        waterfallVisual?: pulumi.Input<inputs.quicksight.DashboardWaterfallVisualArgs>;
        /**
         * A word cloud.
         *
         * For more information, see [Using word clouds](https://docs.aws.amazon.com/quicksight/latest/user/word-cloud.html) in the *Amazon QuickSight User Guide* .
         */
        wordCloudVisual?: pulumi.Input<inputs.quicksight.DashboardWordCloudVisualArgs>;
    }
    interface DashboardVisualAxisSortOptionArgs {
        /**
         * The availaiblity status of a visual's axis sort options.
         */
        availabilityStatus?: pulumi.Input<enums.quicksight.DashboardBehavior>;
    }
    interface DashboardVisualCustomActionArgs {
        /**
         * A list of `VisualCustomActionOperations` .
         *
         * This is a union type structure. For this structure to be valid, only one of the attributes can be defined.
         */
        actionOperations: pulumi.Input<pulumi.Input<inputs.quicksight.DashboardVisualCustomActionOperationArgs>[]>;
        /**
         * The ID of the `VisualCustomAction` .
         */
        customActionId: pulumi.Input<string>;
        /**
         * The name of the `VisualCustomAction` .
         */
        name: pulumi.Input<string>;
        /**
         * The status of the `VisualCustomAction` .
         */
        status?: pulumi.Input<enums.quicksight.DashboardWidgetStatus>;
        /**
         * The trigger of the `VisualCustomAction` .
         *
         * Valid values are defined as follows:
         *
         * - `DATA_POINT_CLICK` : Initiates a custom action by a left pointer click on a data point.
         * - `DATA_POINT_MENU` : Initiates a custom action by right pointer click from the menu.
         */
        trigger: pulumi.Input<enums.quicksight.DashboardVisualCustomActionTrigger>;
    }
    interface DashboardVisualCustomActionOperationArgs {
        /**
         * The filter operation that filters data included in a visual or in an entire sheet.
         */
        filterOperation?: pulumi.Input<inputs.quicksight.DashboardCustomActionFilterOperationArgs>;
        /**
         * The navigation operation that navigates between different sheets in the same analysis.
         */
        navigationOperation?: pulumi.Input<inputs.quicksight.DashboardCustomActionNavigationOperationArgs>;
        /**
         * The set parameter operation that sets parameters in custom action.
         */
        setParametersOperation?: pulumi.Input<inputs.quicksight.DashboardCustomActionSetParametersOperationArgs>;
        /**
         * The URL operation that opens a link to another webpage.
         */
        urlOperation?: pulumi.Input<inputs.quicksight.DashboardCustomActionUrlOperationArgs>;
    }
    interface DashboardVisualInteractionOptionsArgs {
        /**
         * The context menu options for a visual.
         */
        contextMenuOption?: pulumi.Input<inputs.quicksight.DashboardContextMenuOptionArgs>;
        /**
         * The on-visual menu options for a visual.
         */
        visualMenuOption?: pulumi.Input<inputs.quicksight.DashboardVisualMenuOptionArgs>;
    }
    interface DashboardVisualMenuOptionArgs {
        /**
         * The availaiblity status of a visual's menu options.
         */
        availabilityStatus?: pulumi.Input<enums.quicksight.DashboardBehavior>;
    }
    interface DashboardVisualPaletteArgs {
        /**
         * The chart color options for the visual palette.
         */
        chartColor?: pulumi.Input<string>;
        /**
         * The color map options for the visual palette.
         */
        colorMap?: pulumi.Input<pulumi.Input<inputs.quicksight.DashboardDataPathColorArgs>[]>;
    }
    /**
     * <p>The visual publish options of a visual in a dashboard</p>
     */
    interface DashboardVisualPublishOptionsArgs {
        /**
         * Determines if hidden fields are included in an exported dashboard.
         */
        exportHiddenFieldsOption?: pulumi.Input<inputs.quicksight.DashboardExportHiddenFieldsOptionArgs>;
    }
    interface DashboardVisualSubtitleLabelOptionsArgs {
        /**
         * The long text format of the subtitle label, such as plain text or rich text.
         */
        formatText?: pulumi.Input<inputs.quicksight.DashboardLongFormatTextArgs>;
        /**
         * The visibility of the subtitle label.
         */
        visibility?: pulumi.Input<enums.quicksight.DashboardVisibility>;
    }
    interface DashboardVisualTitleLabelOptionsArgs {
        /**
         * The short text format of the title label, such as plain text or rich text.
         */
        formatText?: pulumi.Input<inputs.quicksight.DashboardShortFormatTextArgs>;
        /**
         * The visibility of the title label.
         */
        visibility?: pulumi.Input<enums.quicksight.DashboardVisibility>;
    }
    interface DashboardWaterfallChartAggregatedFieldWellsArgs {
        /**
         * The breakdown field wells of a waterfall visual.
         */
        breakdowns?: pulumi.Input<pulumi.Input<inputs.quicksight.DashboardDimensionFieldArgs>[]>;
        /**
         * The category field wells of a waterfall visual.
         */
        categories?: pulumi.Input<pulumi.Input<inputs.quicksight.DashboardDimensionFieldArgs>[]>;
        /**
         * The value field wells of a waterfall visual.
         */
        values?: pulumi.Input<pulumi.Input<inputs.quicksight.DashboardMeasureFieldArgs>[]>;
    }
    interface DashboardWaterfallChartColorConfigurationArgs {
        /**
         * The color configuration for individual groups within a waterfall visual.
         */
        groupColorConfiguration?: pulumi.Input<inputs.quicksight.DashboardWaterfallChartGroupColorConfigurationArgs>;
    }
    interface DashboardWaterfallChartConfigurationArgs {
        /**
         * The options that determine the presentation of the category axis.
         */
        categoryAxisDisplayOptions?: pulumi.Input<inputs.quicksight.DashboardAxisDisplayOptionsArgs>;
        /**
         * The options that determine the presentation of the category axis label.
         */
        categoryAxisLabelOptions?: pulumi.Input<inputs.quicksight.DashboardChartAxisLabelOptionsArgs>;
        /**
         * The color configuration of a waterfall visual.
         */
        colorConfiguration?: pulumi.Input<inputs.quicksight.DashboardWaterfallChartColorConfigurationArgs>;
        /**
         * The data label configuration of a waterfall visual.
         */
        dataLabels?: pulumi.Input<inputs.quicksight.DashboardDataLabelOptionsArgs>;
        /**
         * The field well configuration of a waterfall visual.
         */
        fieldWells?: pulumi.Input<inputs.quicksight.DashboardWaterfallChartFieldWellsArgs>;
        /**
         * The general visual interactions setup for a visual.
         */
        interactions?: pulumi.Input<inputs.quicksight.DashboardVisualInteractionOptionsArgs>;
        /**
         * The legend configuration of a waterfall visual.
         */
        legend?: pulumi.Input<inputs.quicksight.DashboardLegendOptionsArgs>;
        /**
         * The options that determine the presentation of the y-axis.
         */
        primaryYAxisDisplayOptions?: pulumi.Input<inputs.quicksight.DashboardAxisDisplayOptionsArgs>;
        /**
         * The options that determine the presentation of the y-axis label.
         */
        primaryYAxisLabelOptions?: pulumi.Input<inputs.quicksight.DashboardChartAxisLabelOptionsArgs>;
        /**
         * The sort configuration of a waterfall visual.
         */
        sortConfiguration?: pulumi.Input<inputs.quicksight.DashboardWaterfallChartSortConfigurationArgs>;
        /**
         * The visual palette configuration of a waterfall visual.
         */
        visualPalette?: pulumi.Input<inputs.quicksight.DashboardVisualPaletteArgs>;
        /**
         * The options that determine the presentation of a waterfall visual.
         */
        waterfallChartOptions?: pulumi.Input<inputs.quicksight.DashboardWaterfallChartOptionsArgs>;
    }
    interface DashboardWaterfallChartFieldWellsArgs {
        /**
         * The field well configuration of a waterfall visual.
         */
        waterfallChartAggregatedFieldWells?: pulumi.Input<inputs.quicksight.DashboardWaterfallChartAggregatedFieldWellsArgs>;
    }
    interface DashboardWaterfallChartGroupColorConfigurationArgs {
        /**
         * Defines the color for the negative bars of a waterfall chart.
         */
        negativeBarColor?: pulumi.Input<string>;
        /**
         * Defines the color for the positive bars of a waterfall chart.
         */
        positiveBarColor?: pulumi.Input<string>;
        /**
         * Defines the color for the total bars of a waterfall chart.
         */
        totalBarColor?: pulumi.Input<string>;
    }
    interface DashboardWaterfallChartOptionsArgs {
        /**
         * This option determines the total bar label of a waterfall visual.
         */
        totalBarLabel?: pulumi.Input<string>;
    }
    interface DashboardWaterfallChartSortConfigurationArgs {
        /**
         * The limit on the number of bar groups that are displayed.
         */
        breakdownItemsLimit?: pulumi.Input<inputs.quicksight.DashboardItemsLimitConfigurationArgs>;
        /**
         * The sort configuration of the category fields.
         */
        categorySort?: pulumi.Input<pulumi.Input<inputs.quicksight.DashboardFieldSortOptionsArgs>[]>;
    }
    interface DashboardWaterfallVisualArgs {
        /**
         * The list of custom actions that are configured for a visual.
         */
        actions?: pulumi.Input<pulumi.Input<inputs.quicksight.DashboardVisualCustomActionArgs>[]>;
        /**
         * The configuration for a waterfall visual.
         */
        chartConfiguration?: pulumi.Input<inputs.quicksight.DashboardWaterfallChartConfigurationArgs>;
        /**
         * The column hierarchy that is used during drill-downs and drill-ups.
         */
        columnHierarchies?: pulumi.Input<pulumi.Input<inputs.quicksight.DashboardColumnHierarchyArgs>[]>;
        /**
         * The subtitle that is displayed on the visual.
         */
        subtitle?: pulumi.Input<inputs.quicksight.DashboardVisualSubtitleLabelOptionsArgs>;
        /**
         * The title that is displayed on the visual.
         */
        title?: pulumi.Input<inputs.quicksight.DashboardVisualTitleLabelOptionsArgs>;
        /**
         * The alt text for the visual.
         */
        visualContentAltText?: pulumi.Input<string>;
        /**
         * The unique identifier of a visual. This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers.
         */
        visualId: pulumi.Input<string>;
    }
    interface DashboardWhatIfPointScenarioArgs {
        /**
         * The date that you need the forecast results for.
         */
        date: pulumi.Input<string>;
        /**
         * The target value that you want to meet for the provided date.
         */
        value: pulumi.Input<number>;
    }
    interface DashboardWhatIfRangeScenarioArgs {
        /**
         * The end date in the date range that you need the forecast results for.
         */
        endDate: pulumi.Input<string>;
        /**
         * The start date in the date range that you need the forecast results for.
         */
        startDate: pulumi.Input<string>;
        /**
         * The target value that you want to meet for the provided date range.
         */
        value: pulumi.Input<number>;
    }
    interface DashboardWordCloudAggregatedFieldWellsArgs {
        /**
         * The group by field well of a word cloud. Values are grouped by group by fields.
         */
        groupBy?: pulumi.Input<pulumi.Input<inputs.quicksight.DashboardDimensionFieldArgs>[]>;
        /**
         * The size field well of a word cloud. Values are aggregated based on group by fields.
         */
        size?: pulumi.Input<pulumi.Input<inputs.quicksight.DashboardMeasureFieldArgs>[]>;
    }
    interface DashboardWordCloudChartConfigurationArgs {
        /**
         * The label options (label text, label visibility, and sort icon visibility) for the word cloud category.
         */
        categoryLabelOptions?: pulumi.Input<inputs.quicksight.DashboardChartAxisLabelOptionsArgs>;
        /**
         * The field wells of the visual.
         */
        fieldWells?: pulumi.Input<inputs.quicksight.DashboardWordCloudFieldWellsArgs>;
        /**
         * The general visual interactions setup for a visual.
         */
        interactions?: pulumi.Input<inputs.quicksight.DashboardVisualInteractionOptionsArgs>;
        /**
         * The sort configuration of a word cloud visual.
         */
        sortConfiguration?: pulumi.Input<inputs.quicksight.DashboardWordCloudSortConfigurationArgs>;
        /**
         * The options for a word cloud visual.
         */
        wordCloudOptions?: pulumi.Input<inputs.quicksight.DashboardWordCloudOptionsArgs>;
    }
    interface DashboardWordCloudFieldWellsArgs {
        /**
         * The aggregated field wells of a word cloud.
         */
        wordCloudAggregatedFieldWells?: pulumi.Input<inputs.quicksight.DashboardWordCloudAggregatedFieldWellsArgs>;
    }
    interface DashboardWordCloudOptionsArgs {
        /**
         * The cloud layout options (fluid, normal) of a word cloud.
         */
        cloudLayout?: pulumi.Input<enums.quicksight.DashboardWordCloudCloudLayout>;
        /**
         * The length limit of each word from 1-100.
         */
        maximumStringLength?: pulumi.Input<number>;
        /**
         * The word casing options (lower_case, existing_case) for the words in a word cloud.
         */
        wordCasing?: pulumi.Input<enums.quicksight.DashboardWordCloudWordCasing>;
        /**
         * The word orientation options (horizontal, horizontal_and_vertical) for the words in a word cloud.
         */
        wordOrientation?: pulumi.Input<enums.quicksight.DashboardWordCloudWordOrientation>;
        /**
         * The word padding options (none, small, medium, large) for the words in a word cloud.
         */
        wordPadding?: pulumi.Input<enums.quicksight.DashboardWordCloudWordPadding>;
        /**
         * The word scaling options (emphasize, normal) for the words in a word cloud.
         */
        wordScaling?: pulumi.Input<enums.quicksight.DashboardWordCloudWordScaling>;
    }
    interface DashboardWordCloudSortConfigurationArgs {
        /**
         * The limit on the number of groups that are displayed in a word cloud.
         */
        categoryItemsLimit?: pulumi.Input<inputs.quicksight.DashboardItemsLimitConfigurationArgs>;
        /**
         * The sort configuration of group by fields.
         */
        categorySort?: pulumi.Input<pulumi.Input<inputs.quicksight.DashboardFieldSortOptionsArgs>[]>;
    }
    interface DashboardWordCloudVisualArgs {
        /**
         * The list of custom actions that are configured for a visual.
         */
        actions?: pulumi.Input<pulumi.Input<inputs.quicksight.DashboardVisualCustomActionArgs>[]>;
        /**
         * The configuration settings of the visual.
         */
        chartConfiguration?: pulumi.Input<inputs.quicksight.DashboardWordCloudChartConfigurationArgs>;
        /**
         * The column hierarchy that is used during drill-downs and drill-ups.
         */
        columnHierarchies?: pulumi.Input<pulumi.Input<inputs.quicksight.DashboardColumnHierarchyArgs>[]>;
        /**
         * The subtitle that is displayed on the visual.
         */
        subtitle?: pulumi.Input<inputs.quicksight.DashboardVisualSubtitleLabelOptionsArgs>;
        /**
         * The title that is displayed on the visual.
         */
        title?: pulumi.Input<inputs.quicksight.DashboardVisualTitleLabelOptionsArgs>;
        /**
         * The alt text for the visual.
         */
        visualContentAltText?: pulumi.Input<string>;
        /**
         * The unique identifier of a visual. This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers..
         */
        visualId: pulumi.Input<string>;
    }
    interface DashboardYAxisOptionsArgs {
        /**
         * The Y axis type to be used in the chart.
         *
         * If you choose `PRIMARY_Y_AXIS` , the primary Y Axis is located on the leftmost vertical axis of the chart.
         */
        yAxis: pulumi.Input<enums.quicksight.DashboardSingleYAxisOption>;
    }
    /**
     * <p>A calculated column for a dataset.</p>
     */
    interface DataSetCalculatedColumnArgs {
        /**
         * <p>A unique ID to identify a calculated column. During a dataset update, if the column ID
         *             of a calculated column matches that of an existing calculated column, Amazon QuickSight
         *             preserves the existing calculated column.</p>
         */
        columnId: pulumi.Input<string>;
        /**
         * <p>Column name.</p>
         */
        columnName: pulumi.Input<string>;
        /**
         * <p>An expression that defines the calculated column.</p>
         */
        expression: pulumi.Input<string>;
    }
    /**
     * <p>A transform operation that casts a column to a different type.</p>
     */
    interface DataSetCastColumnTypeOperationArgs {
        /**
         * <p>Column name.</p>
         */
        columnName: pulumi.Input<string>;
        /**
         * <p>When casting a column from string to datetime type, you can supply a string in a
         *             format supported by Amazon QuickSight to denote the source data format.</p>
         */
        format?: pulumi.Input<string>;
        /**
         * New column data type.
         */
        newColumnType: pulumi.Input<enums.quicksight.DataSetColumnDataType>;
        /**
         * The sub data type of the new column. Sub types are only available for decimal columns that are part of a SPICE dataset.
         */
        subType?: pulumi.Input<enums.quicksight.DataSetColumnDataSubType>;
    }
    /**
     * <p>Metadata that contains a description for a column.</p>
     */
    interface DataSetColumnDescriptionArgs {
        /**
         * <p>The text of a description for a column.</p>
         */
        text?: pulumi.Input<string>;
    }
    /**
     * <p>Groupings of columns that work together in certain Amazon QuickSight features. This is
     *             a variant type structure. For this structure to be valid, only one of the attributes can
     *             be non-null.</p>
     */
    interface DataSetColumnGroupArgs {
        /**
         * Geospatial column group that denotes a hierarchy.
         */
        geoSpatialColumnGroup?: pulumi.Input<inputs.quicksight.DataSetGeoSpatialColumnGroupArgs>;
    }
    /**
     * <p>A rule defined to grant access on one or more restricted columns.
     *             Each dataset can have multiple rules.
     *             To create a restricted column, you add it to one or more rules.
     *             Each rule must contain at least one column and at least one user or group.
     *             To be able to see a restricted column, a user or group needs to be added
     *             to a rule for that column.</p>
     */
    interface DataSetColumnLevelPermissionRuleArgs {
        /**
         * <p>An array of column names.</p>
         */
        columnNames?: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * <p>An array of Amazon Resource Names (ARNs) for Amazon QuickSight users or groups.</p>
         */
        principals?: pulumi.Input<pulumi.Input<string>[]>;
    }
    /**
     * <p>A tag for a column in a
     *             <code>
     *                <a href="https://docs.aws.amazon.com/quicksight/latest/APIReference/API_TagColumnOperation.html">TagColumnOperation</a>
     *             </code>
     *             structure. This is a
     *             variant type structure. For this structure to be valid, only one of the attributes can
     *             be non-null.</p>
     */
    interface DataSetColumnTagArgs {
        /**
         * A description for a column.
         */
        columnDescription?: pulumi.Input<inputs.quicksight.DataSetColumnDescriptionArgs>;
        /**
         * A geospatial role for a column.
         */
        columnGeographicRole?: pulumi.Input<enums.quicksight.DataSetGeoSpatialDataRole>;
    }
    /**
     * <p>A transform operation that creates calculated columns. Columns created in one such
     *             operation form a lexical closure.</p>
     */
    interface DataSetCreateColumnsOperationArgs {
        /**
         * <p>Calculated columns to create.</p>
         */
        columns?: pulumi.Input<pulumi.Input<inputs.quicksight.DataSetCalculatedColumnArgs>[]>;
    }
    /**
     * <p>A physical table type built from the results of the custom SQL query.</p>
     */
    interface DataSetCustomSqlArgs {
        /**
         * <p>The column schema from the SQL query result set.</p>
         */
        columns?: pulumi.Input<pulumi.Input<inputs.quicksight.DataSetInputColumnArgs>[]>;
        /**
         * <p>The Amazon Resource Name (ARN) of the data source.</p>
         */
        dataSourceArn: pulumi.Input<string>;
        /**
         * <p>A display name for the SQL query result.</p>
         */
        name: pulumi.Input<string>;
        /**
         * <p>The SQL query.</p>
         */
        sqlQuery: pulumi.Input<string>;
    }
    /**
     * <p>A dataset parameter.</p>
     */
    interface DataSetDatasetParameterArgs {
        /**
         * A date time parameter that is created in the dataset.
         */
        dateTimeDatasetParameter?: pulumi.Input<inputs.quicksight.DataSetDateTimeDatasetParameterArgs>;
        /**
         * A decimal parameter that is created in the dataset.
         */
        decimalDatasetParameter?: pulumi.Input<inputs.quicksight.DataSetDecimalDatasetParameterArgs>;
        /**
         * An integer parameter that is created in the dataset.
         */
        integerDatasetParameter?: pulumi.Input<inputs.quicksight.DataSetIntegerDatasetParameterArgs>;
        /**
         * A string parameter that is created in the dataset.
         */
        stringDatasetParameter?: pulumi.Input<inputs.quicksight.DataSetStringDatasetParameterArgs>;
    }
    /**
     * <p>A date time parameter for a dataset.</p>
     */
    interface DataSetDateTimeDatasetParameterArgs {
        /**
         * A list of default values for a given date time parameter. This structure only accepts static values.
         */
        defaultValues?: pulumi.Input<inputs.quicksight.DataSetDateTimeDatasetParameterDefaultValuesArgs>;
        /**
         * <p>An identifier for the parameter that is created in the dataset.</p>
         */
        id: pulumi.Input<string>;
        /**
         * <p>The name of the date time parameter that is created in the dataset.</p>
         */
        name: pulumi.Input<string>;
        /**
         * The time granularity of the date time parameter.
         */
        timeGranularity?: pulumi.Input<enums.quicksight.DataSetTimeGranularity>;
        /**
         * The value type of the dataset parameter. Valid values are `single value` or `multi value` .
         */
        valueType: pulumi.Input<enums.quicksight.DataSetDatasetParameterValueType>;
    }
    /**
     * <p>The default values of a date time parameter.</p>
     */
    interface DataSetDateTimeDatasetParameterDefaultValuesArgs {
        /**
         * <p>A list of static default values for a given date time parameter.</p>
         */
        staticValues?: pulumi.Input<pulumi.Input<string>[]>;
    }
    /**
     * <p>A decimal parameter for a dataset.</p>
     */
    interface DataSetDecimalDatasetParameterArgs {
        /**
         * A list of default values for a given decimal parameter. This structure only accepts static values.
         */
        defaultValues?: pulumi.Input<inputs.quicksight.DataSetDecimalDatasetParameterDefaultValuesArgs>;
        /**
         * <p>An identifier for the decimal parameter created in the dataset.</p>
         */
        id: pulumi.Input<string>;
        /**
         * <p>The name of the decimal parameter that is created in the dataset.</p>
         */
        name: pulumi.Input<string>;
        /**
         * The value type of the dataset parameter. Valid values are `single value` or `multi value` .
         */
        valueType: pulumi.Input<enums.quicksight.DataSetDatasetParameterValueType>;
    }
    /**
     * <p>The default values of a decimal parameter.</p>
     */
    interface DataSetDecimalDatasetParameterDefaultValuesArgs {
        /**
         * <p>A list of static default values for a given decimal parameter.</p>
         */
        staticValues?: pulumi.Input<pulumi.Input<number>[]>;
    }
    /**
     * <p>A FieldFolder element is a folder that contains fields and nested subfolders.</p>
     */
    interface DataSetFieldFolderArgs {
        /**
         * <p>A folder has a list of columns. A column can only be in one folder.</p>
         */
        columns?: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * <p>The description for a field folder.</p>
         */
        description?: pulumi.Input<string>;
    }
    /**
     * <p>A transform operation that filters rows based on a condition.</p>
     */
    interface DataSetFilterOperationArgs {
        /**
         * <p>An expression that must evaluate to a Boolean value. Rows for which the expression
         *             evaluates to true are kept in the dataset.</p>
         */
        conditionExpression: pulumi.Input<string>;
    }
    /**
     * <p>Geospatial column group that denotes a hierarchy.</p>
     */
    interface DataSetGeoSpatialColumnGroupArgs {
        /**
         * <p>Columns in this hierarchy.</p>
         */
        columns: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * Country code.
         */
        countryCode?: pulumi.Input<enums.quicksight.DataSetGeoSpatialCountryCode>;
        /**
         * <p>A display name for the hierarchy.</p>
         */
        name: pulumi.Input<string>;
    }
    /**
     * <p>The incremental refresh configuration for a dataset.</p>
     */
    interface DataSetIncrementalRefreshArgs {
        /**
         * The lookback window setup for an incremental refresh configuration.
         */
        lookbackWindow: pulumi.Input<inputs.quicksight.DataSetLookbackWindowArgs>;
    }
    /**
     * <p>Wait policy to use when creating/updating dataset. Default is to wait for SPICE ingestion to finish with timeout of 36 hours.</p>
     */
    interface DataSetIngestionWaitPolicyArgs {
        /**
         * <p>The maximum time (in hours) to wait for Ingestion to complete. Default timeout is 36 hours.
         *  Applicable only when DataSetImportMode mode is set to SPICE and WaitForSpiceIngestion is set to true.</p>
         */
        ingestionWaitTimeInHours?: pulumi.Input<number>;
        /**
         * <p>Wait for SPICE ingestion to finish to mark dataset creation/update successful. Default (true).
         *   Applicable only when DataSetImportMode mode is set to SPICE.</p>
         */
        waitForSpiceIngestion?: pulumi.Input<boolean>;
    }
    /**
     * <p>Metadata for a column that is used as the input of a transform operation.</p>
     */
    interface DataSetInputColumnArgs {
        /**
         * <p>The name of this column in the underlying data source.</p>
         */
        name: pulumi.Input<string>;
        /**
         * The sub data type of the column. Sub types are only available for decimal columns that are part of a SPICE dataset.
         */
        subType?: pulumi.Input<enums.quicksight.DataSetColumnDataSubType>;
        /**
         * The data type of the column.
         */
        type: pulumi.Input<enums.quicksight.DataSetInputColumnDataType>;
    }
    /**
     * <p>An integer parameter for a dataset.</p>
     */
    interface DataSetIntegerDatasetParameterArgs {
        /**
         * A list of default values for a given integer parameter. This structure only accepts static values.
         */
        defaultValues?: pulumi.Input<inputs.quicksight.DataSetIntegerDatasetParameterDefaultValuesArgs>;
        /**
         * <p>An identifier for the integer parameter created in the dataset.</p>
         */
        id: pulumi.Input<string>;
        /**
         * <p>The name of the integer parameter that is created in the dataset.</p>
         */
        name: pulumi.Input<string>;
        /**
         * The value type of the dataset parameter. Valid values are `single value` or `multi value` .
         */
        valueType: pulumi.Input<enums.quicksight.DataSetDatasetParameterValueType>;
    }
    /**
     * <p>The default values of an integer parameter.</p>
     */
    interface DataSetIntegerDatasetParameterDefaultValuesArgs {
        /**
         * <p>A list of static default values for a given integer parameter.</p>
         */
        staticValues?: pulumi.Input<pulumi.Input<number>[]>;
    }
    /**
     * <p>The instructions associated with a join. </p>
     */
    interface DataSetJoinInstructionArgs {
        /**
         * Join key properties of the left operand.
         */
        leftJoinKeyProperties?: pulumi.Input<inputs.quicksight.DataSetJoinKeyPropertiesArgs>;
        /**
         * <p>The operand on the left side of a join.</p>
         */
        leftOperand: pulumi.Input<string>;
        /**
         * <p>The join instructions provided in the <code>ON</code> clause of a join.</p>
         */
        onClause: pulumi.Input<string>;
        /**
         * Join key properties of the right operand.
         */
        rightJoinKeyProperties?: pulumi.Input<inputs.quicksight.DataSetJoinKeyPropertiesArgs>;
        /**
         * <p>The operand on the right side of a join.</p>
         */
        rightOperand: pulumi.Input<string>;
        /**
         * The type of join that it is.
         */
        type: pulumi.Input<enums.quicksight.DataSetJoinType>;
    }
    /**
     * <p>Properties associated with the columns participating in a join.</p>
     */
    interface DataSetJoinKeyPropertiesArgs {
        /**
         * <p>A value that indicates that a row in a table is uniquely identified by the columns in
         *             a join key. This is used by Amazon QuickSight to optimize query performance.</p>
         */
        uniqueKey?: pulumi.Input<boolean>;
    }
    /**
     * <p>A <i>logical table</i> is a unit that joins and that data
     *             transformations operate on. A logical table has a source, which can be either a physical
     *             table or result of a join. When a logical table points to a physical table, the logical
     *             table acts as a mutable copy of that physical table through transform operations.</p>
     */
    interface DataSetLogicalTableArgs {
        /**
         * <p>A display name for the logical table.</p>
         */
        alias: pulumi.Input<string>;
        /**
         * <p>Transform operations that act on this logical table. For this structure to be valid, only one of the attributes can be non-null. </p>
         */
        dataTransforms?: pulumi.Input<pulumi.Input<inputs.quicksight.DataSetTransformOperationArgs>[]>;
        /**
         * Source of this logical table.
         */
        source?: pulumi.Input<inputs.quicksight.DataSetLogicalTableSourceArgs>;
    }
    /**
     * <p>Information about the source of a logical table. This is a variant type structure. For
     *             this structure to be valid, only one of the attributes can be non-null.</p>
     */
    interface DataSetLogicalTableSourceArgs {
        /**
         * <p>The Amazon Resource Number (ARN) of the parent dataset.</p>
         */
        dataSetArn?: pulumi.Input<string>;
        /**
         * Specifies the result of a join of two logical tables.
         */
        joinInstruction?: pulumi.Input<inputs.quicksight.DataSetJoinInstructionArgs>;
        /**
         * <p>Physical table ID.</p>
         */
        physicalTableId?: pulumi.Input<string>;
    }
    /**
     * <p>The lookback window setup of an incremental refresh configuration.</p>
     */
    interface DataSetLookbackWindowArgs {
        /**
         * <p>The name of the lookback window column.</p>
         */
        columnName: pulumi.Input<string>;
        /**
         * <p>The lookback window column size.</p>
         */
        size: pulumi.Input<number>;
        /**
         * The size unit that is used for the lookback window column. Valid values for this structure are `HOUR` , `DAY` , and `WEEK` .
         */
        sizeUnit: pulumi.Input<enums.quicksight.DataSetLookbackWindowSizeUnit>;
    }
    /**
     * <p>The configuration that overrides the existing default values for a dataset parameter that is inherited from another dataset.</p>
     */
    interface DataSetNewDefaultValuesArgs {
        /**
         * <p>A list of static default values for a given date time parameter.</p>
         */
        dateTimeStaticValues?: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * <p>A list of static default values for a given decimal parameter.</p>
         */
        decimalStaticValues?: pulumi.Input<pulumi.Input<number>[]>;
        /**
         * <p>A list of static default values for a given integer parameter.</p>
         */
        integerStaticValues?: pulumi.Input<pulumi.Input<number>[]>;
        /**
         * <p>A list of static default values for a given string parameter.</p>
         */
        stringStaticValues?: pulumi.Input<pulumi.Input<string>[]>;
    }
    /**
     * <p>A transform operation that overrides the dataset parameter values that are defined in another dataset.</p>
     */
    interface DataSetOverrideDatasetParameterOperationArgs {
        /**
         * The new default values for the parameter.
         */
        newDefaultValues?: pulumi.Input<inputs.quicksight.DataSetNewDefaultValuesArgs>;
        /**
         * <p>The new name for the parameter.</p>
         */
        newParameterName?: pulumi.Input<string>;
        /**
         * <p>The name of the parameter to be overridden with different values.</p>
         */
        parameterName: pulumi.Input<string>;
    }
    interface DataSetPerformanceConfigurationArgs {
        uniqueKeys?: pulumi.Input<pulumi.Input<inputs.quicksight.DataSetUniqueKeyArgs>[]>;
    }
    /**
     * <p>A view of a data source that contains information about the shape of the data in the
     *             underlying source. This is a variant type structure. For this structure to be valid,
     *             only one of the attributes can be non-null.</p>
     */
    interface DataSetPhysicalTableArgs {
        /**
         * A physical table type built from the results of the custom SQL query.
         */
        customSql?: pulumi.Input<inputs.quicksight.DataSetCustomSqlArgs>;
        /**
         * A physical table type for relational data sources.
         */
        relationalTable?: pulumi.Input<inputs.quicksight.DataSetRelationalTableArgs>;
        /**
         * A physical table type for as S3 data source.
         */
        s3Source?: pulumi.Input<inputs.quicksight.DataSetS3SourceArgs>;
    }
    /**
     * <p>A transform operation that projects columns. Operations that come after a projection
     *             can only refer to projected columns.</p>
     */
    interface DataSetProjectOperationArgs {
        /**
         * <p>Projected columns.</p>
         */
        projectedColumns: pulumi.Input<pulumi.Input<string>[]>;
    }
    /**
     * <p>The refresh configuration of a dataset.</p>
     */
    interface DataSetRefreshConfigurationArgs {
        /**
         * The incremental refresh for the dataset.
         */
        incrementalRefresh: pulumi.Input<inputs.quicksight.DataSetIncrementalRefreshArgs>;
    }
    interface DataSetRefreshFailureConfigurationArgs {
        /**
         * The email alert configuration for a dataset refresh failure.
         */
        emailAlert?: pulumi.Input<inputs.quicksight.DataSetRefreshFailureEmailAlertArgs>;
    }
    interface DataSetRefreshFailureEmailAlertArgs {
        /**
         * The status value that determines if email alerts are sent.
         */
        alertStatus?: pulumi.Input<enums.quicksight.DataSetRefreshFailureAlertStatus>;
    }
    /**
     * <p>The refresh properties of a dataset.</p>
     */
    interface DataSetRefreshPropertiesArgs {
        /**
         * The failure configuration for a dataset.
         */
        failureConfiguration?: pulumi.Input<inputs.quicksight.DataSetRefreshFailureConfigurationArgs>;
        /**
         * The refresh configuration for a dataset.
         */
        refreshConfiguration?: pulumi.Input<inputs.quicksight.DataSetRefreshConfigurationArgs>;
    }
    /**
     * <p>A physical table type for relational data sources.</p>
     */
    interface DataSetRelationalTableArgs {
        /**
         * <p>The catalog associated with a table.</p>
         */
        catalog?: pulumi.Input<string>;
        /**
         * <p>The Amazon Resource Name (ARN) for the data source.</p>
         */
        dataSourceArn: pulumi.Input<string>;
        /**
         * <p>The column schema of the table.</p>
         */
        inputColumns?: pulumi.Input<pulumi.Input<inputs.quicksight.DataSetInputColumnArgs>[]>;
        /**
         * <p>The name of the relational table.</p>
         */
        name: pulumi.Input<string>;
        /**
         * <p>The schema name. This name applies to certain relational database engines.</p>
         */
        schema?: pulumi.Input<string>;
    }
    /**
     * <p>A transform operation that renames a column.</p>
     */
    interface DataSetRenameColumnOperationArgs {
        /**
         * <p>The name of the column to be renamed.</p>
         */
        columnName: pulumi.Input<string>;
        /**
         * <p>The new name for the column.</p>
         */
        newColumnName?: pulumi.Input<string>;
    }
    /**
     * <p>Permission for the resource.</p>
     */
    interface DataSetResourcePermissionArgs {
        /**
         * <p>The IAM action to grant or revoke permissions on.</p>
         */
        actions: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * <p>The Amazon Resource Name (ARN) of the principal. This can be one of the
         *             following:</p>
         *          <ul>
         *             <li>
         *                <p>The ARN of an Amazon QuickSight user or group associated with a data source or dataset. (This is common.)</p>
         *             </li>
         *             <li>
         *                <p>The ARN of an Amazon QuickSight user, group, or namespace associated with an analysis, dashboard, template, or theme. (This is common.)</p>
         *             </li>
         *             <li>
         *                <p>The ARN of an Amazon Web Services account root: This is an IAM ARN rather than a QuickSight
         *                     ARN. Use this option only to share resources (templates) across Amazon Web Services accounts.
         *                     (This is less common.) </p>
         *             </li>
         *          </ul>
         */
        principal: pulumi.Input<string>;
    }
    /**
     * <p>Information about a dataset that contains permissions for row-level security (RLS).
     *             The permissions dataset maps fields to users or groups. For more information, see
     *             <a href="https://docs.aws.amazon.com/quicksight/latest/user/restrict-access-to-a-data-set-using-row-level-security.html">Using Row-Level Security (RLS) to Restrict Access to a Dataset</a> in the <i>Amazon QuickSight User
     *                 Guide</i>.</p>
     *          <p>The option to deny permissions by setting <code>PermissionPolicy</code> to <code>DENY_ACCESS</code> is
     *             not supported for new RLS datasets.</p>
     */
    interface DataSetRowLevelPermissionDataSetArgs {
        /**
         * <p>The Amazon Resource Name (ARN) of the dataset that contains permissions for RLS.</p>
         */
        arn: pulumi.Input<string>;
        /**
         * The user or group rules associated with the dataset that contains permissions for RLS.
         *
         * By default, `FormatVersion` is `VERSION_1` . When `FormatVersion` is `VERSION_1` , `UserName` and `GroupName` are required. When `FormatVersion` is `VERSION_2` , `UserARN` and `GroupARN` are required, and `Namespace` must not exist.
         */
        formatVersion?: pulumi.Input<enums.quicksight.DataSetRowLevelPermissionFormatVersion>;
        /**
         * <p>The namespace associated with the dataset that contains permissions for RLS.</p>
         */
        namespace?: pulumi.Input<string>;
        /**
         * The type of permissions to use when interpreting the permissions for RLS. `DENY_ACCESS` is included for backward compatibility only.
         */
        permissionPolicy: pulumi.Input<enums.quicksight.DataSetRowLevelPermissionPolicy>;
        /**
         * The status of the row-level security permission dataset. If enabled, the status is `ENABLED` . If disabled, the status is `DISABLED` .
         */
        status?: pulumi.Input<enums.quicksight.DataSetStatus>;
    }
    /**
     * <p>The configuration of tags on a dataset to set row-level security. </p>
     */
    interface DataSetRowLevelPermissionTagConfigurationArgs {
        /**
         * The status of row-level security tags. If enabled, the status is `ENABLED` . If disabled, the status is `DISABLED` .
         */
        status?: pulumi.Input<enums.quicksight.DataSetStatus>;
        /**
         * <p>A list of tag configuration rules to apply to a dataset. All tag configurations have the OR condition. Tags within each tile will be joined (AND). At least one rule in this structure must have all tag values assigned to it to apply Row-level security (RLS) to the dataset.</p>
         */
        tagRuleConfigurations?: pulumi.Input<pulumi.Input<pulumi.Input<string>[]>[]>;
        /**
         * <p>A set of rules associated with row-level security, such as the tag names and columns that they are assigned to.</p>
         */
        tagRules: pulumi.Input<pulumi.Input<inputs.quicksight.DataSetRowLevelPermissionTagRuleArgs>[]>;
    }
    /**
     * <p>A set of rules associated with a tag.</p>
     */
    interface DataSetRowLevelPermissionTagRuleArgs {
        /**
         * <p>The column name that a tag key is assigned to.</p>
         */
        columnName: pulumi.Input<string>;
        /**
         * <p>A string that you want to use to filter by all the values in a column in the dataset and don’t want to list the values one by one. For example, you can use an asterisk as your match all value.</p>
         */
        matchAllValue?: pulumi.Input<string>;
        /**
         * <p>The unique key for a tag.</p>
         */
        tagKey: pulumi.Input<string>;
        /**
         * <p>A string that you want to use to delimit the values when you pass the values at run time. For example, you can delimit the values with a comma.</p>
         */
        tagMultiValueDelimiter?: pulumi.Input<string>;
    }
    /**
     * <p>A physical table type for an S3 data source.</p>
     */
    interface DataSetS3SourceArgs {
        /**
         * <p>The Amazon Resource Name (ARN) for the data source.</p>
         */
        dataSourceArn: pulumi.Input<string>;
        /**
         * <p>A physical table type for an S3 data source.</p>
         *          <note>
         *             <p>For files that aren't JSON, only <code>STRING</code> data types are supported in input columns.</p>
         *          </note>
         */
        inputColumns?: pulumi.Input<pulumi.Input<inputs.quicksight.DataSetInputColumnArgs>[]>;
        /**
         * Information about the format for the S3 source file or files.
         */
        uploadSettings?: pulumi.Input<inputs.quicksight.DataSetUploadSettingsArgs>;
    }
    /**
     * <p>A string parameter for a dataset.</p>
     */
    interface DataSetStringDatasetParameterArgs {
        /**
         * A list of default values for a given string dataset parameter type. This structure only accepts static values.
         */
        defaultValues?: pulumi.Input<inputs.quicksight.DataSetStringDatasetParameterDefaultValuesArgs>;
        /**
         * <p>An identifier for the string parameter that is created in the dataset.</p>
         */
        id: pulumi.Input<string>;
        /**
         * <p>The name of the string parameter that is created in the dataset.</p>
         */
        name: pulumi.Input<string>;
        /**
         * The value type of the dataset parameter. Valid values are `single value` or `multi value` .
         */
        valueType: pulumi.Input<enums.quicksight.DataSetDatasetParameterValueType>;
    }
    /**
     * <p>The default values of a string parameter.</p>
     */
    interface DataSetStringDatasetParameterDefaultValuesArgs {
        /**
         * <p>A list of static default values for a given string parameter.</p>
         */
        staticValues?: pulumi.Input<pulumi.Input<string>[]>;
    }
    /**
     * <p>A transform operation that tags a column with additional information.</p>
     */
    interface DataSetTagColumnOperationArgs {
        /**
         * <p>The column that this operation acts on.</p>
         */
        columnName: pulumi.Input<string>;
        /**
         * <p>The dataset column tag, currently only used for geospatial type tagging.</p>
         *          <note>
         *             <p>This is not tags for the Amazon Web Services tagging feature.</p>
         *          </note>
         */
        tags: pulumi.Input<pulumi.Input<inputs.quicksight.DataSetColumnTagArgs>[]>;
    }
    /**
     * <p>A data transformation on a logical table. This is a variant type structure. For this
     *             structure to be valid, only one of the attributes can be non-null.</p>
     */
    interface DataSetTransformOperationArgs {
        /**
         * A transform operation that casts a column to a different type.
         */
        castColumnTypeOperation?: pulumi.Input<inputs.quicksight.DataSetCastColumnTypeOperationArgs>;
        /**
         * An operation that creates calculated columns. Columns created in one such operation form a lexical closure.
         */
        createColumnsOperation?: pulumi.Input<inputs.quicksight.DataSetCreateColumnsOperationArgs>;
        /**
         * An operation that filters rows based on some condition.
         */
        filterOperation?: pulumi.Input<inputs.quicksight.DataSetFilterOperationArgs>;
        /**
         * A transform operation that overrides the dataset parameter values that are defined in another dataset.
         */
        overrideDatasetParameterOperation?: pulumi.Input<inputs.quicksight.DataSetOverrideDatasetParameterOperationArgs>;
        /**
         * An operation that projects columns. Operations that come after a projection can only refer to projected columns.
         */
        projectOperation?: pulumi.Input<inputs.quicksight.DataSetProjectOperationArgs>;
        /**
         * An operation that renames a column.
         */
        renameColumnOperation?: pulumi.Input<inputs.quicksight.DataSetRenameColumnOperationArgs>;
        /**
         * An operation that tags a column with additional information.
         */
        tagColumnOperation?: pulumi.Input<inputs.quicksight.DataSetTagColumnOperationArgs>;
        untagColumnOperation?: pulumi.Input<inputs.quicksight.DataSetUntagColumnOperationArgs>;
    }
    interface DataSetUniqueKeyArgs {
        columnNames: pulumi.Input<pulumi.Input<string>[]>;
    }
    /**
     * <p>A transform operation that removes tags associated with a column.</p>
     */
    interface DataSetUntagColumnOperationArgs {
        /**
         * <p>The column that this operation acts on.</p>
         */
        columnName: pulumi.Input<string>;
        /**
         * <p>The column tags to remove from this column.</p>
         */
        tagNames: pulumi.Input<pulumi.Input<enums.quicksight.DataSetColumnTagName>[]>;
    }
    /**
     * <p>Information about the format for a source file or files.</p>
     */
    interface DataSetUploadSettingsArgs {
        /**
         * <p>Whether the file has a header row, or the files each have a header row.</p>
         */
        containsHeader?: pulumi.Input<boolean>;
        /**
         * <p>The delimiter between values in the file.</p>
         */
        delimiter?: pulumi.Input<string>;
        /**
         * File format.
         */
        format?: pulumi.Input<enums.quicksight.DataSetFileFormat>;
        /**
         * <p>A row number to start reading data from.</p>
         */
        startFromRow?: pulumi.Input<number>;
        /**
         * Text qualifier.
         */
        textQualifier?: pulumi.Input<enums.quicksight.DataSetTextQualifier>;
    }
    /**
     * <p>The usage configuration to apply to child datasets that reference this dataset as a source.</p>
     */
    interface DataSetUsageConfigurationArgs {
        /**
         * <p>An option that controls whether a child dataset of a direct query can use this dataset as a source.</p>
         */
        disableUseAsDirectQuerySource?: pulumi.Input<boolean>;
        /**
         * <p>An option that controls whether a child dataset that's stored in QuickSight can use this dataset as a source.</p>
         */
        disableUseAsImportedSource?: pulumi.Input<boolean>;
    }
    /**
     * <p>The parameters for OpenSearch.</p>
     */
    interface DataSourceAmazonElasticsearchParametersArgs {
        /**
         * <p>The OpenSearch domain.</p>
         */
        domain: pulumi.Input<string>;
    }
    /**
     * <p>The parameters for OpenSearch.</p>
     */
    interface DataSourceAmazonOpenSearchParametersArgs {
        /**
         * <p>The OpenSearch domain.</p>
         */
        domain: pulumi.Input<string>;
    }
    /**
     * <p>Parameters for Amazon Athena.</p>
     */
    interface DataSourceAthenaParametersArgs {
        /**
         * <p>Use the <code>RoleArn</code> structure to override an account-wide role for a specific Athena data source. For example, say an account administrator has turned off all Athena access with an account-wide role. The administrator can then use <code>RoleArn</code> to bypass the account-wide role and allow Athena access for the single Athena data source that is specified in the structure, even if the account-wide role forbidding Athena access is still active.</p>
         */
        roleArn?: pulumi.Input<string>;
        /**
         * <p>The workgroup that Amazon Athena uses.</p>
         */
        workGroup?: pulumi.Input<string>;
    }
    /**
     * <p>Parameters for Amazon Aurora.</p>
     */
    interface DataSourceAuroraParametersArgs {
        /**
         * <p>Database.</p>
         */
        database: pulumi.Input<string>;
        /**
         * <p>Host.</p>
         */
        host: pulumi.Input<string>;
        /**
         * <p>Port.</p>
         */
        port: pulumi.Input<number>;
    }
    /**
     * <p>Parameters for Amazon Aurora PostgreSQL-Compatible Edition.</p>
     */
    interface DataSourceAuroraPostgreSqlParametersArgs {
        /**
         * <p>The Amazon Aurora PostgreSQL database to connect to.</p>
         */
        database: pulumi.Input<string>;
        /**
         * <p>The Amazon Aurora PostgreSQL-Compatible host to connect to.</p>
         */
        host: pulumi.Input<string>;
        /**
         * <p>The port that Amazon Aurora PostgreSQL is listening on.</p>
         */
        port: pulumi.Input<number>;
    }
    /**
     * <p>The combination of user name and password that are used as credentials.</p>
     */
    interface DataSourceCredentialPairArgs {
        /**
         * <p>A set of alternate data source parameters that you want to share for these
         *             credentials. The credentials are applied in tandem with the data source parameters when
         *             you copy a data source by using a create or update request. The API operation compares
         *             the <code>DataSourceParameters</code> structure that's in the request with the
         *             structures in the <code>AlternateDataSourceParameters</code> allow list. If the
         *             structures are an exact match, the request is allowed to use the new data source with
         *             the existing credentials. If the <code>AlternateDataSourceParameters</code> list is
         *             null, the <code>DataSourceParameters</code> originally used with these
         *                 <code>Credentials</code> is automatically allowed.</p>
         */
        alternateDataSourceParameters?: pulumi.Input<pulumi.Input<inputs.quicksight.DataSourceParametersArgs>[]>;
        /**
         * <p>Password.</p>
         */
        password: pulumi.Input<string>;
        /**
         * <p>User name.</p>
         */
        username: pulumi.Input<string>;
    }
    /**
     * <p>Data source credentials. This is a variant type structure. For this structure to be
     *             valid, only one of the attributes can be non-null.</p>
     */
    interface DataSourceCredentialsArgs {
        /**
         * <p>The Amazon Resource Name (ARN) of a data source that has the credential pair that you
         *             want to use. When <code>CopySourceArn</code> is not null, the credential pair from the
         *             data source in the ARN is used as the credentials for the
         *             <code>DataSourceCredentials</code> structure.</p>
         */
        copySourceArn?: pulumi.Input<string>;
        /**
         * Credential pair. For more information, see `[CredentialPair](https://docs.aws.amazon.com/quicksight/latest/APIReference/API_CredentialPair.html)` .
         */
        credentialPair?: pulumi.Input<inputs.quicksight.DataSourceCredentialPairArgs>;
        /**
         * <p>The Amazon Resource Name (ARN) of the secret associated with the data source in Amazon Secrets Manager.</p>
         */
        secretArn?: pulumi.Input<string>;
    }
    /**
     * <p>The parameters that are required to connect to a Databricks data source.</p>
     */
    interface DataSourceDatabricksParametersArgs {
        /**
         * <p>The host name of the Databricks data source.</p>
         */
        host: pulumi.Input<string>;
        /**
         * <p>The port for the Databricks data source.</p>
         */
        port: pulumi.Input<number>;
        /**
         * <p>The HTTP path of the Databricks data source.</p>
         */
        sqlEndpointPath: pulumi.Input<string>;
    }
    /**
     * <p>Error information for the data source creation or update.</p>
     */
    interface DataSourceErrorInfoArgs {
        /**
         * <p>Error message.</p>
         */
        message?: pulumi.Input<string>;
        /**
         * Error type.
         */
        type?: pulumi.Input<enums.quicksight.DataSourceErrorInfoType>;
    }
    /**
     * <p>The parameters for an IAM Identity Center configuration.</p>
     */
    interface DataSourceIdentityCenterConfigurationArgs {
        /**
         * <p>A Boolean option that controls whether Trusted Identity Propagation should be used.</p>
         */
        enableIdentityPropagation?: pulumi.Input<boolean>;
    }
    /**
     * <p>Amazon S3 manifest file location.</p>
     */
    interface DataSourceManifestFileLocationArgs {
        /**
         * <p>Amazon S3 bucket.</p>
         */
        bucket: pulumi.Input<string>;
        /**
         * <p>Amazon S3 key that identifies an object.</p>
         */
        key: pulumi.Input<string>;
    }
    /**
     * <p>The parameters for MariaDB.</p>
     */
    interface DataSourceMariaDbParametersArgs {
        /**
         * <p>Database.</p>
         */
        database: pulumi.Input<string>;
        /**
         * <p>Host.</p>
         */
        host: pulumi.Input<string>;
        /**
         * <p>Port.</p>
         */
        port: pulumi.Input<number>;
    }
    /**
     * <p>The parameters for MySQL.</p>
     */
    interface DataSourceMySqlParametersArgs {
        /**
         * <p>Database.</p>
         */
        database: pulumi.Input<string>;
        /**
         * <p>Host.</p>
         */
        host: pulumi.Input<string>;
        /**
         * <p>Port.</p>
         */
        port: pulumi.Input<number>;
    }
    interface DataSourceOAuthParametersArgs {
        /**
         * The resource uri of the identity provider.
         */
        identityProviderResourceUri?: pulumi.Input<string>;
        identityProviderVpcConnectionProperties?: pulumi.Input<inputs.quicksight.DataSourceVpcConnectionPropertiesArgs>;
        /**
         * The OAuth scope.
         */
        oAuthScope?: pulumi.Input<string>;
        /**
         * The token endpoint URL of the identity provider.
         */
        tokenProviderUrl: pulumi.Input<string>;
    }
    /**
     * <p>The parameters for Oracle.</p>
     */
    interface DataSourceOracleParametersArgs {
        /**
         * <p>The database.</p>
         */
        database: pulumi.Input<string>;
        /**
         * <p>An Oracle host.</p>
         */
        host: pulumi.Input<string>;
        /**
         * <p>The port.</p>
         */
        port: pulumi.Input<number>;
    }
    /**
     * <p>The parameters that Amazon QuickSight uses to connect to your underlying data source.
     *             This is a variant type structure. For this structure to be valid, only one of the
     *             attributes can be non-null.</p>
     */
    interface DataSourceParametersArgs {
        /**
         * The parameters for OpenSearch.
         */
        amazonElasticsearchParameters?: pulumi.Input<inputs.quicksight.DataSourceAmazonElasticsearchParametersArgs>;
        /**
         * The parameters for OpenSearch.
         */
        amazonOpenSearchParameters?: pulumi.Input<inputs.quicksight.DataSourceAmazonOpenSearchParametersArgs>;
        /**
         * The parameters for Amazon Athena.
         */
        athenaParameters?: pulumi.Input<inputs.quicksight.DataSourceAthenaParametersArgs>;
        /**
         * The parameters for Amazon Aurora MySQL.
         */
        auroraParameters?: pulumi.Input<inputs.quicksight.DataSourceAuroraParametersArgs>;
        /**
         * The parameters for Amazon Aurora.
         */
        auroraPostgreSqlParameters?: pulumi.Input<inputs.quicksight.DataSourceAuroraPostgreSqlParametersArgs>;
        /**
         * The required parameters that are needed to connect to a Databricks data source.
         */
        databricksParameters?: pulumi.Input<inputs.quicksight.DataSourceDatabricksParametersArgs>;
        /**
         * The parameters for MariaDB.
         */
        mariaDbParameters?: pulumi.Input<inputs.quicksight.DataSourceMariaDbParametersArgs>;
        /**
         * The parameters for MySQL.
         */
        mySqlParameters?: pulumi.Input<inputs.quicksight.DataSourceMySqlParametersArgs>;
        /**
         * Oracle parameters.
         */
        oracleParameters?: pulumi.Input<inputs.quicksight.DataSourceOracleParametersArgs>;
        /**
         * The parameters for PostgreSQL.
         */
        postgreSqlParameters?: pulumi.Input<inputs.quicksight.DataSourcePostgreSqlParametersArgs>;
        /**
         * The parameters for Presto.
         */
        prestoParameters?: pulumi.Input<inputs.quicksight.DataSourcePrestoParametersArgs>;
        /**
         * The parameters for Amazon RDS.
         */
        rdsParameters?: pulumi.Input<inputs.quicksight.DataSourceRdsParametersArgs>;
        /**
         * The parameters for Amazon Redshift.
         */
        redshiftParameters?: pulumi.Input<inputs.quicksight.DataSourceRedshiftParametersArgs>;
        /**
         * The parameters for S3.
         */
        s3Parameters?: pulumi.Input<inputs.quicksight.DataSourceS3ParametersArgs>;
        /**
         * The parameters for Snowflake.
         */
        snowflakeParameters?: pulumi.Input<inputs.quicksight.DataSourceSnowflakeParametersArgs>;
        /**
         * The parameters for Spark.
         */
        sparkParameters?: pulumi.Input<inputs.quicksight.DataSourceSparkParametersArgs>;
        /**
         * The parameters for SQL Server.
         */
        sqlServerParameters?: pulumi.Input<inputs.quicksight.DataSourceSqlServerParametersArgs>;
        /**
         * The parameters that are required to connect to a Starburst data source.
         */
        starburstParameters?: pulumi.Input<inputs.quicksight.DataSourceStarburstParametersArgs>;
        /**
         * The parameters for Teradata.
         */
        teradataParameters?: pulumi.Input<inputs.quicksight.DataSourceTeradataParametersArgs>;
        /**
         * The parameters that are required to connect to a Trino data source.
         */
        trinoParameters?: pulumi.Input<inputs.quicksight.DataSourceTrinoParametersArgs>;
    }
    /**
     * <p>The parameters for PostgreSQL.</p>
     */
    interface DataSourcePostgreSqlParametersArgs {
        /**
         * <p>Database.</p>
         */
        database: pulumi.Input<string>;
        /**
         * <p>Host.</p>
         */
        host: pulumi.Input<string>;
        /**
         * <p>Port.</p>
         */
        port: pulumi.Input<number>;
    }
    /**
     * <p>The parameters for Presto.</p>
     */
    interface DataSourcePrestoParametersArgs {
        /**
         * <p>Catalog.</p>
         */
        catalog: pulumi.Input<string>;
        /**
         * <p>Host.</p>
         */
        host: pulumi.Input<string>;
        /**
         * <p>Port.</p>
         */
        port: pulumi.Input<number>;
    }
    /**
     * <p>The parameters for Amazon RDS.</p>
     */
    interface DataSourceRdsParametersArgs {
        /**
         * <p>Database.</p>
         */
        database: pulumi.Input<string>;
        /**
         * <p>Instance ID.</p>
         */
        instanceId: pulumi.Input<string>;
    }
    /**
     * <p>A structure that grants Amazon QuickSight access to your cluster and make a call to the <code>redshift:GetClusterCredentials</code> API. For more information on the <code>redshift:GetClusterCredentials</code> API, see <a href="https://docs.aws.amazon.com/redshift/latest/APIReference/API_GetClusterCredentials.html">
     *                <code>GetClusterCredentials</code>
     *             </a>.</p>
     */
    interface DataSourceRedshiftIamParametersArgs {
        /**
         * <p>Automatically creates a database user. If your database doesn't have a <code>DatabaseUser</code>, set this parameter to <code>True</code>. If there is no <code>DatabaseUser</code>, Amazon QuickSight can't connect to your cluster. The <code>RoleArn</code> that you use for this operation must grant access to <code>redshift:CreateClusterUser</code> to successfully create the user.</p>
         */
        autoCreateDatabaseUser?: pulumi.Input<boolean>;
        /**
         * <p>A list of groups whose permissions will be granted to Amazon QuickSight to access the cluster. These permissions are combined with the permissions granted to Amazon QuickSight by the <code>DatabaseUser</code>. If you choose to include this parameter, the <code>RoleArn</code> must grant access to <code>redshift:JoinGroup</code>.</p>
         */
        databaseGroups?: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * <p>The user whose permissions and group memberships will be used by Amazon QuickSight to access the cluster. If this user already exists in your database, Amazon QuickSight is granted the same permissions that the user has. If the user doesn't exist, set the value of <code>AutoCreateDatabaseUser</code> to <code>True</code> to create a new user with PUBLIC permissions.</p>
         */
        databaseUser?: pulumi.Input<string>;
        /**
         * <p>Use the <code>RoleArn</code> structure to allow Amazon QuickSight to call <code>redshift:GetClusterCredentials</code> on your cluster. The calling principal must have <code>iam:PassRole</code> access to pass the role to Amazon QuickSight. The role's trust policy must allow the Amazon QuickSight service principal to assume the role.</p>
         */
        roleArn: pulumi.Input<string>;
    }
    /**
     * <p>The parameters for Amazon Redshift. The <code>ClusterId</code> field can be blank if
     *             <code>Host</code> and <code>Port</code> are both set. The <code>Host</code> and <code>Port</code> fields can be blank if the <code>ClusterId</code> field is set.</p>
     */
    interface DataSourceRedshiftParametersArgs {
        /**
         * <p>Cluster ID. This field can be blank if the <code>Host</code> and <code>Port</code> are
         *             provided.</p>
         */
        clusterId?: pulumi.Input<string>;
        /**
         * <p>Database.</p>
         */
        database: pulumi.Input<string>;
        /**
         * <p>Host. This field can be blank if <code>ClusterId</code> is provided.</p>
         */
        host?: pulumi.Input<string>;
        /**
         * An optional parameter that uses IAM authentication to grant Amazon QuickSight access to your cluster. This parameter can be used instead of [DataSourceCredentials](https://docs.aws.amazon.com/quicksight/latest/APIReference/API_DataSourceCredentials.html) .
         */
        iamParameters?: pulumi.Input<inputs.quicksight.DataSourceRedshiftIamParametersArgs>;
        /**
         * An optional parameter that configures IAM Identity Center authentication to grant Amazon QuickSight access to your cluster.
         *
         * This parameter can only be specified if your Amazon QuickSight account is configured with IAM Identity Center.
         */
        identityCenterConfiguration?: pulumi.Input<inputs.quicksight.DataSourceIdentityCenterConfigurationArgs>;
        /**
         * <p>Port. This field can be blank if the <code>ClusterId</code> is provided.</p>
         */
        port?: pulumi.Input<number>;
    }
    /**
     * <p>Permission for the resource.</p>
     */
    interface DataSourceResourcePermissionArgs {
        /**
         * <p>The IAM action to grant or revoke permissions on.</p>
         */
        actions: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * <p>The Amazon Resource Name (ARN) of the principal. This can be one of the
         *             following:</p>
         *          <ul>
         *             <li>
         *                <p>The ARN of an Amazon QuickSight user or group associated with a data source or dataset. (This is common.)</p>
         *             </li>
         *             <li>
         *                <p>The ARN of an Amazon QuickSight user, group, or namespace associated with an analysis, dashboard, template, or theme. (This is common.)</p>
         *             </li>
         *             <li>
         *                <p>The ARN of an Amazon Web Services account root: This is an IAM ARN rather than a QuickSight
         *                     ARN. Use this option only to share resources (templates) across Amazon Web Services accounts.
         *                     (This is less common.) </p>
         *             </li>
         *          </ul>
         */
        principal: pulumi.Input<string>;
        resource?: pulumi.Input<string>;
    }
    /**
     * <p>The parameters for S3.</p>
     */
    interface DataSourceS3ParametersArgs {
        /**
         * Location of the Amazon S3 manifest file. This is NULL if the manifest file was uploaded into Amazon QuickSight.
         */
        manifestFileLocation: pulumi.Input<inputs.quicksight.DataSourceManifestFileLocationArgs>;
        /**
         * <p>Use the <code>RoleArn</code> structure to override an account-wide role for a specific S3 data source. For example, say an account administrator has turned off all S3 access with an account-wide role. The administrator can then use <code>RoleArn</code> to bypass the account-wide role and allow S3 access for the single S3 data source that is specified in the structure, even if the account-wide role forbidding S3 access is still active.</p>
         */
        roleArn?: pulumi.Input<string>;
    }
    /**
     * <p>The parameters for Snowflake.</p>
     */
    interface DataSourceSnowflakeParametersArgs {
        /**
         * The authentication type that you want to use for your connection. This parameter accepts OAuth and non-OAuth authentication types.
         */
        authenticationType?: pulumi.Input<enums.quicksight.DataSourceAuthenticationType>;
        /**
         * <p>Database.</p>
         */
        database: pulumi.Input<string>;
        /**
         * The database access control role.
         */
        databaseAccessControlRole?: pulumi.Input<string>;
        /**
         * <p>Host.</p>
         */
        host: pulumi.Input<string>;
        /**
         * An object that contains information needed to create a data source connection between an Amazon QuickSight account and Snowflake.
         */
        oAuthParameters?: pulumi.Input<inputs.quicksight.DataSourceOAuthParametersArgs>;
        /**
         * <p>Warehouse.</p>
         */
        warehouse: pulumi.Input<string>;
    }
    /**
     * <p>The parameters for Spark.</p>
     */
    interface DataSourceSparkParametersArgs {
        /**
         * <p>Host.</p>
         */
        host: pulumi.Input<string>;
        /**
         * <p>Port.</p>
         */
        port: pulumi.Input<number>;
    }
    /**
     * <p>The parameters for SQL Server.</p>
     */
    interface DataSourceSqlServerParametersArgs {
        /**
         * <p>Database.</p>
         */
        database: pulumi.Input<string>;
        /**
         * <p>Host.</p>
         */
        host: pulumi.Input<string>;
        /**
         * <p>Port.</p>
         */
        port: pulumi.Input<number>;
    }
    /**
     * <p>Secure Socket Layer (SSL) properties that apply when Amazon QuickSight connects to your
     *             underlying data source.</p>
     */
    interface DataSourceSslPropertiesArgs {
        /**
         * <p>A Boolean option to control whether SSL should be disabled.</p>
         */
        disableSsl?: pulumi.Input<boolean>;
    }
    /**
     * <p>The parameters that are required to connect to a Starburst data source.</p>
     */
    interface DataSourceStarburstParametersArgs {
        /**
         * The authentication type that you want to use for your connection. This parameter accepts OAuth and non-OAuth authentication types.
         */
        authenticationType?: pulumi.Input<enums.quicksight.DataSourceAuthenticationType>;
        /**
         * <p>The catalog name for the Starburst data source.</p>
         */
        catalog: pulumi.Input<string>;
        /**
         * The database access control role.
         */
        databaseAccessControlRole?: pulumi.Input<string>;
        /**
         * <p>The host name of the Starburst data source.</p>
         */
        host: pulumi.Input<string>;
        /**
         * An object that contains information needed to create a data source connection between an Amazon QuickSight account and Starburst.
         */
        oAuthParameters?: pulumi.Input<inputs.quicksight.DataSourceOAuthParametersArgs>;
        /**
         * <p>The port for the Starburst data source.</p>
         */
        port: pulumi.Input<number>;
        /**
         * The product type for the Starburst data source.
         */
        productType?: pulumi.Input<enums.quicksight.DataSourceStarburstProductType>;
    }
    /**
     * <p>The parameters for Teradata.</p>
     */
    interface DataSourceTeradataParametersArgs {
        /**
         * <p>Database.</p>
         */
        database: pulumi.Input<string>;
        /**
         * <p>Host.</p>
         */
        host: pulumi.Input<string>;
        /**
         * <p>Port.</p>
         */
        port: pulumi.Input<number>;
    }
    /**
     * <p>The parameters that are required to connect to a Trino data source.</p>
     */
    interface DataSourceTrinoParametersArgs {
        /**
         * <p>The catalog name for the Trino data source.</p>
         */
        catalog: pulumi.Input<string>;
        /**
         * <p>The host name of the Trino data source.</p>
         */
        host: pulumi.Input<string>;
        /**
         * <p>The port for the Trino data source.</p>
         */
        port: pulumi.Input<number>;
    }
    /**
     * <p>VPC connection properties.</p>
     */
    interface DataSourceVpcConnectionPropertiesArgs {
        /**
         * <p>The Amazon Resource Name (ARN) for the VPC connection.</p>
         */
        vpcConnectionArn: pulumi.Input<string>;
    }
    /**
     * <p>Permission for the resource.</p>
     */
    interface FolderResourcePermissionArgs {
        /**
         * <p>The IAM action to grant or revoke permissions on.</p>
         */
        actions: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * <p>The Amazon Resource Name (ARN) of the principal. This can be one of the
         *             following:</p>
         *          <ul>
         *             <li>
         *                <p>The ARN of an Amazon QuickSight user or group associated with a data source or dataset. (This is common.)</p>
         *             </li>
         *             <li>
         *                <p>The ARN of an Amazon QuickSight user, group, or namespace associated with an analysis, dashboard, template, or theme. (This is common.)</p>
         *             </li>
         *             <li>
         *                <p>The ARN of an Amazon Web Services account root: This is an IAM ARN rather than a QuickSight
         *                     ARN. Use this option only to share resources (templates) across Amazon Web Services accounts.
         *                     (This is less common.) </p>
         *             </li>
         *          </ul>
         */
        principal: pulumi.Input<string>;
    }
    interface RefreshScheduleMapArgs {
        /**
         * The type of refresh that a dataset undergoes. Valid values are as follows:
         *
         * - `FULL_REFRESH` : A complete refresh of a dataset.
         * - `INCREMENTAL_REFRESH` : A partial refresh of some rows of a dataset, based on the time window specified.
         *
         * For more information on full and incremental refreshes, see [Refreshing SPICE data](https://docs.aws.amazon.com/quicksight/latest/user/refreshing-imported-data.html) in the *Amazon QuickSight User Guide* .
         */
        refreshType?: pulumi.Input<enums.quicksight.RefreshScheduleMapRefreshType>;
        /**
         * <p>Information about the schedule frequency.</p>
         */
        scheduleFrequency?: pulumi.Input<inputs.quicksight.RefreshScheduleMapScheduleFrequencyPropertiesArgs>;
        /**
         * <p>An unique identifier for the refresh schedule.</p>
         */
        scheduleId?: pulumi.Input<string>;
        /**
         * <p>The date time after which refresh is to be scheduled</p>
         */
        startAfterDateTime?: pulumi.Input<string>;
    }
    /**
     * <p>Information about the schedule frequency.</p>
     */
    interface RefreshScheduleMapScheduleFrequencyPropertiesArgs {
        interval?: pulumi.Input<enums.quicksight.RefreshScheduleMapScheduleFrequencyPropertiesInterval>;
        /**
         * <p>The day scheduled for refresh.</p>
         */
        refreshOnDay?: pulumi.Input<inputs.quicksight.RefreshScheduleMapScheduleFrequencyPropertiesRefreshOnDayPropertiesArgs>;
        /**
         * <p>The time of the day for scheduled refresh.</p>
         */
        timeOfTheDay?: pulumi.Input<string>;
        /**
         * <p>The timezone for scheduled refresh.</p>
         */
        timeZone?: pulumi.Input<string>;
    }
    /**
     * <p>The day scheduled for refresh.</p>
     */
    interface RefreshScheduleMapScheduleFrequencyPropertiesRefreshOnDayPropertiesArgs {
        /**
         * <p>The Day Of Month for scheduled refresh.</p>
         */
        dayOfMonth?: pulumi.Input<string>;
        dayOfWeek?: pulumi.Input<enums.quicksight.RefreshScheduleMapScheduleFrequencyPropertiesRefreshOnDayPropertiesDayOfWeek>;
    }
    interface TemplateAggregationFunctionArgs {
        /**
         * Aggregation for attributes.
         */
        attributeAggregationFunction?: pulumi.Input<inputs.quicksight.TemplateAttributeAggregationFunctionArgs>;
        /**
         * Aggregation for categorical values.
         *
         * - `COUNT` : Aggregate by the total number of values, including duplicates.
         * - `DISTINCT_COUNT` : Aggregate by the total number of distinct values.
         */
        categoricalAggregationFunction?: pulumi.Input<enums.quicksight.TemplateCategoricalAggregationFunction>;
        /**
         * Aggregation for date values.
         *
         * - `COUNT` : Aggregate by the total number of values, including duplicates.
         * - `DISTINCT_COUNT` : Aggregate by the total number of distinct values.
         * - `MIN` : Select the smallest date value.
         * - `MAX` : Select the largest date value.
         */
        dateAggregationFunction?: pulumi.Input<enums.quicksight.TemplateDateAggregationFunction>;
        /**
         * Aggregation for numerical values.
         */
        numericalAggregationFunction?: pulumi.Input<inputs.quicksight.TemplateNumericalAggregationFunctionArgs>;
    }
    interface TemplateAggregationSortConfigurationArgs {
        /**
         * The function that aggregates the values in `Column` .
         */
        aggregationFunction?: pulumi.Input<inputs.quicksight.TemplateAggregationFunctionArgs>;
        /**
         * The column that determines the sort order of aggregated values.
         */
        column: pulumi.Input<inputs.quicksight.TemplateColumnIdentifierArgs>;
        /**
         * The sort direction of values.
         *
         * - `ASC` : Sort in ascending order.
         * - `DESC` : Sort in descending order.
         */
        sortDirection: pulumi.Input<enums.quicksight.TemplateSortDirection>;
    }
    interface TemplateAllSheetsFilterScopeConfigurationArgs {
    }
    interface TemplateAnalysisDefaultsArgs {
        /**
         * The configuration for default new sheet settings.
         */
        defaultNewSheetConfiguration: pulumi.Input<inputs.quicksight.TemplateDefaultNewSheetConfigurationArgs>;
    }
    interface TemplateAnchorDateConfigurationArgs {
        /**
         * The options for the date configuration. Choose one of the options below:
         *
         * - `NOW`
         */
        anchorOption?: pulumi.Input<enums.quicksight.TemplateAnchorOption>;
        /**
         * The name of the parameter that is used for the anchor date configuration.
         */
        parameterName?: pulumi.Input<string>;
    }
    interface TemplateArcAxisConfigurationArgs {
        /**
         * The arc axis range of a `GaugeChartVisual` .
         */
        range?: pulumi.Input<inputs.quicksight.TemplateArcAxisDisplayRangeArgs>;
        /**
         * The reserved range of the arc axis.
         */
        reserveRange?: pulumi.Input<number>;
    }
    interface TemplateArcAxisDisplayRangeArgs {
        /**
         * The maximum value of the arc axis range.
         */
        max?: pulumi.Input<number>;
        /**
         * The minimum value of the arc axis range.
         */
        min?: pulumi.Input<number>;
    }
    interface TemplateArcConfigurationArgs {
        /**
         * The option that determines the arc angle of a `GaugeChartVisual` .
         */
        arcAngle?: pulumi.Input<number>;
        /**
         * The options that determine the arc thickness of a `GaugeChartVisual` .
         */
        arcThickness?: pulumi.Input<enums.quicksight.TemplateArcThicknessOptions>;
    }
    interface TemplateArcOptionsArgs {
        /**
         * The arc thickness of a `GaugeChartVisual` .
         */
        arcThickness?: pulumi.Input<enums.quicksight.TemplateArcThickness>;
    }
    interface TemplateAssetOptionsArgs {
        /**
         * Determines the timezone for the analysis.
         */
        timezone?: pulumi.Input<string>;
        /**
         * Determines the week start day for an analysis.
         */
        weekStart?: pulumi.Input<enums.quicksight.TemplateDayOfTheWeek>;
    }
    interface TemplateAttributeAggregationFunctionArgs {
        /**
         * The built-in aggregation functions for attributes.
         *
         * - `UNIQUE_VALUE` : Returns the unique value for a field, aggregated by the dimension fields.
         */
        simpleAttributeAggregation?: pulumi.Input<enums.quicksight.TemplateSimpleAttributeAggregationFunction>;
        /**
         * Used by the `UNIQUE_VALUE` aggregation function. If there are multiple values for the field used by the aggregation, the value for this property will be returned instead. Defaults to '*'.
         */
        valueForMultipleValues?: pulumi.Input<string>;
    }
    interface TemplateAxisDataOptionsArgs {
        /**
         * The options for an axis with a date field.
         */
        dateAxisOptions?: pulumi.Input<inputs.quicksight.TemplateDateAxisOptionsArgs>;
        /**
         * The options for an axis with a numeric field.
         */
        numericAxisOptions?: pulumi.Input<inputs.quicksight.TemplateNumericAxisOptionsArgs>;
    }
    interface TemplateAxisDisplayDataDrivenRangeArgs {
    }
    interface TemplateAxisDisplayMinMaxRangeArgs {
        /**
         * The maximum setup for an axis display range.
         */
        maximum?: pulumi.Input<number>;
        /**
         * The minimum setup for an axis display range.
         */
        minimum?: pulumi.Input<number>;
    }
    interface TemplateAxisDisplayOptionsArgs {
        /**
         * Determines whether or not the axis line is visible.
         */
        axisLineVisibility?: any;
        /**
         * String based length that is composed of value and unit in px
         */
        axisOffset?: pulumi.Input<string>;
        /**
         * The data options for an axis.
         */
        dataOptions?: pulumi.Input<inputs.quicksight.TemplateAxisDataOptionsArgs>;
        /**
         * Determines whether or not the grid line is visible.
         */
        gridLineVisibility?: any;
        /**
         * The scroll bar options for an axis.
         */
        scrollbarOptions?: pulumi.Input<inputs.quicksight.TemplateScrollBarOptionsArgs>;
        /**
         * The tick label options of an axis.
         */
        tickLabelOptions?: pulumi.Input<inputs.quicksight.TemplateAxisTickLabelOptionsArgs>;
    }
    interface TemplateAxisDisplayRangeArgs {
        /**
         * The data-driven setup of an axis display range.
         */
        dataDriven?: pulumi.Input<inputs.quicksight.TemplateAxisDisplayDataDrivenRangeArgs>;
        /**
         * The minimum and maximum setup of an axis display range.
         */
        minMax?: pulumi.Input<inputs.quicksight.TemplateAxisDisplayMinMaxRangeArgs>;
    }
    interface TemplateAxisLabelOptionsArgs {
        /**
         * The options that indicate which field the label belongs to.
         */
        applyTo?: pulumi.Input<inputs.quicksight.TemplateAxisLabelReferenceOptionsArgs>;
        /**
         * The text for the axis label.
         */
        customLabel?: pulumi.Input<string>;
        /**
         * The font configuration of the axis label.
         */
        fontConfiguration?: pulumi.Input<inputs.quicksight.TemplateFontConfigurationArgs>;
    }
    interface TemplateAxisLabelReferenceOptionsArgs {
        /**
         * The column that the axis label is targeted to.
         */
        column: pulumi.Input<inputs.quicksight.TemplateColumnIdentifierArgs>;
        /**
         * The field that the axis label is targeted to.
         */
        fieldId: pulumi.Input<string>;
    }
    interface TemplateAxisLinearScaleArgs {
        /**
         * The step count setup of a linear axis.
         */
        stepCount?: pulumi.Input<number>;
        /**
         * The step size setup of a linear axis.
         */
        stepSize?: pulumi.Input<number>;
    }
    interface TemplateAxisLogarithmicScaleArgs {
        /**
         * The base setup of a logarithmic axis scale.
         */
        base?: pulumi.Input<number>;
    }
    interface TemplateAxisScaleArgs {
        /**
         * The linear axis scale setup.
         */
        linear?: pulumi.Input<inputs.quicksight.TemplateAxisLinearScaleArgs>;
        /**
         * The logarithmic axis scale setup.
         */
        logarithmic?: pulumi.Input<inputs.quicksight.TemplateAxisLogarithmicScaleArgs>;
    }
    interface TemplateAxisTickLabelOptionsArgs {
        /**
         * Determines whether or not the axis ticks are visible.
         */
        labelOptions?: pulumi.Input<inputs.quicksight.TemplateLabelOptionsArgs>;
        /**
         * The rotation angle of the axis tick labels.
         */
        rotationAngle?: pulumi.Input<number>;
    }
    interface TemplateBarChartAggregatedFieldWellsArgs {
        /**
         * The category (y-axis) field well of a bar chart.
         */
        category?: pulumi.Input<pulumi.Input<inputs.quicksight.TemplateDimensionFieldArgs>[]>;
        /**
         * The color (group/color) field well of a bar chart.
         */
        colors?: pulumi.Input<pulumi.Input<inputs.quicksight.TemplateDimensionFieldArgs>[]>;
        /**
         * The small multiples field well of a bar chart.
         */
        smallMultiples?: pulumi.Input<pulumi.Input<inputs.quicksight.TemplateDimensionFieldArgs>[]>;
        /**
         * The value field wells of a bar chart. Values are aggregated by category.
         */
        values?: pulumi.Input<pulumi.Input<inputs.quicksight.TemplateMeasureFieldArgs>[]>;
    }
    interface TemplateBarChartConfigurationArgs {
        /**
         * Determines the arrangement of the bars. The orientation and arrangement of bars determine the type of bar that is used in the visual.
         */
        barsArrangement?: pulumi.Input<enums.quicksight.TemplateBarsArrangement>;
        /**
         * The label display options (grid line, range, scale, axis step) for bar chart category.
         */
        categoryAxis?: pulumi.Input<inputs.quicksight.TemplateAxisDisplayOptionsArgs>;
        /**
         * The label options (label text, label visibility and sort icon visibility) for a bar chart.
         */
        categoryLabelOptions?: pulumi.Input<inputs.quicksight.TemplateChartAxisLabelOptionsArgs>;
        /**
         * The label options (label text, label visibility and sort icon visibility) for a color that is used in a bar chart.
         */
        colorLabelOptions?: pulumi.Input<inputs.quicksight.TemplateChartAxisLabelOptionsArgs>;
        /**
         * The contribution analysis (anomaly configuration) setup of the visual.
         */
        contributionAnalysisDefaults?: pulumi.Input<pulumi.Input<inputs.quicksight.TemplateContributionAnalysisDefaultArgs>[]>;
        /**
         * The options that determine if visual data labels are displayed.
         */
        dataLabels?: pulumi.Input<inputs.quicksight.TemplateDataLabelOptionsArgs>;
        /**
         * The field wells of the visual.
         */
        fieldWells?: pulumi.Input<inputs.quicksight.TemplateBarChartFieldWellsArgs>;
        /**
         * The general visual interactions setup for a visual.
         */
        interactions?: pulumi.Input<inputs.quicksight.TemplateVisualInteractionOptionsArgs>;
        /**
         * The legend display setup of the visual.
         */
        legend?: pulumi.Input<inputs.quicksight.TemplateLegendOptionsArgs>;
        /**
         * The orientation of the bars in a bar chart visual. There are two valid values in this structure:
         *
         * - `HORIZONTAL` : Used for charts that have horizontal bars. Visuals that use this value are horizontal bar charts, horizontal stacked bar charts, and horizontal stacked 100% bar charts.
         * - `VERTICAL` : Used for charts that have vertical bars. Visuals that use this value are vertical bar charts, vertical stacked bar charts, and vertical stacked 100% bar charts.
         */
        orientation?: pulumi.Input<enums.quicksight.TemplateBarChartOrientation>;
        /**
         * The reference line setup of the visual.
         */
        referenceLines?: pulumi.Input<pulumi.Input<inputs.quicksight.TemplateReferenceLineArgs>[]>;
        /**
         * The small multiples setup for the visual.
         */
        smallMultiplesOptions?: pulumi.Input<inputs.quicksight.TemplateSmallMultiplesOptionsArgs>;
        /**
         * The sort configuration of a `BarChartVisual` .
         */
        sortConfiguration?: pulumi.Input<inputs.quicksight.TemplateBarChartSortConfigurationArgs>;
        /**
         * The tooltip display setup of the visual.
         */
        tooltip?: pulumi.Input<inputs.quicksight.TemplateTooltipOptionsArgs>;
        /**
         * The label display options (grid line, range, scale, axis step) for a bar chart value.
         */
        valueAxis?: pulumi.Input<inputs.quicksight.TemplateAxisDisplayOptionsArgs>;
        /**
         * The label options (label text, label visibility and sort icon visibility) for a bar chart value.
         */
        valueLabelOptions?: pulumi.Input<inputs.quicksight.TemplateChartAxisLabelOptionsArgs>;
        /**
         * The palette (chart color) display setup of the visual.
         */
        visualPalette?: pulumi.Input<inputs.quicksight.TemplateVisualPaletteArgs>;
    }
    interface TemplateBarChartFieldWellsArgs {
        /**
         * The aggregated field wells of a bar chart.
         */
        barChartAggregatedFieldWells?: pulumi.Input<inputs.quicksight.TemplateBarChartAggregatedFieldWellsArgs>;
    }
    interface TemplateBarChartSortConfigurationArgs {
        /**
         * The limit on the number of categories displayed in a bar chart.
         */
        categoryItemsLimit?: pulumi.Input<inputs.quicksight.TemplateItemsLimitConfigurationArgs>;
        /**
         * The sort configuration of category fields.
         */
        categorySort?: pulumi.Input<pulumi.Input<inputs.quicksight.TemplateFieldSortOptionsArgs>[]>;
        /**
         * The limit on the number of values displayed in a bar chart.
         */
        colorItemsLimit?: pulumi.Input<inputs.quicksight.TemplateItemsLimitConfigurationArgs>;
        /**
         * The sort configuration of color fields in a bar chart.
         */
        colorSort?: pulumi.Input<pulumi.Input<inputs.quicksight.TemplateFieldSortOptionsArgs>[]>;
        /**
         * The limit on the number of small multiples panels that are displayed.
         */
        smallMultiplesLimitConfiguration?: pulumi.Input<inputs.quicksight.TemplateItemsLimitConfigurationArgs>;
        /**
         * The sort configuration of the small multiples field.
         */
        smallMultiplesSort?: pulumi.Input<pulumi.Input<inputs.quicksight.TemplateFieldSortOptionsArgs>[]>;
    }
    interface TemplateBarChartVisualArgs {
        /**
         * The list of custom actions that are configured for a visual.
         */
        actions?: pulumi.Input<pulumi.Input<inputs.quicksight.TemplateVisualCustomActionArgs>[]>;
        /**
         * The configuration settings of the visual.
         */
        chartConfiguration?: pulumi.Input<inputs.quicksight.TemplateBarChartConfigurationArgs>;
        /**
         * The column hierarchy that is used during drill-downs and drill-ups.
         */
        columnHierarchies?: pulumi.Input<pulumi.Input<inputs.quicksight.TemplateColumnHierarchyArgs>[]>;
        /**
         * The subtitle that is displayed on the visual.
         */
        subtitle?: pulumi.Input<inputs.quicksight.TemplateVisualSubtitleLabelOptionsArgs>;
        /**
         * The title that is displayed on the visual.
         */
        title?: pulumi.Input<inputs.quicksight.TemplateVisualTitleLabelOptionsArgs>;
        /**
         * The alt text for the visual.
         */
        visualContentAltText?: pulumi.Input<string>;
        /**
         * The unique identifier of a visual. This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers.
         */
        visualId: pulumi.Input<string>;
    }
    interface TemplateBinCountOptionsArgs {
        /**
         * The options that determine the bin count value.
         */
        value?: pulumi.Input<number>;
    }
    interface TemplateBinWidthOptionsArgs {
        /**
         * The options that determine the bin count limit.
         */
        binCountLimit?: pulumi.Input<number>;
        /**
         * The options that determine the bin width value.
         */
        value?: pulumi.Input<number>;
    }
    interface TemplateBodySectionConfigurationArgs {
        /**
         * The configuration of content in a body section.
         */
        content: pulumi.Input<inputs.quicksight.TemplateBodySectionContentArgs>;
        /**
         * The configuration of a page break for a section.
         */
        pageBreakConfiguration?: pulumi.Input<inputs.quicksight.TemplateSectionPageBreakConfigurationArgs>;
        /**
         * Describes the configurations that are required to declare a section as repeating.
         */
        repeatConfiguration?: pulumi.Input<inputs.quicksight.TemplateBodySectionRepeatConfigurationArgs>;
        /**
         * The unique identifier of a body section.
         */
        sectionId: pulumi.Input<string>;
        /**
         * The style options of a body section.
         */
        style?: pulumi.Input<inputs.quicksight.TemplateSectionStyleArgs>;
    }
    interface TemplateBodySectionContentArgs {
        /**
         * The layout configuration of a body section.
         */
        layout?: pulumi.Input<inputs.quicksight.TemplateSectionLayoutConfigurationArgs>;
    }
    interface TemplateBodySectionDynamicCategoryDimensionConfigurationArgs {
        column: pulumi.Input<inputs.quicksight.TemplateColumnIdentifierArgs>;
        /**
         * Number of values to use from the column for repetition.
         */
        limit?: pulumi.Input<number>;
        /**
         * Sort criteria on the column values that you use for repetition.
         */
        sortByMetrics?: pulumi.Input<pulumi.Input<inputs.quicksight.TemplateColumnSortArgs>[]>;
    }
    interface TemplateBodySectionDynamicNumericDimensionConfigurationArgs {
        column: pulumi.Input<inputs.quicksight.TemplateColumnIdentifierArgs>;
        /**
         * Number of values to use from the column for repetition.
         */
        limit?: pulumi.Input<number>;
        /**
         * Sort criteria on the column values that you use for repetition.
         */
        sortByMetrics?: pulumi.Input<pulumi.Input<inputs.quicksight.TemplateColumnSortArgs>[]>;
    }
    interface TemplateBodySectionRepeatConfigurationArgs {
        /**
         * List of `BodySectionRepeatDimensionConfiguration` values that describe the dataset column and constraints for the column used to repeat the contents of a section.
         */
        dimensionConfigurations?: pulumi.Input<pulumi.Input<inputs.quicksight.TemplateBodySectionRepeatDimensionConfigurationArgs>[]>;
        /**
         * List of visuals to exclude from repetition in repeating sections. The visuals will render identically, and ignore the repeating configurations in all repeating instances.
         */
        nonRepeatingVisuals?: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * Page break configuration to apply for each repeating instance.
         */
        pageBreakConfiguration?: pulumi.Input<inputs.quicksight.TemplateBodySectionRepeatPageBreakConfigurationArgs>;
    }
    interface TemplateBodySectionRepeatDimensionConfigurationArgs {
        /**
         * Describes the *Category* dataset column and constraints around the dynamic values that will be used in repeating the section contents.
         */
        dynamicCategoryDimensionConfiguration?: pulumi.Input<inputs.quicksight.TemplateBodySectionDynamicCategoryDimensionConfigurationArgs>;
        /**
         * Describes the *Numeric* dataset column and constraints around the dynamic values used to repeat the contents of a section.
         */
        dynamicNumericDimensionConfiguration?: pulumi.Input<inputs.quicksight.TemplateBodySectionDynamicNumericDimensionConfigurationArgs>;
    }
    interface TemplateBodySectionRepeatPageBreakConfigurationArgs {
        after?: pulumi.Input<inputs.quicksight.TemplateSectionAfterPageBreakArgs>;
    }
    interface TemplateBoxPlotAggregatedFieldWellsArgs {
        /**
         * The group by field well of a box plot chart. Values are grouped based on group by fields.
         */
        groupBy?: pulumi.Input<pulumi.Input<inputs.quicksight.TemplateDimensionFieldArgs>[]>;
        /**
         * The value field well of a box plot chart. Values are aggregated based on group by fields.
         */
        values?: pulumi.Input<pulumi.Input<inputs.quicksight.TemplateMeasureFieldArgs>[]>;
    }
    interface TemplateBoxPlotChartConfigurationArgs {
        /**
         * The box plot chart options for a box plot visual
         */
        boxPlotOptions?: pulumi.Input<inputs.quicksight.TemplateBoxPlotOptionsArgs>;
        /**
         * The label display options (grid line, range, scale, axis step) of a box plot category.
         */
        categoryAxis?: pulumi.Input<inputs.quicksight.TemplateAxisDisplayOptionsArgs>;
        /**
         * The label options (label text, label visibility and sort Icon visibility) of a box plot category.
         */
        categoryLabelOptions?: pulumi.Input<inputs.quicksight.TemplateChartAxisLabelOptionsArgs>;
        /**
         * The field wells of the visual.
         */
        fieldWells?: pulumi.Input<inputs.quicksight.TemplateBoxPlotFieldWellsArgs>;
        /**
         * The general visual interactions setup for a visual.
         */
        interactions?: pulumi.Input<inputs.quicksight.TemplateVisualInteractionOptionsArgs>;
        legend?: pulumi.Input<inputs.quicksight.TemplateLegendOptionsArgs>;
        /**
         * The label display options (grid line, range, scale, axis step) of a box plot category.
         */
        primaryYAxisDisplayOptions?: pulumi.Input<inputs.quicksight.TemplateAxisDisplayOptionsArgs>;
        /**
         * The label options (label text, label visibility and sort icon visibility) of a box plot value.
         */
        primaryYAxisLabelOptions?: pulumi.Input<inputs.quicksight.TemplateChartAxisLabelOptionsArgs>;
        /**
         * The reference line setup of the visual.
         */
        referenceLines?: pulumi.Input<pulumi.Input<inputs.quicksight.TemplateReferenceLineArgs>[]>;
        /**
         * The sort configuration of a `BoxPlotVisual` .
         */
        sortConfiguration?: pulumi.Input<inputs.quicksight.TemplateBoxPlotSortConfigurationArgs>;
        /**
         * The tooltip display setup of the visual.
         */
        tooltip?: pulumi.Input<inputs.quicksight.TemplateTooltipOptionsArgs>;
        /**
         * The palette (chart color) display setup of the visual.
         */
        visualPalette?: pulumi.Input<inputs.quicksight.TemplateVisualPaletteArgs>;
    }
    interface TemplateBoxPlotFieldWellsArgs {
        /**
         * The aggregated field wells of a box plot.
         */
        boxPlotAggregatedFieldWells?: pulumi.Input<inputs.quicksight.TemplateBoxPlotAggregatedFieldWellsArgs>;
    }
    interface TemplateBoxPlotOptionsArgs {
        /**
         * Determines the visibility of all data points of the box plot.
         */
        allDataPointsVisibility?: any;
        /**
         * Determines the visibility of the outlier in a box plot.
         */
        outlierVisibility?: any;
        /**
         * The style options of the box plot.
         */
        styleOptions?: pulumi.Input<inputs.quicksight.TemplateBoxPlotStyleOptionsArgs>;
    }
    interface TemplateBoxPlotSortConfigurationArgs {
        /**
         * The sort configuration of a group by fields.
         */
        categorySort?: pulumi.Input<pulumi.Input<inputs.quicksight.TemplateFieldSortOptionsArgs>[]>;
        /**
         * The pagination configuration of a table visual or box plot.
         */
        paginationConfiguration?: pulumi.Input<inputs.quicksight.TemplatePaginationConfigurationArgs>;
    }
    interface TemplateBoxPlotStyleOptionsArgs {
        /**
         * The fill styles (solid, transparent) of the box plot.
         */
        fillStyle?: pulumi.Input<enums.quicksight.TemplateBoxPlotFillStyle>;
    }
    interface TemplateBoxPlotVisualArgs {
        /**
         * The list of custom actions that are configured for a visual.
         */
        actions?: pulumi.Input<pulumi.Input<inputs.quicksight.TemplateVisualCustomActionArgs>[]>;
        /**
         * The configuration settings of the visual.
         */
        chartConfiguration?: pulumi.Input<inputs.quicksight.TemplateBoxPlotChartConfigurationArgs>;
        /**
         * The column hierarchy that is used during drill-downs and drill-ups.
         */
        columnHierarchies?: pulumi.Input<pulumi.Input<inputs.quicksight.TemplateColumnHierarchyArgs>[]>;
        /**
         * The subtitle that is displayed on the visual.
         */
        subtitle?: pulumi.Input<inputs.quicksight.TemplateVisualSubtitleLabelOptionsArgs>;
        /**
         * The title that is displayed on the visual.
         */
        title?: pulumi.Input<inputs.quicksight.TemplateVisualTitleLabelOptionsArgs>;
        /**
         * The alt text for the visual.
         */
        visualContentAltText?: pulumi.Input<string>;
        /**
         * The unique identifier of a visual. This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers..
         */
        visualId: pulumi.Input<string>;
    }
    interface TemplateCalculatedFieldArgs {
        /**
         * The data set that is used in this calculated field.
         */
        dataSetIdentifier: pulumi.Input<string>;
        /**
         * The expression of the calculated field.
         */
        expression: pulumi.Input<string>;
        /**
         * The name of the calculated field.
         */
        name: pulumi.Input<string>;
    }
    interface TemplateCalculatedMeasureFieldArgs {
        /**
         * The expression in the table calculation.
         */
        expression: pulumi.Input<string>;
        /**
         * The custom field ID.
         */
        fieldId: pulumi.Input<string>;
    }
    interface TemplateCascadingControlConfigurationArgs {
        /**
         * A list of source controls that determine the values that are used in the current control.
         */
        sourceControls?: pulumi.Input<pulumi.Input<inputs.quicksight.TemplateCascadingControlSourceArgs>[]>;
    }
    interface TemplateCascadingControlSourceArgs {
        /**
         * The column identifier that determines which column to look up for the source sheet control.
         */
        columnToMatch?: pulumi.Input<inputs.quicksight.TemplateColumnIdentifierArgs>;
        /**
         * The source sheet control ID of a `CascadingControlSource` .
         */
        sourceSheetControlId?: pulumi.Input<string>;
    }
    interface TemplateCategoricalDimensionFieldArgs {
        /**
         * The column that is used in the `CategoricalDimensionField` .
         */
        column: pulumi.Input<inputs.quicksight.TemplateColumnIdentifierArgs>;
        /**
         * The custom field ID.
         */
        fieldId: pulumi.Input<string>;
        /**
         * The format configuration of the field.
         */
        formatConfiguration?: pulumi.Input<inputs.quicksight.TemplateStringFormatConfigurationArgs>;
        /**
         * The custom hierarchy ID.
         */
        hierarchyId?: pulumi.Input<string>;
    }
    interface TemplateCategoricalMeasureFieldArgs {
        /**
         * The aggregation function of the measure field.
         */
        aggregationFunction?: pulumi.Input<enums.quicksight.TemplateCategoricalAggregationFunction>;
        /**
         * The column that is used in the `CategoricalMeasureField` .
         */
        column: pulumi.Input<inputs.quicksight.TemplateColumnIdentifierArgs>;
        /**
         * The custom field ID.
         */
        fieldId: pulumi.Input<string>;
        /**
         * The format configuration of the field.
         */
        formatConfiguration?: pulumi.Input<inputs.quicksight.TemplateStringFormatConfigurationArgs>;
    }
    interface TemplateCategoryDrillDownFilterArgs {
        /**
         * A list of the string inputs that are the values of the category drill down filter.
         */
        categoryValues: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * The column that the filter is applied to.
         */
        column: pulumi.Input<inputs.quicksight.TemplateColumnIdentifierArgs>;
    }
    interface TemplateCategoryFilterArgs {
        /**
         * The column that the filter is applied to.
         */
        column: pulumi.Input<inputs.quicksight.TemplateColumnIdentifierArgs>;
        /**
         * The configuration for a `CategoryFilter` .
         */
        configuration: pulumi.Input<inputs.quicksight.TemplateCategoryFilterConfigurationArgs>;
        /**
         * The default configurations for the associated controls. This applies only for filters that are scoped to multiple sheets.
         */
        defaultFilterControlConfiguration?: pulumi.Input<inputs.quicksight.TemplateDefaultFilterControlConfigurationArgs>;
        /**
         * An identifier that uniquely identifies a filter within a dashboard, analysis, or template.
         */
        filterId: pulumi.Input<string>;
    }
    interface TemplateCategoryFilterConfigurationArgs {
        /**
         * A custom filter that filters based on a single value. This filter can be partially matched.
         */
        customFilterConfiguration?: pulumi.Input<inputs.quicksight.TemplateCustomFilterConfigurationArgs>;
        /**
         * A list of custom filter values. In the Amazon QuickSight console, this filter type is called a custom filter list.
         */
        customFilterListConfiguration?: pulumi.Input<inputs.quicksight.TemplateCustomFilterListConfigurationArgs>;
        /**
         * A list of filter configurations. In the Amazon QuickSight console, this filter type is called a filter list.
         */
        filterListConfiguration?: pulumi.Input<inputs.quicksight.TemplateFilterListConfigurationArgs>;
    }
    interface TemplateCategoryInnerFilterArgs {
        column: pulumi.Input<inputs.quicksight.TemplateColumnIdentifierArgs>;
        configuration: pulumi.Input<inputs.quicksight.TemplateCategoryFilterConfigurationArgs>;
        defaultFilterControlConfiguration?: pulumi.Input<inputs.quicksight.TemplateDefaultFilterControlConfigurationArgs>;
    }
    interface TemplateChartAxisLabelOptionsArgs {
        /**
         * The label options for a chart axis.
         */
        axisLabelOptions?: pulumi.Input<pulumi.Input<inputs.quicksight.TemplateAxisLabelOptionsArgs>[]>;
        /**
         * The visibility configuration of the sort icon on a chart's axis label.
         */
        sortIconVisibility?: any;
        /**
         * The visibility of an axis label on a chart. Choose one of the following options:
         *
         * - `VISIBLE` : Shows the axis.
         * - `HIDDEN` : Hides the axis.
         */
        visibility?: any;
    }
    interface TemplateClusterMarkerArgs {
        /**
         * The simple cluster marker of the cluster marker.
         */
        simpleClusterMarker?: pulumi.Input<inputs.quicksight.TemplateSimpleClusterMarkerArgs>;
    }
    interface TemplateClusterMarkerConfigurationArgs {
        /**
         * The cluster marker that is a part of the cluster marker configuration.
         */
        clusterMarker?: pulumi.Input<inputs.quicksight.TemplateClusterMarkerArgs>;
    }
    interface TemplateColorScaleArgs {
        /**
         * Determines the color fill type.
         */
        colorFillType: pulumi.Input<enums.quicksight.TemplateColorFillType>;
        /**
         * Determines the list of colors that are applied to the visual.
         */
        colors: pulumi.Input<pulumi.Input<inputs.quicksight.TemplateDataColorArgs>[]>;
        /**
         * Determines the color that is applied to null values.
         */
        nullValueColor?: pulumi.Input<inputs.quicksight.TemplateDataColorArgs>;
    }
    interface TemplateColorsConfigurationArgs {
        /**
         * A list of up to 50 custom colors.
         */
        customColors?: pulumi.Input<pulumi.Input<inputs.quicksight.TemplateCustomColorArgs>[]>;
    }
    interface TemplateColumnConfigurationArgs {
        /**
         * The color configurations of the column.
         */
        colorsConfiguration?: pulumi.Input<inputs.quicksight.TemplateColorsConfigurationArgs>;
        /**
         * The column.
         */
        column: pulumi.Input<inputs.quicksight.TemplateColumnIdentifierArgs>;
        /**
         * The format configuration of a column.
         */
        formatConfiguration?: pulumi.Input<inputs.quicksight.TemplateFormatConfigurationArgs>;
        /**
         * The role of the column.
         */
        role?: pulumi.Input<enums.quicksight.TemplateColumnRole>;
    }
    /**
     * <p>A structure describing the name, data type, and geographic role of the columns.</p>
     */
    interface TemplateColumnGroupColumnSchemaArgs {
        /**
         * <p>The name of the column group's column schema.</p>
         */
        name?: pulumi.Input<string>;
    }
    /**
     * <p>The column group schema.</p>
     */
    interface TemplateColumnGroupSchemaArgs {
        /**
         * <p>A structure containing the list of schemas for column group columns.</p>
         */
        columnGroupColumnSchemaList?: pulumi.Input<pulumi.Input<inputs.quicksight.TemplateColumnGroupColumnSchemaArgs>[]>;
        /**
         * <p>The name of the column group schema.</p>
         */
        name?: pulumi.Input<string>;
    }
    interface TemplateColumnHierarchyArgs {
        /**
         * The option that determines the hierarchy of any `DateTime` fields.
         */
        dateTimeHierarchy?: pulumi.Input<inputs.quicksight.TemplateDateTimeHierarchyArgs>;
        /**
         * The option that determines the hierarchy of the fields that are built within a visual's field wells. These fields can't be duplicated to other visuals.
         */
        explicitHierarchy?: pulumi.Input<inputs.quicksight.TemplateExplicitHierarchyArgs>;
        /**
         * The option that determines the hierarchy of the fields that are defined during data preparation. These fields are available to use in any analysis that uses the data source.
         */
        predefinedHierarchy?: pulumi.Input<inputs.quicksight.TemplatePredefinedHierarchyArgs>;
    }
    interface TemplateColumnIdentifierArgs {
        /**
         * The name of the column.
         */
        columnName: pulumi.Input<string>;
        /**
         * The data set that the column belongs to.
         */
        dataSetIdentifier: pulumi.Input<string>;
    }
    /**
     * <p>The column schema.</p>
     */
    interface TemplateColumnSchemaArgs {
        /**
         * <p>The data type of the column schema.</p>
         */
        dataType?: pulumi.Input<string>;
        /**
         * <p>The geographic role of the column schema.</p>
         */
        geographicRole?: pulumi.Input<string>;
        /**
         * <p>The name of the column schema.</p>
         */
        name?: pulumi.Input<string>;
    }
    interface TemplateColumnSortArgs {
        /**
         * The aggregation function that is defined in the column sort.
         */
        aggregationFunction?: pulumi.Input<inputs.quicksight.TemplateAggregationFunctionArgs>;
        /**
         * The sort direction.
         */
        direction: pulumi.Input<enums.quicksight.TemplateSortDirection>;
        sortBy: pulumi.Input<inputs.quicksight.TemplateColumnIdentifierArgs>;
    }
    interface TemplateColumnTooltipItemArgs {
        /**
         * The aggregation function of the column tooltip item.
         */
        aggregation?: pulumi.Input<inputs.quicksight.TemplateAggregationFunctionArgs>;
        /**
         * The target column of the tooltip item.
         */
        column: pulumi.Input<inputs.quicksight.TemplateColumnIdentifierArgs>;
        /**
         * The label of the tooltip item.
         */
        label?: pulumi.Input<string>;
        /**
         * Determines the target of the column tooltip item in a combo chart visual.
         */
        tooltipTarget?: pulumi.Input<enums.quicksight.TemplateTooltipTarget>;
        /**
         * The visibility of the tooltip item.
         */
        visibility?: any;
    }
    interface TemplateComboChartAggregatedFieldWellsArgs {
        /**
         * The aggregated `BarValues` field well of a combo chart.
         */
        barValues?: pulumi.Input<pulumi.Input<inputs.quicksight.TemplateMeasureFieldArgs>[]>;
        /**
         * The aggregated category field wells of a combo chart.
         */
        category?: pulumi.Input<pulumi.Input<inputs.quicksight.TemplateDimensionFieldArgs>[]>;
        /**
         * The aggregated colors field well of a combo chart.
         */
        colors?: pulumi.Input<pulumi.Input<inputs.quicksight.TemplateDimensionFieldArgs>[]>;
        /**
         * The aggregated `LineValues` field well of a combo chart.
         */
        lineValues?: pulumi.Input<pulumi.Input<inputs.quicksight.TemplateMeasureFieldArgs>[]>;
    }
    interface TemplateComboChartConfigurationArgs {
        /**
         * The options that determine if visual data labels are displayed.
         *
         * The data label options for a bar in a combo chart.
         */
        barDataLabels?: pulumi.Input<inputs.quicksight.TemplateDataLabelOptionsArgs>;
        /**
         * Determines the bar arrangement in a combo chart. The following are valid values in this structure:
         *
         * - `CLUSTERED` : For clustered bar combo charts.
         * - `STACKED` : For stacked bar combo charts.
         * - `STACKED_PERCENT` : Do not use. If you use this value, the operation returns a validation error.
         */
        barsArrangement?: pulumi.Input<enums.quicksight.TemplateBarsArrangement>;
        /**
         * The category axis of a combo chart.
         */
        categoryAxis?: pulumi.Input<inputs.quicksight.TemplateAxisDisplayOptionsArgs>;
        /**
         * The label options (label text, label visibility, and sort icon visibility) of a combo chart category (group/color) field well.
         */
        categoryLabelOptions?: pulumi.Input<inputs.quicksight.TemplateChartAxisLabelOptionsArgs>;
        /**
         * The label options (label text, label visibility, and sort icon visibility) of a combo chart's color field well.
         */
        colorLabelOptions?: pulumi.Input<inputs.quicksight.TemplateChartAxisLabelOptionsArgs>;
        /**
         * The field wells of the visual.
         */
        fieldWells?: pulumi.Input<inputs.quicksight.TemplateComboChartFieldWellsArgs>;
        /**
         * The general visual interactions setup for a visual.
         */
        interactions?: pulumi.Input<inputs.quicksight.TemplateVisualInteractionOptionsArgs>;
        /**
         * The legend display setup of the visual.
         */
        legend?: pulumi.Input<inputs.quicksight.TemplateLegendOptionsArgs>;
        /**
         * The options that determine if visual data labels are displayed.
         *
         * The data label options for a line in a combo chart.
         */
        lineDataLabels?: pulumi.Input<inputs.quicksight.TemplateDataLabelOptionsArgs>;
        /**
         * The label display options (grid line, range, scale, and axis step) of a combo chart's primary y-axis (bar) field well.
         */
        primaryYAxisDisplayOptions?: pulumi.Input<inputs.quicksight.TemplateAxisDisplayOptionsArgs>;
        /**
         * The label options (label text, label visibility, and sort icon visibility) of a combo chart's primary y-axis (bar) field well.
         */
        primaryYAxisLabelOptions?: pulumi.Input<inputs.quicksight.TemplateChartAxisLabelOptionsArgs>;
        /**
         * The reference line setup of the visual.
         */
        referenceLines?: pulumi.Input<pulumi.Input<inputs.quicksight.TemplateReferenceLineArgs>[]>;
        /**
         * The label display options (grid line, range, scale, axis step) of a combo chart's secondary y-axis (line) field well.
         */
        secondaryYAxisDisplayOptions?: pulumi.Input<inputs.quicksight.TemplateAxisDisplayOptionsArgs>;
        /**
         * The label options (label text, label visibility, and sort icon visibility) of a combo chart's secondary y-axis(line) field well.
         */
        secondaryYAxisLabelOptions?: pulumi.Input<inputs.quicksight.TemplateChartAxisLabelOptionsArgs>;
        singleAxisOptions?: pulumi.Input<inputs.quicksight.TemplateSingleAxisOptionsArgs>;
        /**
         * The sort configuration of a `ComboChartVisual` .
         */
        sortConfiguration?: pulumi.Input<inputs.quicksight.TemplateComboChartSortConfigurationArgs>;
        /**
         * The legend display setup of the visual.
         */
        tooltip?: pulumi.Input<inputs.quicksight.TemplateTooltipOptionsArgs>;
        /**
         * The palette (chart color) display setup of the visual.
         */
        visualPalette?: pulumi.Input<inputs.quicksight.TemplateVisualPaletteArgs>;
    }
    interface TemplateComboChartFieldWellsArgs {
        /**
         * The aggregated field wells of a combo chart. Combo charts only have aggregated field wells. Columns in a combo chart are aggregated by category.
         */
        comboChartAggregatedFieldWells?: pulumi.Input<inputs.quicksight.TemplateComboChartAggregatedFieldWellsArgs>;
    }
    interface TemplateComboChartSortConfigurationArgs {
        /**
         * The item limit configuration for the category field well of a combo chart.
         */
        categoryItemsLimit?: pulumi.Input<inputs.quicksight.TemplateItemsLimitConfigurationArgs>;
        /**
         * The sort configuration of the category field well in a combo chart.
         */
        categorySort?: pulumi.Input<pulumi.Input<inputs.quicksight.TemplateFieldSortOptionsArgs>[]>;
        /**
         * The item limit configuration of the color field well in a combo chart.
         */
        colorItemsLimit?: pulumi.Input<inputs.quicksight.TemplateItemsLimitConfigurationArgs>;
        /**
         * The sort configuration of the color field well in a combo chart.
         */
        colorSort?: pulumi.Input<pulumi.Input<inputs.quicksight.TemplateFieldSortOptionsArgs>[]>;
    }
    interface TemplateComboChartVisualArgs {
        /**
         * The list of custom actions that are configured for a visual.
         */
        actions?: pulumi.Input<pulumi.Input<inputs.quicksight.TemplateVisualCustomActionArgs>[]>;
        /**
         * The configuration settings of the visual.
         */
        chartConfiguration?: pulumi.Input<inputs.quicksight.TemplateComboChartConfigurationArgs>;
        /**
         * The column hierarchy that is used during drill-downs and drill-ups.
         */
        columnHierarchies?: pulumi.Input<pulumi.Input<inputs.quicksight.TemplateColumnHierarchyArgs>[]>;
        /**
         * The subtitle that is displayed on the visual.
         */
        subtitle?: pulumi.Input<inputs.quicksight.TemplateVisualSubtitleLabelOptionsArgs>;
        /**
         * The title that is displayed on the visual.
         */
        title?: pulumi.Input<inputs.quicksight.TemplateVisualTitleLabelOptionsArgs>;
        /**
         * The alt text for the visual.
         */
        visualContentAltText?: pulumi.Input<string>;
        /**
         * The unique identifier of a visual. This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers.
         */
        visualId: pulumi.Input<string>;
    }
    interface TemplateComparisonConfigurationArgs {
        /**
         * The format of the comparison.
         */
        comparisonFormat?: pulumi.Input<inputs.quicksight.TemplateComparisonFormatConfigurationArgs>;
        /**
         * The method of the comparison. Choose from the following options:
         *
         * - `DIFFERENCE`
         * - `PERCENT_DIFFERENCE`
         * - `PERCENT`
         */
        comparisonMethod?: pulumi.Input<enums.quicksight.TemplateComparisonMethod>;
    }
    interface TemplateComparisonFormatConfigurationArgs {
        /**
         * The number display format.
         */
        numberDisplayFormatConfiguration?: pulumi.Input<inputs.quicksight.TemplateNumberDisplayFormatConfigurationArgs>;
        /**
         * The percentage display format.
         */
        percentageDisplayFormatConfiguration?: pulumi.Input<inputs.quicksight.TemplatePercentageDisplayFormatConfigurationArgs>;
    }
    interface TemplateComputationArgs {
        /**
         * The forecast computation configuration.
         */
        forecast?: pulumi.Input<inputs.quicksight.TemplateForecastComputationArgs>;
        /**
         * The growth rate computation configuration.
         */
        growthRate?: pulumi.Input<inputs.quicksight.TemplateGrowthRateComputationArgs>;
        /**
         * The maximum and minimum computation configuration.
         */
        maximumMinimum?: pulumi.Input<inputs.quicksight.TemplateMaximumMinimumComputationArgs>;
        /**
         * The metric comparison computation configuration.
         */
        metricComparison?: pulumi.Input<inputs.quicksight.TemplateMetricComparisonComputationArgs>;
        /**
         * The period over period computation configuration.
         */
        periodOverPeriod?: pulumi.Input<inputs.quicksight.TemplatePeriodOverPeriodComputationArgs>;
        /**
         * The period to `DataSetIdentifier` computation configuration.
         */
        periodToDate?: pulumi.Input<inputs.quicksight.TemplatePeriodToDateComputationArgs>;
        /**
         * The top movers and bottom movers computation configuration.
         */
        topBottomMovers?: pulumi.Input<inputs.quicksight.TemplateTopBottomMoversComputationArgs>;
        /**
         * The top ranked and bottom ranked computation configuration.
         */
        topBottomRanked?: pulumi.Input<inputs.quicksight.TemplateTopBottomRankedComputationArgs>;
        /**
         * The total aggregation computation configuration.
         */
        totalAggregation?: pulumi.Input<inputs.quicksight.TemplateTotalAggregationComputationArgs>;
        /**
         * The unique values computation configuration.
         */
        uniqueValues?: pulumi.Input<inputs.quicksight.TemplateUniqueValuesComputationArgs>;
    }
    interface TemplateConditionalFormattingColorArgs {
        /**
         * Formatting configuration for gradient color.
         */
        gradient?: pulumi.Input<inputs.quicksight.TemplateConditionalFormattingGradientColorArgs>;
        /**
         * Formatting configuration for solid color.
         */
        solid?: pulumi.Input<inputs.quicksight.TemplateConditionalFormattingSolidColorArgs>;
    }
    interface TemplateConditionalFormattingCustomIconConditionArgs {
        /**
         * Determines the color of the icon.
         */
        color?: pulumi.Input<string>;
        /**
         * Determines the icon display configuration.
         */
        displayConfiguration?: pulumi.Input<inputs.quicksight.TemplateConditionalFormattingIconDisplayConfigurationArgs>;
        /**
         * The expression that determines the condition of the icon set.
         */
        expression: pulumi.Input<string>;
        /**
         * Custom icon options for an icon set.
         */
        iconOptions: pulumi.Input<inputs.quicksight.TemplateConditionalFormattingCustomIconOptionsArgs>;
    }
    interface TemplateConditionalFormattingCustomIconOptionsArgs {
        /**
         * Determines the type of icon.
         */
        icon?: pulumi.Input<enums.quicksight.TemplateIcon>;
        /**
         * Determines the Unicode icon type.
         */
        unicodeIcon?: pulumi.Input<string>;
    }
    interface TemplateConditionalFormattingGradientColorArgs {
        /**
         * Determines the color.
         */
        color: pulumi.Input<inputs.quicksight.TemplateGradientColorArgs>;
        /**
         * The expression that determines the formatting configuration for gradient color.
         */
        expression: pulumi.Input<string>;
    }
    interface TemplateConditionalFormattingIconArgs {
        /**
         * Determines the custom condition for an icon set.
         */
        customCondition?: pulumi.Input<inputs.quicksight.TemplateConditionalFormattingCustomIconConditionArgs>;
        /**
         * Formatting configuration for icon set.
         */
        iconSet?: pulumi.Input<inputs.quicksight.TemplateConditionalFormattingIconSetArgs>;
    }
    interface TemplateConditionalFormattingIconDisplayConfigurationArgs {
        /**
         * Determines the icon display configuration.
         */
        iconDisplayOption?: pulumi.Input<enums.quicksight.TemplateConditionalFormattingIconDisplayOption>;
    }
    interface TemplateConditionalFormattingIconSetArgs {
        /**
         * The expression that determines the formatting configuration for the icon set.
         */
        expression: pulumi.Input<string>;
        /**
         * Determines the icon set type.
         */
        iconSetType?: pulumi.Input<enums.quicksight.TemplateConditionalFormattingIconSetType>;
    }
    interface TemplateConditionalFormattingSolidColorArgs {
        /**
         * Determines the color.
         */
        color?: pulumi.Input<string>;
        /**
         * The expression that determines the formatting configuration for solid color.
         */
        expression: pulumi.Input<string>;
    }
    interface TemplateContextMenuOptionArgs {
        /**
         * The availability status of the context menu options. If the value of this property is set to `ENABLED` , dashboard readers can interact with the context menu.
         */
        availabilityStatus?: pulumi.Input<enums.quicksight.TemplateDashboardBehavior>;
    }
    interface TemplateContributionAnalysisDefaultArgs {
        /**
         * The dimensions columns that are used in the contribution analysis, usually a list of `ColumnIdentifiers` .
         */
        contributorDimensions: pulumi.Input<pulumi.Input<inputs.quicksight.TemplateColumnIdentifierArgs>[]>;
        /**
         * The measure field that is used in the contribution analysis.
         */
        measureFieldId: pulumi.Input<string>;
    }
    interface TemplateCurrencyDisplayFormatConfigurationArgs {
        /**
         * The option that determines the decimal places configuration.
         */
        decimalPlacesConfiguration?: pulumi.Input<inputs.quicksight.TemplateDecimalPlacesConfigurationArgs>;
        /**
         * The options that determine the negative value configuration.
         */
        negativeValueConfiguration?: pulumi.Input<inputs.quicksight.TemplateNegativeValueConfigurationArgs>;
        /**
         * The options that determine the null value format configuration.
         */
        nullValueFormatConfiguration?: pulumi.Input<inputs.quicksight.TemplateNullValueFormatConfigurationArgs>;
        /**
         * Determines the number scale value for the currency format.
         */
        numberScale?: pulumi.Input<enums.quicksight.TemplateNumberScale>;
        /**
         * Determines the prefix value of the currency format.
         */
        prefix?: pulumi.Input<string>;
        /**
         * The options that determine the numeric separator configuration.
         */
        separatorConfiguration?: pulumi.Input<inputs.quicksight.TemplateNumericSeparatorConfigurationArgs>;
        /**
         * Determines the suffix value of the currency format.
         */
        suffix?: pulumi.Input<string>;
        /**
         * Determines the symbol for the currency format.
         */
        symbol?: pulumi.Input<string>;
    }
    interface TemplateCustomActionFilterOperationArgs {
        /**
         * The configuration that chooses the fields to be filtered.
         */
        selectedFieldsConfiguration: pulumi.Input<inputs.quicksight.TemplateFilterOperationSelectedFieldsConfigurationArgs>;
        /**
         * The configuration that chooses the target visuals to be filtered.
         */
        targetVisualsConfiguration: pulumi.Input<inputs.quicksight.TemplateFilterOperationTargetVisualsConfigurationArgs>;
    }
    interface TemplateCustomActionNavigationOperationArgs {
        /**
         * The configuration that chooses the navigation target.
         */
        localNavigationConfiguration?: pulumi.Input<inputs.quicksight.TemplateLocalNavigationConfigurationArgs>;
    }
    interface TemplateCustomActionSetParametersOperationArgs {
        /**
         * The parameter that determines the value configuration.
         */
        parameterValueConfigurations: pulumi.Input<pulumi.Input<inputs.quicksight.TemplateSetParameterValueConfigurationArgs>[]>;
    }
    interface TemplateCustomActionUrlOperationArgs {
        /**
         * The target of the `CustomActionURLOperation` .
         *
         * Valid values are defined as follows:
         *
         * - `NEW_TAB` : Opens the target URL in a new browser tab.
         * - `NEW_WINDOW` : Opens the target URL in a new browser window.
         * - `SAME_TAB` : Opens the target URL in the same browser tab.
         */
        urlTarget: pulumi.Input<enums.quicksight.TemplateUrlTargetConfiguration>;
        /**
         * THe URL link of the `CustomActionURLOperation` .
         */
        urlTemplate: pulumi.Input<string>;
    }
    interface TemplateCustomColorArgs {
        /**
         * The color that is applied to the data value.
         */
        color: pulumi.Input<string>;
        /**
         * The data value that the color is applied to.
         */
        fieldValue?: pulumi.Input<string>;
        /**
         * The value of a special data value.
         */
        specialValue?: pulumi.Input<enums.quicksight.TemplateSpecialValue>;
    }
    interface TemplateCustomContentConfigurationArgs {
        /**
         * The content type of the custom content visual. You can use this to have the visual render as an image.
         */
        contentType?: pulumi.Input<enums.quicksight.TemplateCustomContentType>;
        /**
         * The input URL that links to the custom content that you want in the custom visual.
         */
        contentUrl?: pulumi.Input<string>;
        /**
         * The sizing options for the size of the custom content visual. This structure is required when the `ContentType` of the visual is `'IMAGE'` .
         */
        imageScaling?: pulumi.Input<enums.quicksight.TemplateCustomContentImageScalingConfiguration>;
        /**
         * The general visual interactions setup for a visual.
         */
        interactions?: pulumi.Input<inputs.quicksight.TemplateVisualInteractionOptionsArgs>;
    }
    interface TemplateCustomContentVisualArgs {
        /**
         * The list of custom actions that are configured for a visual.
         */
        actions?: pulumi.Input<pulumi.Input<inputs.quicksight.TemplateVisualCustomActionArgs>[]>;
        /**
         * The configuration of a `CustomContentVisual` .
         */
        chartConfiguration?: pulumi.Input<inputs.quicksight.TemplateCustomContentConfigurationArgs>;
        /**
         * The dataset that is used to create the custom content visual. You can't create a visual without a dataset.
         */
        dataSetIdentifier: pulumi.Input<string>;
        /**
         * The subtitle that is displayed on the visual.
         */
        subtitle?: pulumi.Input<inputs.quicksight.TemplateVisualSubtitleLabelOptionsArgs>;
        /**
         * The title that is displayed on the visual.
         */
        title?: pulumi.Input<inputs.quicksight.TemplateVisualTitleLabelOptionsArgs>;
        /**
         * The alt text for the visual.
         */
        visualContentAltText?: pulumi.Input<string>;
        /**
         * The unique identifier of a visual. This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers.
         */
        visualId: pulumi.Input<string>;
    }
    interface TemplateCustomFilterConfigurationArgs {
        /**
         * The category value for the filter.
         *
         * This field is mutually exclusive to `ParameterName` .
         */
        categoryValue?: pulumi.Input<string>;
        /**
         * The match operator that is used to determine if a filter should be applied.
         */
        matchOperator: pulumi.Input<enums.quicksight.TemplateCategoryFilterMatchOperator>;
        /**
         * This option determines how null values should be treated when filtering data.
         *
         * - `ALL_VALUES` : Include null values in filtered results.
         * - `NULLS_ONLY` : Only include null values in filtered results.
         * - `NON_NULLS_ONLY` : Exclude null values from filtered results.
         */
        nullOption: pulumi.Input<enums.quicksight.TemplateFilterNullOption>;
        /**
         * The parameter whose value should be used for the filter value.
         *
         * This field is mutually exclusive to `CategoryValue` .
         */
        parameterName?: pulumi.Input<string>;
        /**
         * Select all of the values. Null is not the assigned value of select all.
         *
         * - `FILTER_ALL_VALUES`
         */
        selectAllOptions?: pulumi.Input<enums.quicksight.TemplateCategoryFilterSelectAllOptions>;
    }
    interface TemplateCustomFilterListConfigurationArgs {
        /**
         * The list of category values for the filter.
         */
        categoryValues?: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * The match operator that is used to determine if a filter should be applied.
         */
        matchOperator: pulumi.Input<enums.quicksight.TemplateCategoryFilterMatchOperator>;
        /**
         * This option determines how null values should be treated when filtering data.
         *
         * - `ALL_VALUES` : Include null values in filtered results.
         * - `NULLS_ONLY` : Only include null values in filtered results.
         * - `NON_NULLS_ONLY` : Exclude null values from filtered results.
         */
        nullOption: pulumi.Input<enums.quicksight.TemplateFilterNullOption>;
        /**
         * Select all of the values. Null is not the assigned value of select all.
         *
         * - `FILTER_ALL_VALUES`
         */
        selectAllOptions?: pulumi.Input<enums.quicksight.TemplateCategoryFilterSelectAllOptions>;
    }
    interface TemplateCustomNarrativeOptionsArgs {
        /**
         * The string input of custom narrative.
         */
        narrative: pulumi.Input<string>;
    }
    interface TemplateCustomParameterValuesArgs {
        /**
         * A list of datetime-type parameter values.
         */
        dateTimeValues?: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * A list of decimal-type parameter values.
         */
        decimalValues?: pulumi.Input<pulumi.Input<number>[]>;
        /**
         * A list of integer-type parameter values.
         */
        integerValues?: pulumi.Input<pulumi.Input<number>[]>;
        /**
         * A list of string-type parameter values.
         */
        stringValues?: pulumi.Input<pulumi.Input<string>[]>;
    }
    interface TemplateCustomValuesConfigurationArgs {
        customValues: pulumi.Input<inputs.quicksight.TemplateCustomParameterValuesArgs>;
        /**
         * Includes the null value in custom action parameter values.
         */
        includeNullValue?: pulumi.Input<boolean>;
    }
    interface TemplateDataBarsOptionsArgs {
        /**
         * The field ID for the data bars options.
         */
        fieldId: pulumi.Input<string>;
        /**
         * The color of the negative data bar.
         */
        negativeColor?: pulumi.Input<string>;
        /**
         * The color of the positive data bar.
         */
        positiveColor?: pulumi.Input<string>;
    }
    interface TemplateDataColorArgs {
        /**
         * The color that is applied to the data value.
         */
        color?: pulumi.Input<string>;
        /**
         * The data value that the color is applied to.
         */
        dataValue?: pulumi.Input<number>;
    }
    interface TemplateDataFieldSeriesItemArgs {
        /**
         * The axis that you are binding the field to.
         */
        axisBinding: pulumi.Input<enums.quicksight.TemplateAxisBinding>;
        /**
         * The field ID of the field that you are setting the axis binding to.
         */
        fieldId: pulumi.Input<string>;
        /**
         * The field value of the field that you are setting the axis binding to.
         */
        fieldValue?: pulumi.Input<string>;
        /**
         * The options that determine the presentation of line series associated to the field.
         */
        settings?: pulumi.Input<inputs.quicksight.TemplateLineChartSeriesSettingsArgs>;
    }
    interface TemplateDataLabelOptionsArgs {
        /**
         * Determines the visibility of the category field labels.
         */
        categoryLabelVisibility?: any;
        /**
         * The option that determines the data label type.
         */
        dataLabelTypes?: pulumi.Input<pulumi.Input<inputs.quicksight.TemplateDataLabelTypeArgs>[]>;
        /**
         * Determines the color of the data labels.
         */
        labelColor?: pulumi.Input<string>;
        /**
         * Determines the content of the data labels.
         */
        labelContent?: pulumi.Input<enums.quicksight.TemplateDataLabelContent>;
        /**
         * Determines the font configuration of the data labels.
         */
        labelFontConfiguration?: pulumi.Input<inputs.quicksight.TemplateFontConfigurationArgs>;
        /**
         * Determines the visibility of the measure field labels.
         */
        measureLabelVisibility?: any;
        /**
         * Determines whether overlap is enabled or disabled for the data labels.
         */
        overlap?: pulumi.Input<enums.quicksight.TemplateDataLabelOverlap>;
        /**
         * Determines the position of the data labels.
         */
        position?: pulumi.Input<enums.quicksight.TemplateDataLabelPosition>;
        /**
         * Determines the visibility of the total.
         */
        totalsVisibility?: any;
        /**
         * Determines the visibility of the data labels.
         */
        visibility?: any;
    }
    interface TemplateDataLabelTypeArgs {
        /**
         * The option that specifies individual data values for labels.
         */
        dataPathLabelType?: pulumi.Input<inputs.quicksight.TemplateDataPathLabelTypeArgs>;
        /**
         * Determines the label configuration for the entire field.
         */
        fieldLabelType?: pulumi.Input<inputs.quicksight.TemplateFieldLabelTypeArgs>;
        /**
         * Determines the label configuration for the maximum value in a visual.
         */
        maximumLabelType?: pulumi.Input<inputs.quicksight.TemplateMaximumLabelTypeArgs>;
        /**
         * Determines the label configuration for the minimum value in a visual.
         */
        minimumLabelType?: pulumi.Input<inputs.quicksight.TemplateMinimumLabelTypeArgs>;
        /**
         * Determines the label configuration for range end value in a visual.
         */
        rangeEndsLabelType?: pulumi.Input<inputs.quicksight.TemplateRangeEndsLabelTypeArgs>;
    }
    interface TemplateDataPathColorArgs {
        /**
         * The color that needs to be applied to the element.
         */
        color: pulumi.Input<string>;
        /**
         * The element that the color needs to be applied to.
         */
        element: pulumi.Input<inputs.quicksight.TemplateDataPathValueArgs>;
        /**
         * The time granularity of the field that the color needs to be applied to.
         */
        timeGranularity?: pulumi.Input<enums.quicksight.TemplateTimeGranularity>;
    }
    interface TemplateDataPathLabelTypeArgs {
        /**
         * The field ID of the field that the data label needs to be applied to.
         */
        fieldId?: pulumi.Input<string>;
        /**
         * The actual value of the field that is labeled.
         */
        fieldValue?: pulumi.Input<string>;
        /**
         * The visibility of the data label.
         */
        visibility?: any;
    }
    interface TemplateDataPathSortArgs {
        /**
         * Determines the sort direction.
         */
        direction: pulumi.Input<enums.quicksight.TemplateSortDirection>;
        /**
         * The list of data paths that need to be sorted.
         */
        sortPaths: pulumi.Input<pulumi.Input<inputs.quicksight.TemplateDataPathValueArgs>[]>;
    }
    interface TemplateDataPathTypeArgs {
        /**
         * The type of data path value utilized in a pivot table. Choose one of the following options:
         *
         * - `HIERARCHY_ROWS_LAYOUT_COLUMN` - The type of data path for the rows layout column, when `RowsLayout` is set to `HIERARCHY` .
         * - `MULTIPLE_ROW_METRICS_COLUMN` - The type of data path for the metric column when the row is set to Metric Placement.
         * - `EMPTY_COLUMN_HEADER` - The type of data path for the column with empty column header, when there is no field in `ColumnsFieldWell` and the row is set to Metric Placement.
         * - `COUNT_METRIC_COLUMN` - The type of data path for the column with `COUNT` as the metric, when there is no field in the `ValuesFieldWell` .
         */
        pivotTableDataPathType?: pulumi.Input<enums.quicksight.TemplatePivotTableDataPathType>;
    }
    interface TemplateDataPathValueArgs {
        /**
         * The type configuration of the field.
         */
        dataPathType?: pulumi.Input<inputs.quicksight.TemplateDataPathTypeArgs>;
        /**
         * The field ID of the field that needs to be sorted.
         */
        fieldId?: pulumi.Input<string>;
        /**
         * The actual value of the field that needs to be sorted.
         */
        fieldValue?: pulumi.Input<string>;
    }
    /**
     * <p>Dataset configuration.</p>
     */
    interface TemplateDataSetConfigurationArgs {
        /**
         * <p>A structure containing the list of column group schemas.</p>
         */
        columnGroupSchemaList?: pulumi.Input<pulumi.Input<inputs.quicksight.TemplateColumnGroupSchemaArgs>[]>;
        /**
         * Dataset schema.
         */
        dataSetSchema?: pulumi.Input<inputs.quicksight.TemplateDataSetSchemaArgs>;
        /**
         * <p>Placeholder.</p>
         */
        placeholder?: pulumi.Input<string>;
    }
    /**
     * <p>Dataset reference.</p>
     */
    interface TemplateDataSetReferenceArgs {
        /**
         * <p>Dataset Amazon Resource Name (ARN).</p>
         */
        dataSetArn: pulumi.Input<string>;
        /**
         * <p>Dataset placeholder.</p>
         */
        dataSetPlaceholder: pulumi.Input<string>;
    }
    /**
     * <p>Dataset schema.</p>
     */
    interface TemplateDataSetSchemaArgs {
        /**
         * <p>A structure containing the list of column schemas.</p>
         */
        columnSchemaList?: pulumi.Input<pulumi.Input<inputs.quicksight.TemplateColumnSchemaArgs>[]>;
    }
    interface TemplateDateAxisOptionsArgs {
        /**
         * Determines whether or not missing dates are displayed.
         */
        missingDateVisibility?: any;
    }
    interface TemplateDateDimensionFieldArgs {
        /**
         * The column that is used in the `DateDimensionField` .
         */
        column: pulumi.Input<inputs.quicksight.TemplateColumnIdentifierArgs>;
        /**
         * The date granularity of the `DateDimensionField` . Choose one of the following options:
         *
         * - `YEAR`
         * - `QUARTER`
         * - `MONTH`
         * - `WEEK`
         * - `DAY`
         * - `HOUR`
         * - `MINUTE`
         * - `SECOND`
         * - `MILLISECOND`
         */
        dateGranularity?: pulumi.Input<enums.quicksight.TemplateTimeGranularity>;
        /**
         * The custom field ID.
         */
        fieldId: pulumi.Input<string>;
        /**
         * The format configuration of the field.
         */
        formatConfiguration?: pulumi.Input<inputs.quicksight.TemplateDateTimeFormatConfigurationArgs>;
        /**
         * The custom hierarchy ID.
         */
        hierarchyId?: pulumi.Input<string>;
    }
    interface TemplateDateMeasureFieldArgs {
        /**
         * The aggregation function of the measure field.
         */
        aggregationFunction?: pulumi.Input<enums.quicksight.TemplateDateAggregationFunction>;
        /**
         * The column that is used in the `DateMeasureField` .
         */
        column: pulumi.Input<inputs.quicksight.TemplateColumnIdentifierArgs>;
        /**
         * The custom field ID.
         */
        fieldId: pulumi.Input<string>;
        /**
         * The format configuration of the field.
         */
        formatConfiguration?: pulumi.Input<inputs.quicksight.TemplateDateTimeFormatConfigurationArgs>;
    }
    interface TemplateDateTimeDefaultValuesArgs {
        /**
         * The dynamic value of the `DataTimeDefaultValues` . Different defaults are displayed according to users, groups, and values mapping.
         */
        dynamicValue?: pulumi.Input<inputs.quicksight.TemplateDynamicDefaultValueArgs>;
        /**
         * The rolling date of the `DataTimeDefaultValues` . The date is determined from the dataset based on input expression.
         */
        rollingDate?: pulumi.Input<inputs.quicksight.TemplateRollingDateConfigurationArgs>;
        /**
         * The static values of the `DataTimeDefaultValues` .
         */
        staticValues?: pulumi.Input<pulumi.Input<string>[]>;
    }
    interface TemplateDateTimeFormatConfigurationArgs {
        /**
         * Determines the `DateTime` format.
         */
        dateTimeFormat?: pulumi.Input<string>;
        /**
         * The options that determine the null value format configuration.
         */
        nullValueFormatConfiguration?: pulumi.Input<inputs.quicksight.TemplateNullValueFormatConfigurationArgs>;
        /**
         * The formatting configuration for numeric `DateTime` fields.
         */
        numericFormatConfiguration?: pulumi.Input<inputs.quicksight.TemplateNumericFormatConfigurationArgs>;
    }
    interface TemplateDateTimeHierarchyArgs {
        /**
         * The option that determines the drill down filters for the `DateTime` hierarchy.
         */
        drillDownFilters?: pulumi.Input<pulumi.Input<inputs.quicksight.TemplateDrillDownFilterArgs>[]>;
        /**
         * The hierarchy ID of the `DateTime` hierarchy.
         */
        hierarchyId: pulumi.Input<string>;
    }
    interface TemplateDateTimeParameterDeclarationArgs {
        /**
         * The default values of a parameter. If the parameter is a single-value parameter, a maximum of one default value can be provided.
         */
        defaultValues?: pulumi.Input<inputs.quicksight.TemplateDateTimeDefaultValuesArgs>;
        mappedDataSetParameters?: pulumi.Input<pulumi.Input<inputs.quicksight.TemplateMappedDataSetParameterArgs>[]>;
        /**
         * The name of the parameter that is being declared.
         */
        name: pulumi.Input<string>;
        /**
         * The level of time precision that is used to aggregate `DateTime` values.
         */
        timeGranularity?: pulumi.Input<enums.quicksight.TemplateTimeGranularity>;
        /**
         * The configuration that defines the default value of a `DateTime` parameter when a value has not been set.
         */
        valueWhenUnset?: pulumi.Input<inputs.quicksight.TemplateDateTimeValueWhenUnsetConfigurationArgs>;
    }
    interface TemplateDateTimePickerControlDisplayOptionsArgs {
        /**
         * The date icon visibility of the `DateTimePickerControlDisplayOptions` .
         */
        dateIconVisibility?: any;
        /**
         * Customize how dates are formatted in controls.
         */
        dateTimeFormat?: pulumi.Input<string>;
        /**
         * The helper text visibility of the `DateTimePickerControlDisplayOptions` .
         */
        helperTextVisibility?: any;
        /**
         * The configuration of info icon label options.
         */
        infoIconLabelOptions?: pulumi.Input<inputs.quicksight.TemplateSheetControlInfoIconLabelOptionsArgs>;
        /**
         * The options to configure the title visibility, name, and font size.
         */
        titleOptions?: pulumi.Input<inputs.quicksight.TemplateLabelOptionsArgs>;
    }
    interface TemplateDateTimeValueWhenUnsetConfigurationArgs {
        /**
         * A custom value that's used when the value of a parameter isn't set.
         */
        customValue?: pulumi.Input<string>;
        /**
         * The built-in options for default values. The value can be one of the following:
         *
         * - `RECOMMENDED` : The recommended value.
         * - `NULL` : The `NULL` value.
         */
        valueWhenUnsetOption?: pulumi.Input<enums.quicksight.TemplateValueWhenUnsetOption>;
    }
    interface TemplateDecimalDefaultValuesArgs {
        /**
         * The dynamic value of the `DecimalDefaultValues` . Different defaults are displayed according to users, groups, and values mapping.
         */
        dynamicValue?: pulumi.Input<inputs.quicksight.TemplateDynamicDefaultValueArgs>;
        /**
         * The static values of the `DecimalDefaultValues` .
         */
        staticValues?: pulumi.Input<pulumi.Input<number>[]>;
    }
    interface TemplateDecimalParameterDeclarationArgs {
        /**
         * The default values of a parameter. If the parameter is a single-value parameter, a maximum of one default value can be provided.
         */
        defaultValues?: pulumi.Input<inputs.quicksight.TemplateDecimalDefaultValuesArgs>;
        mappedDataSetParameters?: pulumi.Input<pulumi.Input<inputs.quicksight.TemplateMappedDataSetParameterArgs>[]>;
        /**
         * The name of the parameter that is being declared.
         */
        name: pulumi.Input<string>;
        /**
         * The value type determines whether the parameter is a single-value or multi-value parameter.
         */
        parameterValueType: pulumi.Input<enums.quicksight.TemplateParameterValueType>;
        /**
         * The configuration that defines the default value of a `Decimal` parameter when a value has not been set.
         */
        valueWhenUnset?: pulumi.Input<inputs.quicksight.TemplateDecimalValueWhenUnsetConfigurationArgs>;
    }
    interface TemplateDecimalPlacesConfigurationArgs {
        /**
         * The values of the decimal places.
         */
        decimalPlaces: pulumi.Input<number>;
    }
    interface TemplateDecimalValueWhenUnsetConfigurationArgs {
        /**
         * A custom value that's used when the value of a parameter isn't set.
         */
        customValue?: pulumi.Input<number>;
        /**
         * The built-in options for default values. The value can be one of the following:
         *
         * - `RECOMMENDED` : The recommended value.
         * - `NULL` : The `NULL` value.
         */
        valueWhenUnsetOption?: pulumi.Input<enums.quicksight.TemplateValueWhenUnsetOption>;
    }
    interface TemplateDefaultDateTimePickerControlOptionsArgs {
        /**
         * The visibility configuration of the Apply button on a `DateTimePickerControl` .
         */
        commitMode?: pulumi.Input<enums.quicksight.TemplateCommitMode>;
        /**
         * The display options of a control.
         */
        displayOptions?: pulumi.Input<inputs.quicksight.TemplateDateTimePickerControlDisplayOptionsArgs>;
        /**
         * The date time picker type of the `DefaultDateTimePickerControlOptions` . Choose one of the following options:
         *
         * - `SINGLE_VALUED` : The filter condition is a fixed date.
         * - `DATE_RANGE` : The filter condition is a date time range.
         */
        type?: pulumi.Input<enums.quicksight.TemplateSheetControlDateTimePickerType>;
    }
    interface TemplateDefaultFilterControlConfigurationArgs {
        /**
         * The control option for the `DefaultFilterControlConfiguration` .
         */
        controlOptions: pulumi.Input<inputs.quicksight.TemplateDefaultFilterControlOptionsArgs>;
        /**
         * The title of the `DefaultFilterControlConfiguration` . This title is shared by all controls that are tied to this filter.
         */
        title: pulumi.Input<string>;
    }
    interface TemplateDefaultFilterControlOptionsArgs {
        /**
         * The default options that correspond to the filter control type of a `DateTimePicker` .
         */
        defaultDateTimePickerOptions?: pulumi.Input<inputs.quicksight.TemplateDefaultDateTimePickerControlOptionsArgs>;
        /**
         * The default options that correspond to the `Dropdown` filter control type.
         */
        defaultDropdownOptions?: pulumi.Input<inputs.quicksight.TemplateDefaultFilterDropDownControlOptionsArgs>;
        /**
         * The default options that correspond to the `List` filter control type.
         */
        defaultListOptions?: pulumi.Input<inputs.quicksight.TemplateDefaultFilterListControlOptionsArgs>;
        /**
         * The default options that correspond to the `RelativeDateTime` filter control type.
         */
        defaultRelativeDateTimeOptions?: pulumi.Input<inputs.quicksight.TemplateDefaultRelativeDateTimeControlOptionsArgs>;
        /**
         * The default options that correspond to the `Slider` filter control type.
         */
        defaultSliderOptions?: pulumi.Input<inputs.quicksight.TemplateDefaultSliderControlOptionsArgs>;
        /**
         * The default options that correspond to the `TextArea` filter control type.
         */
        defaultTextAreaOptions?: pulumi.Input<inputs.quicksight.TemplateDefaultTextAreaControlOptionsArgs>;
        /**
         * The default options that correspond to the `TextField` filter control type.
         */
        defaultTextFieldOptions?: pulumi.Input<inputs.quicksight.TemplateDefaultTextFieldControlOptionsArgs>;
    }
    interface TemplateDefaultFilterDropDownControlOptionsArgs {
        /**
         * The visibility configuration of the Apply button on a `FilterDropDownControl` .
         */
        commitMode?: pulumi.Input<enums.quicksight.TemplateCommitMode>;
        /**
         * The display options of a control.
         */
        displayOptions?: pulumi.Input<inputs.quicksight.TemplateDropDownControlDisplayOptionsArgs>;
        /**
         * A list of selectable values that are used in a control.
         */
        selectableValues?: pulumi.Input<inputs.quicksight.TemplateFilterSelectableValuesArgs>;
        /**
         * The type of the `FilterDropDownControl` . Choose one of the following options:
         *
         * - `MULTI_SELECT` : The user can select multiple entries from a dropdown menu.
         * - `SINGLE_SELECT` : The user can select a single entry from a dropdown menu.
         */
        type?: pulumi.Input<enums.quicksight.TemplateSheetControlListType>;
    }
    interface TemplateDefaultFilterListControlOptionsArgs {
        /**
         * The display options of a control.
         */
        displayOptions?: pulumi.Input<inputs.quicksight.TemplateListControlDisplayOptionsArgs>;
        /**
         * A list of selectable values that are used in a control.
         */
        selectableValues?: pulumi.Input<inputs.quicksight.TemplateFilterSelectableValuesArgs>;
        /**
         * The type of the `DefaultFilterListControlOptions` . Choose one of the following options:
         *
         * - `MULTI_SELECT` : The user can select multiple entries from the list.
         * - `SINGLE_SELECT` : The user can select a single entry from the list.
         */
        type?: pulumi.Input<enums.quicksight.TemplateSheetControlListType>;
    }
    interface TemplateDefaultFreeFormLayoutConfigurationArgs {
        /**
         * Determines the screen canvas size options for a free-form layout.
         */
        canvasSizeOptions: pulumi.Input<inputs.quicksight.TemplateFreeFormLayoutCanvasSizeOptionsArgs>;
    }
    interface TemplateDefaultGridLayoutConfigurationArgs {
        /**
         * Determines the screen canvas size options for a grid layout.
         */
        canvasSizeOptions: pulumi.Input<inputs.quicksight.TemplateGridLayoutCanvasSizeOptionsArgs>;
    }
    interface TemplateDefaultInteractiveLayoutConfigurationArgs {
        /**
         * The options that determine the default settings of a free-form layout configuration.
         */
        freeForm?: pulumi.Input<inputs.quicksight.TemplateDefaultFreeFormLayoutConfigurationArgs>;
        /**
         * The options that determine the default settings for a grid layout configuration.
         */
        grid?: pulumi.Input<inputs.quicksight.TemplateDefaultGridLayoutConfigurationArgs>;
    }
    interface TemplateDefaultNewSheetConfigurationArgs {
        /**
         * The options that determine the default settings for interactive layout configuration.
         */
        interactiveLayoutConfiguration?: pulumi.Input<inputs.quicksight.TemplateDefaultInteractiveLayoutConfigurationArgs>;
        /**
         * The options that determine the default settings for a paginated layout configuration.
         */
        paginatedLayoutConfiguration?: pulumi.Input<inputs.quicksight.TemplateDefaultPaginatedLayoutConfigurationArgs>;
        /**
         * The option that determines the sheet content type.
         */
        sheetContentType?: pulumi.Input<enums.quicksight.TemplateSheetContentType>;
    }
    interface TemplateDefaultPaginatedLayoutConfigurationArgs {
        /**
         * The options that determine the default settings for a section-based layout configuration.
         */
        sectionBased?: pulumi.Input<inputs.quicksight.TemplateDefaultSectionBasedLayoutConfigurationArgs>;
    }
    interface TemplateDefaultRelativeDateTimeControlOptionsArgs {
        /**
         * The visibility configuration of the Apply button on a `RelativeDateTimeControl` .
         */
        commitMode?: pulumi.Input<enums.quicksight.TemplateCommitMode>;
        /**
         * The display options of a control.
         */
        displayOptions?: pulumi.Input<inputs.quicksight.TemplateRelativeDateTimeControlDisplayOptionsArgs>;
    }
    interface TemplateDefaultSectionBasedLayoutConfigurationArgs {
        /**
         * Determines the screen canvas size options for a section-based layout.
         */
        canvasSizeOptions: pulumi.Input<inputs.quicksight.TemplateSectionBasedLayoutCanvasSizeOptionsArgs>;
    }
    interface TemplateDefaultSliderControlOptionsArgs {
        /**
         * The display options of a control.
         */
        displayOptions?: pulumi.Input<inputs.quicksight.TemplateSliderControlDisplayOptionsArgs>;
        /**
         * The larger value that is displayed at the right of the slider.
         */
        maximumValue: pulumi.Input<number>;
        /**
         * The smaller value that is displayed at the left of the slider.
         */
        minimumValue: pulumi.Input<number>;
        /**
         * The number of increments that the slider bar is divided into.
         */
        stepSize: pulumi.Input<number>;
        /**
         * The type of the `DefaultSliderControlOptions` . Choose one of the following options:
         *
         * - `SINGLE_POINT` : Filter against(equals) a single data point.
         * - `RANGE` : Filter data that is in a specified range.
         */
        type?: pulumi.Input<enums.quicksight.TemplateSheetControlSliderType>;
    }
    interface TemplateDefaultTextAreaControlOptionsArgs {
        /**
         * The delimiter that is used to separate the lines in text.
         */
        delimiter?: pulumi.Input<string>;
        /**
         * The display options of a control.
         */
        displayOptions?: pulumi.Input<inputs.quicksight.TemplateTextAreaControlDisplayOptionsArgs>;
    }
    interface TemplateDefaultTextFieldControlOptionsArgs {
        /**
         * The display options of a control.
         */
        displayOptions?: pulumi.Input<inputs.quicksight.TemplateTextFieldControlDisplayOptionsArgs>;
    }
    interface TemplateDestinationParameterValueConfigurationArgs {
        /**
         * The configuration of custom values for destination parameter in `DestinationParameterValueConfiguration` .
         */
        customValuesConfiguration?: pulumi.Input<inputs.quicksight.TemplateCustomValuesConfigurationArgs>;
        /**
         * The configuration that selects all options.
         */
        selectAllValueOptions?: pulumi.Input<enums.quicksight.TemplateSelectAllValueOptions>;
        /**
         * A column of a data set.
         */
        sourceColumn?: pulumi.Input<inputs.quicksight.TemplateColumnIdentifierArgs>;
        /**
         * The source field ID of the destination parameter.
         */
        sourceField?: pulumi.Input<string>;
        /**
         * The source parameter name of the destination parameter.
         */
        sourceParameterName?: pulumi.Input<string>;
    }
    interface TemplateDimensionFieldArgs {
        /**
         * The dimension type field with categorical type columns.
         */
        categoricalDimensionField?: pulumi.Input<inputs.quicksight.TemplateCategoricalDimensionFieldArgs>;
        /**
         * The dimension type field with date type columns.
         */
        dateDimensionField?: pulumi.Input<inputs.quicksight.TemplateDateDimensionFieldArgs>;
        /**
         * The dimension type field with numerical type columns.
         */
        numericalDimensionField?: pulumi.Input<inputs.quicksight.TemplateNumericalDimensionFieldArgs>;
    }
    interface TemplateDonutCenterOptionsArgs {
        /**
         * Determines the visibility of the label in a donut chart. In the Amazon QuickSight console, this option is called `'Show total'` .
         */
        labelVisibility?: any;
    }
    interface TemplateDonutOptionsArgs {
        /**
         * The option for define the arc of the chart shape. Valid values are as follows:
         *
         * - `WHOLE` - A pie chart
         * - `SMALL` - A small-sized donut chart
         * - `MEDIUM` - A medium-sized donut chart
         * - `LARGE` - A large-sized donut chart
         */
        arcOptions?: pulumi.Input<inputs.quicksight.TemplateArcOptionsArgs>;
        /**
         * The label options of the label that is displayed in the center of a donut chart. This option isn't available for pie charts.
         */
        donutCenterOptions?: pulumi.Input<inputs.quicksight.TemplateDonutCenterOptionsArgs>;
    }
    interface TemplateDrillDownFilterArgs {
        /**
         * The category type drill down filter. This filter is used for string type columns.
         */
        categoryFilter?: pulumi.Input<inputs.quicksight.TemplateCategoryDrillDownFilterArgs>;
        /**
         * The numeric equality type drill down filter. This filter is used for number type columns.
         */
        numericEqualityFilter?: pulumi.Input<inputs.quicksight.TemplateNumericEqualityDrillDownFilterArgs>;
        /**
         * The time range drill down filter. This filter is used for date time columns.
         */
        timeRangeFilter?: pulumi.Input<inputs.quicksight.TemplateTimeRangeDrillDownFilterArgs>;
    }
    interface TemplateDropDownControlDisplayOptionsArgs {
        /**
         * The configuration of info icon label options.
         */
        infoIconLabelOptions?: pulumi.Input<inputs.quicksight.TemplateSheetControlInfoIconLabelOptionsArgs>;
        /**
         * The configuration of the `Select all` options in a dropdown control.
         */
        selectAllOptions?: pulumi.Input<inputs.quicksight.TemplateListControlSelectAllOptionsArgs>;
        /**
         * The options to configure the title visibility, name, and font size.
         */
        titleOptions?: pulumi.Input<inputs.quicksight.TemplateLabelOptionsArgs>;
    }
    interface TemplateDynamicDefaultValueArgs {
        /**
         * The column that contains the default value of each user or group.
         */
        defaultValueColumn: pulumi.Input<inputs.quicksight.TemplateColumnIdentifierArgs>;
        /**
         * The column that contains the group name.
         */
        groupNameColumn?: pulumi.Input<inputs.quicksight.TemplateColumnIdentifierArgs>;
        /**
         * The column that contains the username.
         */
        userNameColumn?: pulumi.Input<inputs.quicksight.TemplateColumnIdentifierArgs>;
    }
    interface TemplateEmptyVisualArgs {
        /**
         * The list of custom actions that are configured for a visual.
         */
        actions?: pulumi.Input<pulumi.Input<inputs.quicksight.TemplateVisualCustomActionArgs>[]>;
        /**
         * The data set that is used in the empty visual. Every visual requires a dataset to render.
         */
        dataSetIdentifier: pulumi.Input<string>;
        /**
         * The unique identifier of a visual. This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers.
         */
        visualId: pulumi.Input<string>;
    }
    interface TemplateExcludePeriodConfigurationArgs {
        /**
         * The amount or number of the exclude period.
         */
        amount: pulumi.Input<number>;
        /**
         * The granularity or unit (day, month, year) of the exclude period.
         */
        granularity: pulumi.Input<enums.quicksight.TemplateTimeGranularity>;
        /**
         * The status of the exclude period. Choose from the following options:
         *
         * - `ENABLED`
         * - `DISABLED`
         */
        status?: pulumi.Input<enums.quicksight.TemplateWidgetStatus>;
    }
    interface TemplateExplicitHierarchyArgs {
        /**
         * The list of columns that define the explicit hierarchy.
         */
        columns: pulumi.Input<pulumi.Input<inputs.quicksight.TemplateColumnIdentifierArgs>[]>;
        /**
         * The option that determines the drill down filters for the explicit hierarchy.
         */
        drillDownFilters?: pulumi.Input<pulumi.Input<inputs.quicksight.TemplateDrillDownFilterArgs>[]>;
        /**
         * The hierarchy ID of the explicit hierarchy.
         */
        hierarchyId: pulumi.Input<string>;
    }
    interface TemplateFieldBasedTooltipArgs {
        /**
         * The visibility of `Show aggregations` .
         */
        aggregationVisibility?: any;
        /**
         * The fields configuration in the tooltip.
         */
        tooltipFields?: pulumi.Input<pulumi.Input<inputs.quicksight.TemplateTooltipItemArgs>[]>;
        /**
         * The type for the >tooltip title. Choose one of the following options:
         *
         * - `NONE` : Doesn't use the primary value as the title.
         * - `PRIMARY_VALUE` : Uses primary value as the title.
         */
        tooltipTitleType?: pulumi.Input<enums.quicksight.TemplateTooltipTitleType>;
    }
    interface TemplateFieldLabelTypeArgs {
        /**
         * Indicates the field that is targeted by the field label.
         */
        fieldId?: pulumi.Input<string>;
        /**
         * The visibility of the field label.
         */
        visibility?: any;
    }
    interface TemplateFieldSeriesItemArgs {
        /**
         * The axis that you are binding the field to.
         */
        axisBinding: pulumi.Input<enums.quicksight.TemplateAxisBinding>;
        /**
         * The field ID of the field for which you are setting the axis binding.
         */
        fieldId: pulumi.Input<string>;
        /**
         * The options that determine the presentation of line series associated to the field.
         */
        settings?: pulumi.Input<inputs.quicksight.TemplateLineChartSeriesSettingsArgs>;
    }
    interface TemplateFieldSortArgs {
        /**
         * The sort direction. Choose one of the following options:
         *
         * - `ASC` : Ascending
         * - `DESC` : Descending
         */
        direction: pulumi.Input<enums.quicksight.TemplateSortDirection>;
        /**
         * The sort configuration target field.
         */
        fieldId: pulumi.Input<string>;
    }
    interface TemplateFieldSortOptionsArgs {
        /**
         * The sort configuration for a column that is not used in a field well.
         */
        columnSort?: pulumi.Input<inputs.quicksight.TemplateColumnSortArgs>;
        /**
         * The sort configuration for a field in a field well.
         */
        fieldSort?: pulumi.Input<inputs.quicksight.TemplateFieldSortArgs>;
    }
    interface TemplateFieldTooltipItemArgs {
        /**
         * The unique ID of the field that is targeted by the tooltip.
         */
        fieldId: pulumi.Input<string>;
        /**
         * The label of the tooltip item.
         */
        label?: pulumi.Input<string>;
        /**
         * Determines the target of the field tooltip item in a combo chart visual.
         */
        tooltipTarget?: pulumi.Input<enums.quicksight.TemplateTooltipTarget>;
        /**
         * The visibility of the tooltip item.
         */
        visibility?: any;
    }
    interface TemplateFilledMapAggregatedFieldWellsArgs {
        /**
         * The aggregated location field well of the filled map. Values are grouped by location fields.
         */
        geospatial?: pulumi.Input<pulumi.Input<inputs.quicksight.TemplateDimensionFieldArgs>[]>;
        /**
         * The aggregated color field well of a filled map. Values are aggregated based on location fields.
         */
        values?: pulumi.Input<pulumi.Input<inputs.quicksight.TemplateMeasureFieldArgs>[]>;
    }
    interface TemplateFilledMapConditionalFormattingArgs {
        /**
         * Conditional formatting options of a `FilledMapVisual` .
         */
        conditionalFormattingOptions: pulumi.Input<pulumi.Input<inputs.quicksight.TemplateFilledMapConditionalFormattingOptionArgs>[]>;
    }
    interface TemplateFilledMapConditionalFormattingOptionArgs {
        /**
         * The conditional formatting that determines the shape of the filled map.
         */
        shape: pulumi.Input<inputs.quicksight.TemplateFilledMapShapeConditionalFormattingArgs>;
    }
    interface TemplateFilledMapConfigurationArgs {
        /**
         * The field wells of the visual.
         */
        fieldWells?: pulumi.Input<inputs.quicksight.TemplateFilledMapFieldWellsArgs>;
        /**
         * The general visual interactions setup for a visual.
         */
        interactions?: pulumi.Input<inputs.quicksight.TemplateVisualInteractionOptionsArgs>;
        /**
         * The legend display setup of the visual.
         */
        legend?: pulumi.Input<inputs.quicksight.TemplateLegendOptionsArgs>;
        /**
         * The map style options of the filled map visual.
         */
        mapStyleOptions?: pulumi.Input<inputs.quicksight.TemplateGeospatialMapStyleOptionsArgs>;
        /**
         * The sort configuration of a `FilledMapVisual` .
         */
        sortConfiguration?: pulumi.Input<inputs.quicksight.TemplateFilledMapSortConfigurationArgs>;
        /**
         * The tooltip display setup of the visual.
         */
        tooltip?: pulumi.Input<inputs.quicksight.TemplateTooltipOptionsArgs>;
        /**
         * The window options of the filled map visual.
         */
        windowOptions?: pulumi.Input<inputs.quicksight.TemplateGeospatialWindowOptionsArgs>;
    }
    interface TemplateFilledMapFieldWellsArgs {
        /**
         * The aggregated field well of the filled map.
         */
        filledMapAggregatedFieldWells?: pulumi.Input<inputs.quicksight.TemplateFilledMapAggregatedFieldWellsArgs>;
    }
    interface TemplateFilledMapShapeConditionalFormattingArgs {
        /**
         * The field ID of the filled map shape.
         */
        fieldId: pulumi.Input<string>;
        /**
         * The conditional formatting that determines the background color of a filled map's shape.
         */
        format?: pulumi.Input<inputs.quicksight.TemplateShapeConditionalFormatArgs>;
    }
    interface TemplateFilledMapSortConfigurationArgs {
        /**
         * The sort configuration of the location fields.
         */
        categorySort?: pulumi.Input<pulumi.Input<inputs.quicksight.TemplateFieldSortOptionsArgs>[]>;
    }
    interface TemplateFilledMapVisualArgs {
        /**
         * The list of custom actions that are configured for a visual.
         */
        actions?: pulumi.Input<pulumi.Input<inputs.quicksight.TemplateVisualCustomActionArgs>[]>;
        /**
         * The configuration settings of the visual.
         */
        chartConfiguration?: pulumi.Input<inputs.quicksight.TemplateFilledMapConfigurationArgs>;
        /**
         * The column hierarchy that is used during drill-downs and drill-ups.
         */
        columnHierarchies?: pulumi.Input<pulumi.Input<inputs.quicksight.TemplateColumnHierarchyArgs>[]>;
        /**
         * The conditional formatting of a `FilledMapVisual` .
         */
        conditionalFormatting?: pulumi.Input<inputs.quicksight.TemplateFilledMapConditionalFormattingArgs>;
        /**
         * The subtitle that is displayed on the visual.
         */
        subtitle?: pulumi.Input<inputs.quicksight.TemplateVisualSubtitleLabelOptionsArgs>;
        /**
         * The title that is displayed on the visual.
         */
        title?: pulumi.Input<inputs.quicksight.TemplateVisualTitleLabelOptionsArgs>;
        /**
         * The alt text for the visual.
         */
        visualContentAltText?: pulumi.Input<string>;
        /**
         * The unique identifier of a visual. This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers..
         */
        visualId: pulumi.Input<string>;
    }
    interface TemplateFilterArgs {
        /**
         * A `CategoryFilter` filters text values.
         *
         * For more information, see [Adding text filters](https://docs.aws.amazon.com/quicksight/latest/user/add-a-text-filter-data-prep.html) in the *Amazon QuickSight User Guide* .
         */
        categoryFilter?: pulumi.Input<inputs.quicksight.TemplateCategoryFilterArgs>;
        /**
         * A `NestedFilter` filters data with a subset of data that is defined by the nested inner filter.
         */
        nestedFilter?: pulumi.Input<inputs.quicksight.TemplateNestedFilterArgs>;
        /**
         * A `NumericEqualityFilter` filters numeric values that equal or do not equal a given numeric value.
         */
        numericEqualityFilter?: pulumi.Input<inputs.quicksight.TemplateNumericEqualityFilterArgs>;
        /**
         * A `NumericRangeFilter` filters numeric values that are either inside or outside a given numeric range.
         */
        numericRangeFilter?: pulumi.Input<inputs.quicksight.TemplateNumericRangeFilterArgs>;
        /**
         * A `RelativeDatesFilter` filters date values that are relative to a given date.
         */
        relativeDatesFilter?: pulumi.Input<inputs.quicksight.TemplateRelativeDatesFilterArgs>;
        /**
         * A `TimeEqualityFilter` filters date-time values that equal or do not equal a given date/time value.
         */
        timeEqualityFilter?: pulumi.Input<inputs.quicksight.TemplateTimeEqualityFilterArgs>;
        /**
         * A `TimeRangeFilter` filters date-time values that are either inside or outside a given date/time range.
         */
        timeRangeFilter?: pulumi.Input<inputs.quicksight.TemplateTimeRangeFilterArgs>;
        /**
         * A `TopBottomFilter` filters data to the top or bottom values for a given column.
         */
        topBottomFilter?: pulumi.Input<inputs.quicksight.TemplateTopBottomFilterArgs>;
    }
    interface TemplateFilterControlArgs {
        /**
         * A control from a filter that is scoped across more than one sheet. This represents your filter control on a sheet
         */
        crossSheet?: pulumi.Input<inputs.quicksight.TemplateFilterCrossSheetControlArgs>;
        /**
         * A control from a date filter that is used to specify date and time.
         */
        dateTimePicker?: pulumi.Input<inputs.quicksight.TemplateFilterDateTimePickerControlArgs>;
        /**
         * A control to display a dropdown list with buttons that are used to select a single value.
         */
        dropdown?: pulumi.Input<inputs.quicksight.TemplateFilterDropDownControlArgs>;
        /**
         * A control to display a list of buttons or boxes. This is used to select either a single value or multiple values.
         */
        list?: pulumi.Input<inputs.quicksight.TemplateFilterListControlArgs>;
        /**
         * A control from a date filter that is used to specify the relative date.
         */
        relativeDateTime?: pulumi.Input<inputs.quicksight.TemplateFilterRelativeDateTimeControlArgs>;
        /**
         * A control to display a horizontal toggle bar. This is used to change a value by sliding the toggle.
         */
        slider?: pulumi.Input<inputs.quicksight.TemplateFilterSliderControlArgs>;
        /**
         * A control to display a text box that is used to enter multiple entries.
         */
        textArea?: pulumi.Input<inputs.quicksight.TemplateFilterTextAreaControlArgs>;
        /**
         * A control to display a text box that is used to enter a single entry.
         */
        textField?: pulumi.Input<inputs.quicksight.TemplateFilterTextFieldControlArgs>;
    }
    interface TemplateFilterCrossSheetControlArgs {
        /**
         * The values that are displayed in a control can be configured to only show values that are valid based on what's selected in other controls.
         */
        cascadingControlConfiguration?: pulumi.Input<inputs.quicksight.TemplateCascadingControlConfigurationArgs>;
        /**
         * The ID of the `FilterCrossSheetControl` .
         */
        filterControlId: pulumi.Input<string>;
        /**
         * The source filter ID of the `FilterCrossSheetControl` .
         */
        sourceFilterId: pulumi.Input<string>;
    }
    interface TemplateFilterDateTimePickerControlArgs {
        /**
         * The visibility configurationof the Apply button on a `DateTimePickerControl` .
         */
        commitMode?: pulumi.Input<enums.quicksight.TemplateCommitMode>;
        /**
         * The display options of a control.
         */
        displayOptions?: pulumi.Input<inputs.quicksight.TemplateDateTimePickerControlDisplayOptionsArgs>;
        /**
         * The ID of the `FilterDateTimePickerControl` .
         */
        filterControlId: pulumi.Input<string>;
        /**
         * The source filter ID of the `FilterDateTimePickerControl` .
         */
        sourceFilterId: pulumi.Input<string>;
        /**
         * The title of the `FilterDateTimePickerControl` .
         */
        title: pulumi.Input<string>;
        /**
         * The type of the `FilterDropDownControl` . Choose one of the following options:
         *
         * - `MULTI_SELECT` : The user can select multiple entries from a dropdown menu.
         * - `SINGLE_SELECT` : The user can select a single entry from a dropdown menu.
         */
        type?: pulumi.Input<enums.quicksight.TemplateSheetControlDateTimePickerType>;
    }
    interface TemplateFilterDropDownControlArgs {
        /**
         * The values that are displayed in a control can be configured to only show values that are valid based on what's selected in other controls.
         */
        cascadingControlConfiguration?: pulumi.Input<inputs.quicksight.TemplateCascadingControlConfigurationArgs>;
        /**
         * The visibility configuration of the Apply button on a `FilterDropDownControl` .
         */
        commitMode?: pulumi.Input<enums.quicksight.TemplateCommitMode>;
        /**
         * The display options of the `FilterDropDownControl` .
         */
        displayOptions?: pulumi.Input<inputs.quicksight.TemplateDropDownControlDisplayOptionsArgs>;
        /**
         * The ID of the `FilterDropDownControl` .
         */
        filterControlId: pulumi.Input<string>;
        /**
         * A list of selectable values that are used in a control.
         */
        selectableValues?: pulumi.Input<inputs.quicksight.TemplateFilterSelectableValuesArgs>;
        /**
         * The source filter ID of the `FilterDropDownControl` .
         */
        sourceFilterId: pulumi.Input<string>;
        /**
         * The title of the `FilterDropDownControl` .
         */
        title: pulumi.Input<string>;
        /**
         * The type of the `FilterDropDownControl` . Choose one of the following options:
         *
         * - `MULTI_SELECT` : The user can select multiple entries from a dropdown menu.
         * - `SINGLE_SELECT` : The user can select a single entry from a dropdown menu.
         */
        type?: pulumi.Input<enums.quicksight.TemplateSheetControlListType>;
    }
    interface TemplateFilterGroupArgs {
        /**
         * The filter new feature which can apply filter group to all data sets. Choose one of the following options:
         *
         * - `ALL_DATASETS`
         * - `SINGLE_DATASET`
         */
        crossDataset: pulumi.Input<enums.quicksight.TemplateCrossDatasetTypes>;
        /**
         * The value that uniquely identifies a `FilterGroup` within a dashboard, template, or analysis.
         */
        filterGroupId: pulumi.Input<string>;
        /**
         * The list of filters that are present in a `FilterGroup` .
         */
        filters: pulumi.Input<pulumi.Input<inputs.quicksight.TemplateFilterArgs>[]>;
        /**
         * The configuration that specifies what scope to apply to a `FilterGroup` .
         *
         * This is a union type structure. For this structure to be valid, only one of the attributes can be defined.
         */
        scopeConfiguration: pulumi.Input<inputs.quicksight.TemplateFilterScopeConfigurationArgs>;
        /**
         * The status of the `FilterGroup` .
         */
        status?: pulumi.Input<enums.quicksight.TemplateWidgetStatus>;
    }
    interface TemplateFilterListConfigurationArgs {
        /**
         * The list of category values for the filter.
         */
        categoryValues?: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * The match operator that is used to determine if a filter should be applied.
         */
        matchOperator: pulumi.Input<enums.quicksight.TemplateCategoryFilterMatchOperator>;
        /**
         * This option determines how null values should be treated when filtering data.
         *
         * - `ALL_VALUES` : Include null values in filtered results.
         * - `NULLS_ONLY` : Only include null values in filtered results.
         * - `NON_NULLS_ONLY` : Exclude null values from filtered results.
         */
        nullOption?: pulumi.Input<enums.quicksight.TemplateFilterNullOption>;
        /**
         * Select all of the values. Null is not the assigned value of select all.
         *
         * - `FILTER_ALL_VALUES`
         */
        selectAllOptions?: pulumi.Input<enums.quicksight.TemplateCategoryFilterSelectAllOptions>;
    }
    interface TemplateFilterListControlArgs {
        /**
         * The values that are displayed in a control can be configured to only show values that are valid based on what's selected in other controls.
         */
        cascadingControlConfiguration?: pulumi.Input<inputs.quicksight.TemplateCascadingControlConfigurationArgs>;
        /**
         * The display options of a control.
         */
        displayOptions?: pulumi.Input<inputs.quicksight.TemplateListControlDisplayOptionsArgs>;
        /**
         * The ID of the `FilterListControl` .
         */
        filterControlId: pulumi.Input<string>;
        /**
         * A list of selectable values that are used in a control.
         */
        selectableValues?: pulumi.Input<inputs.quicksight.TemplateFilterSelectableValuesArgs>;
        /**
         * The source filter ID of the `FilterListControl` .
         */
        sourceFilterId: pulumi.Input<string>;
        /**
         * The title of the `FilterListControl` .
         */
        title: pulumi.Input<string>;
        /**
         * The type of the `FilterListControl` . Choose one of the following options:
         *
         * - `MULTI_SELECT` : The user can select multiple entries from the list.
         * - `SINGLE_SELECT` : The user can select a single entry from the list.
         */
        type?: pulumi.Input<enums.quicksight.TemplateSheetControlListType>;
    }
    interface TemplateFilterOperationSelectedFieldsConfigurationArgs {
        /**
         * <p>The selected columns of a dataset.</p>
         */
        selectedColumns?: pulumi.Input<pulumi.Input<inputs.quicksight.TemplateColumnIdentifierArgs>[]>;
        /**
         * A structure that contains the options that choose which fields are filtered in the `CustomActionFilterOperation` .
         *
         * Valid values are defined as follows:
         *
         * - `ALL_FIELDS` : Applies the filter operation to all fields.
         */
        selectedFieldOptions?: pulumi.Input<enums.quicksight.TemplateSelectedFieldOptions>;
        /**
         * Chooses the fields that are filtered in `CustomActionFilterOperation` .
         */
        selectedFields?: pulumi.Input<pulumi.Input<string>[]>;
    }
    interface TemplateFilterOperationTargetVisualsConfigurationArgs {
        /**
         * The configuration of the same-sheet target visuals that you want to be filtered.
         */
        sameSheetTargetVisualConfiguration?: pulumi.Input<inputs.quicksight.TemplateSameSheetTargetVisualConfigurationArgs>;
    }
    interface TemplateFilterRelativeDateTimeControlArgs {
        /**
         * The visibility configuration of the Apply button on a `FilterRelativeDateTimeControl` .
         */
        commitMode?: pulumi.Input<enums.quicksight.TemplateCommitMode>;
        /**
         * The display options of a control.
         */
        displayOptions?: pulumi.Input<inputs.quicksight.TemplateRelativeDateTimeControlDisplayOptionsArgs>;
        /**
         * The ID of the `FilterTextAreaControl` .
         */
        filterControlId: pulumi.Input<string>;
        /**
         * The source filter ID of the `FilterTextAreaControl` .
         */
        sourceFilterId: pulumi.Input<string>;
        /**
         * The title of the `FilterTextAreaControl` .
         */
        title: pulumi.Input<string>;
    }
    interface TemplateFilterScopeConfigurationArgs {
        /**
         * The configuration that applies a filter to all sheets. When you choose `AllSheets` as the value for a `FilterScopeConfiguration` , this filter is applied to all visuals of all sheets in an Analysis, Dashboard, or Template. The `AllSheetsFilterScopeConfiguration` is chosen.
         */
        allSheets?: pulumi.Input<inputs.quicksight.TemplateAllSheetsFilterScopeConfigurationArgs>;
        /**
         * The configuration for applying a filter to specific sheets.
         */
        selectedSheets?: pulumi.Input<inputs.quicksight.TemplateSelectedSheetsFilterScopeConfigurationArgs>;
    }
    interface TemplateFilterSelectableValuesArgs {
        /**
         * The values that are used in the `FilterSelectableValues` .
         */
        values?: pulumi.Input<pulumi.Input<string>[]>;
    }
    interface TemplateFilterSliderControlArgs {
        /**
         * The display options of a control.
         */
        displayOptions?: pulumi.Input<inputs.quicksight.TemplateSliderControlDisplayOptionsArgs>;
        /**
         * The ID of the `FilterSliderControl` .
         */
        filterControlId: pulumi.Input<string>;
        /**
         * The larger value that is displayed at the right of the slider.
         */
        maximumValue: pulumi.Input<number>;
        /**
         * The smaller value that is displayed at the left of the slider.
         */
        minimumValue: pulumi.Input<number>;
        /**
         * The source filter ID of the `FilterSliderControl` .
         */
        sourceFilterId: pulumi.Input<string>;
        /**
         * The number of increments that the slider bar is divided into.
         */
        stepSize: pulumi.Input<number>;
        /**
         * The title of the `FilterSliderControl` .
         */
        title: pulumi.Input<string>;
        /**
         * The type of the `FilterSliderControl` . Choose one of the following options:
         *
         * - `SINGLE_POINT` : Filter against(equals) a single data point.
         * - `RANGE` : Filter data that is in a specified range.
         */
        type?: pulumi.Input<enums.quicksight.TemplateSheetControlSliderType>;
    }
    interface TemplateFilterTextAreaControlArgs {
        /**
         * The delimiter that is used to separate the lines in text.
         */
        delimiter?: pulumi.Input<string>;
        /**
         * The display options of a control.
         */
        displayOptions?: pulumi.Input<inputs.quicksight.TemplateTextAreaControlDisplayOptionsArgs>;
        /**
         * The ID of the `FilterTextAreaControl` .
         */
        filterControlId: pulumi.Input<string>;
        /**
         * The source filter ID of the `FilterTextAreaControl` .
         */
        sourceFilterId: pulumi.Input<string>;
        /**
         * The title of the `FilterTextAreaControl` .
         */
        title: pulumi.Input<string>;
    }
    interface TemplateFilterTextFieldControlArgs {
        /**
         * The display options of a control.
         */
        displayOptions?: pulumi.Input<inputs.quicksight.TemplateTextFieldControlDisplayOptionsArgs>;
        /**
         * The ID of the `FilterTextFieldControl` .
         */
        filterControlId: pulumi.Input<string>;
        /**
         * The source filter ID of the `FilterTextFieldControl` .
         */
        sourceFilterId: pulumi.Input<string>;
        /**
         * The title of the `FilterTextFieldControl` .
         */
        title: pulumi.Input<string>;
    }
    interface TemplateFontConfigurationArgs {
        /**
         * Determines the color of the text.
         */
        fontColor?: pulumi.Input<string>;
        /**
         * Determines the appearance of decorative lines on the text.
         */
        fontDecoration?: pulumi.Input<enums.quicksight.TemplateFontDecoration>;
        /**
         * The font family that you want to use.
         */
        fontFamily?: pulumi.Input<string>;
        /**
         * The option that determines the text display size.
         */
        fontSize?: pulumi.Input<inputs.quicksight.TemplateFontSizeArgs>;
        /**
         * Determines the text display face that is inherited by the given font family.
         */
        fontStyle?: pulumi.Input<enums.quicksight.TemplateFontStyle>;
        /**
         * The option that determines the text display weight, or boldness.
         */
        fontWeight?: pulumi.Input<inputs.quicksight.TemplateFontWeightArgs>;
    }
    interface TemplateFontSizeArgs {
        /**
         * String based length that is composed of value and unit in px
         */
        absolute?: pulumi.Input<string>;
        /**
         * The lexical name for the text size, proportional to its surrounding context.
         */
        relative?: pulumi.Input<enums.quicksight.TemplateRelativeFontSize>;
    }
    interface TemplateFontWeightArgs {
        /**
         * The lexical name for the level of boldness of the text display.
         */
        name?: pulumi.Input<enums.quicksight.TemplateFontWeightName>;
    }
    interface TemplateForecastComputationArgs {
        /**
         * The ID for a computation.
         */
        computationId: pulumi.Input<string>;
        /**
         * The custom seasonality value setup of a forecast computation.
         */
        customSeasonalityValue?: pulumi.Input<number>;
        /**
         * The lower boundary setup of a forecast computation.
         */
        lowerBoundary?: pulumi.Input<number>;
        /**
         * The name of a computation.
         */
        name?: pulumi.Input<string>;
        /**
         * The periods backward setup of a forecast computation.
         */
        periodsBackward?: pulumi.Input<number>;
        /**
         * The periods forward setup of a forecast computation.
         */
        periodsForward?: pulumi.Input<number>;
        /**
         * The prediction interval setup of a forecast computation.
         */
        predictionInterval?: pulumi.Input<number>;
        /**
         * The seasonality setup of a forecast computation. Choose one of the following options:
         *
         * - `AUTOMATIC`
         * - `CUSTOM` : Checks the custom seasonality value.
         */
        seasonality?: pulumi.Input<enums.quicksight.TemplateForecastComputationSeasonality>;
        /**
         * The time field that is used in a computation.
         */
        time?: pulumi.Input<inputs.quicksight.TemplateDimensionFieldArgs>;
        /**
         * The upper boundary setup of a forecast computation.
         */
        upperBoundary?: pulumi.Input<number>;
        /**
         * The value field that is used in a computation.
         */
        value?: pulumi.Input<inputs.quicksight.TemplateMeasureFieldArgs>;
    }
    interface TemplateForecastConfigurationArgs {
        /**
         * The forecast properties setup of a forecast in the line chart.
         */
        forecastProperties?: pulumi.Input<inputs.quicksight.TemplateTimeBasedForecastPropertiesArgs>;
        /**
         * The forecast scenario of a forecast in the line chart.
         */
        scenario?: pulumi.Input<inputs.quicksight.TemplateForecastScenarioArgs>;
    }
    interface TemplateForecastScenarioArgs {
        /**
         * The what-if analysis forecast setup with the target date.
         */
        whatIfPointScenario?: pulumi.Input<inputs.quicksight.TemplateWhatIfPointScenarioArgs>;
        /**
         * The what-if analysis forecast setup with the date range.
         */
        whatIfRangeScenario?: pulumi.Input<inputs.quicksight.TemplateWhatIfRangeScenarioArgs>;
    }
    interface TemplateFormatConfigurationArgs {
        /**
         * Formatting configuration for `DateTime` fields.
         */
        dateTimeFormatConfiguration?: pulumi.Input<inputs.quicksight.TemplateDateTimeFormatConfigurationArgs>;
        /**
         * Formatting configuration for number fields.
         */
        numberFormatConfiguration?: pulumi.Input<inputs.quicksight.TemplateNumberFormatConfigurationArgs>;
        /**
         * Formatting configuration for string fields.
         */
        stringFormatConfiguration?: pulumi.Input<inputs.quicksight.TemplateStringFormatConfigurationArgs>;
    }
    interface TemplateFreeFormLayoutCanvasSizeOptionsArgs {
        /**
         * The options that determine the sizing of the canvas used in a free-form layout.
         */
        screenCanvasSizeOptions?: pulumi.Input<inputs.quicksight.TemplateFreeFormLayoutScreenCanvasSizeOptionsArgs>;
    }
    interface TemplateFreeFormLayoutConfigurationArgs {
        canvasSizeOptions?: pulumi.Input<inputs.quicksight.TemplateFreeFormLayoutCanvasSizeOptionsArgs>;
        /**
         * The elements that are included in a free-form layout.
         */
        elements: pulumi.Input<pulumi.Input<inputs.quicksight.TemplateFreeFormLayoutElementArgs>[]>;
    }
    interface TemplateFreeFormLayoutElementArgs {
        /**
         * The background style configuration of a free-form layout element.
         */
        backgroundStyle?: pulumi.Input<inputs.quicksight.TemplateFreeFormLayoutElementBackgroundStyleArgs>;
        /**
         * The border style configuration of a free-form layout element.
         */
        borderStyle?: pulumi.Input<inputs.quicksight.TemplateFreeFormLayoutElementBorderStyleArgs>;
        /**
         * A unique identifier for an element within a free-form layout.
         */
        elementId: pulumi.Input<string>;
        /**
         * The type of element.
         */
        elementType: pulumi.Input<enums.quicksight.TemplateLayoutElementType>;
        /**
         * String based length that is composed of value and unit in px
         */
        height: pulumi.Input<string>;
        /**
         * The loading animation configuration of a free-form layout element.
         */
        loadingAnimation?: pulumi.Input<inputs.quicksight.TemplateLoadingAnimationArgs>;
        /**
         * The rendering rules that determine when an element should be displayed within a free-form layout.
         */
        renderingRules?: pulumi.Input<pulumi.Input<inputs.quicksight.TemplateSheetElementRenderingRuleArgs>[]>;
        /**
         * The border style configuration of a free-form layout element. This border style is used when the element is selected.
         */
        selectedBorderStyle?: pulumi.Input<inputs.quicksight.TemplateFreeFormLayoutElementBorderStyleArgs>;
        /**
         * The visibility of an element within a free-form layout.
         */
        visibility?: any;
        /**
         * String based length that is composed of value and unit in px
         */
        width: pulumi.Input<string>;
        /**
         * String based length that is composed of value and unit in px
         */
        xAxisLocation: pulumi.Input<string>;
        /**
         * String based length that is composed of value and unit in px with Integer.MAX_VALUE as maximum value
         */
        yAxisLocation: pulumi.Input<string>;
    }
    interface TemplateFreeFormLayoutElementBackgroundStyleArgs {
        /**
         * The background color of a free-form layout element.
         */
        color?: pulumi.Input<string>;
        /**
         * The background visibility of a free-form layout element.
         */
        visibility?: any;
    }
    interface TemplateFreeFormLayoutElementBorderStyleArgs {
        /**
         * The border color of a free-form layout element.
         */
        color?: pulumi.Input<string>;
        /**
         * The border visibility of a free-form layout element.
         */
        visibility?: any;
    }
    interface TemplateFreeFormLayoutScreenCanvasSizeOptionsArgs {
        /**
         * String based length that is composed of value and unit in px
         */
        optimizedViewPortWidth: pulumi.Input<string>;
    }
    interface TemplateFreeFormSectionLayoutConfigurationArgs {
        /**
         * The elements that are included in the free-form layout.
         */
        elements: pulumi.Input<pulumi.Input<inputs.quicksight.TemplateFreeFormLayoutElementArgs>[]>;
    }
    interface TemplateFunnelChartAggregatedFieldWellsArgs {
        /**
         * The category field wells of a funnel chart. Values are grouped by category fields.
         */
        category?: pulumi.Input<pulumi.Input<inputs.quicksight.TemplateDimensionFieldArgs>[]>;
        /**
         * The value field wells of a funnel chart. Values are aggregated based on categories.
         */
        values?: pulumi.Input<pulumi.Input<inputs.quicksight.TemplateMeasureFieldArgs>[]>;
    }
    interface TemplateFunnelChartConfigurationArgs {
        /**
         * The label options of the categories that are displayed in a `FunnelChartVisual` .
         */
        categoryLabelOptions?: pulumi.Input<inputs.quicksight.TemplateChartAxisLabelOptionsArgs>;
        /**
         * The options that determine the presentation of the data labels.
         */
        dataLabelOptions?: pulumi.Input<inputs.quicksight.TemplateFunnelChartDataLabelOptionsArgs>;
        /**
         * The field well configuration of a `FunnelChartVisual` .
         */
        fieldWells?: pulumi.Input<inputs.quicksight.TemplateFunnelChartFieldWellsArgs>;
        /**
         * The general visual interactions setup for a visual.
         */
        interactions?: pulumi.Input<inputs.quicksight.TemplateVisualInteractionOptionsArgs>;
        /**
         * The sort configuration of a `FunnelChartVisual` .
         */
        sortConfiguration?: pulumi.Input<inputs.quicksight.TemplateFunnelChartSortConfigurationArgs>;
        /**
         * The tooltip configuration of a `FunnelChartVisual` .
         */
        tooltip?: pulumi.Input<inputs.quicksight.TemplateTooltipOptionsArgs>;
        /**
         * The label options for the values that are displayed in a `FunnelChartVisual` .
         */
        valueLabelOptions?: pulumi.Input<inputs.quicksight.TemplateChartAxisLabelOptionsArgs>;
        /**
         * The visual palette configuration of a `FunnelChartVisual` .
         */
        visualPalette?: pulumi.Input<inputs.quicksight.TemplateVisualPaletteArgs>;
    }
    interface TemplateFunnelChartDataLabelOptionsArgs {
        /**
         * The visibility of the category labels within the data labels.
         */
        categoryLabelVisibility?: any;
        /**
         * The color of the data label text.
         */
        labelColor?: pulumi.Input<string>;
        /**
         * The font configuration for the data labels.
         *
         * Only the `FontSize` attribute of the font configuration is used for data labels.
         */
        labelFontConfiguration?: pulumi.Input<inputs.quicksight.TemplateFontConfigurationArgs>;
        /**
         * Determines the style of the metric labels.
         */
        measureDataLabelStyle?: pulumi.Input<enums.quicksight.TemplateFunnelChartMeasureDataLabelStyle>;
        /**
         * The visibility of the measure labels within the data labels.
         */
        measureLabelVisibility?: any;
        /**
         * Determines the positioning of the data label relative to a section of the funnel.
         */
        position?: pulumi.Input<enums.quicksight.TemplateDataLabelPosition>;
        /**
         * The visibility option that determines if data labels are displayed.
         */
        visibility?: any;
    }
    interface TemplateFunnelChartFieldWellsArgs {
        /**
         * The field well configuration of a `FunnelChartVisual` .
         */
        funnelChartAggregatedFieldWells?: pulumi.Input<inputs.quicksight.TemplateFunnelChartAggregatedFieldWellsArgs>;
    }
    interface TemplateFunnelChartSortConfigurationArgs {
        /**
         * The limit on the number of categories displayed.
         */
        categoryItemsLimit?: pulumi.Input<inputs.quicksight.TemplateItemsLimitConfigurationArgs>;
        /**
         * The sort configuration of the category fields.
         */
        categorySort?: pulumi.Input<pulumi.Input<inputs.quicksight.TemplateFieldSortOptionsArgs>[]>;
    }
    interface TemplateFunnelChartVisualArgs {
        /**
         * The list of custom actions that are configured for a visual.
         */
        actions?: pulumi.Input<pulumi.Input<inputs.quicksight.TemplateVisualCustomActionArgs>[]>;
        /**
         * The configuration of a `FunnelChartVisual` .
         */
        chartConfiguration?: pulumi.Input<inputs.quicksight.TemplateFunnelChartConfigurationArgs>;
        /**
         * The column hierarchy that is used during drill-downs and drill-ups.
         */
        columnHierarchies?: pulumi.Input<pulumi.Input<inputs.quicksight.TemplateColumnHierarchyArgs>[]>;
        /**
         * The subtitle that is displayed on the visual.
         */
        subtitle?: pulumi.Input<inputs.quicksight.TemplateVisualSubtitleLabelOptionsArgs>;
        /**
         * The title that is displayed on the visual.
         */
        title?: pulumi.Input<inputs.quicksight.TemplateVisualTitleLabelOptionsArgs>;
        /**
         * The alt text for the visual.
         */
        visualContentAltText?: pulumi.Input<string>;
        /**
         * The unique identifier of a visual. This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers..
         */
        visualId: pulumi.Input<string>;
    }
    interface TemplateGaugeChartArcConditionalFormattingArgs {
        /**
         * The conditional formatting of the arc foreground color.
         */
        foregroundColor?: pulumi.Input<inputs.quicksight.TemplateConditionalFormattingColorArgs>;
    }
    interface TemplateGaugeChartColorConfigurationArgs {
        /**
         * The background color configuration of a `GaugeChartVisual` .
         */
        backgroundColor?: pulumi.Input<string>;
        /**
         * The foreground color configuration of a `GaugeChartVisual` .
         */
        foregroundColor?: pulumi.Input<string>;
    }
    interface TemplateGaugeChartConditionalFormattingArgs {
        /**
         * Conditional formatting options of a `GaugeChartVisual` .
         */
        conditionalFormattingOptions?: pulumi.Input<pulumi.Input<inputs.quicksight.TemplateGaugeChartConditionalFormattingOptionArgs>[]>;
    }
    interface TemplateGaugeChartConditionalFormattingOptionArgs {
        /**
         * The options that determine the presentation of the arc of a `GaugeChartVisual` .
         */
        arc?: pulumi.Input<inputs.quicksight.TemplateGaugeChartArcConditionalFormattingArgs>;
        /**
         * The conditional formatting for the primary value of a `GaugeChartVisual` .
         */
        primaryValue?: pulumi.Input<inputs.quicksight.TemplateGaugeChartPrimaryValueConditionalFormattingArgs>;
    }
    interface TemplateGaugeChartConfigurationArgs {
        /**
         * The color configuration of a `GaugeChartVisual` .
         */
        colorConfiguration?: pulumi.Input<inputs.quicksight.TemplateGaugeChartColorConfigurationArgs>;
        /**
         * The data label configuration of a `GaugeChartVisual` .
         */
        dataLabels?: pulumi.Input<inputs.quicksight.TemplateDataLabelOptionsArgs>;
        /**
         * The field well configuration of a `GaugeChartVisual` .
         */
        fieldWells?: pulumi.Input<inputs.quicksight.TemplateGaugeChartFieldWellsArgs>;
        /**
         * The options that determine the presentation of the `GaugeChartVisual` .
         */
        gaugeChartOptions?: pulumi.Input<inputs.quicksight.TemplateGaugeChartOptionsArgs>;
        /**
         * The general visual interactions setup for a visual.
         */
        interactions?: pulumi.Input<inputs.quicksight.TemplateVisualInteractionOptionsArgs>;
        /**
         * The tooltip configuration of a `GaugeChartVisual` .
         */
        tooltipOptions?: pulumi.Input<inputs.quicksight.TemplateTooltipOptionsArgs>;
        /**
         * The visual palette configuration of a `GaugeChartVisual` .
         */
        visualPalette?: pulumi.Input<inputs.quicksight.TemplateVisualPaletteArgs>;
    }
    interface TemplateGaugeChartFieldWellsArgs {
        /**
         * The target value field wells of a `GaugeChartVisual` .
         */
        targetValues?: pulumi.Input<pulumi.Input<inputs.quicksight.TemplateMeasureFieldArgs>[]>;
        /**
         * The value field wells of a `GaugeChartVisual` .
         */
        values?: pulumi.Input<pulumi.Input<inputs.quicksight.TemplateMeasureFieldArgs>[]>;
    }
    interface TemplateGaugeChartOptionsArgs {
        /**
         * The arc configuration of a `GaugeChartVisual` .
         */
        arc?: pulumi.Input<inputs.quicksight.TemplateArcConfigurationArgs>;
        /**
         * The arc axis configuration of a `GaugeChartVisual` .
         */
        arcAxis?: pulumi.Input<inputs.quicksight.TemplateArcAxisConfigurationArgs>;
        /**
         * The comparison configuration of a `GaugeChartVisual` .
         */
        comparison?: pulumi.Input<inputs.quicksight.TemplateComparisonConfigurationArgs>;
        /**
         * The options that determine the primary value display type.
         */
        primaryValueDisplayType?: pulumi.Input<enums.quicksight.TemplatePrimaryValueDisplayType>;
        /**
         * The options that determine the primary value font configuration.
         */
        primaryValueFontConfiguration?: pulumi.Input<inputs.quicksight.TemplateFontConfigurationArgs>;
    }
    interface TemplateGaugeChartPrimaryValueConditionalFormattingArgs {
        /**
         * The conditional formatting of the primary value icon.
         */
        icon?: pulumi.Input<inputs.quicksight.TemplateConditionalFormattingIconArgs>;
        /**
         * The conditional formatting of the primary value text color.
         */
        textColor?: pulumi.Input<inputs.quicksight.TemplateConditionalFormattingColorArgs>;
    }
    interface TemplateGaugeChartVisualArgs {
        /**
         * The list of custom actions that are configured for a visual.
         */
        actions?: pulumi.Input<pulumi.Input<inputs.quicksight.TemplateVisualCustomActionArgs>[]>;
        /**
         * The configuration of a `GaugeChartVisual` .
         */
        chartConfiguration?: pulumi.Input<inputs.quicksight.TemplateGaugeChartConfigurationArgs>;
        /**
         * The conditional formatting of a `GaugeChartVisual` .
         */
        conditionalFormatting?: pulumi.Input<inputs.quicksight.TemplateGaugeChartConditionalFormattingArgs>;
        /**
         * The subtitle that is displayed on the visual.
         */
        subtitle?: pulumi.Input<inputs.quicksight.TemplateVisualSubtitleLabelOptionsArgs>;
        /**
         * The title that is displayed on the visual.
         */
        title?: pulumi.Input<inputs.quicksight.TemplateVisualTitleLabelOptionsArgs>;
        /**
         * The alt text for the visual.
         */
        visualContentAltText?: pulumi.Input<string>;
        /**
         * The unique identifier of a visual. This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers.
         */
        visualId: pulumi.Input<string>;
    }
    interface TemplateGeospatialCoordinateBoundsArgs {
        /**
         * The longitude of the east bound of the geospatial coordinate bounds.
         */
        east: pulumi.Input<number>;
        /**
         * The latitude of the north bound of the geospatial coordinate bounds.
         */
        north: pulumi.Input<number>;
        /**
         * The latitude of the south bound of the geospatial coordinate bounds.
         */
        south: pulumi.Input<number>;
        /**
         * The longitude of the west bound of the geospatial coordinate bounds.
         */
        west: pulumi.Input<number>;
    }
    interface TemplateGeospatialHeatmapColorScaleArgs {
        /**
         * The list of colors to be used in heatmap point style.
         */
        colors?: pulumi.Input<pulumi.Input<inputs.quicksight.TemplateGeospatialHeatmapDataColorArgs>[]>;
    }
    interface TemplateGeospatialHeatmapConfigurationArgs {
        /**
         * The color scale specification for the heatmap point style.
         */
        heatmapColor?: pulumi.Input<inputs.quicksight.TemplateGeospatialHeatmapColorScaleArgs>;
    }
    interface TemplateGeospatialHeatmapDataColorArgs {
        /**
         * The hex color to be used in the heatmap point style.
         */
        color: pulumi.Input<string>;
    }
    interface TemplateGeospatialMapAggregatedFieldWellsArgs {
        /**
         * The color field wells of a geospatial map.
         */
        colors?: pulumi.Input<pulumi.Input<inputs.quicksight.TemplateDimensionFieldArgs>[]>;
        /**
         * The geospatial field wells of a geospatial map. Values are grouped by geospatial fields.
         */
        geospatial?: pulumi.Input<pulumi.Input<inputs.quicksight.TemplateDimensionFieldArgs>[]>;
        /**
         * The size field wells of a geospatial map. Values are aggregated based on geospatial fields.
         */
        values?: pulumi.Input<pulumi.Input<inputs.quicksight.TemplateMeasureFieldArgs>[]>;
    }
    interface TemplateGeospatialMapConfigurationArgs {
        /**
         * The field wells of the visual.
         */
        fieldWells?: pulumi.Input<inputs.quicksight.TemplateGeospatialMapFieldWellsArgs>;
        /**
         * The legend display setup of the visual.
         */
        legend?: pulumi.Input<inputs.quicksight.TemplateLegendOptionsArgs>;
        /**
         * The map style options of the geospatial map.
         */
        mapStyleOptions?: pulumi.Input<inputs.quicksight.TemplateGeospatialMapStyleOptionsArgs>;
        /**
         * The point style options of the geospatial map.
         */
        pointStyleOptions?: pulumi.Input<inputs.quicksight.TemplateGeospatialPointStyleOptionsArgs>;
        /**
         * The tooltip display setup of the visual.
         */
        tooltip?: pulumi.Input<inputs.quicksight.TemplateTooltipOptionsArgs>;
        visualPalette?: pulumi.Input<inputs.quicksight.TemplateVisualPaletteArgs>;
        /**
         * The window options of the geospatial map.
         */
        windowOptions?: pulumi.Input<inputs.quicksight.TemplateGeospatialWindowOptionsArgs>;
    }
    interface TemplateGeospatialMapFieldWellsArgs {
        /**
         * The aggregated field well for a geospatial map.
         */
        geospatialMapAggregatedFieldWells?: pulumi.Input<inputs.quicksight.TemplateGeospatialMapAggregatedFieldWellsArgs>;
    }
    interface TemplateGeospatialMapStyleOptionsArgs {
        /**
         * The base map style of the geospatial map.
         */
        baseMapStyle?: pulumi.Input<enums.quicksight.TemplateBaseMapStyleType>;
    }
    interface TemplateGeospatialMapVisualArgs {
        /**
         * The list of custom actions that are configured for a visual.
         */
        actions?: pulumi.Input<pulumi.Input<inputs.quicksight.TemplateVisualCustomActionArgs>[]>;
        /**
         * The configuration settings of the visual.
         */
        chartConfiguration?: pulumi.Input<inputs.quicksight.TemplateGeospatialMapConfigurationArgs>;
        /**
         * The column hierarchy that is used during drill-downs and drill-ups.
         */
        columnHierarchies?: pulumi.Input<pulumi.Input<inputs.quicksight.TemplateColumnHierarchyArgs>[]>;
        /**
         * The subtitle that is displayed on the visual.
         */
        subtitle?: pulumi.Input<inputs.quicksight.TemplateVisualSubtitleLabelOptionsArgs>;
        /**
         * The title that is displayed on the visual.
         */
        title?: pulumi.Input<inputs.quicksight.TemplateVisualTitleLabelOptionsArgs>;
        /**
         * The alt text for the visual.
         */
        visualContentAltText?: pulumi.Input<string>;
        /**
         * The unique identifier of a visual. This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers..
         */
        visualId: pulumi.Input<string>;
    }
    interface TemplateGeospatialPointStyleOptionsArgs {
        /**
         * The cluster marker configuration of the geospatial point style.
         */
        clusterMarkerConfiguration?: pulumi.Input<inputs.quicksight.TemplateClusterMarkerConfigurationArgs>;
        /**
         * The heatmap configuration of the geospatial point style.
         */
        heatmapConfiguration?: pulumi.Input<inputs.quicksight.TemplateGeospatialHeatmapConfigurationArgs>;
        /**
         * The selected point styles (point, cluster) of the geospatial map.
         */
        selectedPointStyle?: pulumi.Input<enums.quicksight.TemplateGeospatialSelectedPointStyle>;
    }
    interface TemplateGeospatialWindowOptionsArgs {
        /**
         * The bounds options (north, south, west, east) of the geospatial window options.
         */
        bounds?: pulumi.Input<inputs.quicksight.TemplateGeospatialCoordinateBoundsArgs>;
        /**
         * The map zoom modes (manual, auto) of the geospatial window options.
         */
        mapZoomMode?: pulumi.Input<enums.quicksight.TemplateMapZoomMode>;
    }
    interface TemplateGlobalTableBorderOptionsArgs {
        /**
         * Determines the options for side specific border.
         */
        sideSpecificBorder?: pulumi.Input<inputs.quicksight.TemplateTableSideBorderOptionsArgs>;
        /**
         * Determines the options for uniform border.
         */
        uniformBorder?: pulumi.Input<inputs.quicksight.TemplateTableBorderOptionsArgs>;
    }
    interface TemplateGradientColorArgs {
        /**
         * The list of gradient color stops.
         */
        stops?: pulumi.Input<pulumi.Input<inputs.quicksight.TemplateGradientStopArgs>[]>;
    }
    interface TemplateGradientStopArgs {
        /**
         * Determines the color.
         */
        color?: pulumi.Input<string>;
        /**
         * Determines the data value.
         */
        dataValue?: pulumi.Input<number>;
        /**
         * Determines gradient offset value.
         */
        gradientOffset: pulumi.Input<number>;
    }
    interface TemplateGridLayoutCanvasSizeOptionsArgs {
        /**
         * The options that determine the sizing of the canvas used in a grid layout.
         */
        screenCanvasSizeOptions?: pulumi.Input<inputs.quicksight.TemplateGridLayoutScreenCanvasSizeOptionsArgs>;
    }
    interface TemplateGridLayoutConfigurationArgs {
        canvasSizeOptions?: pulumi.Input<inputs.quicksight.TemplateGridLayoutCanvasSizeOptionsArgs>;
        /**
         * The elements that are included in a grid layout.
         */
        elements: pulumi.Input<pulumi.Input<inputs.quicksight.TemplateGridLayoutElementArgs>[]>;
    }
    interface TemplateGridLayoutElementArgs {
        /**
         * The column index for the upper left corner of an element.
         */
        columnIndex?: pulumi.Input<number>;
        /**
         * The width of a grid element expressed as a number of grid columns.
         */
        columnSpan: pulumi.Input<number>;
        /**
         * A unique identifier for an element within a grid layout.
         */
        elementId: pulumi.Input<string>;
        /**
         * The type of element.
         */
        elementType: pulumi.Input<enums.quicksight.TemplateLayoutElementType>;
        /**
         * The row index for the upper left corner of an element.
         */
        rowIndex?: pulumi.Input<number>;
        /**
         * The height of a grid element expressed as a number of grid rows.
         */
        rowSpan: pulumi.Input<number>;
    }
    interface TemplateGridLayoutScreenCanvasSizeOptionsArgs {
        /**
         * String based length that is composed of value and unit in px
         */
        optimizedViewPortWidth?: pulumi.Input<string>;
        /**
         * This value determines the layout behavior when the viewport is resized.
         *
         * - `FIXED` : A fixed width will be used when optimizing the layout. In the Amazon QuickSight console, this option is called `Classic` .
         * - `RESPONSIVE` : The width of the canvas will be responsive and optimized to the view port. In the Amazon QuickSight console, this option is called `Tiled` .
         */
        resizeOption: pulumi.Input<enums.quicksight.TemplateResizeOption>;
    }
    interface TemplateGrowthRateComputationArgs {
        /**
         * The ID for a computation.
         */
        computationId: pulumi.Input<string>;
        /**
         * The name of a computation.
         */
        name?: pulumi.Input<string>;
        /**
         * The period size setup of a growth rate computation.
         */
        periodSize?: pulumi.Input<number>;
        /**
         * The time field that is used in a computation.
         */
        time?: pulumi.Input<inputs.quicksight.TemplateDimensionFieldArgs>;
        /**
         * The value field that is used in a computation.
         */
        value?: pulumi.Input<inputs.quicksight.TemplateMeasureFieldArgs>;
    }
    interface TemplateHeaderFooterSectionConfigurationArgs {
        /**
         * The layout configuration of the header or footer section.
         */
        layout: pulumi.Input<inputs.quicksight.TemplateSectionLayoutConfigurationArgs>;
        /**
         * The unique identifier of the header or footer section.
         */
        sectionId: pulumi.Input<string>;
        /**
         * The style options of a header or footer section.
         */
        style?: pulumi.Input<inputs.quicksight.TemplateSectionStyleArgs>;
    }
    interface TemplateHeatMapAggregatedFieldWellsArgs {
        /**
         * The columns field well of a heat map.
         */
        columns?: pulumi.Input<pulumi.Input<inputs.quicksight.TemplateDimensionFieldArgs>[]>;
        /**
         * The rows field well of a heat map.
         */
        rows?: pulumi.Input<pulumi.Input<inputs.quicksight.TemplateDimensionFieldArgs>[]>;
        /**
         * The values field well of a heat map.
         */
        values?: pulumi.Input<pulumi.Input<inputs.quicksight.TemplateMeasureFieldArgs>[]>;
    }
    interface TemplateHeatMapConfigurationArgs {
        /**
         * The color options (gradient color, point of divergence) in a heat map.
         */
        colorScale?: pulumi.Input<inputs.quicksight.TemplateColorScaleArgs>;
        /**
         * The label options of the column that is displayed in a heat map.
         */
        columnLabelOptions?: pulumi.Input<inputs.quicksight.TemplateChartAxisLabelOptionsArgs>;
        /**
         * The options that determine if visual data labels are displayed.
         */
        dataLabels?: pulumi.Input<inputs.quicksight.TemplateDataLabelOptionsArgs>;
        /**
         * The field wells of the visual.
         */
        fieldWells?: pulumi.Input<inputs.quicksight.TemplateHeatMapFieldWellsArgs>;
        /**
         * The general visual interactions setup for a visual.
         */
        interactions?: pulumi.Input<inputs.quicksight.TemplateVisualInteractionOptionsArgs>;
        /**
         * The legend display setup of the visual.
         */
        legend?: pulumi.Input<inputs.quicksight.TemplateLegendOptionsArgs>;
        /**
         * The label options of the row that is displayed in a `heat map` .
         */
        rowLabelOptions?: pulumi.Input<inputs.quicksight.TemplateChartAxisLabelOptionsArgs>;
        /**
         * The sort configuration of a heat map.
         */
        sortConfiguration?: pulumi.Input<inputs.quicksight.TemplateHeatMapSortConfigurationArgs>;
        /**
         * The tooltip display setup of the visual.
         */
        tooltip?: pulumi.Input<inputs.quicksight.TemplateTooltipOptionsArgs>;
    }
    interface TemplateHeatMapFieldWellsArgs {
        /**
         * The aggregated field wells of a heat map.
         */
        heatMapAggregatedFieldWells?: pulumi.Input<inputs.quicksight.TemplateHeatMapAggregatedFieldWellsArgs>;
    }
    interface TemplateHeatMapSortConfigurationArgs {
        /**
         * The limit on the number of columns that are displayed in a heat map.
         */
        heatMapColumnItemsLimitConfiguration?: pulumi.Input<inputs.quicksight.TemplateItemsLimitConfigurationArgs>;
        /**
         * The column sort configuration for heat map for columns that aren't a part of a field well.
         */
        heatMapColumnSort?: pulumi.Input<pulumi.Input<inputs.quicksight.TemplateFieldSortOptionsArgs>[]>;
        /**
         * The limit on the number of rows that are displayed in a heat map.
         */
        heatMapRowItemsLimitConfiguration?: pulumi.Input<inputs.quicksight.TemplateItemsLimitConfigurationArgs>;
        /**
         * The field sort configuration of the rows fields.
         */
        heatMapRowSort?: pulumi.Input<pulumi.Input<inputs.quicksight.TemplateFieldSortOptionsArgs>[]>;
    }
    interface TemplateHeatMapVisualArgs {
        /**
         * The list of custom actions that are configured for a visual.
         */
        actions?: pulumi.Input<pulumi.Input<inputs.quicksight.TemplateVisualCustomActionArgs>[]>;
        /**
         * The configuration of a heat map.
         */
        chartConfiguration?: pulumi.Input<inputs.quicksight.TemplateHeatMapConfigurationArgs>;
        /**
         * The column hierarchy that is used during drill-downs and drill-ups.
         */
        columnHierarchies?: pulumi.Input<pulumi.Input<inputs.quicksight.TemplateColumnHierarchyArgs>[]>;
        /**
         * The subtitle that is displayed on the visual.
         */
        subtitle?: pulumi.Input<inputs.quicksight.TemplateVisualSubtitleLabelOptionsArgs>;
        /**
         * The title that is displayed on the visual.
         */
        title?: pulumi.Input<inputs.quicksight.TemplateVisualTitleLabelOptionsArgs>;
        /**
         * The alt text for the visual.
         */
        visualContentAltText?: pulumi.Input<string>;
        /**
         * The unique identifier of a visual. This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers.
         */
        visualId: pulumi.Input<string>;
    }
    interface TemplateHistogramAggregatedFieldWellsArgs {
        /**
         * The value field wells of a histogram. Values are aggregated by `COUNT` or `DISTINCT_COUNT` .
         */
        values?: pulumi.Input<pulumi.Input<inputs.quicksight.TemplateMeasureFieldArgs>[]>;
    }
    interface TemplateHistogramBinOptionsArgs {
        /**
         * The options that determine the bin count of a histogram.
         */
        binCount?: pulumi.Input<inputs.quicksight.TemplateBinCountOptionsArgs>;
        /**
         * The options that determine the bin width of a histogram.
         */
        binWidth?: pulumi.Input<inputs.quicksight.TemplateBinWidthOptionsArgs>;
        /**
         * The options that determine the selected bin type.
         */
        selectedBinType?: pulumi.Input<enums.quicksight.TemplateHistogramBinType>;
        /**
         * The options that determine the bin start value.
         */
        startValue?: pulumi.Input<number>;
    }
    interface TemplateHistogramConfigurationArgs {
        /**
         * The options that determine the presentation of histogram bins.
         */
        binOptions?: pulumi.Input<inputs.quicksight.TemplateHistogramBinOptionsArgs>;
        /**
         * The data label configuration of a histogram.
         */
        dataLabels?: pulumi.Input<inputs.quicksight.TemplateDataLabelOptionsArgs>;
        /**
         * The field well configuration of a histogram.
         */
        fieldWells?: pulumi.Input<inputs.quicksight.TemplateHistogramFieldWellsArgs>;
        /**
         * The general visual interactions setup for a visual.
         */
        interactions?: pulumi.Input<inputs.quicksight.TemplateVisualInteractionOptionsArgs>;
        /**
         * The tooltip configuration of a histogram.
         */
        tooltip?: pulumi.Input<inputs.quicksight.TemplateTooltipOptionsArgs>;
        /**
         * The visual palette configuration of a histogram.
         */
        visualPalette?: pulumi.Input<inputs.quicksight.TemplateVisualPaletteArgs>;
        /**
         * The options that determine the presentation of the x-axis.
         */
        xAxisDisplayOptions?: pulumi.Input<inputs.quicksight.TemplateAxisDisplayOptionsArgs>;
        /**
         * The options that determine the presentation of the x-axis label.
         */
        xAxisLabelOptions?: pulumi.Input<inputs.quicksight.TemplateChartAxisLabelOptionsArgs>;
        /**
         * The options that determine the presentation of the y-axis.
         */
        yAxisDisplayOptions?: pulumi.Input<inputs.quicksight.TemplateAxisDisplayOptionsArgs>;
    }
    interface TemplateHistogramFieldWellsArgs {
        /**
         * The field well configuration of a histogram.
         */
        histogramAggregatedFieldWells?: pulumi.Input<inputs.quicksight.TemplateHistogramAggregatedFieldWellsArgs>;
    }
    interface TemplateHistogramVisualArgs {
        /**
         * The list of custom actions that are configured for a visual.
         */
        actions?: pulumi.Input<pulumi.Input<inputs.quicksight.TemplateVisualCustomActionArgs>[]>;
        /**
         * The configuration for a `HistogramVisual` .
         */
        chartConfiguration?: pulumi.Input<inputs.quicksight.TemplateHistogramConfigurationArgs>;
        /**
         * The subtitle that is displayed on the visual.
         */
        subtitle?: pulumi.Input<inputs.quicksight.TemplateVisualSubtitleLabelOptionsArgs>;
        /**
         * The title that is displayed on the visual.
         */
        title?: pulumi.Input<inputs.quicksight.TemplateVisualTitleLabelOptionsArgs>;
        /**
         * The alt text for the visual.
         */
        visualContentAltText?: pulumi.Input<string>;
        /**
         * The unique identifier of a visual. This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers.
         */
        visualId: pulumi.Input<string>;
    }
    interface TemplateImageCustomActionArgs {
        /**
         * A list of `ImageCustomActionOperations` .
         *
         * This is a union type structure. For this structure to be valid, only one of the attributes can be defined.
         */
        actionOperations: pulumi.Input<pulumi.Input<inputs.quicksight.TemplateImageCustomActionOperationArgs>[]>;
        /**
         * The ID of the custom action.
         */
        customActionId: pulumi.Input<string>;
        /**
         * The name of the custom action.
         */
        name: pulumi.Input<string>;
        /**
         * The status of the custom action.
         */
        status?: pulumi.Input<enums.quicksight.TemplateWidgetStatus>;
        /**
         * The trigger of the `VisualCustomAction` .
         *
         * Valid values are defined as follows:
         *
         * - `CLICK` : Initiates a custom action by a left pointer click on a data point.
         * - `MENU` : Initiates a custom action by right pointer click from the menu.
         */
        trigger: pulumi.Input<enums.quicksight.TemplateImageCustomActionTrigger>;
    }
    interface TemplateImageCustomActionOperationArgs {
        navigationOperation?: pulumi.Input<inputs.quicksight.TemplateCustomActionNavigationOperationArgs>;
        setParametersOperation?: pulumi.Input<inputs.quicksight.TemplateCustomActionSetParametersOperationArgs>;
        urlOperation?: pulumi.Input<inputs.quicksight.TemplateCustomActionUrlOperationArgs>;
    }
    interface TemplateImageInteractionOptionsArgs {
        /**
         * The menu options for the image.
         */
        imageMenuOption?: pulumi.Input<inputs.quicksight.TemplateImageMenuOptionArgs>;
    }
    interface TemplateImageMenuOptionArgs {
        /**
         * The availability status of the image menu. If the value of this property is set to `ENABLED` , dashboard readers can interact with the image menu.
         */
        availabilityStatus?: pulumi.Input<enums.quicksight.TemplateDashboardBehavior>;
    }
    interface TemplateInnerFilterArgs {
        /**
         * A `CategoryInnerFilter` filters text values for the `NestedFilter` .
         */
        categoryInnerFilter?: pulumi.Input<inputs.quicksight.TemplateCategoryInnerFilterArgs>;
    }
    interface TemplateInsightConfigurationArgs {
        /**
         * The computations configurations of the insight visual
         */
        computations?: pulumi.Input<pulumi.Input<inputs.quicksight.TemplateComputationArgs>[]>;
        /**
         * The custom narrative of the insight visual.
         */
        customNarrative?: pulumi.Input<inputs.quicksight.TemplateCustomNarrativeOptionsArgs>;
        /**
         * The general visual interactions setup for a visual.
         */
        interactions?: pulumi.Input<inputs.quicksight.TemplateVisualInteractionOptionsArgs>;
    }
    interface TemplateInsightVisualArgs {
        /**
         * The list of custom actions that are configured for a visual.
         */
        actions?: pulumi.Input<pulumi.Input<inputs.quicksight.TemplateVisualCustomActionArgs>[]>;
        /**
         * The dataset that is used in the insight visual.
         */
        dataSetIdentifier: pulumi.Input<string>;
        /**
         * The configuration of an insight visual.
         */
        insightConfiguration?: pulumi.Input<inputs.quicksight.TemplateInsightConfigurationArgs>;
        /**
         * The subtitle that is displayed on the visual.
         */
        subtitle?: pulumi.Input<inputs.quicksight.TemplateVisualSubtitleLabelOptionsArgs>;
        /**
         * The title that is displayed on the visual.
         */
        title?: pulumi.Input<inputs.quicksight.TemplateVisualTitleLabelOptionsArgs>;
        /**
         * The alt text for the visual.
         */
        visualContentAltText?: pulumi.Input<string>;
        /**
         * The unique identifier of a visual. This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers.
         */
        visualId: pulumi.Input<string>;
    }
    interface TemplateIntegerDefaultValuesArgs {
        /**
         * The dynamic value of the `IntegerDefaultValues` . Different defaults are displayed according to users, groups, and values mapping.
         */
        dynamicValue?: pulumi.Input<inputs.quicksight.TemplateDynamicDefaultValueArgs>;
        /**
         * The static values of the `IntegerDefaultValues` .
         */
        staticValues?: pulumi.Input<pulumi.Input<number>[]>;
    }
    interface TemplateIntegerParameterDeclarationArgs {
        /**
         * The default values of a parameter. If the parameter is a single-value parameter, a maximum of one default value can be provided.
         */
        defaultValues?: pulumi.Input<inputs.quicksight.TemplateIntegerDefaultValuesArgs>;
        mappedDataSetParameters?: pulumi.Input<pulumi.Input<inputs.quicksight.TemplateMappedDataSetParameterArgs>[]>;
        /**
         * The name of the parameter that is being declared.
         */
        name: pulumi.Input<string>;
        /**
         * The value type determines whether the parameter is a single-value or multi-value parameter.
         */
        parameterValueType: pulumi.Input<enums.quicksight.TemplateParameterValueType>;
        /**
         * A parameter declaration for the `Integer` data type.
         */
        valueWhenUnset?: pulumi.Input<inputs.quicksight.TemplateIntegerValueWhenUnsetConfigurationArgs>;
    }
    interface TemplateIntegerValueWhenUnsetConfigurationArgs {
        /**
         * A custom value that's used when the value of a parameter isn't set.
         */
        customValue?: pulumi.Input<number>;
        /**
         * The built-in options for default values. The value can be one of the following:
         *
         * - `RECOMMENDED` : The recommended value.
         * - `NULL` : The `NULL` value.
         */
        valueWhenUnsetOption?: pulumi.Input<enums.quicksight.TemplateValueWhenUnsetOption>;
    }
    interface TemplateItemsLimitConfigurationArgs {
        /**
         * The limit on how many items of a field are showed in the chart. For example, the number of slices that are displayed in a pie chart.
         */
        itemsLimit?: pulumi.Input<number>;
        /**
         * The `Show other` of an axis in the chart. Choose one of the following options:
         *
         * - `INCLUDE`
         * - `EXCLUDE`
         */
        otherCategories?: pulumi.Input<enums.quicksight.TemplateOtherCategories>;
    }
    interface TemplateKpiActualValueConditionalFormattingArgs {
        /**
         * The conditional formatting of the actual value's icon.
         */
        icon?: pulumi.Input<inputs.quicksight.TemplateConditionalFormattingIconArgs>;
        /**
         * The conditional formatting of the actual value's text color.
         */
        textColor?: pulumi.Input<inputs.quicksight.TemplateConditionalFormattingColorArgs>;
    }
    interface TemplateKpiComparisonValueConditionalFormattingArgs {
        /**
         * The conditional formatting of the comparison value's icon.
         */
        icon?: pulumi.Input<inputs.quicksight.TemplateConditionalFormattingIconArgs>;
        /**
         * The conditional formatting of the comparison value's text color.
         */
        textColor?: pulumi.Input<inputs.quicksight.TemplateConditionalFormattingColorArgs>;
    }
    interface TemplateKpiConditionalFormattingArgs {
        /**
         * The conditional formatting options of a KPI visual.
         */
        conditionalFormattingOptions?: pulumi.Input<pulumi.Input<inputs.quicksight.TemplateKpiConditionalFormattingOptionArgs>[]>;
    }
    interface TemplateKpiConditionalFormattingOptionArgs {
        /**
         * The conditional formatting for the actual value of a KPI visual.
         */
        actualValue?: pulumi.Input<inputs.quicksight.TemplateKpiActualValueConditionalFormattingArgs>;
        /**
         * The conditional formatting for the comparison value of a KPI visual.
         */
        comparisonValue?: pulumi.Input<inputs.quicksight.TemplateKpiComparisonValueConditionalFormattingArgs>;
        /**
         * The conditional formatting for the primary value of a KPI visual.
         */
        primaryValue?: pulumi.Input<inputs.quicksight.TemplateKpiPrimaryValueConditionalFormattingArgs>;
        /**
         * The conditional formatting for the progress bar of a KPI visual.
         */
        progressBar?: pulumi.Input<inputs.quicksight.TemplateKpiProgressBarConditionalFormattingArgs>;
    }
    interface TemplateKpiConfigurationArgs {
        /**
         * The field well configuration of a KPI visual.
         */
        fieldWells?: pulumi.Input<inputs.quicksight.TemplateKpiFieldWellsArgs>;
        /**
         * The general visual interactions setup for a visual.
         */
        interactions?: pulumi.Input<inputs.quicksight.TemplateVisualInteractionOptionsArgs>;
        /**
         * The options that determine the presentation of a KPI visual.
         */
        kpiOptions?: pulumi.Input<inputs.quicksight.TemplateKpiOptionsArgs>;
        /**
         * The sort configuration of a KPI visual.
         */
        sortConfiguration?: pulumi.Input<inputs.quicksight.TemplateKpiSortConfigurationArgs>;
    }
    interface TemplateKpiFieldWellsArgs {
        /**
         * The target value field wells of a KPI visual.
         */
        targetValues?: pulumi.Input<pulumi.Input<inputs.quicksight.TemplateMeasureFieldArgs>[]>;
        /**
         * The trend group field wells of a KPI visual.
         */
        trendGroups?: pulumi.Input<pulumi.Input<inputs.quicksight.TemplateDimensionFieldArgs>[]>;
        /**
         * The value field wells of a KPI visual.
         */
        values?: pulumi.Input<pulumi.Input<inputs.quicksight.TemplateMeasureFieldArgs>[]>;
    }
    interface TemplateKpiOptionsArgs {
        /**
         * The comparison configuration of a KPI visual.
         */
        comparison?: pulumi.Input<inputs.quicksight.TemplateComparisonConfigurationArgs>;
        /**
         * The options that determine the primary value display type.
         */
        primaryValueDisplayType?: pulumi.Input<enums.quicksight.TemplatePrimaryValueDisplayType>;
        /**
         * The options that determine the primary value font configuration.
         */
        primaryValueFontConfiguration?: pulumi.Input<inputs.quicksight.TemplateFontConfigurationArgs>;
        /**
         * The options that determine the presentation of the progress bar of a KPI visual.
         */
        progressBar?: pulumi.Input<inputs.quicksight.TemplateProgressBarOptionsArgs>;
        /**
         * The options that determine the presentation of the secondary value of a KPI visual.
         */
        secondaryValue?: pulumi.Input<inputs.quicksight.TemplateSecondaryValueOptionsArgs>;
        /**
         * The options that determine the secondary value font configuration.
         */
        secondaryValueFontConfiguration?: pulumi.Input<inputs.quicksight.TemplateFontConfigurationArgs>;
        /**
         * The options that determine the visibility, color, type, and tooltip visibility of the sparkline of a KPI visual.
         */
        sparkline?: pulumi.Input<inputs.quicksight.TemplateKpiSparklineOptionsArgs>;
        /**
         * The options that determine the presentation of trend arrows in a KPI visual.
         */
        trendArrows?: pulumi.Input<inputs.quicksight.TemplateTrendArrowOptionsArgs>;
        /**
         * The options that determine the layout a KPI visual.
         */
        visualLayoutOptions?: pulumi.Input<inputs.quicksight.TemplateKpiVisualLayoutOptionsArgs>;
    }
    interface TemplateKpiPrimaryValueConditionalFormattingArgs {
        /**
         * The conditional formatting of the primary value's icon.
         */
        icon?: pulumi.Input<inputs.quicksight.TemplateConditionalFormattingIconArgs>;
        /**
         * The conditional formatting of the primary value's text color.
         */
        textColor?: pulumi.Input<inputs.quicksight.TemplateConditionalFormattingColorArgs>;
    }
    interface TemplateKpiProgressBarConditionalFormattingArgs {
        /**
         * The conditional formatting of the progress bar's foreground color.
         */
        foregroundColor?: pulumi.Input<inputs.quicksight.TemplateConditionalFormattingColorArgs>;
    }
    interface TemplateKpiSortConfigurationArgs {
        /**
         * The sort configuration of the trend group fields.
         */
        trendGroupSort?: pulumi.Input<pulumi.Input<inputs.quicksight.TemplateFieldSortOptionsArgs>[]>;
    }
    interface TemplateKpiSparklineOptionsArgs {
        /**
         * The color of the sparkline.
         */
        color?: pulumi.Input<string>;
        /**
         * The tooltip visibility of the sparkline.
         */
        tooltipVisibility?: any;
        /**
         * The type of the sparkline.
         */
        type: pulumi.Input<enums.quicksight.TemplateKpiSparklineType>;
        /**
         * The visibility of the sparkline.
         */
        visibility?: any;
    }
    interface TemplateKpiVisualArgs {
        /**
         * The list of custom actions that are configured for a visual.
         */
        actions?: pulumi.Input<pulumi.Input<inputs.quicksight.TemplateVisualCustomActionArgs>[]>;
        /**
         * The configuration of a KPI visual.
         */
        chartConfiguration?: pulumi.Input<inputs.quicksight.TemplateKpiConfigurationArgs>;
        /**
         * The column hierarchy that is used during drill-downs and drill-ups.
         */
        columnHierarchies?: pulumi.Input<pulumi.Input<inputs.quicksight.TemplateColumnHierarchyArgs>[]>;
        /**
         * The conditional formatting of a KPI visual.
         */
        conditionalFormatting?: pulumi.Input<inputs.quicksight.TemplateKpiConditionalFormattingArgs>;
        /**
         * The subtitle that is displayed on the visual.
         */
        subtitle?: pulumi.Input<inputs.quicksight.TemplateVisualSubtitleLabelOptionsArgs>;
        /**
         * The title that is displayed on the visual.
         */
        title?: pulumi.Input<inputs.quicksight.TemplateVisualTitleLabelOptionsArgs>;
        /**
         * The alt text for the visual.
         */
        visualContentAltText?: pulumi.Input<string>;
        /**
         * The unique identifier of a visual. This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers.
         */
        visualId: pulumi.Input<string>;
    }
    interface TemplateKpiVisualLayoutOptionsArgs {
        /**
         * The standard layout of the KPI visual.
         */
        standardLayout?: pulumi.Input<inputs.quicksight.TemplateKpiVisualStandardLayoutArgs>;
    }
    interface TemplateKpiVisualStandardLayoutArgs {
        /**
         * The standard layout type.
         */
        type: pulumi.Input<enums.quicksight.TemplateKpiVisualStandardLayoutType>;
    }
    interface TemplateLabelOptionsArgs {
        /**
         * The text for the label.
         */
        customLabel?: pulumi.Input<string>;
        /**
         * The font configuration of the label.
         */
        fontConfiguration?: pulumi.Input<inputs.quicksight.TemplateFontConfigurationArgs>;
        /**
         * Determines whether or not the label is visible.
         */
        visibility?: any;
    }
    interface TemplateLayoutArgs {
        /**
         * The configuration that determines what the type of layout for a sheet.
         */
        configuration: pulumi.Input<inputs.quicksight.TemplateLayoutConfigurationArgs>;
    }
    interface TemplateLayoutConfigurationArgs {
        /**
         * A free-form is optimized for a fixed width and has more control over the exact placement of layout elements.
         */
        freeFormLayout?: pulumi.Input<inputs.quicksight.TemplateFreeFormLayoutConfigurationArgs>;
        /**
         * A type of layout that can be used on a sheet. In a grid layout, visuals snap to a grid with standard spacing and alignment. Dashboards are displayed as designed, with options to fit to screen or view at actual size. A grid layout can be configured to behave in one of two ways when the viewport is resized: `FIXED` or `RESPONSIVE` .
         */
        gridLayout?: pulumi.Input<inputs.quicksight.TemplateGridLayoutConfigurationArgs>;
        /**
         * A section based layout organizes visuals into multiple sections and has customized header, footer and page break.
         */
        sectionBasedLayout?: pulumi.Input<inputs.quicksight.TemplateSectionBasedLayoutConfigurationArgs>;
    }
    interface TemplateLegendOptionsArgs {
        /**
         * String based length that is composed of value and unit in px
         */
        height?: pulumi.Input<string>;
        /**
         * The positions for the legend. Choose one of the following options:
         *
         * - `AUTO`
         * - `RIGHT`
         * - `BOTTOM`
         * - `LEFT`
         */
        position?: pulumi.Input<enums.quicksight.TemplateLegendPosition>;
        /**
         * The custom title for the legend.
         */
        title?: pulumi.Input<inputs.quicksight.TemplateLabelOptionsArgs>;
        valueFontConfiguration?: pulumi.Input<inputs.quicksight.TemplateFontConfigurationArgs>;
        /**
         * Determines whether or not the legend is visible.
         */
        visibility?: any;
        /**
         * String based length that is composed of value and unit in px
         */
        width?: pulumi.Input<string>;
    }
    interface TemplateLineChartAggregatedFieldWellsArgs {
        /**
         * The category field wells of a line chart. Values are grouped by category fields.
         */
        category?: pulumi.Input<pulumi.Input<inputs.quicksight.TemplateDimensionFieldArgs>[]>;
        /**
         * The color field wells of a line chart. Values are grouped by category fields.
         */
        colors?: pulumi.Input<pulumi.Input<inputs.quicksight.TemplateDimensionFieldArgs>[]>;
        /**
         * The small multiples field well of a line chart.
         */
        smallMultiples?: pulumi.Input<pulumi.Input<inputs.quicksight.TemplateDimensionFieldArgs>[]>;
        /**
         * The value field wells of a line chart. Values are aggregated based on categories.
         */
        values?: pulumi.Input<pulumi.Input<inputs.quicksight.TemplateMeasureFieldArgs>[]>;
    }
    interface TemplateLineChartConfigurationArgs {
        /**
         * The default configuration of a line chart's contribution analysis.
         */
        contributionAnalysisDefaults?: pulumi.Input<pulumi.Input<inputs.quicksight.TemplateContributionAnalysisDefaultArgs>[]>;
        /**
         * The data label configuration of a line chart.
         */
        dataLabels?: pulumi.Input<inputs.quicksight.TemplateDataLabelOptionsArgs>;
        /**
         * The options that determine the default presentation of all line series in `LineChartVisual` .
         */
        defaultSeriesSettings?: pulumi.Input<inputs.quicksight.TemplateLineChartDefaultSeriesSettingsArgs>;
        /**
         * The field well configuration of a line chart.
         */
        fieldWells?: pulumi.Input<inputs.quicksight.TemplateLineChartFieldWellsArgs>;
        /**
         * The forecast configuration of a line chart.
         */
        forecastConfigurations?: pulumi.Input<pulumi.Input<inputs.quicksight.TemplateForecastConfigurationArgs>[]>;
        /**
         * The general visual interactions setup for a visual.
         */
        interactions?: pulumi.Input<inputs.quicksight.TemplateVisualInteractionOptionsArgs>;
        /**
         * The legend configuration of a line chart.
         */
        legend?: pulumi.Input<inputs.quicksight.TemplateLegendOptionsArgs>;
        /**
         * The series axis configuration of a line chart.
         */
        primaryYAxisDisplayOptions?: pulumi.Input<inputs.quicksight.TemplateLineSeriesAxisDisplayOptionsArgs>;
        /**
         * The options that determine the presentation of the y-axis label.
         */
        primaryYAxisLabelOptions?: pulumi.Input<inputs.quicksight.TemplateChartAxisLabelOptionsArgs>;
        /**
         * The reference lines configuration of a line chart.
         */
        referenceLines?: pulumi.Input<pulumi.Input<inputs.quicksight.TemplateReferenceLineArgs>[]>;
        /**
         * The series axis configuration of a line chart.
         */
        secondaryYAxisDisplayOptions?: pulumi.Input<inputs.quicksight.TemplateLineSeriesAxisDisplayOptionsArgs>;
        /**
         * The options that determine the presentation of the secondary y-axis label.
         */
        secondaryYAxisLabelOptions?: pulumi.Input<inputs.quicksight.TemplateChartAxisLabelOptionsArgs>;
        /**
         * The series item configuration of a line chart.
         */
        series?: pulumi.Input<pulumi.Input<inputs.quicksight.TemplateSeriesItemArgs>[]>;
        singleAxisOptions?: pulumi.Input<inputs.quicksight.TemplateSingleAxisOptionsArgs>;
        /**
         * The small multiples setup for the visual.
         */
        smallMultiplesOptions?: pulumi.Input<inputs.quicksight.TemplateSmallMultiplesOptionsArgs>;
        /**
         * The sort configuration of a line chart.
         */
        sortConfiguration?: pulumi.Input<inputs.quicksight.TemplateLineChartSortConfigurationArgs>;
        /**
         * The tooltip configuration of a line chart.
         */
        tooltip?: pulumi.Input<inputs.quicksight.TemplateTooltipOptionsArgs>;
        /**
         * Determines the type of the line chart.
         */
        type?: pulumi.Input<enums.quicksight.TemplateLineChartType>;
        /**
         * The visual palette configuration of a line chart.
         */
        visualPalette?: pulumi.Input<inputs.quicksight.TemplateVisualPaletteArgs>;
        /**
         * The options that determine the presentation of the x-axis.
         */
        xAxisDisplayOptions?: pulumi.Input<inputs.quicksight.TemplateAxisDisplayOptionsArgs>;
        /**
         * The options that determine the presentation of the x-axis label.
         */
        xAxisLabelOptions?: pulumi.Input<inputs.quicksight.TemplateChartAxisLabelOptionsArgs>;
    }
    interface TemplateLineChartDefaultSeriesSettingsArgs {
        /**
         * The axis to which you are binding all line series to.
         */
        axisBinding?: pulumi.Input<enums.quicksight.TemplateAxisBinding>;
        /**
         * Line styles options for all line series in the visual.
         */
        lineStyleSettings?: pulumi.Input<inputs.quicksight.TemplateLineChartLineStyleSettingsArgs>;
        /**
         * Marker styles options for all line series in the visual.
         */
        markerStyleSettings?: pulumi.Input<inputs.quicksight.TemplateLineChartMarkerStyleSettingsArgs>;
    }
    interface TemplateLineChartFieldWellsArgs {
        /**
         * The field well configuration of a line chart.
         */
        lineChartAggregatedFieldWells?: pulumi.Input<inputs.quicksight.TemplateLineChartAggregatedFieldWellsArgs>;
    }
    interface TemplateLineChartLineStyleSettingsArgs {
        /**
         * Interpolation style for line series.
         *
         * - `LINEAR` : Show as default, linear style.
         * - `SMOOTH` : Show as a smooth curve.
         * - `STEPPED` : Show steps in line.
         */
        lineInterpolation?: pulumi.Input<enums.quicksight.TemplateLineInterpolation>;
        /**
         * Line style for line series.
         *
         * - `SOLID` : Show as a solid line.
         * - `DOTTED` : Show as a dotted line.
         * - `DASHED` : Show as a dashed line.
         */
        lineStyle?: pulumi.Input<enums.quicksight.TemplateLineChartLineStyle>;
        /**
         * Configuration option that determines whether to show the line for the series.
         */
        lineVisibility?: any;
        /**
         * String based length that is composed of value and unit in px
         */
        lineWidth?: pulumi.Input<string>;
    }
    interface TemplateLineChartMarkerStyleSettingsArgs {
        /**
         * Color of marker in the series.
         */
        markerColor?: pulumi.Input<string>;
        /**
         * Shape option for markers in the series.
         *
         * - `CIRCLE` : Show marker as a circle.
         * - `TRIANGLE` : Show marker as a triangle.
         * - `SQUARE` : Show marker as a square.
         * - `DIAMOND` : Show marker as a diamond.
         * - `ROUNDED_SQUARE` : Show marker as a rounded square.
         */
        markerShape?: pulumi.Input<enums.quicksight.TemplateLineChartMarkerShape>;
        /**
         * String based length that is composed of value and unit in px
         */
        markerSize?: pulumi.Input<string>;
        /**
         * Configuration option that determines whether to show the markers in the series.
         */
        markerVisibility?: any;
    }
    interface TemplateLineChartSeriesSettingsArgs {
        /**
         * Line styles options for a line series in `LineChartVisual` .
         */
        lineStyleSettings?: pulumi.Input<inputs.quicksight.TemplateLineChartLineStyleSettingsArgs>;
        /**
         * Marker styles options for a line series in `LineChartVisual` .
         */
        markerStyleSettings?: pulumi.Input<inputs.quicksight.TemplateLineChartMarkerStyleSettingsArgs>;
    }
    interface TemplateLineChartSortConfigurationArgs {
        /**
         * The limit on the number of categories that are displayed in a line chart.
         */
        categoryItemsLimitConfiguration?: pulumi.Input<inputs.quicksight.TemplateItemsLimitConfigurationArgs>;
        /**
         * The sort configuration of the category fields.
         */
        categorySort?: pulumi.Input<pulumi.Input<inputs.quicksight.TemplateFieldSortOptionsArgs>[]>;
        /**
         * The limit on the number of lines that are displayed in a line chart.
         */
        colorItemsLimitConfiguration?: pulumi.Input<inputs.quicksight.TemplateItemsLimitConfigurationArgs>;
        /**
         * The limit on the number of small multiples panels that are displayed.
         */
        smallMultiplesLimitConfiguration?: pulumi.Input<inputs.quicksight.TemplateItemsLimitConfigurationArgs>;
        /**
         * The sort configuration of the small multiples field.
         */
        smallMultiplesSort?: pulumi.Input<pulumi.Input<inputs.quicksight.TemplateFieldSortOptionsArgs>[]>;
    }
    interface TemplateLineChartVisualArgs {
        /**
         * The list of custom actions that are configured for a visual.
         */
        actions?: pulumi.Input<pulumi.Input<inputs.quicksight.TemplateVisualCustomActionArgs>[]>;
        /**
         * The configuration of a line chart.
         */
        chartConfiguration?: pulumi.Input<inputs.quicksight.TemplateLineChartConfigurationArgs>;
        /**
         * The column hierarchy that is used during drill-downs and drill-ups.
         */
        columnHierarchies?: pulumi.Input<pulumi.Input<inputs.quicksight.TemplateColumnHierarchyArgs>[]>;
        /**
         * The subtitle that is displayed on the visual.
         */
        subtitle?: pulumi.Input<inputs.quicksight.TemplateVisualSubtitleLabelOptionsArgs>;
        /**
         * The title that is displayed on the visual.
         */
        title?: pulumi.Input<inputs.quicksight.TemplateVisualTitleLabelOptionsArgs>;
        /**
         * The alt text for the visual.
         */
        visualContentAltText?: pulumi.Input<string>;
        /**
         * The unique identifier of a visual. This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers.
         */
        visualId: pulumi.Input<string>;
    }
    interface TemplateLineSeriesAxisDisplayOptionsArgs {
        /**
         * The options that determine the presentation of the line series axis.
         */
        axisOptions?: pulumi.Input<inputs.quicksight.TemplateAxisDisplayOptionsArgs>;
        /**
         * The configuration options that determine how missing data is treated during the rendering of a line chart.
         */
        missingDataConfigurations?: pulumi.Input<pulumi.Input<inputs.quicksight.TemplateMissingDataConfigurationArgs>[]>;
    }
    interface TemplateListControlDisplayOptionsArgs {
        /**
         * The configuration of info icon label options.
         */
        infoIconLabelOptions?: pulumi.Input<inputs.quicksight.TemplateSheetControlInfoIconLabelOptionsArgs>;
        /**
         * The configuration of the search options in a list control.
         */
        searchOptions?: pulumi.Input<inputs.quicksight.TemplateListControlSearchOptionsArgs>;
        /**
         * The configuration of the `Select all` options in a list control.
         */
        selectAllOptions?: pulumi.Input<inputs.quicksight.TemplateListControlSelectAllOptionsArgs>;
        /**
         * The options to configure the title visibility, name, and font size.
         */
        titleOptions?: pulumi.Input<inputs.quicksight.TemplateLabelOptionsArgs>;
    }
    interface TemplateListControlSearchOptionsArgs {
        /**
         * The visibility configuration of the search options in a list control.
         */
        visibility?: any;
    }
    interface TemplateListControlSelectAllOptionsArgs {
        /**
         * The visibility configuration of the `Select all` options in a list control.
         */
        visibility?: any;
    }
    interface TemplateLoadingAnimationArgs {
        /**
         * The visibility configuration of `LoadingAnimation` .
         */
        visibility?: any;
    }
    interface TemplateLocalNavigationConfigurationArgs {
        /**
         * The sheet that is targeted for navigation in the same analysis.
         */
        targetSheetId: pulumi.Input<string>;
    }
    interface TemplateLongFormatTextArgs {
        /**
         * Plain text format.
         */
        plainText?: pulumi.Input<string>;
        /**
         * Rich text. Examples of rich text include bold, underline, and italics.
         */
        richText?: pulumi.Input<string>;
    }
    interface TemplateMappedDataSetParameterArgs {
        /**
         * A unique name that identifies a dataset within the analysis or dashboard.
         */
        dataSetIdentifier: pulumi.Input<string>;
        /**
         * The name of the dataset parameter.
         */
        dataSetParameterName: pulumi.Input<string>;
    }
    interface TemplateMaximumLabelTypeArgs {
        /**
         * The visibility of the maximum label.
         */
        visibility?: any;
    }
    interface TemplateMaximumMinimumComputationArgs {
        /**
         * The ID for a computation.
         */
        computationId: pulumi.Input<string>;
        /**
         * The name of a computation.
         */
        name?: pulumi.Input<string>;
        /**
         * The time field that is used in a computation.
         */
        time?: pulumi.Input<inputs.quicksight.TemplateDimensionFieldArgs>;
        /**
         * The type of computation. Choose one of the following options:
         *
         * - MAXIMUM: A maximum computation.
         * - MINIMUM: A minimum computation.
         */
        type: pulumi.Input<enums.quicksight.TemplateMaximumMinimumComputationType>;
        /**
         * The value field that is used in a computation.
         */
        value?: pulumi.Input<inputs.quicksight.TemplateMeasureFieldArgs>;
    }
    interface TemplateMeasureFieldArgs {
        /**
         * The calculated measure field only used in pivot tables.
         */
        calculatedMeasureField?: pulumi.Input<inputs.quicksight.TemplateCalculatedMeasureFieldArgs>;
        /**
         * The measure type field with categorical type columns.
         */
        categoricalMeasureField?: pulumi.Input<inputs.quicksight.TemplateCategoricalMeasureFieldArgs>;
        /**
         * The measure type field with date type columns.
         */
        dateMeasureField?: pulumi.Input<inputs.quicksight.TemplateDateMeasureFieldArgs>;
        /**
         * The measure type field with numerical type columns.
         */
        numericalMeasureField?: pulumi.Input<inputs.quicksight.TemplateNumericalMeasureFieldArgs>;
    }
    interface TemplateMetricComparisonComputationArgs {
        /**
         * The ID for a computation.
         */
        computationId: pulumi.Input<string>;
        /**
         * The field that is used in a metric comparison from value setup.
         */
        fromValue?: pulumi.Input<inputs.quicksight.TemplateMeasureFieldArgs>;
        /**
         * The name of a computation.
         */
        name?: pulumi.Input<string>;
        /**
         * The field that is used in a metric comparison to value setup.
         */
        targetValue?: pulumi.Input<inputs.quicksight.TemplateMeasureFieldArgs>;
        /**
         * The time field that is used in a computation.
         */
        time?: pulumi.Input<inputs.quicksight.TemplateDimensionFieldArgs>;
    }
    interface TemplateMinimumLabelTypeArgs {
        /**
         * The visibility of the minimum label.
         */
        visibility?: any;
    }
    interface TemplateMissingDataConfigurationArgs {
        /**
         * The treatment option that determines how missing data should be rendered. Choose from the following options:
         *
         * - `INTERPOLATE` : Interpolate missing values between the prior and the next known value.
         * - `SHOW_AS_ZERO` : Show missing values as the value `0` .
         * - `SHOW_AS_BLANK` : Display a blank space when rendering missing data.
         */
        treatmentOption?: pulumi.Input<enums.quicksight.TemplateMissingDataTreatmentOption>;
    }
    interface TemplateNegativeValueConfigurationArgs {
        /**
         * Determines the display mode of the negative value configuration.
         */
        displayMode: pulumi.Input<enums.quicksight.TemplateNegativeValueDisplayMode>;
    }
    interface TemplateNestedFilterArgs {
        /**
         * The column that the filter is applied to.
         */
        column: pulumi.Input<inputs.quicksight.TemplateColumnIdentifierArgs>;
        /**
         * An identifier that uniquely identifies a filter within a dashboard, analysis, or template.
         */
        filterId: pulumi.Input<string>;
        /**
         * A boolean condition to include or exclude the subset that is defined by the values of the nested inner filter.
         */
        includeInnerSet: pulumi.Input<boolean>;
        /**
         * The `InnerFilter` defines the subset of data to be used with the `NestedFilter` .
         */
        innerFilter: pulumi.Input<inputs.quicksight.TemplateInnerFilterArgs>;
    }
    interface TemplateNullValueFormatConfigurationArgs {
        /**
         * Determines the null string of null values.
         */
        nullString: pulumi.Input<string>;
    }
    interface TemplateNumberDisplayFormatConfigurationArgs {
        /**
         * The option that determines the decimal places configuration.
         */
        decimalPlacesConfiguration?: pulumi.Input<inputs.quicksight.TemplateDecimalPlacesConfigurationArgs>;
        /**
         * The options that determine the negative value configuration.
         */
        negativeValueConfiguration?: pulumi.Input<inputs.quicksight.TemplateNegativeValueConfigurationArgs>;
        /**
         * The options that determine the null value format configuration.
         */
        nullValueFormatConfiguration?: pulumi.Input<inputs.quicksight.TemplateNullValueFormatConfigurationArgs>;
        /**
         * Determines the number scale value of the number format.
         */
        numberScale?: pulumi.Input<enums.quicksight.TemplateNumberScale>;
        /**
         * Determines the prefix value of the number format.
         */
        prefix?: pulumi.Input<string>;
        /**
         * The options that determine the numeric separator configuration.
         */
        separatorConfiguration?: pulumi.Input<inputs.quicksight.TemplateNumericSeparatorConfigurationArgs>;
        /**
         * Determines the suffix value of the number format.
         */
        suffix?: pulumi.Input<string>;
    }
    interface TemplateNumberFormatConfigurationArgs {
        /**
         * The options that determine the numeric format configuration.
         */
        formatConfiguration?: pulumi.Input<inputs.quicksight.TemplateNumericFormatConfigurationArgs>;
    }
    interface TemplateNumericAxisOptionsArgs {
        /**
         * The range setup of a numeric axis.
         */
        range?: pulumi.Input<inputs.quicksight.TemplateAxisDisplayRangeArgs>;
        /**
         * The scale setup of a numeric axis.
         */
        scale?: pulumi.Input<inputs.quicksight.TemplateAxisScaleArgs>;
    }
    interface TemplateNumericEqualityDrillDownFilterArgs {
        /**
         * The column that the filter is applied to.
         */
        column: pulumi.Input<inputs.quicksight.TemplateColumnIdentifierArgs>;
        /**
         * The value of the double input numeric drill down filter.
         */
        value: pulumi.Input<number>;
    }
    interface TemplateNumericEqualityFilterArgs {
        /**
         * The aggregation function of the filter.
         */
        aggregationFunction?: pulumi.Input<inputs.quicksight.TemplateAggregationFunctionArgs>;
        /**
         * The column that the filter is applied to.
         */
        column: pulumi.Input<inputs.quicksight.TemplateColumnIdentifierArgs>;
        /**
         * The default configurations for the associated controls. This applies only for filters that are scoped to multiple sheets.
         */
        defaultFilterControlConfiguration?: pulumi.Input<inputs.quicksight.TemplateDefaultFilterControlConfigurationArgs>;
        /**
         * An identifier that uniquely identifies a filter within a dashboard, analysis, or template.
         */
        filterId: pulumi.Input<string>;
        /**
         * The match operator that is used to determine if a filter should be applied.
         */
        matchOperator: pulumi.Input<enums.quicksight.TemplateNumericEqualityMatchOperator>;
        /**
         * This option determines how null values should be treated when filtering data.
         *
         * - `ALL_VALUES` : Include null values in filtered results.
         * - `NULLS_ONLY` : Only include null values in filtered results.
         * - `NON_NULLS_ONLY` : Exclude null values from filtered results.
         */
        nullOption: pulumi.Input<enums.quicksight.TemplateFilterNullOption>;
        /**
         * The parameter whose value should be used for the filter value.
         */
        parameterName?: pulumi.Input<string>;
        /**
         * Select all of the values. Null is not the assigned value of select all.
         *
         * - `FILTER_ALL_VALUES`
         */
        selectAllOptions?: pulumi.Input<enums.quicksight.TemplateNumericFilterSelectAllOptions>;
        /**
         * The input value.
         */
        value?: pulumi.Input<number>;
    }
    interface TemplateNumericFormatConfigurationArgs {
        /**
         * The options that determine the currency display format configuration.
         */
        currencyDisplayFormatConfiguration?: pulumi.Input<inputs.quicksight.TemplateCurrencyDisplayFormatConfigurationArgs>;
        /**
         * The options that determine the number display format configuration.
         */
        numberDisplayFormatConfiguration?: pulumi.Input<inputs.quicksight.TemplateNumberDisplayFormatConfigurationArgs>;
        /**
         * The options that determine the percentage display format configuration.
         */
        percentageDisplayFormatConfiguration?: pulumi.Input<inputs.quicksight.TemplatePercentageDisplayFormatConfigurationArgs>;
    }
    interface TemplateNumericRangeFilterArgs {
        /**
         * The aggregation function of the filter.
         */
        aggregationFunction?: pulumi.Input<inputs.quicksight.TemplateAggregationFunctionArgs>;
        /**
         * The column that the filter is applied to.
         */
        column: pulumi.Input<inputs.quicksight.TemplateColumnIdentifierArgs>;
        /**
         * The default configurations for the associated controls. This applies only for filters that are scoped to multiple sheets.
         */
        defaultFilterControlConfiguration?: pulumi.Input<inputs.quicksight.TemplateDefaultFilterControlConfigurationArgs>;
        /**
         * An identifier that uniquely identifies a filter within a dashboard, analysis, or template.
         */
        filterId: pulumi.Input<string>;
        /**
         * Determines whether the maximum value in the filter value range should be included in the filtered results.
         */
        includeMaximum?: pulumi.Input<boolean>;
        /**
         * Determines whether the minimum value in the filter value range should be included in the filtered results.
         */
        includeMinimum?: pulumi.Input<boolean>;
        /**
         * This option determines how null values should be treated when filtering data.
         *
         * - `ALL_VALUES` : Include null values in filtered results.
         * - `NULLS_ONLY` : Only include null values in filtered results.
         * - `NON_NULLS_ONLY` : Exclude null values from filtered results.
         */
        nullOption: pulumi.Input<enums.quicksight.TemplateFilterNullOption>;
        /**
         * The maximum value for the filter value range.
         */
        rangeMaximum?: pulumi.Input<inputs.quicksight.TemplateNumericRangeFilterValueArgs>;
        /**
         * The minimum value for the filter value range.
         */
        rangeMinimum?: pulumi.Input<inputs.quicksight.TemplateNumericRangeFilterValueArgs>;
        /**
         * Select all of the values. Null is not the assigned value of select all.
         *
         * - `FILTER_ALL_VALUES`
         */
        selectAllOptions?: pulumi.Input<enums.quicksight.TemplateNumericFilterSelectAllOptions>;
    }
    interface TemplateNumericRangeFilterValueArgs {
        /**
         * The parameter that is used in the numeric range.
         */
        parameter?: pulumi.Input<string>;
        /**
         * The static value of the numeric range filter.
         */
        staticValue?: pulumi.Input<number>;
    }
    interface TemplateNumericSeparatorConfigurationArgs {
        /**
         * Determines the decimal separator.
         */
        decimalSeparator?: pulumi.Input<enums.quicksight.TemplateNumericSeparatorSymbol>;
        /**
         * The options that determine the thousands separator configuration.
         */
        thousandsSeparator?: pulumi.Input<inputs.quicksight.TemplateThousandSeparatorOptionsArgs>;
    }
    interface TemplateNumericalAggregationFunctionArgs {
        /**
         * An aggregation based on the percentile of values in a dimension or measure.
         */
        percentileAggregation?: pulumi.Input<inputs.quicksight.TemplatePercentileAggregationArgs>;
        /**
         * Built-in aggregation functions for numerical values.
         *
         * - `SUM` : The sum of a dimension or measure.
         * - `AVERAGE` : The average of a dimension or measure.
         * - `MIN` : The minimum value of a dimension or measure.
         * - `MAX` : The maximum value of a dimension or measure.
         * - `COUNT` : The count of a dimension or measure.
         * - `DISTINCT_COUNT` : The count of distinct values in a dimension or measure.
         * - `VAR` : The variance of a dimension or measure.
         * - `VARP` : The partitioned variance of a dimension or measure.
         * - `STDEV` : The standard deviation of a dimension or measure.
         * - `STDEVP` : The partitioned standard deviation of a dimension or measure.
         * - `MEDIAN` : The median value of a dimension or measure.
         */
        simpleNumericalAggregation?: pulumi.Input<enums.quicksight.TemplateSimpleNumericalAggregationFunction>;
    }
    interface TemplateNumericalDimensionFieldArgs {
        /**
         * The column that is used in the `NumericalDimensionField` .
         */
        column: pulumi.Input<inputs.quicksight.TemplateColumnIdentifierArgs>;
        /**
         * The custom field ID.
         */
        fieldId: pulumi.Input<string>;
        /**
         * The format configuration of the field.
         */
        formatConfiguration?: pulumi.Input<inputs.quicksight.TemplateNumberFormatConfigurationArgs>;
        /**
         * The custom hierarchy ID.
         */
        hierarchyId?: pulumi.Input<string>;
    }
    interface TemplateNumericalMeasureFieldArgs {
        /**
         * The aggregation function of the measure field.
         */
        aggregationFunction?: pulumi.Input<inputs.quicksight.TemplateNumericalAggregationFunctionArgs>;
        /**
         * The column that is used in the `NumericalMeasureField` .
         */
        column: pulumi.Input<inputs.quicksight.TemplateColumnIdentifierArgs>;
        /**
         * The custom field ID.
         */
        fieldId: pulumi.Input<string>;
        /**
         * The format configuration of the field.
         */
        formatConfiguration?: pulumi.Input<inputs.quicksight.TemplateNumberFormatConfigurationArgs>;
    }
    interface TemplatePaginationConfigurationArgs {
        /**
         * Indicates the page number.
         */
        pageNumber: pulumi.Input<number>;
        /**
         * Indicates how many items render in one page.
         */
        pageSize: pulumi.Input<number>;
    }
    interface TemplatePanelConfigurationArgs {
        /**
         * Sets the background color for each panel.
         */
        backgroundColor?: pulumi.Input<string>;
        /**
         * Determines whether or not a background for each small multiples panel is rendered.
         */
        backgroundVisibility?: any;
        /**
         * Sets the line color of panel borders.
         */
        borderColor?: pulumi.Input<string>;
        /**
         * Sets the line style of panel borders.
         */
        borderStyle?: pulumi.Input<enums.quicksight.TemplatePanelBorderStyle>;
        /**
         * String based length that is composed of value and unit in px
         */
        borderThickness?: pulumi.Input<string>;
        /**
         * Determines whether or not each panel displays a border.
         */
        borderVisibility?: any;
        /**
         * String based length that is composed of value and unit in px
         */
        gutterSpacing?: pulumi.Input<string>;
        /**
         * Determines whether or not negative space between sibling panels is rendered.
         */
        gutterVisibility?: any;
        /**
         * Configures the title display within each small multiples panel.
         */
        title?: pulumi.Input<inputs.quicksight.TemplatePanelTitleOptionsArgs>;
    }
    interface TemplatePanelTitleOptionsArgs {
        fontConfiguration?: pulumi.Input<inputs.quicksight.TemplateFontConfigurationArgs>;
        /**
         * Sets the horizontal text alignment of the title within each panel.
         */
        horizontalTextAlignment?: pulumi.Input<enums.quicksight.TemplateHorizontalTextAlignment>;
        /**
         * Determines whether or not panel titles are displayed.
         */
        visibility?: any;
    }
    interface TemplateParameterControlArgs {
        /**
         * A control from a date parameter that specifies date and time.
         */
        dateTimePicker?: pulumi.Input<inputs.quicksight.TemplateParameterDateTimePickerControlArgs>;
        /**
         * A control to display a dropdown list with buttons that are used to select a single value.
         */
        dropdown?: pulumi.Input<inputs.quicksight.TemplateParameterDropDownControlArgs>;
        /**
         * A control to display a list with buttons or boxes that are used to select either a single value or multiple values.
         */
        list?: pulumi.Input<inputs.quicksight.TemplateParameterListControlArgs>;
        /**
         * A control to display a horizontal toggle bar. This is used to change a value by sliding the toggle.
         */
        slider?: pulumi.Input<inputs.quicksight.TemplateParameterSliderControlArgs>;
        /**
         * A control to display a text box that is used to enter multiple entries.
         */
        textArea?: pulumi.Input<inputs.quicksight.TemplateParameterTextAreaControlArgs>;
        /**
         * A control to display a text box that is used to enter a single entry.
         */
        textField?: pulumi.Input<inputs.quicksight.TemplateParameterTextFieldControlArgs>;
    }
    interface TemplateParameterDateTimePickerControlArgs {
        /**
         * The display options of a control.
         */
        displayOptions?: pulumi.Input<inputs.quicksight.TemplateDateTimePickerControlDisplayOptionsArgs>;
        /**
         * The ID of the `ParameterDateTimePickerControl` .
         */
        parameterControlId: pulumi.Input<string>;
        /**
         * The name of the `ParameterDateTimePickerControl` .
         */
        sourceParameterName: pulumi.Input<string>;
        /**
         * The title of the `ParameterDateTimePickerControl` .
         */
        title: pulumi.Input<string>;
    }
    interface TemplateParameterDeclarationArgs {
        /**
         * A parameter declaration for the `DateTime` data type.
         */
        dateTimeParameterDeclaration?: pulumi.Input<inputs.quicksight.TemplateDateTimeParameterDeclarationArgs>;
        /**
         * A parameter declaration for the `Decimal` data type.
         */
        decimalParameterDeclaration?: pulumi.Input<inputs.quicksight.TemplateDecimalParameterDeclarationArgs>;
        /**
         * A parameter declaration for the `Integer` data type.
         */
        integerParameterDeclaration?: pulumi.Input<inputs.quicksight.TemplateIntegerParameterDeclarationArgs>;
        /**
         * A parameter declaration for the `String` data type.
         */
        stringParameterDeclaration?: pulumi.Input<inputs.quicksight.TemplateStringParameterDeclarationArgs>;
    }
    interface TemplateParameterDropDownControlArgs {
        /**
         * The values that are displayed in a control can be configured to only show values that are valid based on what's selected in other controls.
         */
        cascadingControlConfiguration?: pulumi.Input<inputs.quicksight.TemplateCascadingControlConfigurationArgs>;
        /**
         * The visibility configuration of the Apply button on a `ParameterDropDownControl` .
         */
        commitMode?: pulumi.Input<enums.quicksight.TemplateCommitMode>;
        /**
         * The display options of a control.
         */
        displayOptions?: pulumi.Input<inputs.quicksight.TemplateDropDownControlDisplayOptionsArgs>;
        /**
         * The ID of the `ParameterDropDownControl` .
         */
        parameterControlId: pulumi.Input<string>;
        /**
         * A list of selectable values that are used in a control.
         */
        selectableValues?: pulumi.Input<inputs.quicksight.TemplateParameterSelectableValuesArgs>;
        /**
         * The source parameter name of the `ParameterDropDownControl` .
         */
        sourceParameterName: pulumi.Input<string>;
        /**
         * The title of the `ParameterDropDownControl` .
         */
        title: pulumi.Input<string>;
        /**
         * The type parameter name of the `ParameterDropDownControl` .
         */
        type?: pulumi.Input<enums.quicksight.TemplateSheetControlListType>;
    }
    interface TemplateParameterListControlArgs {
        /**
         * The values that are displayed in a control can be configured to only show values that are valid based on what's selected in other controls.
         */
        cascadingControlConfiguration?: pulumi.Input<inputs.quicksight.TemplateCascadingControlConfigurationArgs>;
        /**
         * The display options of a control.
         */
        displayOptions?: pulumi.Input<inputs.quicksight.TemplateListControlDisplayOptionsArgs>;
        /**
         * The ID of the `ParameterListControl` .
         */
        parameterControlId: pulumi.Input<string>;
        /**
         * A list of selectable values that are used in a control.
         */
        selectableValues?: pulumi.Input<inputs.quicksight.TemplateParameterSelectableValuesArgs>;
        /**
         * The source parameter name of the `ParameterListControl` .
         */
        sourceParameterName: pulumi.Input<string>;
        /**
         * The title of the `ParameterListControl` .
         */
        title: pulumi.Input<string>;
        /**
         * The type of `ParameterListControl` .
         */
        type?: pulumi.Input<enums.quicksight.TemplateSheetControlListType>;
    }
    interface TemplateParameterSelectableValuesArgs {
        /**
         * The column identifier that fetches values from the data set.
         */
        linkToDataSetColumn?: pulumi.Input<inputs.quicksight.TemplateColumnIdentifierArgs>;
        /**
         * The values that are used in `ParameterSelectableValues` .
         */
        values?: pulumi.Input<pulumi.Input<string>[]>;
    }
    interface TemplateParameterSliderControlArgs {
        /**
         * The display options of a control.
         */
        displayOptions?: pulumi.Input<inputs.quicksight.TemplateSliderControlDisplayOptionsArgs>;
        /**
         * The larger value that is displayed at the right of the slider.
         */
        maximumValue: pulumi.Input<number>;
        /**
         * The smaller value that is displayed at the left of the slider.
         */
        minimumValue: pulumi.Input<number>;
        /**
         * The ID of the `ParameterSliderControl` .
         */
        parameterControlId: pulumi.Input<string>;
        /**
         * The source parameter name of the `ParameterSliderControl` .
         */
        sourceParameterName: pulumi.Input<string>;
        /**
         * The number of increments that the slider bar is divided into.
         */
        stepSize: pulumi.Input<number>;
        /**
         * The title of the `ParameterSliderControl` .
         */
        title: pulumi.Input<string>;
    }
    interface TemplateParameterTextAreaControlArgs {
        /**
         * The delimiter that is used to separate the lines in text.
         */
        delimiter?: pulumi.Input<string>;
        /**
         * The display options of a control.
         */
        displayOptions?: pulumi.Input<inputs.quicksight.TemplateTextAreaControlDisplayOptionsArgs>;
        /**
         * The ID of the `ParameterTextAreaControl` .
         */
        parameterControlId: pulumi.Input<string>;
        /**
         * The source parameter name of the `ParameterTextAreaControl` .
         */
        sourceParameterName: pulumi.Input<string>;
        /**
         * The title of the `ParameterTextAreaControl` .
         */
        title: pulumi.Input<string>;
    }
    interface TemplateParameterTextFieldControlArgs {
        /**
         * The display options of a control.
         */
        displayOptions?: pulumi.Input<inputs.quicksight.TemplateTextFieldControlDisplayOptionsArgs>;
        /**
         * The ID of the `ParameterTextFieldControl` .
         */
        parameterControlId: pulumi.Input<string>;
        /**
         * The source parameter name of the `ParameterTextFieldControl` .
         */
        sourceParameterName: pulumi.Input<string>;
        /**
         * The title of the `ParameterTextFieldControl` .
         */
        title: pulumi.Input<string>;
    }
    interface TemplatePercentVisibleRangeArgs {
        /**
         * The lower bound of the range.
         */
        from?: pulumi.Input<number>;
        /**
         * The top bound of the range.
         */
        to?: pulumi.Input<number>;
    }
    interface TemplatePercentageDisplayFormatConfigurationArgs {
        /**
         * The option that determines the decimal places configuration.
         */
        decimalPlacesConfiguration?: pulumi.Input<inputs.quicksight.TemplateDecimalPlacesConfigurationArgs>;
        /**
         * The options that determine the negative value configuration.
         */
        negativeValueConfiguration?: pulumi.Input<inputs.quicksight.TemplateNegativeValueConfigurationArgs>;
        /**
         * The options that determine the null value format configuration.
         */
        nullValueFormatConfiguration?: pulumi.Input<inputs.quicksight.TemplateNullValueFormatConfigurationArgs>;
        /**
         * Determines the prefix value of the percentage format.
         */
        prefix?: pulumi.Input<string>;
        /**
         * The options that determine the numeric separator configuration.
         */
        separatorConfiguration?: pulumi.Input<inputs.quicksight.TemplateNumericSeparatorConfigurationArgs>;
        /**
         * Determines the suffix value of the percentage format.
         */
        suffix?: pulumi.Input<string>;
    }
    interface TemplatePercentileAggregationArgs {
        /**
         * The percentile value. This value can be any numeric constant 0–100. A percentile value of 50 computes the median value of the measure.
         */
        percentileValue?: pulumi.Input<number>;
    }
    interface TemplatePeriodOverPeriodComputationArgs {
        /**
         * The ID for a computation.
         */
        computationId: pulumi.Input<string>;
        /**
         * The name of a computation.
         */
        name?: pulumi.Input<string>;
        /**
         * The time field that is used in a computation.
         */
        time?: pulumi.Input<inputs.quicksight.TemplateDimensionFieldArgs>;
        /**
         * The value field that is used in a computation.
         */
        value?: pulumi.Input<inputs.quicksight.TemplateMeasureFieldArgs>;
    }
    interface TemplatePeriodToDateComputationArgs {
        /**
         * The ID for a computation.
         */
        computationId: pulumi.Input<string>;
        /**
         * The name of a computation.
         */
        name?: pulumi.Input<string>;
        /**
         * The time granularity setup of period to date computation. Choose from the following options:
         *
         * - YEAR: Year to date.
         * - MONTH: Month to date.
         */
        periodTimeGranularity?: pulumi.Input<enums.quicksight.TemplateTimeGranularity>;
        /**
         * The time field that is used in a computation.
         */
        time?: pulumi.Input<inputs.quicksight.TemplateDimensionFieldArgs>;
        /**
         * The value field that is used in a computation.
         */
        value?: pulumi.Input<inputs.quicksight.TemplateMeasureFieldArgs>;
    }
    interface TemplatePieChartAggregatedFieldWellsArgs {
        /**
         * The category (group/color) field wells of a pie chart.
         */
        category?: pulumi.Input<pulumi.Input<inputs.quicksight.TemplateDimensionFieldArgs>[]>;
        /**
         * The small multiples field well of a pie chart.
         */
        smallMultiples?: pulumi.Input<pulumi.Input<inputs.quicksight.TemplateDimensionFieldArgs>[]>;
        /**
         * The value field wells of a pie chart. Values are aggregated based on categories.
         */
        values?: pulumi.Input<pulumi.Input<inputs.quicksight.TemplateMeasureFieldArgs>[]>;
    }
    interface TemplatePieChartConfigurationArgs {
        /**
         * The label options of the group/color that is displayed in a pie chart.
         */
        categoryLabelOptions?: pulumi.Input<inputs.quicksight.TemplateChartAxisLabelOptionsArgs>;
        /**
         * The contribution analysis (anomaly configuration) setup of the visual.
         */
        contributionAnalysisDefaults?: pulumi.Input<pulumi.Input<inputs.quicksight.TemplateContributionAnalysisDefaultArgs>[]>;
        /**
         * The options that determine if visual data labels are displayed.
         */
        dataLabels?: pulumi.Input<inputs.quicksight.TemplateDataLabelOptionsArgs>;
        /**
         * The options that determine the shape of the chart. This option determines whether the chart is a pie chart or a donut chart.
         */
        donutOptions?: pulumi.Input<inputs.quicksight.TemplateDonutOptionsArgs>;
        /**
         * The field wells of the visual.
         */
        fieldWells?: pulumi.Input<inputs.quicksight.TemplatePieChartFieldWellsArgs>;
        /**
         * The general visual interactions setup for a visual.
         */
        interactions?: pulumi.Input<inputs.quicksight.TemplateVisualInteractionOptionsArgs>;
        /**
         * The legend display setup of the visual.
         */
        legend?: pulumi.Input<inputs.quicksight.TemplateLegendOptionsArgs>;
        /**
         * The small multiples setup for the visual.
         */
        smallMultiplesOptions?: pulumi.Input<inputs.quicksight.TemplateSmallMultiplesOptionsArgs>;
        /**
         * The sort configuration of a pie chart.
         */
        sortConfiguration?: pulumi.Input<inputs.quicksight.TemplatePieChartSortConfigurationArgs>;
        /**
         * The tooltip display setup of the visual.
         */
        tooltip?: pulumi.Input<inputs.quicksight.TemplateTooltipOptionsArgs>;
        /**
         * The label options for the value that is displayed in a pie chart.
         */
        valueLabelOptions?: pulumi.Input<inputs.quicksight.TemplateChartAxisLabelOptionsArgs>;
        /**
         * The palette (chart color) display setup of the visual.
         */
        visualPalette?: pulumi.Input<inputs.quicksight.TemplateVisualPaletteArgs>;
    }
    interface TemplatePieChartFieldWellsArgs {
        /**
         * The field well configuration of a pie chart.
         */
        pieChartAggregatedFieldWells?: pulumi.Input<inputs.quicksight.TemplatePieChartAggregatedFieldWellsArgs>;
    }
    interface TemplatePieChartSortConfigurationArgs {
        /**
         * The limit on the number of categories that are displayed in a pie chart.
         */
        categoryItemsLimit?: pulumi.Input<inputs.quicksight.TemplateItemsLimitConfigurationArgs>;
        /**
         * The sort configuration of the category fields.
         */
        categorySort?: pulumi.Input<pulumi.Input<inputs.quicksight.TemplateFieldSortOptionsArgs>[]>;
        /**
         * The limit on the number of small multiples panels that are displayed.
         */
        smallMultiplesLimitConfiguration?: pulumi.Input<inputs.quicksight.TemplateItemsLimitConfigurationArgs>;
        /**
         * The sort configuration of the small multiples field.
         */
        smallMultiplesSort?: pulumi.Input<pulumi.Input<inputs.quicksight.TemplateFieldSortOptionsArgs>[]>;
    }
    interface TemplatePieChartVisualArgs {
        /**
         * The list of custom actions that are configured for a visual.
         */
        actions?: pulumi.Input<pulumi.Input<inputs.quicksight.TemplateVisualCustomActionArgs>[]>;
        /**
         * The configuration of a pie chart.
         */
        chartConfiguration?: pulumi.Input<inputs.quicksight.TemplatePieChartConfigurationArgs>;
        /**
         * The column hierarchy that is used during drill-downs and drill-ups.
         */
        columnHierarchies?: pulumi.Input<pulumi.Input<inputs.quicksight.TemplateColumnHierarchyArgs>[]>;
        /**
         * The subtitle that is displayed on the visual.
         */
        subtitle?: pulumi.Input<inputs.quicksight.TemplateVisualSubtitleLabelOptionsArgs>;
        /**
         * The title that is displayed on the visual.
         */
        title?: pulumi.Input<inputs.quicksight.TemplateVisualTitleLabelOptionsArgs>;
        /**
         * The alt text for the visual.
         */
        visualContentAltText?: pulumi.Input<string>;
        /**
         * The unique identifier of a visual. This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers.
         */
        visualId: pulumi.Input<string>;
    }
    interface TemplatePivotFieldSortOptionsArgs {
        /**
         * The field ID for the field sort options.
         */
        fieldId: pulumi.Input<string>;
        /**
         * The sort by field for the field sort options.
         */
        sortBy: pulumi.Input<inputs.quicksight.TemplatePivotTableSortByArgs>;
    }
    interface TemplatePivotTableAggregatedFieldWellsArgs {
        /**
         * The columns field well for a pivot table. Values are grouped by columns fields.
         */
        columns?: pulumi.Input<pulumi.Input<inputs.quicksight.TemplateDimensionFieldArgs>[]>;
        /**
         * The rows field well for a pivot table. Values are grouped by rows fields.
         */
        rows?: pulumi.Input<pulumi.Input<inputs.quicksight.TemplateDimensionFieldArgs>[]>;
        /**
         * The values field well for a pivot table. Values are aggregated based on rows and columns fields.
         */
        values?: pulumi.Input<pulumi.Input<inputs.quicksight.TemplateMeasureFieldArgs>[]>;
    }
    interface TemplatePivotTableCellConditionalFormattingArgs {
        /**
         * The field ID of the cell for conditional formatting.
         */
        fieldId: pulumi.Input<string>;
        /**
         * The scope of the cell for conditional formatting.
         */
        scope?: pulumi.Input<inputs.quicksight.TemplatePivotTableConditionalFormattingScopeArgs>;
        /**
         * A list of cell scopes for conditional formatting.
         */
        scopes?: pulumi.Input<pulumi.Input<inputs.quicksight.TemplatePivotTableConditionalFormattingScopeArgs>[]>;
        /**
         * The text format of the cell for conditional formatting.
         */
        textFormat?: pulumi.Input<inputs.quicksight.TemplateTextConditionalFormatArgs>;
    }
    interface TemplatePivotTableConditionalFormattingArgs {
        /**
         * Conditional formatting options for a `PivotTableVisual` .
         */
        conditionalFormattingOptions?: pulumi.Input<pulumi.Input<inputs.quicksight.TemplatePivotTableConditionalFormattingOptionArgs>[]>;
    }
    interface TemplatePivotTableConditionalFormattingOptionArgs {
        /**
         * The cell conditional formatting option for a pivot table.
         */
        cell?: pulumi.Input<inputs.quicksight.TemplatePivotTableCellConditionalFormattingArgs>;
    }
    interface TemplatePivotTableConditionalFormattingScopeArgs {
        /**
         * The role (field, field total, grand total) of the cell for conditional formatting.
         */
        role?: pulumi.Input<enums.quicksight.TemplatePivotTableConditionalFormattingScopeRole>;
    }
    interface TemplatePivotTableConfigurationArgs {
        /**
         * The field options for a pivot table visual.
         */
        fieldOptions?: pulumi.Input<inputs.quicksight.TemplatePivotTableFieldOptionsArgs>;
        /**
         * The field wells of the visual.
         */
        fieldWells?: pulumi.Input<inputs.quicksight.TemplatePivotTableFieldWellsArgs>;
        /**
         * The general visual interactions setup for a visual.
         */
        interactions?: pulumi.Input<inputs.quicksight.TemplateVisualInteractionOptionsArgs>;
        /**
         * The paginated report options for a pivot table visual.
         */
        paginatedReportOptions?: pulumi.Input<inputs.quicksight.TemplatePivotTablePaginatedReportOptionsArgs>;
        /**
         * The sort configuration for a `PivotTableVisual` .
         */
        sortConfiguration?: pulumi.Input<inputs.quicksight.TemplatePivotTableSortConfigurationArgs>;
        /**
         * The table options for a pivot table visual.
         */
        tableOptions?: pulumi.Input<inputs.quicksight.TemplatePivotTableOptionsArgs>;
        /**
         * The total options for a pivot table visual.
         */
        totalOptions?: pulumi.Input<inputs.quicksight.TemplatePivotTableTotalOptionsArgs>;
    }
    interface TemplatePivotTableDataPathOptionArgs {
        /**
         * The list of data path values for the data path options.
         */
        dataPathList: pulumi.Input<pulumi.Input<inputs.quicksight.TemplateDataPathValueArgs>[]>;
        /**
         * String based length that is composed of value and unit in px
         */
        width?: pulumi.Input<string>;
    }
    interface TemplatePivotTableFieldCollapseStateOptionArgs {
        /**
         * The state of the field target of a pivot table. Choose one of the following options:
         *
         * - `COLLAPSED`
         * - `EXPANDED`
         */
        state?: pulumi.Input<enums.quicksight.TemplatePivotTableFieldCollapseState>;
        /**
         * A tagged-union object that sets the collapse state.
         */
        target: pulumi.Input<inputs.quicksight.TemplatePivotTableFieldCollapseStateTargetArgs>;
    }
    interface TemplatePivotTableFieldCollapseStateTargetArgs {
        /**
         * The data path of the pivot table's header. Used to set the collapse state.
         */
        fieldDataPathValues?: pulumi.Input<pulumi.Input<inputs.quicksight.TemplateDataPathValueArgs>[]>;
        /**
         * The field ID of the pivot table that the collapse state needs to be set to.
         */
        fieldId?: pulumi.Input<string>;
    }
    interface TemplatePivotTableFieldOptionArgs {
        /**
         * The custom label of the pivot table field.
         */
        customLabel?: pulumi.Input<string>;
        /**
         * The field ID of the pivot table field.
         */
        fieldId: pulumi.Input<string>;
        /**
         * The visibility of the pivot table field.
         */
        visibility?: any;
    }
    interface TemplatePivotTableFieldOptionsArgs {
        /**
         * The collapse state options for the pivot table field options.
         */
        collapseStateOptions?: pulumi.Input<pulumi.Input<inputs.quicksight.TemplatePivotTableFieldCollapseStateOptionArgs>[]>;
        /**
         * The data path options for the pivot table field options.
         */
        dataPathOptions?: pulumi.Input<pulumi.Input<inputs.quicksight.TemplatePivotTableDataPathOptionArgs>[]>;
        /**
         * The selected field options for the pivot table field options.
         */
        selectedFieldOptions?: pulumi.Input<pulumi.Input<inputs.quicksight.TemplatePivotTableFieldOptionArgs>[]>;
    }
    interface TemplatePivotTableFieldSubtotalOptionsArgs {
        /**
         * The field ID of the subtotal options.
         */
        fieldId?: pulumi.Input<string>;
    }
    interface TemplatePivotTableFieldWellsArgs {
        /**
         * The aggregated field well for the pivot table.
         */
        pivotTableAggregatedFieldWells?: pulumi.Input<inputs.quicksight.TemplatePivotTableAggregatedFieldWellsArgs>;
    }
    interface TemplatePivotTableOptionsArgs {
        /**
         * The table cell style of cells.
         */
        cellStyle?: pulumi.Input<inputs.quicksight.TemplateTableCellStyleArgs>;
        /**
         * The visibility setting of a pivot table's collapsed row dimension fields. If the value of this structure is `HIDDEN` , all collapsed columns in a pivot table are automatically hidden. The default value is `VISIBLE` .
         */
        collapsedRowDimensionsVisibility?: any;
        /**
         * The table cell style of the column header.
         */
        columnHeaderStyle?: pulumi.Input<inputs.quicksight.TemplateTableCellStyleArgs>;
        /**
         * The visibility of the column names.
         */
        columnNamesVisibility?: any;
        /**
         * String based length that is composed of value and unit in px
         */
        defaultCellWidth?: pulumi.Input<string>;
        /**
         * The metric placement (row, column) options.
         */
        metricPlacement?: pulumi.Input<enums.quicksight.TemplatePivotTableMetricPlacement>;
        /**
         * The row alternate color options (widget status, row alternate colors).
         */
        rowAlternateColorOptions?: pulumi.Input<inputs.quicksight.TemplateRowAlternateColorOptionsArgs>;
        /**
         * The table cell style of row field names.
         */
        rowFieldNamesStyle?: pulumi.Input<inputs.quicksight.TemplateTableCellStyleArgs>;
        /**
         * The table cell style of the row headers.
         */
        rowHeaderStyle?: pulumi.Input<inputs.quicksight.TemplateTableCellStyleArgs>;
        /**
         * The options for the label that is located above the row headers. This option is only applicable when `RowsLayout` is set to `HIERARCHY` .
         */
        rowsLabelOptions?: pulumi.Input<inputs.quicksight.TemplatePivotTableRowsLabelOptionsArgs>;
        /**
         * The layout for the row dimension headers of a pivot table. Choose one of the following options.
         *
         * - `TABULAR` : (Default) Each row field is displayed in a separate column.
         * - `HIERARCHY` : All row fields are displayed in a single column. Indentation is used to differentiate row headers of different fields.
         */
        rowsLayout?: pulumi.Input<enums.quicksight.TemplatePivotTableRowsLayout>;
        /**
         * The visibility of the single metric options.
         */
        singleMetricVisibility?: any;
        /**
         * Determines the visibility of the pivot table.
         */
        toggleButtonsVisibility?: any;
    }
    interface TemplatePivotTablePaginatedReportOptionsArgs {
        /**
         * The visibility of the repeating header rows on each page.
         */
        overflowColumnHeaderVisibility?: any;
        /**
         * The visibility of the printing table overflow across pages.
         */
        verticalOverflowVisibility?: any;
    }
    interface TemplatePivotTableRowsLabelOptionsArgs {
        /**
         * The custom label string for the rows label.
         */
        customLabel?: pulumi.Input<string>;
        /**
         * The visibility of the rows label.
         */
        visibility?: any;
    }
    interface TemplatePivotTableSortByArgs {
        /**
         * The column sort (field id, direction) for the pivot table sort by options.
         */
        column?: pulumi.Input<inputs.quicksight.TemplateColumnSortArgs>;
        /**
         * The data path sort (data path value, direction) for the pivot table sort by options.
         */
        dataPath?: pulumi.Input<inputs.quicksight.TemplateDataPathSortArgs>;
        /**
         * The field sort (field id, direction) for the pivot table sort by options.
         */
        field?: pulumi.Input<inputs.quicksight.TemplateFieldSortArgs>;
    }
    interface TemplatePivotTableSortConfigurationArgs {
        /**
         * The field sort options for a pivot table sort configuration.
         */
        fieldSortOptions?: pulumi.Input<pulumi.Input<inputs.quicksight.TemplatePivotFieldSortOptionsArgs>[]>;
    }
    interface TemplatePivotTableTotalOptionsArgs {
        /**
         * The column subtotal options.
         */
        columnSubtotalOptions?: pulumi.Input<inputs.quicksight.TemplateSubtotalOptionsArgs>;
        /**
         * The column total options.
         */
        columnTotalOptions?: pulumi.Input<inputs.quicksight.TemplatePivotTotalOptionsArgs>;
        /**
         * The row subtotal options.
         */
        rowSubtotalOptions?: pulumi.Input<inputs.quicksight.TemplateSubtotalOptionsArgs>;
        /**
         * The row total options.
         */
        rowTotalOptions?: pulumi.Input<inputs.quicksight.TemplatePivotTotalOptionsArgs>;
    }
    interface TemplatePivotTableVisualArgs {
        /**
         * The list of custom actions that are configured for a visual.
         */
        actions?: pulumi.Input<pulumi.Input<inputs.quicksight.TemplateVisualCustomActionArgs>[]>;
        /**
         * The configuration settings of the visual.
         */
        chartConfiguration?: pulumi.Input<inputs.quicksight.TemplatePivotTableConfigurationArgs>;
        /**
         * The conditional formatting for a `PivotTableVisual` .
         */
        conditionalFormatting?: pulumi.Input<inputs.quicksight.TemplatePivotTableConditionalFormattingArgs>;
        /**
         * The subtitle that is displayed on the visual.
         */
        subtitle?: pulumi.Input<inputs.quicksight.TemplateVisualSubtitleLabelOptionsArgs>;
        /**
         * The title that is displayed on the visual.
         */
        title?: pulumi.Input<inputs.quicksight.TemplateVisualTitleLabelOptionsArgs>;
        /**
         * The alt text for the visual.
         */
        visualContentAltText?: pulumi.Input<string>;
        /**
         * The unique identifier of a visual. This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers..
         */
        visualId: pulumi.Input<string>;
    }
    interface TemplatePivotTotalOptionsArgs {
        /**
         * The custom label string for the total cells.
         */
        customLabel?: pulumi.Input<string>;
        /**
         * The cell styling options for the total of header cells.
         */
        metricHeaderCellStyle?: pulumi.Input<inputs.quicksight.TemplateTableCellStyleArgs>;
        /**
         * The placement (start, end) for the total cells.
         */
        placement?: pulumi.Input<enums.quicksight.TemplateTableTotalsPlacement>;
        /**
         * The scroll status (pinned, scrolled) for the total cells.
         */
        scrollStatus?: pulumi.Input<enums.quicksight.TemplateTableTotalsScrollStatus>;
        /**
         * The total aggregation options for each value field.
         */
        totalAggregationOptions?: pulumi.Input<pulumi.Input<inputs.quicksight.TemplateTotalAggregationOptionArgs>[]>;
        /**
         * The cell styling options for the total cells.
         */
        totalCellStyle?: pulumi.Input<inputs.quicksight.TemplateTableCellStyleArgs>;
        /**
         * The visibility configuration for the total cells.
         */
        totalsVisibility?: any;
        /**
         * The cell styling options for the totals of value cells.
         */
        valueCellStyle?: pulumi.Input<inputs.quicksight.TemplateTableCellStyleArgs>;
    }
    interface TemplatePluginVisualArgs {
        /**
         * A description of the plugin field wells and their persisted properties.
         */
        chartConfiguration?: pulumi.Input<inputs.quicksight.TemplatePluginVisualConfigurationArgs>;
        /**
         * The Amazon Resource Name (ARN) that reflects the plugin and version.
         */
        pluginArn: pulumi.Input<string>;
        subtitle?: pulumi.Input<inputs.quicksight.TemplateVisualSubtitleLabelOptionsArgs>;
        title?: pulumi.Input<inputs.quicksight.TemplateVisualTitleLabelOptionsArgs>;
        /**
         * The alt text for the visual.
         */
        visualContentAltText?: pulumi.Input<string>;
        /**
         * The ID of the visual that you want to use.
         */
        visualId: pulumi.Input<string>;
    }
    interface TemplatePluginVisualConfigurationArgs {
        /**
         * The field wells configuration of the plugin visual.
         */
        fieldWells?: pulumi.Input<pulumi.Input<inputs.quicksight.TemplatePluginVisualFieldWellArgs>[]>;
        /**
         * The sort configuration of the plugin visual.
         */
        sortConfiguration?: pulumi.Input<inputs.quicksight.TemplatePluginVisualSortConfigurationArgs>;
        /**
         * The persisted properties of the plugin visual.
         */
        visualOptions?: pulumi.Input<inputs.quicksight.TemplatePluginVisualOptionsArgs>;
    }
    interface TemplatePluginVisualFieldWellArgs {
        /**
         * The semantic axis name for the field well.
         */
        axisName?: pulumi.Input<enums.quicksight.TemplatePluginVisualAxisName>;
        /**
         * A list of dimensions for the field well.
         */
        dimensions?: pulumi.Input<pulumi.Input<inputs.quicksight.TemplateDimensionFieldArgs>[]>;
        /**
         * A list of measures that exist in the field well.
         */
        measures?: pulumi.Input<pulumi.Input<inputs.quicksight.TemplateMeasureFieldArgs>[]>;
        /**
         * A list of unaggregated fields that exist in the field well.
         */
        unaggregated?: pulumi.Input<pulumi.Input<inputs.quicksight.TemplateUnaggregatedFieldArgs>[]>;
    }
    interface TemplatePluginVisualItemsLimitConfigurationArgs {
        /**
         * Determines how many values are be fetched at once.
         */
        itemsLimit?: pulumi.Input<number>;
    }
    interface TemplatePluginVisualOptionsArgs {
        /**
         * The persisted properties and their values.
         */
        visualProperties?: pulumi.Input<pulumi.Input<inputs.quicksight.TemplatePluginVisualPropertyArgs>[]>;
    }
    interface TemplatePluginVisualPropertyArgs {
        /**
         * The name of the plugin visual property.
         */
        name?: pulumi.Input<string>;
        /**
         * The value of the plugin visual property.
         */
        value?: pulumi.Input<string>;
    }
    interface TemplatePluginVisualSortConfigurationArgs {
        /**
         * The table query sorting options for the plugin visual.
         */
        pluginVisualTableQuerySort?: pulumi.Input<inputs.quicksight.TemplatePluginVisualTableQuerySortArgs>;
    }
    interface TemplatePluginVisualTableQuerySortArgs {
        /**
         * The maximum amount of data to be returned by a query.
         */
        itemsLimitConfiguration?: pulumi.Input<inputs.quicksight.TemplatePluginVisualItemsLimitConfigurationArgs>;
        /**
         * Determines how data is sorted in the response.
         */
        rowSort?: pulumi.Input<pulumi.Input<inputs.quicksight.TemplateFieldSortOptionsArgs>[]>;
    }
    interface TemplatePredefinedHierarchyArgs {
        /**
         * The list of columns that define the predefined hierarchy.
         */
        columns: pulumi.Input<pulumi.Input<inputs.quicksight.TemplateColumnIdentifierArgs>[]>;
        /**
         * The option that determines the drill down filters for the predefined hierarchy.
         */
        drillDownFilters?: pulumi.Input<pulumi.Input<inputs.quicksight.TemplateDrillDownFilterArgs>[]>;
        /**
         * The hierarchy ID of the predefined hierarchy.
         */
        hierarchyId: pulumi.Input<string>;
    }
    interface TemplateProgressBarOptionsArgs {
        /**
         * The visibility of the progress bar.
         */
        visibility?: any;
    }
    interface TemplateQueryExecutionOptionsArgs {
        /**
         * A structure that describes the query execution mode.
         */
        queryExecutionMode?: pulumi.Input<enums.quicksight.TemplateQueryExecutionMode>;
    }
    interface TemplateRadarChartAggregatedFieldWellsArgs {
        /**
         * The aggregated field well categories of a radar chart.
         */
        category?: pulumi.Input<pulumi.Input<inputs.quicksight.TemplateDimensionFieldArgs>[]>;
        /**
         * The color that are assigned to the aggregated field wells of a radar chart.
         */
        color?: pulumi.Input<pulumi.Input<inputs.quicksight.TemplateDimensionFieldArgs>[]>;
        /**
         * The values that are assigned to the aggregated field wells of a radar chart.
         */
        values?: pulumi.Input<pulumi.Input<inputs.quicksight.TemplateMeasureFieldArgs>[]>;
    }
    interface TemplateRadarChartAreaStyleSettingsArgs {
        /**
         * The visibility settings of a radar chart.
         */
        visibility?: any;
    }
    interface TemplateRadarChartConfigurationArgs {
        /**
         * Determines the visibility of the colors of alternatign bands in a radar chart.
         */
        alternateBandColorsVisibility?: any;
        /**
         * The color of the even-numbered alternate bands of a radar chart.
         */
        alternateBandEvenColor?: pulumi.Input<string>;
        /**
         * The color of the odd-numbered alternate bands of a radar chart.
         */
        alternateBandOddColor?: pulumi.Input<string>;
        /**
         * The axis behavior options of a radar chart.
         */
        axesRangeScale?: pulumi.Input<enums.quicksight.TemplateRadarChartAxesRangeScale>;
        /**
         * The base sreies settings of a radar chart.
         */
        baseSeriesSettings?: pulumi.Input<inputs.quicksight.TemplateRadarChartSeriesSettingsArgs>;
        /**
         * The category axis of a radar chart.
         */
        categoryAxis?: pulumi.Input<inputs.quicksight.TemplateAxisDisplayOptionsArgs>;
        /**
         * The category label options of a radar chart.
         */
        categoryLabelOptions?: pulumi.Input<inputs.quicksight.TemplateChartAxisLabelOptionsArgs>;
        /**
         * The color axis of a radar chart.
         */
        colorAxis?: pulumi.Input<inputs.quicksight.TemplateAxisDisplayOptionsArgs>;
        /**
         * The color label options of a radar chart.
         */
        colorLabelOptions?: pulumi.Input<inputs.quicksight.TemplateChartAxisLabelOptionsArgs>;
        /**
         * The field well configuration of a `RadarChartVisual` .
         */
        fieldWells?: pulumi.Input<inputs.quicksight.TemplateRadarChartFieldWellsArgs>;
        /**
         * The general visual interactions setup for a visual.
         */
        interactions?: pulumi.Input<inputs.quicksight.TemplateVisualInteractionOptionsArgs>;
        /**
         * The legend display setup of the visual.
         */
        legend?: pulumi.Input<inputs.quicksight.TemplateLegendOptionsArgs>;
        /**
         * The shape of the radar chart.
         */
        shape?: pulumi.Input<enums.quicksight.TemplateRadarChartShape>;
        /**
         * The sort configuration of a `RadarChartVisual` .
         */
        sortConfiguration?: pulumi.Input<inputs.quicksight.TemplateRadarChartSortConfigurationArgs>;
        /**
         * The start angle of a radar chart's axis.
         */
        startAngle?: pulumi.Input<number>;
        /**
         * The palette (chart color) display setup of the visual.
         */
        visualPalette?: pulumi.Input<inputs.quicksight.TemplateVisualPaletteArgs>;
    }
    interface TemplateRadarChartFieldWellsArgs {
        /**
         * The aggregated field wells of a radar chart visual.
         */
        radarChartAggregatedFieldWells?: pulumi.Input<inputs.quicksight.TemplateRadarChartAggregatedFieldWellsArgs>;
    }
    interface TemplateRadarChartSeriesSettingsArgs {
        /**
         * The area style settings of a radar chart.
         */
        areaStyleSettings?: pulumi.Input<inputs.quicksight.TemplateRadarChartAreaStyleSettingsArgs>;
    }
    interface TemplateRadarChartSortConfigurationArgs {
        /**
         * The category items limit for a radar chart.
         */
        categoryItemsLimit?: pulumi.Input<inputs.quicksight.TemplateItemsLimitConfigurationArgs>;
        /**
         * The category sort options of a radar chart.
         */
        categorySort?: pulumi.Input<pulumi.Input<inputs.quicksight.TemplateFieldSortOptionsArgs>[]>;
        /**
         * The color items limit of a radar chart.
         */
        colorItemsLimit?: pulumi.Input<inputs.quicksight.TemplateItemsLimitConfigurationArgs>;
        /**
         * The color sort configuration of a radar chart.
         */
        colorSort?: pulumi.Input<pulumi.Input<inputs.quicksight.TemplateFieldSortOptionsArgs>[]>;
    }
    interface TemplateRadarChartVisualArgs {
        /**
         * The list of custom actions that are configured for a visual.
         */
        actions?: pulumi.Input<pulumi.Input<inputs.quicksight.TemplateVisualCustomActionArgs>[]>;
        /**
         * The configuration settings of the visual.
         */
        chartConfiguration?: pulumi.Input<inputs.quicksight.TemplateRadarChartConfigurationArgs>;
        /**
         * The column hierarchy that is used during drill-downs and drill-ups.
         */
        columnHierarchies?: pulumi.Input<pulumi.Input<inputs.quicksight.TemplateColumnHierarchyArgs>[]>;
        /**
         * The subtitle that is displayed on the visual.
         */
        subtitle?: pulumi.Input<inputs.quicksight.TemplateVisualSubtitleLabelOptionsArgs>;
        /**
         * The title that is displayed on the visual.
         */
        title?: pulumi.Input<inputs.quicksight.TemplateVisualTitleLabelOptionsArgs>;
        /**
         * The alt text for the visual.
         */
        visualContentAltText?: pulumi.Input<string>;
        /**
         * The unique identifier of a visual. This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers.
         */
        visualId: pulumi.Input<string>;
    }
    interface TemplateRangeEndsLabelTypeArgs {
        /**
         * The visibility of the range ends label.
         */
        visibility?: any;
    }
    interface TemplateReferenceLineArgs {
        /**
         * The data configuration of the reference line.
         */
        dataConfiguration: pulumi.Input<inputs.quicksight.TemplateReferenceLineDataConfigurationArgs>;
        /**
         * The label configuration of the reference line.
         */
        labelConfiguration?: pulumi.Input<inputs.quicksight.TemplateReferenceLineLabelConfigurationArgs>;
        /**
         * The status of the reference line. Choose one of the following options:
         *
         * - `ENABLE`
         * - `DISABLE`
         */
        status?: pulumi.Input<enums.quicksight.TemplateWidgetStatus>;
        /**
         * The style configuration of the reference line.
         */
        styleConfiguration?: pulumi.Input<inputs.quicksight.TemplateReferenceLineStyleConfigurationArgs>;
    }
    interface TemplateReferenceLineCustomLabelConfigurationArgs {
        /**
         * The string text of the custom label.
         */
        customLabel: pulumi.Input<string>;
    }
    interface TemplateReferenceLineDataConfigurationArgs {
        /**
         * The axis binding type of the reference line. Choose one of the following options:
         *
         * - `PrimaryY`
         * - `SecondaryY`
         */
        axisBinding?: pulumi.Input<enums.quicksight.TemplateAxisBinding>;
        /**
         * The dynamic configuration of the reference line data configuration.
         */
        dynamicConfiguration?: pulumi.Input<inputs.quicksight.TemplateReferenceLineDynamicDataConfigurationArgs>;
        /**
         * The series type of the reference line data configuration. Choose one of the following options:
         *
         * - `BAR`
         * - `LINE`
         */
        seriesType?: pulumi.Input<enums.quicksight.TemplateReferenceLineSeriesType>;
        /**
         * The static data configuration of the reference line data configuration.
         */
        staticConfiguration?: pulumi.Input<inputs.quicksight.TemplateReferenceLineStaticDataConfigurationArgs>;
    }
    interface TemplateReferenceLineDynamicDataConfigurationArgs {
        /**
         * The calculation that is used in the dynamic data.
         */
        calculation: pulumi.Input<inputs.quicksight.TemplateNumericalAggregationFunctionArgs>;
        /**
         * The column that the dynamic data targets.
         */
        column: pulumi.Input<inputs.quicksight.TemplateColumnIdentifierArgs>;
        /**
         * The aggregation function that is used in the dynamic data.
         */
        measureAggregationFunction?: pulumi.Input<inputs.quicksight.TemplateAggregationFunctionArgs>;
    }
    interface TemplateReferenceLineLabelConfigurationArgs {
        /**
         * The custom label configuration of the label in a reference line.
         */
        customLabelConfiguration?: pulumi.Input<inputs.quicksight.TemplateReferenceLineCustomLabelConfigurationArgs>;
        /**
         * The font color configuration of the label in a reference line.
         */
        fontColor?: pulumi.Input<string>;
        /**
         * The font configuration of the label in a reference line.
         */
        fontConfiguration?: pulumi.Input<inputs.quicksight.TemplateFontConfigurationArgs>;
        /**
         * The horizontal position configuration of the label in a reference line. Choose one of the following options:
         *
         * - `LEFT`
         * - `CENTER`
         * - `RIGHT`
         */
        horizontalPosition?: pulumi.Input<enums.quicksight.TemplateReferenceLineLabelHorizontalPosition>;
        /**
         * The value label configuration of the label in a reference line.
         */
        valueLabelConfiguration?: pulumi.Input<inputs.quicksight.TemplateReferenceLineValueLabelConfigurationArgs>;
        /**
         * The vertical position configuration of the label in a reference line. Choose one of the following options:
         *
         * - `ABOVE`
         * - `BELOW`
         */
        verticalPosition?: pulumi.Input<enums.quicksight.TemplateReferenceLineLabelVerticalPosition>;
    }
    interface TemplateReferenceLineStaticDataConfigurationArgs {
        /**
         * The double input of the static data.
         */
        value: pulumi.Input<number>;
    }
    interface TemplateReferenceLineStyleConfigurationArgs {
        /**
         * The hex color of the reference line.
         */
        color?: pulumi.Input<string>;
        /**
         * The pattern type of the line style. Choose one of the following options:
         *
         * - `SOLID`
         * - `DASHED`
         * - `DOTTED`
         */
        pattern?: pulumi.Input<enums.quicksight.TemplateReferenceLinePatternType>;
    }
    interface TemplateReferenceLineValueLabelConfigurationArgs {
        /**
         * The format configuration of the value label.
         */
        formatConfiguration?: pulumi.Input<inputs.quicksight.TemplateNumericFormatConfigurationArgs>;
        /**
         * The relative position of the value label. Choose one of the following options:
         *
         * - `BEFORE_CUSTOM_LABEL`
         * - `AFTER_CUSTOM_LABEL`
         */
        relativePosition?: pulumi.Input<enums.quicksight.TemplateReferenceLineValueLabelRelativePosition>;
    }
    interface TemplateRelativeDateTimeControlDisplayOptionsArgs {
        /**
         * Customize how dates are formatted in controls.
         */
        dateTimeFormat?: pulumi.Input<string>;
        /**
         * The configuration of info icon label options.
         */
        infoIconLabelOptions?: pulumi.Input<inputs.quicksight.TemplateSheetControlInfoIconLabelOptionsArgs>;
        /**
         * The options to configure the title visibility, name, and font size.
         */
        titleOptions?: pulumi.Input<inputs.quicksight.TemplateLabelOptionsArgs>;
    }
    interface TemplateRelativeDatesFilterArgs {
        /**
         * The date configuration of the filter.
         */
        anchorDateConfiguration: pulumi.Input<inputs.quicksight.TemplateAnchorDateConfigurationArgs>;
        /**
         * The column that the filter is applied to.
         */
        column: pulumi.Input<inputs.quicksight.TemplateColumnIdentifierArgs>;
        /**
         * The default configurations for the associated controls. This applies only for filters that are scoped to multiple sheets.
         */
        defaultFilterControlConfiguration?: pulumi.Input<inputs.quicksight.TemplateDefaultFilterControlConfigurationArgs>;
        /**
         * The configuration for the exclude period of the filter.
         */
        excludePeriodConfiguration?: pulumi.Input<inputs.quicksight.TemplateExcludePeriodConfigurationArgs>;
        /**
         * An identifier that uniquely identifies a filter within a dashboard, analysis, or template.
         */
        filterId: pulumi.Input<string>;
        /**
         * The minimum granularity (period granularity) of the relative dates filter.
         */
        minimumGranularity?: pulumi.Input<enums.quicksight.TemplateTimeGranularity>;
        /**
         * This option determines how null values should be treated when filtering data.
         *
         * - `ALL_VALUES` : Include null values in filtered results.
         * - `NULLS_ONLY` : Only include null values in filtered results.
         * - `NON_NULLS_ONLY` : Exclude null values from filtered results.
         */
        nullOption: pulumi.Input<enums.quicksight.TemplateFilterNullOption>;
        /**
         * The parameter whose value should be used for the filter value.
         */
        parameterName?: pulumi.Input<string>;
        /**
         * The range date type of the filter. Choose one of the options below:
         *
         * - `PREVIOUS`
         * - `THIS`
         * - `LAST`
         * - `NOW`
         * - `NEXT`
         */
        relativeDateType: pulumi.Input<enums.quicksight.TemplateRelativeDateType>;
        /**
         * The date value of the filter.
         */
        relativeDateValue?: pulumi.Input<number>;
        /**
         * The level of time precision that is used to aggregate `DateTime` values.
         */
        timeGranularity: pulumi.Input<enums.quicksight.TemplateTimeGranularity>;
    }
    /**
     * <p>Permission for the resource.</p>
     */
    interface TemplateResourcePermissionArgs {
        /**
         * <p>The IAM action to grant or revoke permissions on.</p>
         */
        actions: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * <p>The Amazon Resource Name (ARN) of the principal. This can be one of the
         *             following:</p>
         *          <ul>
         *             <li>
         *                <p>The ARN of an Amazon QuickSight user or group associated with a data source or dataset. (This is common.)</p>
         *             </li>
         *             <li>
         *                <p>The ARN of an Amazon QuickSight user, group, or namespace associated with an analysis, dashboard, template, or theme. (This is common.)</p>
         *             </li>
         *             <li>
         *                <p>The ARN of an Amazon Web Services account root: This is an IAM ARN rather than a QuickSight
         *                     ARN. Use this option only to share resources (templates) across Amazon Web Services accounts.
         *                     (This is less common.) </p>
         *             </li>
         *          </ul>
         */
        principal: pulumi.Input<string>;
    }
    interface TemplateRollingDateConfigurationArgs {
        /**
         * The data set that is used in the rolling date configuration.
         */
        dataSetIdentifier?: pulumi.Input<string>;
        /**
         * The expression of the rolling date configuration.
         */
        expression: pulumi.Input<string>;
    }
    interface TemplateRowAlternateColorOptionsArgs {
        /**
         * Determines the list of row alternate colors.
         */
        rowAlternateColors?: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * Determines the widget status.
         */
        status?: pulumi.Input<enums.quicksight.TemplateWidgetStatus>;
        /**
         * The primary background color options for alternate rows.
         */
        usePrimaryBackgroundColor?: pulumi.Input<enums.quicksight.TemplateWidgetStatus>;
    }
    interface TemplateSameSheetTargetVisualConfigurationArgs {
        /**
         * The options that choose the target visual in the same sheet.
         *
         * Valid values are defined as follows:
         *
         * - `ALL_VISUALS` : Applies the filter operation to all visuals in the same sheet.
         */
        targetVisualOptions?: pulumi.Input<enums.quicksight.TemplateTargetVisualOptions>;
        /**
         * A list of the target visual IDs that are located in the same sheet of the analysis.
         */
        targetVisuals?: pulumi.Input<pulumi.Input<string>[]>;
    }
    interface TemplateSankeyDiagramAggregatedFieldWellsArgs {
        /**
         * The destination field wells of a sankey diagram.
         */
        destination?: pulumi.Input<pulumi.Input<inputs.quicksight.TemplateDimensionFieldArgs>[]>;
        /**
         * The source field wells of a sankey diagram.
         */
        source?: pulumi.Input<pulumi.Input<inputs.quicksight.TemplateDimensionFieldArgs>[]>;
        /**
         * The weight field wells of a sankey diagram.
         */
        weight?: pulumi.Input<pulumi.Input<inputs.quicksight.TemplateMeasureFieldArgs>[]>;
    }
    interface TemplateSankeyDiagramChartConfigurationArgs {
        /**
         * The data label configuration of a sankey diagram.
         */
        dataLabels?: pulumi.Input<inputs.quicksight.TemplateDataLabelOptionsArgs>;
        /**
         * The field well configuration of a sankey diagram.
         */
        fieldWells?: pulumi.Input<inputs.quicksight.TemplateSankeyDiagramFieldWellsArgs>;
        /**
         * The general visual interactions setup for a visual.
         */
        interactions?: pulumi.Input<inputs.quicksight.TemplateVisualInteractionOptionsArgs>;
        /**
         * The sort configuration of a sankey diagram.
         */
        sortConfiguration?: pulumi.Input<inputs.quicksight.TemplateSankeyDiagramSortConfigurationArgs>;
    }
    interface TemplateSankeyDiagramFieldWellsArgs {
        /**
         * The field well configuration of a sankey diagram.
         */
        sankeyDiagramAggregatedFieldWells?: pulumi.Input<inputs.quicksight.TemplateSankeyDiagramAggregatedFieldWellsArgs>;
    }
    interface TemplateSankeyDiagramSortConfigurationArgs {
        /**
         * The limit on the number of destination nodes that are displayed in a sankey diagram.
         */
        destinationItemsLimit?: pulumi.Input<inputs.quicksight.TemplateItemsLimitConfigurationArgs>;
        /**
         * The limit on the number of source nodes that are displayed in a sankey diagram.
         */
        sourceItemsLimit?: pulumi.Input<inputs.quicksight.TemplateItemsLimitConfigurationArgs>;
        /**
         * The sort configuration of the weight fields.
         */
        weightSort?: pulumi.Input<pulumi.Input<inputs.quicksight.TemplateFieldSortOptionsArgs>[]>;
    }
    interface TemplateSankeyDiagramVisualArgs {
        /**
         * The list of custom actions that are configured for a visual.
         */
        actions?: pulumi.Input<pulumi.Input<inputs.quicksight.TemplateVisualCustomActionArgs>[]>;
        /**
         * The configuration of a sankey diagram.
         */
        chartConfiguration?: pulumi.Input<inputs.quicksight.TemplateSankeyDiagramChartConfigurationArgs>;
        /**
         * The subtitle that is displayed on the visual.
         */
        subtitle?: pulumi.Input<inputs.quicksight.TemplateVisualSubtitleLabelOptionsArgs>;
        /**
         * The title that is displayed on the visual.
         */
        title?: pulumi.Input<inputs.quicksight.TemplateVisualTitleLabelOptionsArgs>;
        /**
         * The alt text for the visual.
         */
        visualContentAltText?: pulumi.Input<string>;
        /**
         * The unique identifier of a visual. This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers.
         */
        visualId: pulumi.Input<string>;
    }
    interface TemplateScatterPlotCategoricallyAggregatedFieldWellsArgs {
        /**
         * The category field well of a scatter plot.
         */
        category?: pulumi.Input<pulumi.Input<inputs.quicksight.TemplateDimensionFieldArgs>[]>;
        /**
         * The label field well of a scatter plot.
         */
        label?: pulumi.Input<pulumi.Input<inputs.quicksight.TemplateDimensionFieldArgs>[]>;
        /**
         * The size field well of a scatter plot.
         */
        size?: pulumi.Input<pulumi.Input<inputs.quicksight.TemplateMeasureFieldArgs>[]>;
        /**
         * The x-axis field well of a scatter plot.
         *
         * The x-axis is aggregated by category.
         */
        xAxis?: pulumi.Input<pulumi.Input<inputs.quicksight.TemplateMeasureFieldArgs>[]>;
        /**
         * The y-axis field well of a scatter plot.
         *
         * The y-axis is aggregated by category.
         */
        yAxis?: pulumi.Input<pulumi.Input<inputs.quicksight.TemplateMeasureFieldArgs>[]>;
    }
    interface TemplateScatterPlotConfigurationArgs {
        /**
         * The options that determine if visual data labels are displayed.
         */
        dataLabels?: pulumi.Input<inputs.quicksight.TemplateDataLabelOptionsArgs>;
        /**
         * The field wells of the visual.
         */
        fieldWells?: pulumi.Input<inputs.quicksight.TemplateScatterPlotFieldWellsArgs>;
        /**
         * The general visual interactions setup for a visual.
         */
        interactions?: pulumi.Input<inputs.quicksight.TemplateVisualInteractionOptionsArgs>;
        /**
         * The legend display setup of the visual.
         */
        legend?: pulumi.Input<inputs.quicksight.TemplateLegendOptionsArgs>;
        /**
         * The sort configuration of a scatter plot.
         */
        sortConfiguration?: pulumi.Input<inputs.quicksight.TemplateScatterPlotSortConfigurationArgs>;
        /**
         * The legend display setup of the visual.
         */
        tooltip?: pulumi.Input<inputs.quicksight.TemplateTooltipOptionsArgs>;
        /**
         * The palette (chart color) display setup of the visual.
         */
        visualPalette?: pulumi.Input<inputs.quicksight.TemplateVisualPaletteArgs>;
        /**
         * The label display options (grid line, range, scale, and axis step) of the scatter plot's x-axis.
         */
        xAxisDisplayOptions?: pulumi.Input<inputs.quicksight.TemplateAxisDisplayOptionsArgs>;
        /**
         * The label options (label text, label visibility, and sort icon visibility) of the scatter plot's x-axis.
         */
        xAxisLabelOptions?: pulumi.Input<inputs.quicksight.TemplateChartAxisLabelOptionsArgs>;
        /**
         * The label display options (grid line, range, scale, and axis step) of the scatter plot's y-axis.
         */
        yAxisDisplayOptions?: pulumi.Input<inputs.quicksight.TemplateAxisDisplayOptionsArgs>;
        /**
         * The label options (label text, label visibility, and sort icon visibility) of the scatter plot's y-axis.
         */
        yAxisLabelOptions?: pulumi.Input<inputs.quicksight.TemplateChartAxisLabelOptionsArgs>;
    }
    interface TemplateScatterPlotFieldWellsArgs {
        /**
         * The aggregated field wells of a scatter plot. The x and y-axes of scatter plots with aggregated field wells are aggregated by category, label, or both.
         */
        scatterPlotCategoricallyAggregatedFieldWells?: pulumi.Input<inputs.quicksight.TemplateScatterPlotCategoricallyAggregatedFieldWellsArgs>;
        /**
         * The unaggregated field wells of a scatter plot. The x and y-axes of these scatter plots are unaggregated.
         */
        scatterPlotUnaggregatedFieldWells?: pulumi.Input<inputs.quicksight.TemplateScatterPlotUnaggregatedFieldWellsArgs>;
    }
    interface TemplateScatterPlotSortConfigurationArgs {
        scatterPlotLimitConfiguration?: pulumi.Input<inputs.quicksight.TemplateItemsLimitConfigurationArgs>;
    }
    interface TemplateScatterPlotUnaggregatedFieldWellsArgs {
        /**
         * The category field well of a scatter plot.
         */
        category?: pulumi.Input<pulumi.Input<inputs.quicksight.TemplateDimensionFieldArgs>[]>;
        /**
         * The label field well of a scatter plot.
         */
        label?: pulumi.Input<pulumi.Input<inputs.quicksight.TemplateDimensionFieldArgs>[]>;
        /**
         * The size field well of a scatter plot.
         */
        size?: pulumi.Input<pulumi.Input<inputs.quicksight.TemplateMeasureFieldArgs>[]>;
        /**
         * The x-axis field well of a scatter plot.
         *
         * The x-axis is a dimension field and cannot be aggregated.
         */
        xAxis?: pulumi.Input<pulumi.Input<inputs.quicksight.TemplateDimensionFieldArgs>[]>;
        /**
         * The y-axis field well of a scatter plot.
         *
         * The y-axis is a dimension field and cannot be aggregated.
         */
        yAxis?: pulumi.Input<pulumi.Input<inputs.quicksight.TemplateDimensionFieldArgs>[]>;
    }
    interface TemplateScatterPlotVisualArgs {
        /**
         * The list of custom actions that are configured for a visual.
         */
        actions?: pulumi.Input<pulumi.Input<inputs.quicksight.TemplateVisualCustomActionArgs>[]>;
        /**
         * The configuration settings of the visual.
         */
        chartConfiguration?: pulumi.Input<inputs.quicksight.TemplateScatterPlotConfigurationArgs>;
        /**
         * The column hierarchy that is used during drill-downs and drill-ups.
         */
        columnHierarchies?: pulumi.Input<pulumi.Input<inputs.quicksight.TemplateColumnHierarchyArgs>[]>;
        /**
         * The subtitle that is displayed on the visual.
         */
        subtitle?: pulumi.Input<inputs.quicksight.TemplateVisualSubtitleLabelOptionsArgs>;
        /**
         * The title that is displayed on the visual.
         */
        title?: pulumi.Input<inputs.quicksight.TemplateVisualTitleLabelOptionsArgs>;
        /**
         * The alt text for the visual.
         */
        visualContentAltText?: pulumi.Input<string>;
        /**
         * The unique identifier of a visual. This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers.
         */
        visualId: pulumi.Input<string>;
    }
    interface TemplateScrollBarOptionsArgs {
        /**
         * The visibility of the data zoom scroll bar.
         */
        visibility?: any;
        /**
         * The visibility range for the data zoom scroll bar.
         */
        visibleRange?: pulumi.Input<inputs.quicksight.TemplateVisibleRangeOptionsArgs>;
    }
    interface TemplateSecondaryValueOptionsArgs {
        /**
         * Determines the visibility of the secondary value.
         */
        visibility?: any;
    }
    interface TemplateSectionAfterPageBreakArgs {
        /**
         * The option that enables or disables a page break at the end of a section.
         */
        status?: pulumi.Input<enums.quicksight.TemplateSectionPageBreakStatus>;
    }
    interface TemplateSectionBasedLayoutCanvasSizeOptionsArgs {
        /**
         * The options for a paper canvas of a section-based layout.
         */
        paperCanvasSizeOptions?: pulumi.Input<inputs.quicksight.TemplateSectionBasedLayoutPaperCanvasSizeOptionsArgs>;
    }
    interface TemplateSectionBasedLayoutConfigurationArgs {
        /**
         * A list of body section configurations.
         */
        bodySections: pulumi.Input<pulumi.Input<inputs.quicksight.TemplateBodySectionConfigurationArgs>[]>;
        /**
         * The options for the canvas of a section-based layout.
         */
        canvasSizeOptions: pulumi.Input<inputs.quicksight.TemplateSectionBasedLayoutCanvasSizeOptionsArgs>;
        /**
         * A list of footer section configurations.
         */
        footerSections: pulumi.Input<pulumi.Input<inputs.quicksight.TemplateHeaderFooterSectionConfigurationArgs>[]>;
        /**
         * A list of header section configurations.
         */
        headerSections: pulumi.Input<pulumi.Input<inputs.quicksight.TemplateHeaderFooterSectionConfigurationArgs>[]>;
    }
    interface TemplateSectionBasedLayoutPaperCanvasSizeOptionsArgs {
        /**
         * Defines the spacing between the canvas content and the top, bottom, left, and right edges.
         */
        paperMargin?: pulumi.Input<inputs.quicksight.TemplateSpacingArgs>;
        /**
         * The paper orientation that is used to define canvas dimensions. Choose one of the following options:
         *
         * - PORTRAIT
         * - LANDSCAPE
         */
        paperOrientation?: pulumi.Input<enums.quicksight.TemplatePaperOrientation>;
        /**
         * The paper size that is used to define canvas dimensions.
         */
        paperSize?: pulumi.Input<enums.quicksight.TemplatePaperSize>;
    }
    interface TemplateSectionLayoutConfigurationArgs {
        /**
         * The free-form layout configuration of a section.
         */
        freeFormLayout: pulumi.Input<inputs.quicksight.TemplateFreeFormSectionLayoutConfigurationArgs>;
    }
    interface TemplateSectionPageBreakConfigurationArgs {
        /**
         * The configuration of a page break after a section.
         */
        after?: pulumi.Input<inputs.quicksight.TemplateSectionAfterPageBreakArgs>;
    }
    interface TemplateSectionStyleArgs {
        /**
         * String based length that is composed of value and unit in px
         */
        height?: pulumi.Input<string>;
        /**
         * The spacing between section content and its top, bottom, left, and right edges.
         *
         * There is no padding by default.
         */
        padding?: pulumi.Input<inputs.quicksight.TemplateSpacingArgs>;
    }
    interface TemplateSelectedSheetsFilterScopeConfigurationArgs {
        /**
         * The sheet ID and visual IDs of the sheet and visuals that the filter is applied to.
         */
        sheetVisualScopingConfigurations?: pulumi.Input<pulumi.Input<inputs.quicksight.TemplateSheetVisualScopingConfigurationArgs>[]>;
    }
    interface TemplateSeriesItemArgs {
        /**
         * The data field series item configuration of a line chart.
         */
        dataFieldSeriesItem?: pulumi.Input<inputs.quicksight.TemplateDataFieldSeriesItemArgs>;
        /**
         * The field series item configuration of a line chart.
         */
        fieldSeriesItem?: pulumi.Input<inputs.quicksight.TemplateFieldSeriesItemArgs>;
    }
    interface TemplateSetParameterValueConfigurationArgs {
        /**
         * The destination parameter name of the `SetParameterValueConfiguration` .
         */
        destinationParameterName: pulumi.Input<string>;
        value: pulumi.Input<inputs.quicksight.TemplateDestinationParameterValueConfigurationArgs>;
    }
    interface TemplateShapeConditionalFormatArgs {
        /**
         * The conditional formatting for the shape background color of a filled map visual.
         */
        backgroundColor: pulumi.Input<inputs.quicksight.TemplateConditionalFormattingColorArgs>;
    }
    interface TemplateSheetControlInfoIconLabelOptionsArgs {
        /**
         * The text content of info icon.
         */
        infoIconText?: pulumi.Input<string>;
        /**
         * The visibility configuration of info icon label options.
         */
        visibility?: any;
    }
    interface TemplateSheetControlLayoutArgs {
        /**
         * The configuration that determines the elements and canvas size options of sheet control.
         */
        configuration: pulumi.Input<inputs.quicksight.TemplateSheetControlLayoutConfigurationArgs>;
    }
    interface TemplateSheetControlLayoutConfigurationArgs {
        /**
         * The configuration that determines the elements and canvas size options of sheet control.
         */
        gridLayout?: pulumi.Input<inputs.quicksight.TemplateGridLayoutConfigurationArgs>;
    }
    interface TemplateSheetDefinitionArgs {
        /**
         * The layout content type of the sheet. Choose one of the following options:
         *
         * - `PAGINATED` : Creates a sheet for a paginated report.
         * - `INTERACTIVE` : Creates a sheet for an interactive dashboard.
         */
        contentType?: pulumi.Input<enums.quicksight.TemplateSheetContentType>;
        /**
         * A description of the sheet.
         */
        description?: pulumi.Input<string>;
        /**
         * The list of filter controls that are on a sheet.
         *
         * For more information, see [Adding filter controls to analysis sheets](https://docs.aws.amazon.com/quicksight/latest/user/filter-controls.html) in the *Amazon QuickSight User Guide* .
         */
        filterControls?: pulumi.Input<pulumi.Input<inputs.quicksight.TemplateFilterControlArgs>[]>;
        /**
         * A list of images on a sheet.
         */
        images?: pulumi.Input<pulumi.Input<inputs.quicksight.TemplateSheetImageArgs>[]>;
        /**
         * Layouts define how the components of a sheet are arranged.
         *
         * For more information, see [Types of layout](https://docs.aws.amazon.com/quicksight/latest/user/types-of-layout.html) in the *Amazon QuickSight User Guide* .
         */
        layouts?: pulumi.Input<pulumi.Input<inputs.quicksight.TemplateLayoutArgs>[]>;
        /**
         * The name of the sheet. This name is displayed on the sheet's tab in the Amazon QuickSight console.
         */
        name?: pulumi.Input<string>;
        /**
         * The list of parameter controls that are on a sheet.
         *
         * For more information, see [Using a Control with a Parameter in Amazon QuickSight](https://docs.aws.amazon.com/quicksight/latest/user/parameters-controls.html) in the *Amazon QuickSight User Guide* .
         */
        parameterControls?: pulumi.Input<pulumi.Input<inputs.quicksight.TemplateParameterControlArgs>[]>;
        /**
         * The control layouts of the sheet.
         */
        sheetControlLayouts?: pulumi.Input<pulumi.Input<inputs.quicksight.TemplateSheetControlLayoutArgs>[]>;
        /**
         * The unique identifier of a sheet.
         */
        sheetId: pulumi.Input<string>;
        /**
         * The text boxes that are on a sheet.
         */
        textBoxes?: pulumi.Input<pulumi.Input<inputs.quicksight.TemplateSheetTextBoxArgs>[]>;
        /**
         * The title of the sheet.
         */
        title?: pulumi.Input<string>;
        /**
         * A list of the visuals that are on a sheet. Visual placement is determined by the layout of the sheet.
         */
        visuals?: pulumi.Input<pulumi.Input<inputs.quicksight.TemplateVisualArgs>[]>;
    }
    interface TemplateSheetElementConfigurationOverridesArgs {
        /**
         * Determines whether or not the overrides are visible. Choose one of the following options:
         *
         * - `VISIBLE`
         * - `HIDDEN`
         */
        visibility?: any;
    }
    interface TemplateSheetElementRenderingRuleArgs {
        /**
         * The override configuration of the rendering rules of a sheet.
         */
        configurationOverrides: pulumi.Input<inputs.quicksight.TemplateSheetElementConfigurationOverridesArgs>;
        /**
         * The expression of the rendering rules of a sheet.
         */
        expression: pulumi.Input<string>;
    }
    interface TemplateSheetImageArgs {
        /**
         * A list of custom actions that are configured for an image.
         */
        actions?: pulumi.Input<pulumi.Input<inputs.quicksight.TemplateImageCustomActionArgs>[]>;
        /**
         * The alt text for the image.
         */
        imageContentAltText?: pulumi.Input<string>;
        /**
         * The general image interactions setup for an image.
         */
        interactions?: pulumi.Input<inputs.quicksight.TemplateImageInteractionOptionsArgs>;
        /**
         * Determines how the image is scaled.
         */
        scaling?: pulumi.Input<inputs.quicksight.TemplateSheetImageScalingConfigurationArgs>;
        /**
         * The ID of the sheet image.
         */
        sheetImageId: pulumi.Input<string>;
        /**
         * The source of the image.
         */
        source: pulumi.Input<inputs.quicksight.TemplateSheetImageSourceArgs>;
        /**
         * The tooltip to be shown when hovering over the image.
         */
        tooltip?: pulumi.Input<inputs.quicksight.TemplateSheetImageTooltipConfigurationArgs>;
    }
    interface TemplateSheetImageScalingConfigurationArgs {
        /**
         * The scaling option to use when fitting the image inside the container.
         *
         * Valid values are defined as follows:
         *
         * - `SCALE_TO_WIDTH` : The image takes up the entire width of the container. The image aspect ratio is preserved.
         * - `SCALE_TO_HEIGHT` : The image takes up the entire height of the container. The image aspect ratio is preserved.
         * - `SCALE_TO_CONTAINER` : The image takes up the entire width and height of the container. The image aspect ratio is not preserved.
         * - `SCALE_NONE` : The image is displayed in its original size and is not scaled to the container.
         */
        scalingType?: pulumi.Input<enums.quicksight.TemplateSheetImageScalingType>;
    }
    interface TemplateSheetImageSourceArgs {
        /**
         * The source of the static file that contains the image.
         */
        sheetImageStaticFileSource?: pulumi.Input<inputs.quicksight.TemplateSheetImageStaticFileSourceArgs>;
    }
    interface TemplateSheetImageStaticFileSourceArgs {
        /**
         * The ID of the static file that contains the image.
         */
        staticFileId: pulumi.Input<string>;
    }
    interface TemplateSheetImageTooltipConfigurationArgs {
        /**
         * The text that appears in the tooltip.
         */
        tooltipText?: pulumi.Input<inputs.quicksight.TemplateSheetImageTooltipTextArgs>;
        /**
         * The visibility of the tooltip.
         */
        visibility?: any;
    }
    interface TemplateSheetImageTooltipTextArgs {
        /**
         * The plain text format.
         */
        plainText?: pulumi.Input<string>;
    }
    interface TemplateSheetTextBoxArgs {
        /**
         * The content that is displayed in the text box.
         */
        content?: pulumi.Input<string>;
        /**
         * The unique identifier for a text box. This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have text boxes that share identifiers.
         */
        sheetTextBoxId: pulumi.Input<string>;
    }
    interface TemplateSheetVisualScopingConfigurationArgs {
        /**
         * The scope of the applied entities. Choose one of the following options:
         *
         * - `ALL_VISUALS`
         * - `SELECTED_VISUALS`
         */
        scope: pulumi.Input<enums.quicksight.TemplateFilterVisualScope>;
        /**
         * The selected sheet that the filter is applied to.
         */
        sheetId: pulumi.Input<string>;
        /**
         * The selected visuals that the filter is applied to.
         */
        visualIds?: pulumi.Input<pulumi.Input<string>[]>;
    }
    interface TemplateShortFormatTextArgs {
        /**
         * Plain text format.
         */
        plainText?: pulumi.Input<string>;
        /**
         * Rich text. Examples of rich text include bold, underline, and italics.
         */
        richText?: pulumi.Input<string>;
    }
    interface TemplateSimpleClusterMarkerArgs {
        /**
         * The color of the simple cluster marker.
         */
        color?: pulumi.Input<string>;
    }
    interface TemplateSingleAxisOptionsArgs {
        /**
         * The Y axis options of a single axis configuration.
         */
        yAxisOptions?: pulumi.Input<inputs.quicksight.TemplateYAxisOptionsArgs>;
    }
    interface TemplateSliderControlDisplayOptionsArgs {
        /**
         * The configuration of info icon label options.
         */
        infoIconLabelOptions?: pulumi.Input<inputs.quicksight.TemplateSheetControlInfoIconLabelOptionsArgs>;
        /**
         * The options to configure the title visibility, name, and font size.
         */
        titleOptions?: pulumi.Input<inputs.quicksight.TemplateLabelOptionsArgs>;
    }
    interface TemplateSmallMultiplesAxisPropertiesArgs {
        /**
         * Defines the placement of the axis. By default, axes are rendered `OUTSIDE` of the panels. Axes with `INDEPENDENT` scale are rendered `INSIDE` the panels.
         */
        placement?: pulumi.Input<enums.quicksight.TemplateSmallMultiplesAxisPlacement>;
        /**
         * Determines whether scale of the axes are shared or independent. The default value is `SHARED` .
         */
        scale?: pulumi.Input<enums.quicksight.TemplateSmallMultiplesAxisScale>;
    }
    interface TemplateSmallMultiplesOptionsArgs {
        /**
         * Sets the maximum number of visible columns to display in the grid of small multiples panels.
         *
         * The default is `Auto` , which automatically adjusts the columns in the grid to fit the overall layout and size of the given chart.
         */
        maxVisibleColumns?: pulumi.Input<number>;
        /**
         * Sets the maximum number of visible rows to display in the grid of small multiples panels.
         *
         * The default value is `Auto` , which automatically adjusts the rows in the grid to fit the overall layout and size of the given chart.
         */
        maxVisibleRows?: pulumi.Input<number>;
        /**
         * Configures the display options for each small multiples panel.
         */
        panelConfiguration?: pulumi.Input<inputs.quicksight.TemplatePanelConfigurationArgs>;
        /**
         * The properties of a small multiples X axis.
         */
        xAxis?: pulumi.Input<inputs.quicksight.TemplateSmallMultiplesAxisPropertiesArgs>;
        /**
         * The properties of a small multiples Y axis.
         */
        yAxis?: pulumi.Input<inputs.quicksight.TemplateSmallMultiplesAxisPropertiesArgs>;
    }
    /**
     * <p>The source analysis of the template.</p>
     */
    interface TemplateSourceAnalysisArgs {
        /**
         * <p>The Amazon Resource Name (ARN) of the resource.</p>
         */
        arn: pulumi.Input<string>;
        /**
         * <p>A structure containing information about the dataset references used as placeholders
         *             in the template.</p>
         */
        dataSetReferences: pulumi.Input<pulumi.Input<inputs.quicksight.TemplateDataSetReferenceArgs>[]>;
    }
    /**
     * <p>The source entity of the template.</p>
     */
    interface TemplateSourceEntityArgs {
        /**
         * The source analysis, if it is based on an analysis.
         */
        sourceAnalysis?: pulumi.Input<inputs.quicksight.TemplateSourceAnalysisArgs>;
        /**
         * The source template, if it is based on an template.
         */
        sourceTemplate?: pulumi.Input<inputs.quicksight.TemplateSourceTemplateArgs>;
    }
    /**
     * <p>The source template of the template.</p>
     */
    interface TemplateSourceTemplateArgs {
        /**
         * <p>The Amazon Resource Name (ARN) of the resource.</p>
         */
        arn: pulumi.Input<string>;
    }
    interface TemplateSpacingArgs {
        /**
         * String based length that is composed of value and unit
         */
        bottom?: pulumi.Input<string>;
        /**
         * String based length that is composed of value and unit
         */
        left?: pulumi.Input<string>;
        /**
         * String based length that is composed of value and unit
         */
        right?: pulumi.Input<string>;
        /**
         * String based length that is composed of value and unit
         */
        top?: pulumi.Input<string>;
    }
    interface TemplateStringDefaultValuesArgs {
        /**
         * The dynamic value of the `StringDefaultValues` . Different defaults displayed according to users, groups, and values mapping.
         */
        dynamicValue?: pulumi.Input<inputs.quicksight.TemplateDynamicDefaultValueArgs>;
        /**
         * The static values of the `DecimalDefaultValues` .
         */
        staticValues?: pulumi.Input<pulumi.Input<string>[]>;
    }
    interface TemplateStringFormatConfigurationArgs {
        /**
         * The options that determine the null value format configuration.
         */
        nullValueFormatConfiguration?: pulumi.Input<inputs.quicksight.TemplateNullValueFormatConfigurationArgs>;
        /**
         * The formatting configuration for numeric strings.
         */
        numericFormatConfiguration?: pulumi.Input<inputs.quicksight.TemplateNumericFormatConfigurationArgs>;
    }
    interface TemplateStringParameterDeclarationArgs {
        /**
         * The default values of a parameter. If the parameter is a single-value parameter, a maximum of one default value can be provided.
         */
        defaultValues?: pulumi.Input<inputs.quicksight.TemplateStringDefaultValuesArgs>;
        mappedDataSetParameters?: pulumi.Input<pulumi.Input<inputs.quicksight.TemplateMappedDataSetParameterArgs>[]>;
        /**
         * The name of the parameter that is being declared.
         */
        name: pulumi.Input<string>;
        /**
         * The value type determines whether the parameter is a single-value or multi-value parameter.
         */
        parameterValueType: pulumi.Input<enums.quicksight.TemplateParameterValueType>;
        /**
         * The configuration that defines the default value of a `String` parameter when a value has not been set.
         */
        valueWhenUnset?: pulumi.Input<inputs.quicksight.TemplateStringValueWhenUnsetConfigurationArgs>;
    }
    interface TemplateStringValueWhenUnsetConfigurationArgs {
        /**
         * A custom value that's used when the value of a parameter isn't set.
         */
        customValue?: pulumi.Input<string>;
        /**
         * The built-in options for default values. The value can be one of the following:
         *
         * - `RECOMMENDED` : The recommended value.
         * - `NULL` : The `NULL` value.
         */
        valueWhenUnsetOption?: pulumi.Input<enums.quicksight.TemplateValueWhenUnsetOption>;
    }
    interface TemplateSubtotalOptionsArgs {
        /**
         * The custom label string for the subtotal cells.
         */
        customLabel?: pulumi.Input<string>;
        /**
         * The field level (all, custom, last) for the subtotal cells.
         */
        fieldLevel?: pulumi.Input<enums.quicksight.TemplatePivotTableSubtotalLevel>;
        /**
         * The optional configuration of subtotal cells.
         */
        fieldLevelOptions?: pulumi.Input<pulumi.Input<inputs.quicksight.TemplatePivotTableFieldSubtotalOptionsArgs>[]>;
        /**
         * The cell styling options for the subtotals of header cells.
         */
        metricHeaderCellStyle?: pulumi.Input<inputs.quicksight.TemplateTableCellStyleArgs>;
        /**
         * The style targets options for subtotals.
         */
        styleTargets?: pulumi.Input<pulumi.Input<inputs.quicksight.TemplateTableStyleTargetArgs>[]>;
        /**
         * The cell styling options for the subtotal cells.
         */
        totalCellStyle?: pulumi.Input<inputs.quicksight.TemplateTableCellStyleArgs>;
        /**
         * The visibility configuration for the subtotal cells.
         */
        totalsVisibility?: any;
        /**
         * The cell styling options for the subtotals of value cells.
         */
        valueCellStyle?: pulumi.Input<inputs.quicksight.TemplateTableCellStyleArgs>;
    }
    interface TemplateTableAggregatedFieldWellsArgs {
        /**
         * The group by field well for a pivot table. Values are grouped by group by fields.
         */
        groupBy?: pulumi.Input<pulumi.Input<inputs.quicksight.TemplateDimensionFieldArgs>[]>;
        /**
         * The values field well for a pivot table. Values are aggregated based on group by fields.
         */
        values?: pulumi.Input<pulumi.Input<inputs.quicksight.TemplateMeasureFieldArgs>[]>;
    }
    interface TemplateTableBorderOptionsArgs {
        /**
         * The color of a table border.
         */
        color?: pulumi.Input<string>;
        /**
         * The style (none, solid) of a table border.
         */
        style?: pulumi.Input<enums.quicksight.TemplateTableBorderStyle>;
        /**
         * The thickness of a table border.
         */
        thickness?: pulumi.Input<number>;
    }
    interface TemplateTableCellConditionalFormattingArgs {
        /**
         * The field ID of the cell for conditional formatting.
         */
        fieldId: pulumi.Input<string>;
        /**
         * The text format of the cell for conditional formatting.
         */
        textFormat?: pulumi.Input<inputs.quicksight.TemplateTextConditionalFormatArgs>;
    }
    interface TemplateTableCellImageSizingConfigurationArgs {
        /**
         * The cell scaling configuration of the sizing options for the table image configuration.
         */
        tableCellImageScalingConfiguration?: pulumi.Input<enums.quicksight.TemplateTableCellImageScalingConfiguration>;
    }
    interface TemplateTableCellStyleArgs {
        /**
         * The background color for the table cells.
         */
        backgroundColor?: pulumi.Input<string>;
        /**
         * The borders for the table cells.
         */
        border?: pulumi.Input<inputs.quicksight.TemplateGlobalTableBorderOptionsArgs>;
        /**
         * The font configuration of the table cells.
         */
        fontConfiguration?: pulumi.Input<inputs.quicksight.TemplateFontConfigurationArgs>;
        /**
         * The height color for the table cells.
         */
        height?: pulumi.Input<number>;
        /**
         * The horizontal text alignment (left, center, right, auto) for the table cells.
         */
        horizontalTextAlignment?: pulumi.Input<enums.quicksight.TemplateHorizontalTextAlignment>;
        /**
         * The text wrap (none, wrap) for the table cells.
         */
        textWrap?: pulumi.Input<enums.quicksight.TemplateTextWrap>;
        /**
         * The vertical text alignment (top, middle, bottom) for the table cells.
         */
        verticalTextAlignment?: pulumi.Input<enums.quicksight.TemplateVerticalTextAlignment>;
        /**
         * The visibility of the table cells.
         */
        visibility?: any;
    }
    interface TemplateTableConditionalFormattingArgs {
        /**
         * Conditional formatting options for a `PivotTableVisual` .
         */
        conditionalFormattingOptions?: pulumi.Input<pulumi.Input<inputs.quicksight.TemplateTableConditionalFormattingOptionArgs>[]>;
    }
    interface TemplateTableConditionalFormattingOptionArgs {
        /**
         * The cell conditional formatting option for a table.
         */
        cell?: pulumi.Input<inputs.quicksight.TemplateTableCellConditionalFormattingArgs>;
        /**
         * The row conditional formatting option for a table.
         */
        row?: pulumi.Input<inputs.quicksight.TemplateTableRowConditionalFormattingArgs>;
    }
    interface TemplateTableConfigurationArgs {
        /**
         * The field options for a table visual.
         */
        fieldOptions?: pulumi.Input<inputs.quicksight.TemplateTableFieldOptionsArgs>;
        /**
         * The field wells of the visual.
         */
        fieldWells?: pulumi.Input<inputs.quicksight.TemplateTableFieldWellsArgs>;
        /**
         * The general visual interactions setup for a visual.
         */
        interactions?: pulumi.Input<inputs.quicksight.TemplateVisualInteractionOptionsArgs>;
        /**
         * The paginated report options for a table visual.
         */
        paginatedReportOptions?: pulumi.Input<inputs.quicksight.TemplateTablePaginatedReportOptionsArgs>;
        /**
         * The sort configuration for a `TableVisual` .
         */
        sortConfiguration?: pulumi.Input<inputs.quicksight.TemplateTableSortConfigurationArgs>;
        /**
         * A collection of inline visualizations to display within a chart.
         */
        tableInlineVisualizations?: pulumi.Input<pulumi.Input<inputs.quicksight.TemplateTableInlineVisualizationArgs>[]>;
        /**
         * The table options for a table visual.
         */
        tableOptions?: pulumi.Input<inputs.quicksight.TemplateTableOptionsArgs>;
        /**
         * The total options for a table visual.
         */
        totalOptions?: pulumi.Input<inputs.quicksight.TemplateTotalOptionsArgs>;
    }
    interface TemplateTableFieldCustomIconContentArgs {
        /**
         * The icon set type (link) of the custom icon content for table URL link content.
         */
        icon?: pulumi.Input<enums.quicksight.TemplateTableFieldIconSetType>;
    }
    interface TemplateTableFieldCustomTextContentArgs {
        /**
         * The font configuration of the custom text content for the table URL link content.
         */
        fontConfiguration: pulumi.Input<inputs.quicksight.TemplateFontConfigurationArgs>;
        /**
         * The string value of the custom text content for the table URL link content.
         */
        value?: pulumi.Input<string>;
    }
    interface TemplateTableFieldImageConfigurationArgs {
        /**
         * The sizing options for the table image configuration.
         */
        sizingOptions?: pulumi.Input<inputs.quicksight.TemplateTableCellImageSizingConfigurationArgs>;
    }
    interface TemplateTableFieldLinkConfigurationArgs {
        /**
         * The URL content (text, icon) for the table link configuration.
         */
        content: pulumi.Input<inputs.quicksight.TemplateTableFieldLinkContentConfigurationArgs>;
        /**
         * The URL target (new tab, new window, same tab) for the table link configuration.
         */
        target: pulumi.Input<enums.quicksight.TemplateUrlTargetConfiguration>;
    }
    interface TemplateTableFieldLinkContentConfigurationArgs {
        /**
         * The custom icon content for the table link content configuration.
         */
        customIconContent?: pulumi.Input<inputs.quicksight.TemplateTableFieldCustomIconContentArgs>;
        /**
         * The custom text content (value, font configuration) for the table link content configuration.
         */
        customTextContent?: pulumi.Input<inputs.quicksight.TemplateTableFieldCustomTextContentArgs>;
    }
    interface TemplateTableFieldOptionArgs {
        /**
         * The custom label for a table field.
         */
        customLabel?: pulumi.Input<string>;
        /**
         * The field ID for a table field.
         */
        fieldId: pulumi.Input<string>;
        /**
         * The URL configuration for a table field.
         */
        urlStyling?: pulumi.Input<inputs.quicksight.TemplateTableFieldUrlConfigurationArgs>;
        /**
         * The visibility of a table field.
         */
        visibility?: any;
        /**
         * String based length that is composed of value and unit in px
         */
        width?: pulumi.Input<string>;
    }
    interface TemplateTableFieldOptionsArgs {
        /**
         * The order of the field IDs that are configured as field options for a table visual.
         */
        order?: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * The settings for the pinned columns of a table visual.
         */
        pinnedFieldOptions?: pulumi.Input<inputs.quicksight.TemplateTablePinnedFieldOptionsArgs>;
        /**
         * The field options to be configured to a table.
         */
        selectedFieldOptions?: pulumi.Input<pulumi.Input<inputs.quicksight.TemplateTableFieldOptionArgs>[]>;
        /**
         * The `TableOptions` of a transposed table.
         */
        transposedTableOptions?: pulumi.Input<pulumi.Input<inputs.quicksight.TemplateTransposedTableOptionArgs>[]>;
    }
    interface TemplateTableFieldUrlConfigurationArgs {
        /**
         * The image configuration of a table field URL.
         */
        imageConfiguration?: pulumi.Input<inputs.quicksight.TemplateTableFieldImageConfigurationArgs>;
        /**
         * The link configuration of a table field URL.
         */
        linkConfiguration?: pulumi.Input<inputs.quicksight.TemplateTableFieldLinkConfigurationArgs>;
    }
    interface TemplateTableFieldWellsArgs {
        /**
         * The aggregated field well for the table.
         */
        tableAggregatedFieldWells?: pulumi.Input<inputs.quicksight.TemplateTableAggregatedFieldWellsArgs>;
        /**
         * The unaggregated field well for the table.
         */
        tableUnaggregatedFieldWells?: pulumi.Input<inputs.quicksight.TemplateTableUnaggregatedFieldWellsArgs>;
    }
    interface TemplateTableInlineVisualizationArgs {
        /**
         * The configuration of the inline visualization of the data bars within a chart.
         */
        dataBars?: pulumi.Input<inputs.quicksight.TemplateDataBarsOptionsArgs>;
    }
    interface TemplateTableOptionsArgs {
        /**
         * The table cell style of table cells.
         */
        cellStyle?: pulumi.Input<inputs.quicksight.TemplateTableCellStyleArgs>;
        /**
         * The table cell style of a table header.
         */
        headerStyle?: pulumi.Input<inputs.quicksight.TemplateTableCellStyleArgs>;
        /**
         * The orientation (vertical, horizontal) for a table.
         */
        orientation?: pulumi.Input<enums.quicksight.TemplateTableOrientation>;
        /**
         * The row alternate color options (widget status, row alternate colors) for a table.
         */
        rowAlternateColorOptions?: pulumi.Input<inputs.quicksight.TemplateRowAlternateColorOptionsArgs>;
    }
    interface TemplateTablePaginatedReportOptionsArgs {
        /**
         * The visibility of repeating header rows on each page.
         */
        overflowColumnHeaderVisibility?: any;
        /**
         * The visibility of printing table overflow across pages.
         */
        verticalOverflowVisibility?: any;
    }
    interface TemplateTablePinnedFieldOptionsArgs {
        /**
         * A list of columns to be pinned to the left of a table visual.
         */
        pinnedLeftFields?: pulumi.Input<pulumi.Input<string>[]>;
    }
    interface TemplateTableRowConditionalFormattingArgs {
        /**
         * The conditional formatting color (solid, gradient) of the background for a table row.
         */
        backgroundColor?: pulumi.Input<inputs.quicksight.TemplateConditionalFormattingColorArgs>;
        /**
         * The conditional formatting color (solid, gradient) of the text for a table row.
         */
        textColor?: pulumi.Input<inputs.quicksight.TemplateConditionalFormattingColorArgs>;
    }
    interface TemplateTableSideBorderOptionsArgs {
        /**
         * The table border options of the bottom border.
         */
        bottom?: pulumi.Input<inputs.quicksight.TemplateTableBorderOptionsArgs>;
        /**
         * The table border options of the inner horizontal border.
         */
        innerHorizontal?: pulumi.Input<inputs.quicksight.TemplateTableBorderOptionsArgs>;
        /**
         * The table border options of the inner vertical border.
         */
        innerVertical?: pulumi.Input<inputs.quicksight.TemplateTableBorderOptionsArgs>;
        /**
         * The table border options of the left border.
         */
        left?: pulumi.Input<inputs.quicksight.TemplateTableBorderOptionsArgs>;
        /**
         * The table border options of the right border.
         */
        right?: pulumi.Input<inputs.quicksight.TemplateTableBorderOptionsArgs>;
        /**
         * The table border options of the top border.
         */
        top?: pulumi.Input<inputs.quicksight.TemplateTableBorderOptionsArgs>;
    }
    interface TemplateTableSortConfigurationArgs {
        /**
         * The pagination configuration (page size, page number) for the table.
         */
        paginationConfiguration?: pulumi.Input<inputs.quicksight.TemplatePaginationConfigurationArgs>;
        /**
         * The field sort options for rows in the table.
         */
        rowSort?: pulumi.Input<pulumi.Input<inputs.quicksight.TemplateFieldSortOptionsArgs>[]>;
    }
    interface TemplateTableStyleTargetArgs {
        /**
         * The cell type of the table style target.
         */
        cellType: pulumi.Input<enums.quicksight.TemplateStyledCellType>;
    }
    interface TemplateTableUnaggregatedFieldWellsArgs {
        /**
         * The values field well for a pivot table. Values are unaggregated for an unaggregated table.
         */
        values?: pulumi.Input<pulumi.Input<inputs.quicksight.TemplateUnaggregatedFieldArgs>[]>;
    }
    interface TemplateTableVisualArgs {
        /**
         * The list of custom actions that are configured for a visual.
         */
        actions?: pulumi.Input<pulumi.Input<inputs.quicksight.TemplateVisualCustomActionArgs>[]>;
        /**
         * The configuration settings of the visual.
         */
        chartConfiguration?: pulumi.Input<inputs.quicksight.TemplateTableConfigurationArgs>;
        /**
         * The conditional formatting for a `PivotTableVisual` .
         */
        conditionalFormatting?: pulumi.Input<inputs.quicksight.TemplateTableConditionalFormattingArgs>;
        /**
         * The subtitle that is displayed on the visual.
         */
        subtitle?: pulumi.Input<inputs.quicksight.TemplateVisualSubtitleLabelOptionsArgs>;
        /**
         * The title that is displayed on the visual.
         */
        title?: pulumi.Input<inputs.quicksight.TemplateVisualTitleLabelOptionsArgs>;
        /**
         * The alt text for the visual.
         */
        visualContentAltText?: pulumi.Input<string>;
        /**
         * The unique identifier of a visual. This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers..
         */
        visualId: pulumi.Input<string>;
    }
    interface TemplateTextAreaControlDisplayOptionsArgs {
        /**
         * The configuration of info icon label options.
         */
        infoIconLabelOptions?: pulumi.Input<inputs.quicksight.TemplateSheetControlInfoIconLabelOptionsArgs>;
        /**
         * The configuration of the placeholder options in a text area control.
         */
        placeholderOptions?: pulumi.Input<inputs.quicksight.TemplateTextControlPlaceholderOptionsArgs>;
        /**
         * The options to configure the title visibility, name, and font size.
         */
        titleOptions?: pulumi.Input<inputs.quicksight.TemplateLabelOptionsArgs>;
    }
    interface TemplateTextConditionalFormatArgs {
        /**
         * The conditional formatting for the text background color.
         */
        backgroundColor?: pulumi.Input<inputs.quicksight.TemplateConditionalFormattingColorArgs>;
        /**
         * The conditional formatting for the icon.
         */
        icon?: pulumi.Input<inputs.quicksight.TemplateConditionalFormattingIconArgs>;
        /**
         * The conditional formatting for the text color.
         */
        textColor?: pulumi.Input<inputs.quicksight.TemplateConditionalFormattingColorArgs>;
    }
    interface TemplateTextControlPlaceholderOptionsArgs {
        /**
         * The visibility configuration of the placeholder options in a text control.
         */
        visibility?: any;
    }
    interface TemplateTextFieldControlDisplayOptionsArgs {
        /**
         * The configuration of info icon label options.
         */
        infoIconLabelOptions?: pulumi.Input<inputs.quicksight.TemplateSheetControlInfoIconLabelOptionsArgs>;
        /**
         * The configuration of the placeholder options in a text field control.
         */
        placeholderOptions?: pulumi.Input<inputs.quicksight.TemplateTextControlPlaceholderOptionsArgs>;
        /**
         * The options to configure the title visibility, name, and font size.
         */
        titleOptions?: pulumi.Input<inputs.quicksight.TemplateLabelOptionsArgs>;
    }
    interface TemplateThousandSeparatorOptionsArgs {
        /**
         * Determines the way numbers are styled to accommodate different readability standards. The `DEFAULT` value uses the standard international grouping system and groups numbers by the thousands. The `LAKHS` value uses the Indian numbering system and groups numbers by lakhs and crores.
         */
        groupingStyle?: pulumi.Input<enums.quicksight.TemplateDigitGroupingStyle>;
        /**
         * Determines the thousands separator symbol.
         */
        symbol?: pulumi.Input<enums.quicksight.TemplateNumericSeparatorSymbol>;
        /**
         * Determines the visibility of the thousands separator.
         */
        visibility?: any;
    }
    interface TemplateTimeBasedForecastPropertiesArgs {
        /**
         * The lower boundary setup of a forecast computation.
         */
        lowerBoundary?: pulumi.Input<number>;
        /**
         * The periods backward setup of a forecast computation.
         */
        periodsBackward?: pulumi.Input<number>;
        /**
         * The periods forward setup of a forecast computation.
         */
        periodsForward?: pulumi.Input<number>;
        /**
         * The prediction interval setup of a forecast computation.
         */
        predictionInterval?: pulumi.Input<number>;
        /**
         * The seasonality setup of a forecast computation. Choose one of the following options:
         *
         * - `NULL` : The input is set to `NULL` .
         * - `NON_NULL` : The input is set to a custom value.
         */
        seasonality?: pulumi.Input<number>;
        /**
         * The upper boundary setup of a forecast computation.
         */
        upperBoundary?: pulumi.Input<number>;
    }
    interface TemplateTimeEqualityFilterArgs {
        /**
         * The column that the filter is applied to.
         */
        column: pulumi.Input<inputs.quicksight.TemplateColumnIdentifierArgs>;
        /**
         * The default configurations for the associated controls. This applies only for filters that are scoped to multiple sheets.
         */
        defaultFilterControlConfiguration?: pulumi.Input<inputs.quicksight.TemplateDefaultFilterControlConfigurationArgs>;
        /**
         * An identifier that uniquely identifies a filter within a dashboard, analysis, or template.
         */
        filterId: pulumi.Input<string>;
        /**
         * The parameter whose value should be used for the filter value.
         *
         * This field is mutually exclusive to `Value` and `RollingDate` .
         */
        parameterName?: pulumi.Input<string>;
        /**
         * The rolling date input for the `TimeEquality` filter.
         *
         * This field is mutually exclusive to `Value` and `ParameterName` .
         */
        rollingDate?: pulumi.Input<inputs.quicksight.TemplateRollingDateConfigurationArgs>;
        /**
         * The level of time precision that is used to aggregate `DateTime` values.
         */
        timeGranularity?: pulumi.Input<enums.quicksight.TemplateTimeGranularity>;
        /**
         * The value of a `TimeEquality` filter.
         *
         * This field is mutually exclusive to `RollingDate` and `ParameterName` .
         */
        value?: pulumi.Input<string>;
    }
    interface TemplateTimeRangeDrillDownFilterArgs {
        /**
         * The column that the filter is applied to.
         */
        column: pulumi.Input<inputs.quicksight.TemplateColumnIdentifierArgs>;
        /**
         * The maximum value for the filter value range.
         */
        rangeMaximum: pulumi.Input<string>;
        /**
         * The minimum value for the filter value range.
         */
        rangeMinimum: pulumi.Input<string>;
        /**
         * The level of time precision that is used to aggregate `DateTime` values.
         */
        timeGranularity: pulumi.Input<enums.quicksight.TemplateTimeGranularity>;
    }
    interface TemplateTimeRangeFilterArgs {
        /**
         * The column that the filter is applied to.
         */
        column: pulumi.Input<inputs.quicksight.TemplateColumnIdentifierArgs>;
        /**
         * The default configurations for the associated controls. This applies only for filters that are scoped to multiple sheets.
         */
        defaultFilterControlConfiguration?: pulumi.Input<inputs.quicksight.TemplateDefaultFilterControlConfigurationArgs>;
        /**
         * The exclude period of the time range filter.
         */
        excludePeriodConfiguration?: pulumi.Input<inputs.quicksight.TemplateExcludePeriodConfigurationArgs>;
        /**
         * An identifier that uniquely identifies a filter within a dashboard, analysis, or template.
         */
        filterId: pulumi.Input<string>;
        /**
         * Determines whether the maximum value in the filter value range should be included in the filtered results.
         */
        includeMaximum?: pulumi.Input<boolean>;
        /**
         * Determines whether the minimum value in the filter value range should be included in the filtered results.
         */
        includeMinimum?: pulumi.Input<boolean>;
        /**
         * This option determines how null values should be treated when filtering data.
         *
         * - `ALL_VALUES` : Include null values in filtered results.
         * - `NULLS_ONLY` : Only include null values in filtered results.
         * - `NON_NULLS_ONLY` : Exclude null values from filtered results.
         */
        nullOption: pulumi.Input<enums.quicksight.TemplateFilterNullOption>;
        /**
         * The maximum value for the filter value range.
         */
        rangeMaximumValue?: pulumi.Input<inputs.quicksight.TemplateTimeRangeFilterValueArgs>;
        /**
         * The minimum value for the filter value range.
         */
        rangeMinimumValue?: pulumi.Input<inputs.quicksight.TemplateTimeRangeFilterValueArgs>;
        /**
         * The level of time precision that is used to aggregate `DateTime` values.
         */
        timeGranularity?: pulumi.Input<enums.quicksight.TemplateTimeGranularity>;
    }
    interface TemplateTimeRangeFilterValueArgs {
        /**
         * The parameter type input value.
         */
        parameter?: pulumi.Input<string>;
        /**
         * The rolling date input value.
         */
        rollingDate?: pulumi.Input<inputs.quicksight.TemplateRollingDateConfigurationArgs>;
        /**
         * The static input value.
         */
        staticValue?: pulumi.Input<string>;
    }
    interface TemplateTooltipItemArgs {
        /**
         * The tooltip item for the columns that are not part of a field well.
         */
        columnTooltipItem?: pulumi.Input<inputs.quicksight.TemplateColumnTooltipItemArgs>;
        /**
         * The tooltip item for the fields.
         */
        fieldTooltipItem?: pulumi.Input<inputs.quicksight.TemplateFieldTooltipItemArgs>;
    }
    interface TemplateTooltipOptionsArgs {
        /**
         * The setup for the detailed tooltip. The tooltip setup is always saved. The display type is decided based on the tooltip type.
         */
        fieldBasedTooltip?: pulumi.Input<inputs.quicksight.TemplateFieldBasedTooltipArgs>;
        /**
         * The selected type for the tooltip. Choose one of the following options:
         *
         * - `BASIC` : A basic tooltip.
         * - `DETAILED` : A detailed tooltip.
         */
        selectedTooltipType?: pulumi.Input<enums.quicksight.TemplateSelectedTooltipType>;
        /**
         * Determines whether or not the tooltip is visible.
         */
        tooltipVisibility?: any;
    }
    interface TemplateTopBottomFilterArgs {
        /**
         * The aggregation and sort configuration of the top bottom filter.
         */
        aggregationSortConfigurations: pulumi.Input<pulumi.Input<inputs.quicksight.TemplateAggregationSortConfigurationArgs>[]>;
        /**
         * The column that the filter is applied to.
         */
        column: pulumi.Input<inputs.quicksight.TemplateColumnIdentifierArgs>;
        /**
         * The default configurations for the associated controls. This applies only for filters that are scoped to multiple sheets.
         */
        defaultFilterControlConfiguration?: pulumi.Input<inputs.quicksight.TemplateDefaultFilterControlConfigurationArgs>;
        /**
         * An identifier that uniquely identifies a filter within a dashboard, analysis, or template.
         */
        filterId: pulumi.Input<string>;
        /**
         * The number of items to include in the top bottom filter results.
         */
        limit?: pulumi.Input<number>;
        /**
         * The parameter whose value should be used for the filter value.
         */
        parameterName?: pulumi.Input<string>;
        /**
         * The level of time precision that is used to aggregate `DateTime` values.
         */
        timeGranularity?: pulumi.Input<enums.quicksight.TemplateTimeGranularity>;
    }
    interface TemplateTopBottomMoversComputationArgs {
        /**
         * The category field that is used in a computation.
         */
        category?: pulumi.Input<inputs.quicksight.TemplateDimensionFieldArgs>;
        /**
         * The ID for a computation.
         */
        computationId: pulumi.Input<string>;
        /**
         * The mover size setup of the top and bottom movers computation.
         */
        moverSize?: pulumi.Input<number>;
        /**
         * The name of a computation.
         */
        name?: pulumi.Input<string>;
        /**
         * The sort order setup of the top and bottom movers computation.
         */
        sortOrder?: pulumi.Input<enums.quicksight.TemplateTopBottomSortOrder>;
        /**
         * The time field that is used in a computation.
         */
        time?: pulumi.Input<inputs.quicksight.TemplateDimensionFieldArgs>;
        /**
         * The computation type. Choose from the following options:
         *
         * - TOP: Top movers computation.
         * - BOTTOM: Bottom movers computation.
         */
        type: pulumi.Input<enums.quicksight.TemplateTopBottomComputationType>;
        /**
         * The value field that is used in a computation.
         */
        value?: pulumi.Input<inputs.quicksight.TemplateMeasureFieldArgs>;
    }
    interface TemplateTopBottomRankedComputationArgs {
        /**
         * The category field that is used in a computation.
         */
        category?: pulumi.Input<inputs.quicksight.TemplateDimensionFieldArgs>;
        /**
         * The ID for a computation.
         */
        computationId: pulumi.Input<string>;
        /**
         * The name of a computation.
         */
        name?: pulumi.Input<string>;
        /**
         * The result size of a top and bottom ranked computation.
         */
        resultSize?: pulumi.Input<number>;
        /**
         * The computation type. Choose one of the following options:
         *
         * - TOP: A top ranked computation.
         * - BOTTOM: A bottom ranked computation.
         */
        type: pulumi.Input<enums.quicksight.TemplateTopBottomComputationType>;
        /**
         * The value field that is used in a computation.
         */
        value?: pulumi.Input<inputs.quicksight.TemplateMeasureFieldArgs>;
    }
    interface TemplateTotalAggregationComputationArgs {
        /**
         * The ID for a computation.
         */
        computationId: pulumi.Input<string>;
        /**
         * The name of a computation.
         */
        name?: pulumi.Input<string>;
        /**
         * The value field that is used in a computation.
         */
        value?: pulumi.Input<inputs.quicksight.TemplateMeasureFieldArgs>;
    }
    interface TemplateTotalAggregationFunctionArgs {
        /**
         * A built in aggregation function for total values.
         */
        simpleTotalAggregationFunction?: pulumi.Input<enums.quicksight.TemplateSimpleTotalAggregationFunction>;
    }
    interface TemplateTotalAggregationOptionArgs {
        /**
         * The field id that's associated with the total aggregation option.
         */
        fieldId: pulumi.Input<string>;
        /**
         * The total aggregation function that you want to set for a specified field id.
         */
        totalAggregationFunction: pulumi.Input<inputs.quicksight.TemplateTotalAggregationFunctionArgs>;
    }
    interface TemplateTotalOptionsArgs {
        /**
         * The custom label string for the total cells.
         */
        customLabel?: pulumi.Input<string>;
        /**
         * The placement (start, end) for the total cells.
         */
        placement?: pulumi.Input<enums.quicksight.TemplateTableTotalsPlacement>;
        /**
         * The scroll status (pinned, scrolled) for the total cells.
         */
        scrollStatus?: pulumi.Input<enums.quicksight.TemplateTableTotalsScrollStatus>;
        /**
         * The total aggregation settings for each value field.
         */
        totalAggregationOptions?: pulumi.Input<pulumi.Input<inputs.quicksight.TemplateTotalAggregationOptionArgs>[]>;
        /**
         * Cell styling options for the total cells.
         */
        totalCellStyle?: pulumi.Input<inputs.quicksight.TemplateTableCellStyleArgs>;
        /**
         * The visibility configuration for the total cells.
         */
        totalsVisibility?: any;
    }
    interface TemplateTransposedTableOptionArgs {
        /**
         * The index of a columns in a transposed table. The index range is 0-9999.
         */
        columnIndex?: pulumi.Input<number>;
        /**
         * The column type of the column in a transposed table. Choose one of the following options:
         *
         * - `ROW_HEADER_COLUMN` : Refers to the leftmost column of the row header in the transposed table.
         * - `VALUE_COLUMN` : Refers to all value columns in the transposed table.
         */
        columnType: pulumi.Input<enums.quicksight.TemplateTransposedColumnType>;
        /**
         * String based length that is composed of value and unit in px
         */
        columnWidth?: pulumi.Input<string>;
    }
    interface TemplateTreeMapAggregatedFieldWellsArgs {
        /**
         * The color field well of a tree map. Values are grouped by aggregations based on group by fields.
         */
        colors?: pulumi.Input<pulumi.Input<inputs.quicksight.TemplateMeasureFieldArgs>[]>;
        /**
         * The group by field well of a tree map. Values are grouped based on group by fields.
         */
        groups?: pulumi.Input<pulumi.Input<inputs.quicksight.TemplateDimensionFieldArgs>[]>;
        /**
         * The size field well of a tree map. Values are aggregated based on group by fields.
         */
        sizes?: pulumi.Input<pulumi.Input<inputs.quicksight.TemplateMeasureFieldArgs>[]>;
    }
    interface TemplateTreeMapConfigurationArgs {
        /**
         * The label options (label text, label visibility) for the colors displayed in a tree map.
         */
        colorLabelOptions?: pulumi.Input<inputs.quicksight.TemplateChartAxisLabelOptionsArgs>;
        /**
         * The color options (gradient color, point of divergence) of a tree map.
         */
        colorScale?: pulumi.Input<inputs.quicksight.TemplateColorScaleArgs>;
        /**
         * The options that determine if visual data labels are displayed.
         */
        dataLabels?: pulumi.Input<inputs.quicksight.TemplateDataLabelOptionsArgs>;
        /**
         * The field wells of the visual.
         */
        fieldWells?: pulumi.Input<inputs.quicksight.TemplateTreeMapFieldWellsArgs>;
        /**
         * The label options (label text, label visibility) of the groups that are displayed in a tree map.
         */
        groupLabelOptions?: pulumi.Input<inputs.quicksight.TemplateChartAxisLabelOptionsArgs>;
        /**
         * The general visual interactions setup for a visual.
         */
        interactions?: pulumi.Input<inputs.quicksight.TemplateVisualInteractionOptionsArgs>;
        /**
         * The legend display setup of the visual.
         */
        legend?: pulumi.Input<inputs.quicksight.TemplateLegendOptionsArgs>;
        /**
         * The label options (label text, label visibility) of the sizes that are displayed in a tree map.
         */
        sizeLabelOptions?: pulumi.Input<inputs.quicksight.TemplateChartAxisLabelOptionsArgs>;
        /**
         * The sort configuration of a tree map.
         */
        sortConfiguration?: pulumi.Input<inputs.quicksight.TemplateTreeMapSortConfigurationArgs>;
        /**
         * The tooltip display setup of the visual.
         */
        tooltip?: pulumi.Input<inputs.quicksight.TemplateTooltipOptionsArgs>;
    }
    interface TemplateTreeMapFieldWellsArgs {
        /**
         * The aggregated field wells of a tree map.
         */
        treeMapAggregatedFieldWells?: pulumi.Input<inputs.quicksight.TemplateTreeMapAggregatedFieldWellsArgs>;
    }
    interface TemplateTreeMapSortConfigurationArgs {
        /**
         * The limit on the number of groups that are displayed.
         */
        treeMapGroupItemsLimitConfiguration?: pulumi.Input<inputs.quicksight.TemplateItemsLimitConfigurationArgs>;
        /**
         * The sort configuration of group by fields.
         */
        treeMapSort?: pulumi.Input<pulumi.Input<inputs.quicksight.TemplateFieldSortOptionsArgs>[]>;
    }
    interface TemplateTreeMapVisualArgs {
        /**
         * The list of custom actions that are configured for a visual.
         */
        actions?: pulumi.Input<pulumi.Input<inputs.quicksight.TemplateVisualCustomActionArgs>[]>;
        /**
         * The configuration settings of the visual.
         */
        chartConfiguration?: pulumi.Input<inputs.quicksight.TemplateTreeMapConfigurationArgs>;
        /**
         * The column hierarchy that is used during drill-downs and drill-ups.
         */
        columnHierarchies?: pulumi.Input<pulumi.Input<inputs.quicksight.TemplateColumnHierarchyArgs>[]>;
        /**
         * The subtitle that is displayed on the visual.
         */
        subtitle?: pulumi.Input<inputs.quicksight.TemplateVisualSubtitleLabelOptionsArgs>;
        /**
         * The title that is displayed on the visual.
         */
        title?: pulumi.Input<inputs.quicksight.TemplateVisualTitleLabelOptionsArgs>;
        /**
         * The alt text for the visual.
         */
        visualContentAltText?: pulumi.Input<string>;
        /**
         * The unique identifier of a visual. This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers..
         */
        visualId: pulumi.Input<string>;
    }
    interface TemplateTrendArrowOptionsArgs {
        /**
         * The visibility of the trend arrows.
         */
        visibility?: any;
    }
    interface TemplateUnaggregatedFieldArgs {
        /**
         * The column that is used in the `UnaggregatedField` .
         */
        column: pulumi.Input<inputs.quicksight.TemplateColumnIdentifierArgs>;
        /**
         * The custom field ID.
         */
        fieldId: pulumi.Input<string>;
        /**
         * The format configuration of the field.
         */
        formatConfiguration?: pulumi.Input<inputs.quicksight.TemplateFormatConfigurationArgs>;
    }
    interface TemplateUniqueValuesComputationArgs {
        /**
         * The category field that is used in a computation.
         */
        category?: pulumi.Input<inputs.quicksight.TemplateDimensionFieldArgs>;
        /**
         * The ID for a computation.
         */
        computationId: pulumi.Input<string>;
        /**
         * The name of a computation.
         */
        name?: pulumi.Input<string>;
    }
    /**
     * <p>The option to relax the validation that is required to create and update analyses, dashboards, and templates with definition objects. When you set this value to <code>LENIENT</code>, validation is skipped for specific errors.</p>
     */
    interface TemplateValidationStrategyArgs {
        /**
         * The mode of validation for the asset to be created or updated. When you set this value to `STRICT` , strict validation for every error is enforced. When you set this value to `LENIENT` , validation is skipped for specific UI errors.
         */
        mode: pulumi.Input<enums.quicksight.TemplateValidationStrategyMode>;
    }
    interface TemplateVersionDefinitionArgs {
        analysisDefaults?: pulumi.Input<inputs.quicksight.TemplateAnalysisDefaultsArgs>;
        /**
         * An array of calculated field definitions for the template.
         */
        calculatedFields?: pulumi.Input<pulumi.Input<inputs.quicksight.TemplateCalculatedFieldArgs>[]>;
        /**
         * An array of template-level column configurations. Column configurations are used to set default formatting for a column that's used throughout a template.
         */
        columnConfigurations?: pulumi.Input<pulumi.Input<inputs.quicksight.TemplateColumnConfigurationArgs>[]>;
        /**
         * An array of dataset configurations. These configurations define the required columns for each dataset used within a template.
         */
        dataSetConfigurations: pulumi.Input<pulumi.Input<inputs.quicksight.TemplateDataSetConfigurationArgs>[]>;
        /**
         * Filter definitions for a template.
         *
         * For more information, see [Filtering Data](https://docs.aws.amazon.com/quicksight/latest/user/filtering-visual-data.html) in the *Amazon QuickSight User Guide* .
         */
        filterGroups?: pulumi.Input<pulumi.Input<inputs.quicksight.TemplateFilterGroupArgs>[]>;
        /**
         * An array of option definitions for a template.
         */
        options?: pulumi.Input<inputs.quicksight.TemplateAssetOptionsArgs>;
        /**
         * An array of parameter declarations for a template.
         *
         * *Parameters* are named variables that can transfer a value for use by an action or an object.
         *
         * For more information, see [Parameters in Amazon QuickSight](https://docs.aws.amazon.com/quicksight/latest/user/parameters-in-quicksight.html) in the *Amazon QuickSight User Guide* .
         */
        parameterDeclarations?: pulumi.Input<pulumi.Input<inputs.quicksight.TemplateParameterDeclarationArgs>[]>;
        queryExecutionOptions?: pulumi.Input<inputs.quicksight.TemplateQueryExecutionOptionsArgs>;
        /**
         * An array of sheet definitions for a template.
         */
        sheets?: pulumi.Input<pulumi.Input<inputs.quicksight.TemplateSheetDefinitionArgs>[]>;
    }
    interface TemplateVisibleRangeOptionsArgs {
        /**
         * The percent range in the visible range.
         */
        percentRange?: pulumi.Input<inputs.quicksight.TemplatePercentVisibleRangeArgs>;
    }
    interface TemplateVisualArgs {
        /**
         * A bar chart.
         *
         * For more information, see [Using bar charts](https://docs.aws.amazon.com/quicksight/latest/user/bar-charts.html) in the *Amazon QuickSight User Guide* .
         */
        barChartVisual?: pulumi.Input<inputs.quicksight.TemplateBarChartVisualArgs>;
        /**
         * A box plot.
         *
         * For more information, see [Using box plots](https://docs.aws.amazon.com/quicksight/latest/user/box-plots.html) in the *Amazon QuickSight User Guide* .
         */
        boxPlotVisual?: pulumi.Input<inputs.quicksight.TemplateBoxPlotVisualArgs>;
        /**
         * A combo chart.
         *
         * For more information, see [Using combo charts](https://docs.aws.amazon.com/quicksight/latest/user/combo-charts.html) in the *Amazon QuickSight User Guide* .
         */
        comboChartVisual?: pulumi.Input<inputs.quicksight.TemplateComboChartVisualArgs>;
        /**
         * A visual that contains custom content.
         *
         * For more information, see [Using custom visual content](https://docs.aws.amazon.com/quicksight/latest/user/custom-visual-content.html) in the *Amazon QuickSight User Guide* .
         */
        customContentVisual?: pulumi.Input<inputs.quicksight.TemplateCustomContentVisualArgs>;
        /**
         * An empty visual.
         */
        emptyVisual?: pulumi.Input<inputs.quicksight.TemplateEmptyVisualArgs>;
        /**
         * A filled map.
         *
         * For more information, see [Creating filled maps](https://docs.aws.amazon.com/quicksight/latest/user/filled-maps.html) in the *Amazon QuickSight User Guide* .
         */
        filledMapVisual?: pulumi.Input<inputs.quicksight.TemplateFilledMapVisualArgs>;
        /**
         * A funnel chart.
         *
         * For more information, see [Using funnel charts](https://docs.aws.amazon.com/quicksight/latest/user/funnel-visual-content.html) in the *Amazon QuickSight User Guide* .
         */
        funnelChartVisual?: pulumi.Input<inputs.quicksight.TemplateFunnelChartVisualArgs>;
        /**
         * A gauge chart.
         *
         * For more information, see [Using gauge charts](https://docs.aws.amazon.com/quicksight/latest/user/gauge-chart.html) in the *Amazon QuickSight User Guide* .
         */
        gaugeChartVisual?: pulumi.Input<inputs.quicksight.TemplateGaugeChartVisualArgs>;
        /**
         * A geospatial map or a points on map visual.
         *
         * For more information, see [Creating point maps](https://docs.aws.amazon.com/quicksight/latest/user/point-maps.html) in the *Amazon QuickSight User Guide* .
         */
        geospatialMapVisual?: pulumi.Input<inputs.quicksight.TemplateGeospatialMapVisualArgs>;
        /**
         * A heat map.
         *
         * For more information, see [Using heat maps](https://docs.aws.amazon.com/quicksight/latest/user/heat-map.html) in the *Amazon QuickSight User Guide* .
         */
        heatMapVisual?: pulumi.Input<inputs.quicksight.TemplateHeatMapVisualArgs>;
        /**
         * A histogram.
         *
         * For more information, see [Using histograms](https://docs.aws.amazon.com/quicksight/latest/user/histogram-charts.html) in the *Amazon QuickSight User Guide* .
         */
        histogramVisual?: pulumi.Input<inputs.quicksight.TemplateHistogramVisualArgs>;
        /**
         * An insight visual.
         *
         * For more information, see [Working with insights](https://docs.aws.amazon.com/quicksight/latest/user/computational-insights.html) in the *Amazon QuickSight User Guide* .
         */
        insightVisual?: pulumi.Input<inputs.quicksight.TemplateInsightVisualArgs>;
        /**
         * A key performance indicator (KPI).
         *
         * For more information, see [Using KPIs](https://docs.aws.amazon.com/quicksight/latest/user/kpi.html) in the *Amazon QuickSight User Guide* .
         */
        kpiVisual?: pulumi.Input<inputs.quicksight.TemplateKpiVisualArgs>;
        /**
         * A line chart.
         *
         * For more information, see [Using line charts](https://docs.aws.amazon.com/quicksight/latest/user/line-charts.html) in the *Amazon QuickSight User Guide* .
         */
        lineChartVisual?: pulumi.Input<inputs.quicksight.TemplateLineChartVisualArgs>;
        /**
         * A pie or donut chart.
         *
         * For more information, see [Using pie charts](https://docs.aws.amazon.com/quicksight/latest/user/pie-chart.html) in the *Amazon QuickSight User Guide* .
         */
        pieChartVisual?: pulumi.Input<inputs.quicksight.TemplatePieChartVisualArgs>;
        /**
         * A pivot table.
         *
         * For more information, see [Using pivot tables](https://docs.aws.amazon.com/quicksight/latest/user/pivot-table.html) in the *Amazon QuickSight User Guide* .
         */
        pivotTableVisual?: pulumi.Input<inputs.quicksight.TemplatePivotTableVisualArgs>;
        /**
         * The custom plugin visual type.
         */
        pluginVisual?: pulumi.Input<inputs.quicksight.TemplatePluginVisualArgs>;
        /**
         * A radar chart visual.
         *
         * For more information, see [Using radar charts](https://docs.aws.amazon.com/quicksight/latest/user/radar-chart.html) in the *Amazon QuickSight User Guide* .
         */
        radarChartVisual?: pulumi.Input<inputs.quicksight.TemplateRadarChartVisualArgs>;
        /**
         * A sankey diagram.
         *
         * For more information, see [Using Sankey diagrams](https://docs.aws.amazon.com/quicksight/latest/user/sankey-diagram.html) in the *Amazon QuickSight User Guide* .
         */
        sankeyDiagramVisual?: pulumi.Input<inputs.quicksight.TemplateSankeyDiagramVisualArgs>;
        /**
         * A scatter plot.
         *
         * For more information, see [Using scatter plots](https://docs.aws.amazon.com/quicksight/latest/user/scatter-plot.html) in the *Amazon QuickSight User Guide* .
         */
        scatterPlotVisual?: pulumi.Input<inputs.quicksight.TemplateScatterPlotVisualArgs>;
        /**
         * A table visual.
         *
         * For more information, see [Using tables as visuals](https://docs.aws.amazon.com/quicksight/latest/user/tabular.html) in the *Amazon QuickSight User Guide* .
         */
        tableVisual?: pulumi.Input<inputs.quicksight.TemplateTableVisualArgs>;
        /**
         * A tree map.
         *
         * For more information, see [Using tree maps](https://docs.aws.amazon.com/quicksight/latest/user/tree-map.html) in the *Amazon QuickSight User Guide* .
         */
        treeMapVisual?: pulumi.Input<inputs.quicksight.TemplateTreeMapVisualArgs>;
        /**
         * A waterfall chart.
         *
         * For more information, see [Using waterfall charts](https://docs.aws.amazon.com/quicksight/latest/user/waterfall-chart.html) in the *Amazon QuickSight User Guide* .
         */
        waterfallVisual?: pulumi.Input<inputs.quicksight.TemplateWaterfallVisualArgs>;
        /**
         * A word cloud.
         *
         * For more information, see [Using word clouds](https://docs.aws.amazon.com/quicksight/latest/user/word-cloud.html) in the *Amazon QuickSight User Guide* .
         */
        wordCloudVisual?: pulumi.Input<inputs.quicksight.TemplateWordCloudVisualArgs>;
    }
    interface TemplateVisualCustomActionArgs {
        /**
         * A list of `VisualCustomActionOperations` .
         *
         * This is a union type structure. For this structure to be valid, only one of the attributes can be defined.
         */
        actionOperations: pulumi.Input<pulumi.Input<inputs.quicksight.TemplateVisualCustomActionOperationArgs>[]>;
        /**
         * The ID of the `VisualCustomAction` .
         */
        customActionId: pulumi.Input<string>;
        /**
         * The name of the `VisualCustomAction` .
         */
        name: pulumi.Input<string>;
        /**
         * The status of the `VisualCustomAction` .
         */
        status?: pulumi.Input<enums.quicksight.TemplateWidgetStatus>;
        /**
         * The trigger of the `VisualCustomAction` .
         *
         * Valid values are defined as follows:
         *
         * - `DATA_POINT_CLICK` : Initiates a custom action by a left pointer click on a data point.
         * - `DATA_POINT_MENU` : Initiates a custom action by right pointer click from the menu.
         */
        trigger: pulumi.Input<enums.quicksight.TemplateVisualCustomActionTrigger>;
    }
    interface TemplateVisualCustomActionOperationArgs {
        /**
         * The filter operation that filters data included in a visual or in an entire sheet.
         */
        filterOperation?: pulumi.Input<inputs.quicksight.TemplateCustomActionFilterOperationArgs>;
        /**
         * The navigation operation that navigates between different sheets in the same analysis.
         */
        navigationOperation?: pulumi.Input<inputs.quicksight.TemplateCustomActionNavigationOperationArgs>;
        /**
         * The set parameter operation that sets parameters in custom action.
         */
        setParametersOperation?: pulumi.Input<inputs.quicksight.TemplateCustomActionSetParametersOperationArgs>;
        /**
         * The URL operation that opens a link to another webpage.
         */
        urlOperation?: pulumi.Input<inputs.quicksight.TemplateCustomActionUrlOperationArgs>;
    }
    interface TemplateVisualInteractionOptionsArgs {
        /**
         * The context menu options for a visual.
         */
        contextMenuOption?: pulumi.Input<inputs.quicksight.TemplateContextMenuOptionArgs>;
        /**
         * The on-visual menu options for a visual.
         */
        visualMenuOption?: pulumi.Input<inputs.quicksight.TemplateVisualMenuOptionArgs>;
    }
    interface TemplateVisualMenuOptionArgs {
        /**
         * The availaiblity status of a visual's menu options.
         */
        availabilityStatus?: pulumi.Input<enums.quicksight.TemplateDashboardBehavior>;
    }
    interface TemplateVisualPaletteArgs {
        /**
         * The chart color options for the visual palette.
         */
        chartColor?: pulumi.Input<string>;
        /**
         * The color map options for the visual palette.
         */
        colorMap?: pulumi.Input<pulumi.Input<inputs.quicksight.TemplateDataPathColorArgs>[]>;
    }
    interface TemplateVisualSubtitleLabelOptionsArgs {
        /**
         * The long text format of the subtitle label, such as plain text or rich text.
         */
        formatText?: pulumi.Input<inputs.quicksight.TemplateLongFormatTextArgs>;
        /**
         * The visibility of the subtitle label.
         */
        visibility?: any;
    }
    interface TemplateVisualTitleLabelOptionsArgs {
        /**
         * The short text format of the title label, such as plain text or rich text.
         */
        formatText?: pulumi.Input<inputs.quicksight.TemplateShortFormatTextArgs>;
        /**
         * The visibility of the title label.
         */
        visibility?: any;
    }
    interface TemplateWaterfallChartAggregatedFieldWellsArgs {
        /**
         * The breakdown field wells of a waterfall visual.
         */
        breakdowns?: pulumi.Input<pulumi.Input<inputs.quicksight.TemplateDimensionFieldArgs>[]>;
        /**
         * The category field wells of a waterfall visual.
         */
        categories?: pulumi.Input<pulumi.Input<inputs.quicksight.TemplateDimensionFieldArgs>[]>;
        /**
         * The value field wells of a waterfall visual.
         */
        values?: pulumi.Input<pulumi.Input<inputs.quicksight.TemplateMeasureFieldArgs>[]>;
    }
    interface TemplateWaterfallChartColorConfigurationArgs {
        /**
         * The color configuration for individual groups within a waterfall visual.
         */
        groupColorConfiguration?: pulumi.Input<inputs.quicksight.TemplateWaterfallChartGroupColorConfigurationArgs>;
    }
    interface TemplateWaterfallChartConfigurationArgs {
        /**
         * The options that determine the presentation of the category axis.
         */
        categoryAxisDisplayOptions?: pulumi.Input<inputs.quicksight.TemplateAxisDisplayOptionsArgs>;
        /**
         * The options that determine the presentation of the category axis label.
         */
        categoryAxisLabelOptions?: pulumi.Input<inputs.quicksight.TemplateChartAxisLabelOptionsArgs>;
        /**
         * The color configuration of a waterfall visual.
         */
        colorConfiguration?: pulumi.Input<inputs.quicksight.TemplateWaterfallChartColorConfigurationArgs>;
        /**
         * The data label configuration of a waterfall visual.
         */
        dataLabels?: pulumi.Input<inputs.quicksight.TemplateDataLabelOptionsArgs>;
        /**
         * The field well configuration of a waterfall visual.
         */
        fieldWells?: pulumi.Input<inputs.quicksight.TemplateWaterfallChartFieldWellsArgs>;
        /**
         * The general visual interactions setup for a visual.
         */
        interactions?: pulumi.Input<inputs.quicksight.TemplateVisualInteractionOptionsArgs>;
        /**
         * The legend configuration of a waterfall visual.
         */
        legend?: pulumi.Input<inputs.quicksight.TemplateLegendOptionsArgs>;
        /**
         * The options that determine the presentation of the y-axis.
         */
        primaryYAxisDisplayOptions?: pulumi.Input<inputs.quicksight.TemplateAxisDisplayOptionsArgs>;
        /**
         * The options that determine the presentation of the y-axis label.
         */
        primaryYAxisLabelOptions?: pulumi.Input<inputs.quicksight.TemplateChartAxisLabelOptionsArgs>;
        /**
         * The sort configuration of a waterfall visual.
         */
        sortConfiguration?: pulumi.Input<inputs.quicksight.TemplateWaterfallChartSortConfigurationArgs>;
        /**
         * The visual palette configuration of a waterfall visual.
         */
        visualPalette?: pulumi.Input<inputs.quicksight.TemplateVisualPaletteArgs>;
        /**
         * The options that determine the presentation of a waterfall visual.
         */
        waterfallChartOptions?: pulumi.Input<inputs.quicksight.TemplateWaterfallChartOptionsArgs>;
    }
    interface TemplateWaterfallChartFieldWellsArgs {
        /**
         * The field well configuration of a waterfall visual.
         */
        waterfallChartAggregatedFieldWells?: pulumi.Input<inputs.quicksight.TemplateWaterfallChartAggregatedFieldWellsArgs>;
    }
    interface TemplateWaterfallChartGroupColorConfigurationArgs {
        /**
         * Defines the color for the negative bars of a waterfall chart.
         */
        negativeBarColor?: pulumi.Input<string>;
        /**
         * Defines the color for the positive bars of a waterfall chart.
         */
        positiveBarColor?: pulumi.Input<string>;
        /**
         * Defines the color for the total bars of a waterfall chart.
         */
        totalBarColor?: pulumi.Input<string>;
    }
    interface TemplateWaterfallChartOptionsArgs {
        /**
         * This option determines the total bar label of a waterfall visual.
         */
        totalBarLabel?: pulumi.Input<string>;
    }
    interface TemplateWaterfallChartSortConfigurationArgs {
        /**
         * The limit on the number of bar groups that are displayed.
         */
        breakdownItemsLimit?: pulumi.Input<inputs.quicksight.TemplateItemsLimitConfigurationArgs>;
        /**
         * The sort configuration of the category fields.
         */
        categorySort?: pulumi.Input<pulumi.Input<inputs.quicksight.TemplateFieldSortOptionsArgs>[]>;
    }
    interface TemplateWaterfallVisualArgs {
        /**
         * The list of custom actions that are configured for a visual.
         */
        actions?: pulumi.Input<pulumi.Input<inputs.quicksight.TemplateVisualCustomActionArgs>[]>;
        /**
         * The configuration for a waterfall visual.
         */
        chartConfiguration?: pulumi.Input<inputs.quicksight.TemplateWaterfallChartConfigurationArgs>;
        /**
         * The column hierarchy that is used during drill-downs and drill-ups.
         */
        columnHierarchies?: pulumi.Input<pulumi.Input<inputs.quicksight.TemplateColumnHierarchyArgs>[]>;
        /**
         * The subtitle that is displayed on the visual.
         */
        subtitle?: pulumi.Input<inputs.quicksight.TemplateVisualSubtitleLabelOptionsArgs>;
        /**
         * The title that is displayed on the visual.
         */
        title?: pulumi.Input<inputs.quicksight.TemplateVisualTitleLabelOptionsArgs>;
        /**
         * The alt text for the visual.
         */
        visualContentAltText?: pulumi.Input<string>;
        /**
         * The unique identifier of a visual. This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers.
         */
        visualId: pulumi.Input<string>;
    }
    interface TemplateWhatIfPointScenarioArgs {
        /**
         * The date that you need the forecast results for.
         */
        date: pulumi.Input<string>;
        /**
         * The target value that you want to meet for the provided date.
         */
        value: pulumi.Input<number>;
    }
    interface TemplateWhatIfRangeScenarioArgs {
        /**
         * The end date in the date range that you need the forecast results for.
         */
        endDate: pulumi.Input<string>;
        /**
         * The start date in the date range that you need the forecast results for.
         */
        startDate: pulumi.Input<string>;
        /**
         * The target value that you want to meet for the provided date range.
         */
        value: pulumi.Input<number>;
    }
    interface TemplateWordCloudAggregatedFieldWellsArgs {
        /**
         * The group by field well of a word cloud. Values are grouped by group by fields.
         */
        groupBy?: pulumi.Input<pulumi.Input<inputs.quicksight.TemplateDimensionFieldArgs>[]>;
        /**
         * The size field well of a word cloud. Values are aggregated based on group by fields.
         */
        size?: pulumi.Input<pulumi.Input<inputs.quicksight.TemplateMeasureFieldArgs>[]>;
    }
    interface TemplateWordCloudChartConfigurationArgs {
        /**
         * The label options (label text, label visibility, and sort icon visibility) for the word cloud category.
         */
        categoryLabelOptions?: pulumi.Input<inputs.quicksight.TemplateChartAxisLabelOptionsArgs>;
        /**
         * The field wells of the visual.
         */
        fieldWells?: pulumi.Input<inputs.quicksight.TemplateWordCloudFieldWellsArgs>;
        /**
         * The general visual interactions setup for a visual.
         */
        interactions?: pulumi.Input<inputs.quicksight.TemplateVisualInteractionOptionsArgs>;
        /**
         * The sort configuration of a word cloud visual.
         */
        sortConfiguration?: pulumi.Input<inputs.quicksight.TemplateWordCloudSortConfigurationArgs>;
        /**
         * The options for a word cloud visual.
         */
        wordCloudOptions?: pulumi.Input<inputs.quicksight.TemplateWordCloudOptionsArgs>;
    }
    interface TemplateWordCloudFieldWellsArgs {
        /**
         * The aggregated field wells of a word cloud.
         */
        wordCloudAggregatedFieldWells?: pulumi.Input<inputs.quicksight.TemplateWordCloudAggregatedFieldWellsArgs>;
    }
    interface TemplateWordCloudOptionsArgs {
        /**
         * The cloud layout options (fluid, normal) of a word cloud.
         */
        cloudLayout?: pulumi.Input<enums.quicksight.TemplateWordCloudCloudLayout>;
        /**
         * The length limit of each word from 1-100.
         */
        maximumStringLength?: pulumi.Input<number>;
        /**
         * The word casing options (lower_case, existing_case) for the words in a word cloud.
         */
        wordCasing?: pulumi.Input<enums.quicksight.TemplateWordCloudWordCasing>;
        /**
         * The word orientation options (horizontal, horizontal_and_vertical) for the words in a word cloud.
         */
        wordOrientation?: pulumi.Input<enums.quicksight.TemplateWordCloudWordOrientation>;
        /**
         * The word padding options (none, small, medium, large) for the words in a word cloud.
         */
        wordPadding?: pulumi.Input<enums.quicksight.TemplateWordCloudWordPadding>;
        /**
         * The word scaling options (emphasize, normal) for the words in a word cloud.
         */
        wordScaling?: pulumi.Input<enums.quicksight.TemplateWordCloudWordScaling>;
    }
    interface TemplateWordCloudSortConfigurationArgs {
        /**
         * The limit on the number of groups that are displayed in a word cloud.
         */
        categoryItemsLimit?: pulumi.Input<inputs.quicksight.TemplateItemsLimitConfigurationArgs>;
        /**
         * The sort configuration of group by fields.
         */
        categorySort?: pulumi.Input<pulumi.Input<inputs.quicksight.TemplateFieldSortOptionsArgs>[]>;
    }
    interface TemplateWordCloudVisualArgs {
        /**
         * The list of custom actions that are configured for a visual.
         */
        actions?: pulumi.Input<pulumi.Input<inputs.quicksight.TemplateVisualCustomActionArgs>[]>;
        /**
         * The configuration settings of the visual.
         */
        chartConfiguration?: pulumi.Input<inputs.quicksight.TemplateWordCloudChartConfigurationArgs>;
        /**
         * The column hierarchy that is used during drill-downs and drill-ups.
         */
        columnHierarchies?: pulumi.Input<pulumi.Input<inputs.quicksight.TemplateColumnHierarchyArgs>[]>;
        /**
         * The subtitle that is displayed on the visual.
         */
        subtitle?: pulumi.Input<inputs.quicksight.TemplateVisualSubtitleLabelOptionsArgs>;
        /**
         * The title that is displayed on the visual.
         */
        title?: pulumi.Input<inputs.quicksight.TemplateVisualTitleLabelOptionsArgs>;
        /**
         * The alt text for the visual.
         */
        visualContentAltText?: pulumi.Input<string>;
        /**
         * The unique identifier of a visual. This identifier must be unique within the context of a dashboard, template, or analysis. Two dashboards, analyses, or templates can have visuals with the same identifiers..
         */
        visualId: pulumi.Input<string>;
    }
    interface TemplateYAxisOptionsArgs {
        /**
         * The Y axis type to be used in the chart.
         *
         * If you choose `PRIMARY_Y_AXIS` , the primary Y Axis is located on the leftmost vertical axis of the chart.
         */
        yAxis: pulumi.Input<enums.quicksight.TemplateSingleYAxisOption>;
    }
    /**
     * <p>The display options for tile borders for visuals.</p>
     */
    interface ThemeBorderStyleArgs {
        /**
         * <p>The option to enable display of borders for visuals.</p>
         */
        show?: pulumi.Input<boolean>;
    }
    /**
     * <p>The theme configuration. This configuration contains all of the display properties for
     *             a theme.</p>
     */
    interface ThemeConfigurationArgs {
        /**
         * Color properties that apply to chart data colors.
         */
        dataColorPalette?: pulumi.Input<inputs.quicksight.ThemeDataColorPaletteArgs>;
        /**
         * Display options related to sheets.
         */
        sheet?: pulumi.Input<inputs.quicksight.ThemeSheetStyleArgs>;
        /**
         * Determines the typography options.
         */
        typography?: pulumi.Input<inputs.quicksight.ThemeTypographyArgs>;
        /**
         * Color properties that apply to the UI and to charts, excluding the colors that apply to data.
         */
        uiColorPalette?: pulumi.Input<inputs.quicksight.ThemeUiColorPaletteArgs>;
    }
    /**
     * <p>The theme colors that are used for data colors in charts. The colors description is a
     *             hexadecimal color code that consists of six alphanumerical characters, prefixed with
     *                 <code>#</code>, for example #37BFF5. </p>
     */
    interface ThemeDataColorPaletteArgs {
        /**
         * <p>The hexadecimal codes for the colors.</p>
         */
        colors?: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * <p>The hexadecimal code of a color that applies to charts where a lack of data is
         *             highlighted.</p>
         */
        emptyFillColor?: pulumi.Input<string>;
        /**
         * <p>The minimum and maximum hexadecimal codes that describe a color gradient. </p>
         */
        minMaxGradient?: pulumi.Input<pulumi.Input<string>[]>;
    }
    interface ThemeFontArgs {
        /**
         * Determines the font family settings.
         */
        fontFamily?: pulumi.Input<string>;
    }
    /**
     * <p>The display options for gutter spacing between tiles on a sheet.</p>
     */
    interface ThemeGutterStyleArgs {
        /**
         * <p>This Boolean value controls whether to display a gutter space between sheet tiles.
         *         </p>
         */
        show?: pulumi.Input<boolean>;
    }
    /**
     * <p>The display options for margins around the outside edge of sheets.</p>
     */
    interface ThemeMarginStyleArgs {
        /**
         * <p>This Boolean value controls whether to display sheet margins.</p>
         */
        show?: pulumi.Input<boolean>;
    }
    /**
     * <p>Permission for the resource.</p>
     */
    interface ThemeResourcePermissionArgs {
        /**
         * <p>The IAM action to grant or revoke permissions on.</p>
         */
        actions: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * <p>The Amazon Resource Name (ARN) of the principal. This can be one of the
         *             following:</p>
         *          <ul>
         *             <li>
         *                <p>The ARN of an Amazon QuickSight user or group associated with a data source or dataset. (This is common.)</p>
         *             </li>
         *             <li>
         *                <p>The ARN of an Amazon QuickSight user, group, or namespace associated with an analysis, dashboard, template, or theme. (This is common.)</p>
         *             </li>
         *             <li>
         *                <p>The ARN of an Amazon Web Services account root: This is an IAM ARN rather than a QuickSight
         *                     ARN. Use this option only to share resources (templates) across Amazon Web Services accounts.
         *                     (This is less common.) </p>
         *             </li>
         *          </ul>
         */
        principal: pulumi.Input<string>;
    }
    /**
     * <p>The theme display options for sheets. </p>
     */
    interface ThemeSheetStyleArgs {
        /**
         * The display options for tiles.
         */
        tile?: pulumi.Input<inputs.quicksight.ThemeTileStyleArgs>;
        /**
         * The layout options for tiles.
         */
        tileLayout?: pulumi.Input<inputs.quicksight.ThemeTileLayoutStyleArgs>;
    }
    /**
     * <p>The display options for the layout of tiles on a sheet.</p>
     */
    interface ThemeTileLayoutStyleArgs {
        /**
         * The gutter settings that apply between tiles.
         */
        gutter?: pulumi.Input<inputs.quicksight.ThemeGutterStyleArgs>;
        /**
         * The margin settings that apply around the outside edge of sheets.
         */
        margin?: pulumi.Input<inputs.quicksight.ThemeMarginStyleArgs>;
    }
    /**
     * <p>Display options related to tiles on a sheet.</p>
     */
    interface ThemeTileStyleArgs {
        /**
         * The border around a tile.
         */
        border?: pulumi.Input<inputs.quicksight.ThemeBorderStyleArgs>;
    }
    interface ThemeTypographyArgs {
        /**
         * Determines the list of font families.
         */
        fontFamilies?: pulumi.Input<pulumi.Input<inputs.quicksight.ThemeFontArgs>[]>;
    }
    /**
     * <p>The theme colors that apply to UI and to charts, excluding data colors. The colors
     *             description is a hexadecimal color code that consists of six alphanumerical characters,
     *             prefixed with <code>#</code>, for example #37BFF5. For more information, see <a href="https://docs.aws.amazon.com/quicksight/latest/user/themes-in-quicksight.html">Using Themes in Amazon QuickSight</a> in the <i>Amazon QuickSight User
     *                 Guide.</i>
     *          </p>
     */
    interface ThemeUiColorPaletteArgs {
        /**
         * <p>This color is that applies to selected states and buttons.</p>
         */
        accent?: pulumi.Input<string>;
        /**
         * <p>The foreground color that applies to any text or other elements that appear over the
         *             accent color.</p>
         */
        accentForeground?: pulumi.Input<string>;
        /**
         * <p>The color that applies to error messages.</p>
         */
        danger?: pulumi.Input<string>;
        /**
         * <p>The foreground color that applies to any text or other elements that appear over the
         *             error color.</p>
         */
        dangerForeground?: pulumi.Input<string>;
        /**
         * <p>The color that applies to the names of fields that are identified as
         *             dimensions.</p>
         */
        dimension?: pulumi.Input<string>;
        /**
         * <p>The foreground color that applies to any text or other elements that appear over the
         *             dimension color.</p>
         */
        dimensionForeground?: pulumi.Input<string>;
        /**
         * <p>The color that applies to the names of fields that are identified as measures.</p>
         */
        measure?: pulumi.Input<string>;
        /**
         * <p>The foreground color that applies to any text or other elements that appear over the
         *             measure color.</p>
         */
        measureForeground?: pulumi.Input<string>;
        /**
         * <p>The background color that applies to visuals and other high emphasis UI.</p>
         */
        primaryBackground?: pulumi.Input<string>;
        /**
         * <p>The color of text and other foreground elements that appear over the primary
         *             background regions, such as grid lines, borders, table banding, icons, and so on.</p>
         */
        primaryForeground?: pulumi.Input<string>;
        /**
         * <p>The background color that applies to the sheet background and sheet controls.</p>
         */
        secondaryBackground?: pulumi.Input<string>;
        /**
         * <p>The foreground color that applies to any sheet title, sheet control text, or UI that
         *             appears over the secondary background.</p>
         */
        secondaryForeground?: pulumi.Input<string>;
        /**
         * <p>The color that applies to success messages, for example the check mark for a
         *             successful download.</p>
         */
        success?: pulumi.Input<string>;
        /**
         * <p>The foreground color that applies to any text or other elements that appear over the
         *             success color.</p>
         */
        successForeground?: pulumi.Input<string>;
        /**
         * <p>This color that applies to warning and informational messages.</p>
         */
        warning?: pulumi.Input<string>;
        /**
         * <p>The foreground color that applies to any text or other elements that appear over the
         *             warning color.</p>
         */
        warningForeground?: pulumi.Input<string>;
    }
    interface TopicCalculatedFieldArgs {
        /**
         * The default aggregation. Valid values for this structure are `SUM` , `MAX` , `MIN` , `COUNT` , `DISTINCT_COUNT` , and `AVERAGE` .
         */
        aggregation?: pulumi.Input<enums.quicksight.TopicDefaultAggregation>;
        /**
         * The list of aggregation types that are allowed for the calculated field. Valid values for this structure are `COUNT` , `DISTINCT_COUNT` , `MIN` , `MAX` , `MEDIAN` , `SUM` , `AVERAGE` , `STDEV` , `STDEVP` , `VAR` , `VARP` , and `PERCENTILE` .
         */
        allowedAggregations?: pulumi.Input<pulumi.Input<enums.quicksight.TopicAuthorSpecifiedAggregation>[]>;
        /**
         * The calculated field description.
         */
        calculatedFieldDescription?: pulumi.Input<string>;
        /**
         * The calculated field name.
         */
        calculatedFieldName: pulumi.Input<string>;
        /**
         * The other names or aliases for the calculated field.
         */
        calculatedFieldSynonyms?: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * The other names or aliases for the calculated field cell value.
         */
        cellValueSynonyms?: pulumi.Input<pulumi.Input<inputs.quicksight.TopicCellValueSynonymArgs>[]>;
        /**
         * The column data role for a calculated field. Valid values for this structure are `DIMENSION` and `MEASURE` .
         */
        columnDataRole?: pulumi.Input<enums.quicksight.TopicColumnDataRole>;
        /**
         * The order in which data is displayed for the calculated field when it's used in a comparative context.
         */
        comparativeOrder?: pulumi.Input<inputs.quicksight.TopicComparativeOrderArgs>;
        /**
         * The default formatting definition.
         */
        defaultFormatting?: pulumi.Input<inputs.quicksight.TopicDefaultFormattingArgs>;
        /**
         * A Boolean value that indicates if a calculated field is visible in the autocomplete.
         */
        disableIndexing?: pulumi.Input<boolean>;
        /**
         * The calculated field expression.
         */
        expression: pulumi.Input<string>;
        /**
         * A boolean value that indicates if a calculated field is included in the topic.
         */
        isIncludedInTopic?: pulumi.Input<boolean>;
        /**
         * A Boolean value that indicates whether to never aggregate calculated field in filters.
         */
        neverAggregateInFilter?: pulumi.Input<boolean>;
        /**
         * The non additive for the table style target.
         */
        nonAdditive?: pulumi.Input<boolean>;
        /**
         * The list of aggregation types that are not allowed for the calculated field. Valid values for this structure are `COUNT` , `DISTINCT_COUNT` , `MIN` , `MAX` , `MEDIAN` , `SUM` , `AVERAGE` , `STDEV` , `STDEVP` , `VAR` , `VARP` , and `PERCENTILE` .
         */
        notAllowedAggregations?: pulumi.Input<pulumi.Input<enums.quicksight.TopicAuthorSpecifiedAggregation>[]>;
        /**
         * The semantic type.
         */
        semanticType?: pulumi.Input<inputs.quicksight.TopicSemanticTypeArgs>;
        /**
         * The level of time precision that is used to aggregate `DateTime` values.
         */
        timeGranularity?: pulumi.Input<enums.quicksight.TopicTimeGranularity>;
    }
    interface TopicCategoryFilterArgs {
        /**
         * The category filter function. Valid values for this structure are `EXACT` and `CONTAINS` .
         */
        categoryFilterFunction?: pulumi.Input<enums.quicksight.TopicCategoryFilterFunction>;
        /**
         * The category filter type. This element is used to specify whether a filter is a simple category filter or an inverse category filter.
         */
        categoryFilterType?: pulumi.Input<enums.quicksight.TopicCategoryFilterType>;
        /**
         * The constant used in a category filter.
         */
        constant?: pulumi.Input<inputs.quicksight.TopicCategoryFilterConstantArgs>;
        /**
         * A Boolean value that indicates if the filter is inverse.
         */
        inverse?: pulumi.Input<boolean>;
    }
    interface TopicCategoryFilterConstantArgs {
        /**
         * A collective constant used in a category filter. This element is used to specify a list of values for the constant.
         */
        collectiveConstant?: pulumi.Input<inputs.quicksight.TopicCollectiveConstantArgs>;
        /**
         * The type of category filter constant. This element is used to specify whether a constant is a singular or collective. Valid values are `SINGULAR` and `COLLECTIVE` .
         */
        constantType?: pulumi.Input<enums.quicksight.TopicConstantType>;
        /**
         * A singular constant used in a category filter. This element is used to specify a single value for the constant.
         */
        singularConstant?: pulumi.Input<string>;
    }
    interface TopicCellValueSynonymArgs {
        /**
         * The cell value.
         */
        cellValue?: pulumi.Input<string>;
        /**
         * Other names or aliases for the cell value.
         */
        synonyms?: pulumi.Input<pulumi.Input<string>[]>;
    }
    interface TopicCollectiveConstantArgs {
        /**
         * A list of values for the collective constant.
         */
        valueList?: pulumi.Input<pulumi.Input<string>[]>;
    }
    interface TopicColumnArgs {
        /**
         * The type of aggregation that is performed on the column data when it's queried.
         */
        aggregation?: pulumi.Input<enums.quicksight.TopicDefaultAggregation>;
        /**
         * The list of aggregation types that are allowed for the column. Valid values for this structure are `COUNT` , `DISTINCT_COUNT` , `MIN` , `MAX` , `MEDIAN` , `SUM` , `AVERAGE` , `STDEV` , `STDEVP` , `VAR` , `VARP` , and `PERCENTILE` .
         */
        allowedAggregations?: pulumi.Input<pulumi.Input<enums.quicksight.TopicAuthorSpecifiedAggregation>[]>;
        /**
         * The other names or aliases for the column cell value.
         */
        cellValueSynonyms?: pulumi.Input<pulumi.Input<inputs.quicksight.TopicCellValueSynonymArgs>[]>;
        /**
         * The role of the column in the data. Valid values are `DIMENSION` and `MEASURE` .
         */
        columnDataRole?: pulumi.Input<enums.quicksight.TopicColumnDataRole>;
        /**
         * A description of the column and its contents.
         */
        columnDescription?: pulumi.Input<string>;
        /**
         * A user-friendly name for the column.
         */
        columnFriendlyName?: pulumi.Input<string>;
        /**
         * The name of the column.
         */
        columnName: pulumi.Input<string>;
        /**
         * The other names or aliases for the column.
         */
        columnSynonyms?: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * The order in which data is displayed for the column when it's used in a comparative context.
         */
        comparativeOrder?: pulumi.Input<inputs.quicksight.TopicComparativeOrderArgs>;
        /**
         * The default formatting used for values in the column.
         */
        defaultFormatting?: pulumi.Input<inputs.quicksight.TopicDefaultFormattingArgs>;
        /**
         * A Boolean value that indicates whether the column shows in the autocomplete functionality.
         */
        disableIndexing?: pulumi.Input<boolean>;
        /**
         * A Boolean value that indicates whether the column is included in the query results.
         */
        isIncludedInTopic?: pulumi.Input<boolean>;
        /**
         * A Boolean value that indicates whether to aggregate the column data when it's used in a filter context.
         */
        neverAggregateInFilter?: pulumi.Input<boolean>;
        /**
         * The non additive value for the column.
         */
        nonAdditive?: pulumi.Input<boolean>;
        /**
         * The list of aggregation types that are not allowed for the column. Valid values for this structure are `COUNT` , `DISTINCT_COUNT` , `MIN` , `MAX` , `MEDIAN` , `SUM` , `AVERAGE` , `STDEV` , `STDEVP` , `VAR` , `VARP` , and `PERCENTILE` .
         */
        notAllowedAggregations?: pulumi.Input<pulumi.Input<enums.quicksight.TopicAuthorSpecifiedAggregation>[]>;
        /**
         * The semantic type of data contained in the column.
         */
        semanticType?: pulumi.Input<inputs.quicksight.TopicSemanticTypeArgs>;
        /**
         * The level of time precision that is used to aggregate `DateTime` values.
         */
        timeGranularity?: pulumi.Input<enums.quicksight.TopicTimeGranularity>;
    }
    interface TopicComparativeOrderArgs {
        /**
         * The list of columns to be used in the ordering.
         */
        specifedOrder?: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * The treat of undefined specified values. Valid values for this structure are `LEAST` and `MOST` .
         */
        treatUndefinedSpecifiedValues?: pulumi.Input<enums.quicksight.TopicUndefinedSpecifiedValueType>;
        /**
         * The ordering type for a column. Valid values for this structure are `GREATER_IS_BETTER` , `LESSER_IS_BETTER` and `SPECIFIED` .
         */
        useOrdering?: pulumi.Input<enums.quicksight.TopicColumnOrderingType>;
    }
    /**
     * Model for configuration of a Topic
     */
    interface TopicConfigOptionsArgs {
        /**
         * Enables Amazon Q Business Insights for a `Topic` .
         */
        qBusinessInsightsEnabled?: pulumi.Input<boolean>;
    }
    interface TopicDataAggregationArgs {
        /**
         * The level of time precision that is used to aggregate `DateTime` values.
         */
        datasetRowDateGranularity?: pulumi.Input<enums.quicksight.TopicTimeGranularity>;
        /**
         * The column name for the default date.
         */
        defaultDateColumnName?: pulumi.Input<string>;
    }
    interface TopicDatasetMetadataArgs {
        /**
         * The list of calculated field definitions.
         */
        calculatedFields?: pulumi.Input<pulumi.Input<inputs.quicksight.TopicCalculatedFieldArgs>[]>;
        /**
         * The list of column definitions.
         */
        columns?: pulumi.Input<pulumi.Input<inputs.quicksight.TopicColumnArgs>[]>;
        /**
         * The definition of a data aggregation.
         */
        dataAggregation?: pulumi.Input<inputs.quicksight.TopicDataAggregationArgs>;
        /**
         * The Amazon Resource Name (ARN) of the dataset.
         */
        datasetArn: pulumi.Input<string>;
        /**
         * The description of the dataset.
         */
        datasetDescription?: pulumi.Input<string>;
        /**
         * The name of the dataset.
         */
        datasetName?: pulumi.Input<string>;
        /**
         * The list of filter definitions.
         */
        filters?: pulumi.Input<pulumi.Input<inputs.quicksight.TopicFilterArgs>[]>;
        /**
         * The list of named entities definitions.
         */
        namedEntities?: pulumi.Input<pulumi.Input<inputs.quicksight.TopicNamedEntityArgs>[]>;
    }
    interface TopicDateRangeFilterArgs {
        /**
         * The constant used in a date range filter.
         */
        constant?: pulumi.Input<inputs.quicksight.TopicRangeFilterConstantArgs>;
        /**
         * A Boolean value that indicates whether the date range filter should include the boundary values. If set to true, the filter includes the start and end dates. If set to false, the filter excludes them.
         */
        inclusive?: pulumi.Input<boolean>;
    }
    interface TopicDefaultFormattingArgs {
        /**
         * The display format. Valid values for this structure are `AUTO` , `PERCENT` , `CURRENCY` , `NUMBER` , `DATE` , and `STRING` .
         */
        displayFormat?: pulumi.Input<enums.quicksight.TopicDisplayFormat>;
        /**
         * The additional options for display formatting.
         */
        displayFormatOptions?: pulumi.Input<inputs.quicksight.TopicDisplayFormatOptionsArgs>;
    }
    interface TopicDisplayFormatOptionsArgs {
        /**
         * Determines the blank cell format.
         */
        blankCellFormat?: pulumi.Input<string>;
        /**
         * The currency symbol, such as `USD` .
         */
        currencySymbol?: pulumi.Input<string>;
        /**
         * Determines the `DateTime` format.
         */
        dateFormat?: pulumi.Input<string>;
        /**
         * Determines the decimal separator.
         */
        decimalSeparator?: pulumi.Input<enums.quicksight.TopicNumericSeparatorSymbol>;
        /**
         * Determines the number of fraction digits.
         */
        fractionDigits?: pulumi.Input<number>;
        /**
         * Determines the grouping separator.
         */
        groupingSeparator?: pulumi.Input<string>;
        /**
         * The negative format.
         */
        negativeFormat?: pulumi.Input<inputs.quicksight.TopicNegativeFormatArgs>;
        /**
         * The prefix value for a display format.
         */
        prefix?: pulumi.Input<string>;
        /**
         * The suffix value for a display format.
         */
        suffix?: pulumi.Input<string>;
        /**
         * The unit scaler. Valid values for this structure are: `NONE` , `AUTO` , `THOUSANDS` , `MILLIONS` , `BILLIONS` , and `TRILLIONS` .
         */
        unitScaler?: pulumi.Input<enums.quicksight.TopicNumberScale>;
        /**
         * A Boolean value that indicates whether to use blank cell format.
         */
        useBlankCellFormat?: pulumi.Input<boolean>;
        /**
         * A Boolean value that indicates whether to use grouping.
         */
        useGrouping?: pulumi.Input<boolean>;
    }
    interface TopicFilterArgs {
        /**
         * The category filter that is associated with this filter.
         */
        categoryFilter?: pulumi.Input<inputs.quicksight.TopicCategoryFilterArgs>;
        /**
         * The date range filter.
         */
        dateRangeFilter?: pulumi.Input<inputs.quicksight.TopicDateRangeFilterArgs>;
        /**
         * The class of the filter. Valid values for this structure are `ENFORCED_VALUE_FILTER` , `CONDITIONAL_VALUE_FILTER` , and `NAMED_VALUE_FILTER` .
         */
        filterClass?: pulumi.Input<enums.quicksight.TopicFilterClass>;
        /**
         * A description of the filter used to select items for a topic.
         */
        filterDescription?: pulumi.Input<string>;
        /**
         * The name of the filter.
         */
        filterName: pulumi.Input<string>;
        /**
         * The other names or aliases for the filter.
         */
        filterSynonyms?: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * The type of the filter. Valid values for this structure are `CATEGORY_FILTER` , `NUMERIC_EQUALITY_FILTER` , `NUMERIC_RANGE_FILTER` , `DATE_RANGE_FILTER` , and `RELATIVE_DATE_FILTER` .
         */
        filterType?: pulumi.Input<enums.quicksight.TopicNamedFilterType>;
        /**
         * The numeric equality filter.
         */
        numericEqualityFilter?: pulumi.Input<inputs.quicksight.TopicNumericEqualityFilterArgs>;
        /**
         * The numeric range filter.
         */
        numericRangeFilter?: pulumi.Input<inputs.quicksight.TopicNumericRangeFilterArgs>;
        /**
         * The name of the field that the filter operates on.
         */
        operandFieldName: pulumi.Input<string>;
        /**
         * The relative date filter.
         */
        relativeDateFilter?: pulumi.Input<inputs.quicksight.TopicRelativeDateFilterArgs>;
    }
    interface TopicNamedEntityArgs {
        /**
         * The definition of a named entity.
         */
        definition?: pulumi.Input<pulumi.Input<inputs.quicksight.TopicNamedEntityDefinitionArgs>[]>;
        /**
         * The description of the named entity.
         */
        entityDescription?: pulumi.Input<string>;
        /**
         * The name of the named entity.
         */
        entityName: pulumi.Input<string>;
        /**
         * The other names or aliases for the named entity.
         */
        entitySynonyms?: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * The type of named entity that a topic represents.
         */
        semanticEntityType?: pulumi.Input<inputs.quicksight.TopicSemanticEntityTypeArgs>;
    }
    interface TopicNamedEntityDefinitionArgs {
        /**
         * The name of the entity.
         */
        fieldName?: pulumi.Input<string>;
        /**
         * The definition of a metric.
         */
        metric?: pulumi.Input<inputs.quicksight.TopicNamedEntityDefinitionMetricArgs>;
        /**
         * The property name to be used for the named entity.
         */
        propertyName?: pulumi.Input<string>;
        /**
         * The property role. Valid values for this structure are `PRIMARY` and `ID` .
         */
        propertyRole?: pulumi.Input<enums.quicksight.TopicPropertyRole>;
        /**
         * The property usage. Valid values for this structure are `INHERIT` , `DIMENSION` , and `MEASURE` .
         */
        propertyUsage?: pulumi.Input<enums.quicksight.TopicPropertyUsage>;
    }
    interface TopicNamedEntityDefinitionMetricArgs {
        /**
         * The aggregation of a named entity. Valid values for this structure are `SUM` , `MIN` , `MAX` , `COUNT` , `AVERAGE` , `DISTINCT_COUNT` , `STDEV` , `STDEVP` , `VAR` , `VARP` , `PERCENTILE` , `MEDIAN` , and `CUSTOM` .
         */
        aggregation?: pulumi.Input<enums.quicksight.TopicNamedEntityAggType>;
        /**
         * The additional parameters for an aggregation function.
         */
        aggregationFunctionParameters?: pulumi.Input<{
            [key: string]: pulumi.Input<string>;
        }>;
    }
    interface TopicNegativeFormatArgs {
        /**
         * The prefix for a negative format.
         */
        prefix?: pulumi.Input<string>;
        /**
         * The suffix for a negative format.
         */
        suffix?: pulumi.Input<string>;
    }
    interface TopicNumericEqualityFilterArgs {
        /**
         * An aggregation function that specifies how to calculate the value of a numeric field for a topic. Valid values for this structure are `NO_AGGREGATION` , `SUM` , `AVERAGE` , `COUNT` , `DISTINCT_COUNT` , `MAX` , `MEDIAN` , `MIN` , `STDEV` , `STDEVP` , `VAR` , and `VARP` .
         */
        aggregation?: pulumi.Input<enums.quicksight.TopicNamedFilterAggType>;
        /**
         * The constant used in a numeric equality filter.
         */
        constant?: pulumi.Input<inputs.quicksight.TopicSingularFilterConstantArgs>;
    }
    interface TopicNumericRangeFilterArgs {
        /**
         * An aggregation function that specifies how to calculate the value of a numeric field for a topic, Valid values for this structure are `NO_AGGREGATION` , `SUM` , `AVERAGE` , `COUNT` , `DISTINCT_COUNT` , `MAX` , `MEDIAN` , `MIN` , `STDEV` , `STDEVP` , `VAR` , and `VARP` .
         */
        aggregation?: pulumi.Input<enums.quicksight.TopicNamedFilterAggType>;
        /**
         * The constant used in a numeric range filter.
         */
        constant?: pulumi.Input<inputs.quicksight.TopicRangeFilterConstantArgs>;
        /**
         * A Boolean value that indicates whether the endpoints of the numeric range are included in the filter. If set to true, topics whose numeric field value is equal to the endpoint values will be included in the filter. If set to false, topics whose numeric field value is equal to the endpoint values will be excluded from the filter.
         */
        inclusive?: pulumi.Input<boolean>;
    }
    interface TopicRangeConstantArgs {
        /**
         * The maximum value for a range constant.
         */
        maximum?: pulumi.Input<string>;
        /**
         * The minimum value for a range constant.
         */
        minimum?: pulumi.Input<string>;
    }
    interface TopicRangeFilterConstantArgs {
        /**
         * The data type of the constant value that is used in a range filter. Valid values for this structure are `RANGE` .
         */
        constantType?: pulumi.Input<enums.quicksight.TopicConstantType>;
        /**
         * The value of the constant that is used to specify the endpoints of a range filter.
         */
        rangeConstant?: pulumi.Input<inputs.quicksight.TopicRangeConstantArgs>;
    }
    interface TopicRelativeDateFilterArgs {
        /**
         * The constant used in a relative date filter.
         */
        constant?: pulumi.Input<inputs.quicksight.TopicSingularFilterConstantArgs>;
        /**
         * The function to be used in a relative date filter to determine the range of dates to include in the results. Valid values for this structure are `BEFORE` , `AFTER` , and `BETWEEN` .
         */
        relativeDateFilterFunction?: pulumi.Input<enums.quicksight.TopicRelativeDateFilterFunction>;
        /**
         * The level of time precision that is used to aggregate `DateTime` values.
         */
        timeGranularity?: pulumi.Input<enums.quicksight.TopicTimeGranularity>;
    }
    interface TopicSemanticEntityTypeArgs {
        /**
         * The semantic entity sub type name.
         */
        subTypeName?: pulumi.Input<string>;
        /**
         * The semantic entity type name.
         */
        typeName?: pulumi.Input<string>;
        /**
         * The semantic entity type parameters.
         */
        typeParameters?: pulumi.Input<{
            [key: string]: pulumi.Input<string>;
        }>;
    }
    interface TopicSemanticTypeArgs {
        /**
         * The semantic type falsey cell value.
         */
        falseyCellValue?: pulumi.Input<string>;
        /**
         * The other names or aliases for the false cell value.
         */
        falseyCellValueSynonyms?: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * The semantic type sub type name.
         */
        subTypeName?: pulumi.Input<string>;
        /**
         * The semantic type truthy cell value.
         */
        truthyCellValue?: pulumi.Input<string>;
        /**
         * The other names or aliases for the true cell value.
         */
        truthyCellValueSynonyms?: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * The semantic type name.
         */
        typeName?: pulumi.Input<string>;
        /**
         * The semantic type parameters.
         */
        typeParameters?: pulumi.Input<{
            [key: string]: pulumi.Input<string>;
        }>;
    }
    interface TopicSingularFilterConstantArgs {
        /**
         * The type of the singular filter constant. Valid values for this structure are `SINGULAR` .
         */
        constantType?: pulumi.Input<enums.quicksight.TopicConstantType>;
        /**
         * The value of the singular filter constant.
         */
        singularConstant?: pulumi.Input<string>;
    }
}
export declare namespace ram {
}
export declare namespace rbin {
    /**
     * The resource tag of the rule.
     */
    interface RuleResourceTagArgs {
        /**
         * The tag key of the resource.
         */
        resourceTagKey: pulumi.Input<string>;
        /**
         * The tag value of the resource
         */
        resourceTagValue: pulumi.Input<string>;
    }
    /**
     * The retention period of the rule.
     */
    interface RuleRetentionPeriodArgs {
        /**
         * The retention period unit of the rule
         */
        retentionPeriodUnit: pulumi.Input<enums.rbin.RuleRetentionPeriodRetentionPeriodUnit>;
        /**
         * The retention period value of the rule.
         */
        retentionPeriodValue: pulumi.Input<number>;
    }
    interface RuleUnlockDelayArgs {
        /**
         * The unit of time in which to measure the unlock delay. Currently, the unlock delay can be measure only in days.
         */
        unlockDelayUnit?: pulumi.Input<enums.rbin.RuleUnlockDelayUnlockDelayUnit>;
        /**
         * The unlock delay period, measured in the unit specified for UnlockDelayUnit.
         */
        unlockDelayValue?: pulumi.Input<number>;
    }
}
export declare namespace rds {
    /**
     * Describes an AWS Identity and Access Management (IAM) role that is associated with a DB cluster.
     */
    interface DbClusterDbClusterRoleArgs {
        /**
         * The name of the feature associated with the AWS Identity and Access Management (IAM) role. IAM roles that are associated with a DB cluster grant permission for the DB cluster to access other AWS services on your behalf. For the list of supported feature names, see the ``SupportedFeatureNames`` description in [DBEngineVersion](https://docs.aws.amazon.com/AmazonRDS/latest/APIReference/API_DBEngineVersion.html) in the *Amazon RDS API Reference*.
         */
        featureName?: pulumi.Input<string>;
        /**
         * The Amazon Resource Name (ARN) of the IAM role that is associated with the DB cluster.
         */
        roleArn: pulumi.Input<string>;
    }
    /**
     * The ``MasterUserSecret`` return value specifies the secret managed by RDS in AWS Secrets Manager for the master user password.
     *  For more information, see [Password management with Secrets Manager](https://docs.aws.amazon.com/AmazonRDS/latest/UserGuide/rds-secrets-manager.html) in the *Amazon RDS User Guide* and [Password management with Secrets Manager](https://docs.aws.amazon.com/AmazonRDS/latest/AuroraUserGuide/rds-secrets-manager.html) in the *Amazon Aurora User Guide.*
     */
    interface DbClusterMasterUserSecretArgs {
        /**
         * The AWS KMS key identifier that is used to encrypt the secret.
         */
        kmsKeyId?: pulumi.Input<string>;
        /**
         * The Amazon Resource Name (ARN) of the secret. This parameter is a return value that you can retrieve using the ``Fn::GetAtt`` intrinsic function. For more information, see [Return values](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-rds-dbcluster.html#aws-resource-rds-dbcluster-return-values).
         */
        secretArn?: pulumi.Input<string>;
    }
    /**
     * The ``ScalingConfiguration`` property type specifies the scaling configuration of an Aurora Serverless v1 DB cluster.
     *  For more information, see [Using Amazon Aurora Serverless](https://docs.aws.amazon.com/AmazonRDS/latest/AuroraUserGuide/aurora-serverless.html) in the *Amazon Aurora User Guide*.
     *  This property is only supported for Aurora Serverless v1. For Aurora Serverless v2, Use the ``ServerlessV2ScalingConfiguration`` property.
     *  Valid for: Aurora Serverless v1 DB clusters only
     */
    interface DbClusterScalingConfigurationArgs {
        /**
         * Indicates whether to allow or disallow automatic pause for an Aurora DB cluster in ``serverless`` DB engine mode. A DB cluster can be paused only when it's idle (it has no connections).
         *   If a DB cluster is paused for more than seven days, the DB cluster might be backed up with a snapshot. In this case, the DB cluster is restored when there is a request to connect to it.
         */
        autoPause?: pulumi.Input<boolean>;
        /**
         * The maximum capacity for an Aurora DB cluster in ``serverless`` DB engine mode.
         *  For Aurora MySQL, valid capacity values are ``1``, ``2``, ``4``, ``8``, ``16``, ``32``, ``64``, ``128``, and ``256``.
         *  For Aurora PostgreSQL, valid capacity values are ``2``, ``4``, ``8``, ``16``, ``32``, ``64``, ``192``, and ``384``.
         *  The maximum capacity must be greater than or equal to the minimum capacity.
         */
        maxCapacity?: pulumi.Input<number>;
        /**
         * The minimum capacity for an Aurora DB cluster in ``serverless`` DB engine mode.
         *  For Aurora MySQL, valid capacity values are ``1``, ``2``, ``4``, ``8``, ``16``, ``32``, ``64``, ``128``, and ``256``.
         *  For Aurora PostgreSQL, valid capacity values are ``2``, ``4``, ``8``, ``16``, ``32``, ``64``, ``192``, and ``384``.
         *  The minimum capacity must be less than or equal to the maximum capacity.
         */
        minCapacity?: pulumi.Input<number>;
        /**
         * The amount of time, in seconds, that Aurora Serverless v1 tries to find a scaling point to perform seamless scaling before enforcing the timeout action. The default is 300.
         *  Specify a value between 60 and 600 seconds.
         */
        secondsBeforeTimeout?: pulumi.Input<number>;
        /**
         * The time, in seconds, before an Aurora DB cluster in ``serverless`` mode is paused.
         *  Specify a value between 300 and 86,400 seconds.
         */
        secondsUntilAutoPause?: pulumi.Input<number>;
        /**
         * The action to take when the timeout is reached, either ``ForceApplyCapacityChange`` or ``RollbackCapacityChange``.
         *   ``ForceApplyCapacityChange`` sets the capacity to the specified value as soon as possible.
         *   ``RollbackCapacityChange``, the default, ignores the capacity change if a scaling point isn't found in the timeout period.
         *   If you specify ``ForceApplyCapacityChange``, connections that prevent Aurora Serverless v1 from finding a scaling point might be dropped.
         *   For more information, see [Autoscaling for Aurora Serverless v1](https://docs.aws.amazon.com/AmazonRDS/latest/AuroraUserGuide/aurora-serverless.how-it-works.html#aurora-serverless.how-it-works.auto-scaling) in the *Amazon Aurora User Guide*.
         */
        timeoutAction?: pulumi.Input<string>;
    }
    /**
     * The ``ServerlessV2ScalingConfiguration`` property type specifies the scaling configuration of an Aurora Serverless V2 DB cluster. For more information, see [Using Amazon Aurora Serverless v2](https://docs.aws.amazon.com/AmazonRDS/latest/AuroraUserGuide/aurora-serverless-v2.html) in the *Amazon Aurora User Guide*.
     *  If you have an Aurora cluster, you must set this attribute before you add a DB instance that uses the ``db.serverless`` DB instance class. For more information, see [Clusters that use Aurora Serverless v2 must have a capacity range specified](https://docs.aws.amazon.com/AmazonRDS/latest/AuroraUserGuide/aurora-serverless-v2.requirements.html#aurora-serverless-v2.requirements.capacity-range) in the *Amazon Aurora User Guide*.
     *  This property is only supported for Aurora Serverless v2. For Aurora Serverless v1, use the ``ScalingConfiguration`` property.
     *  Valid for: Aurora Serverless v2 DB clusters
     */
    interface DbClusterServerlessV2ScalingConfigurationArgs {
        /**
         * The maximum number of Aurora capacity units (ACUs) for a DB instance in an Aurora Serverless v2 cluster. You can specify ACU values in half-step increments, such as 40, 40.5, 41, and so on. The largest value that you can use is 128.
         *  The maximum capacity must be higher than 0.5 ACUs. For more information, see [Choosing the maximum Aurora Serverless v2 capacity setting for a cluster](https://docs.aws.amazon.com/AmazonRDS/latest/AuroraUserGuide/aurora-serverless-v2.setting-capacity.html#aurora-serverless-v2.max_capacity_considerations) in the *Amazon Aurora User Guide*.
         *  Aurora automatically sets certain parameters for Aurora Serverless V2 DB instances to values that depend on the maximum ACU value in the capacity range. When you update the maximum capacity value, the ``ParameterApplyStatus`` value for the DB instance changes to ``pending-reboot``. You can update the parameter values by rebooting the DB instance after changing the capacity range.
         */
        maxCapacity?: pulumi.Input<number>;
        /**
         * The minimum number of Aurora capacity units (ACUs) for a DB instance in an Aurora Serverless v2 cluster. You can specify ACU values in half-step increments, such as 8, 8.5, 9, and so on. For Aurora versions that support the Aurora Serverless v2 auto-pause feature, the smallest value that you can use is 0. For versions that don't support Aurora Serverless v2 auto-pause, the smallest value that you can use is 0.5.
         */
        minCapacity?: pulumi.Input<number>;
        /**
         * Specifies the number of seconds an Aurora Serverless v2 DB instance must be idle before Aurora attempts to automatically pause it.
         *  Specify a value between 300 seconds (five minutes) and 86,400 seconds (one day). The default is 300 seconds.
         */
        secondsUntilAutoPause?: pulumi.Input<number>;
    }
    /**
     * Information about an AWS Identity and Access Management (IAM) role that is associated with a DB instance.
     */
    interface DbInstanceDbInstanceRoleArgs {
        /**
         * The name of the feature associated with the AWS Identity and Access Management (IAM) role. IAM roles that are associated with a DB instance grant permission for the DB instance to access other AWS services on your behalf. For the list of supported feature names, see the ``SupportedFeatureNames`` description in [DBEngineVersion](https://docs.aws.amazon.com/AmazonRDS/latest/APIReference/API_DBEngineVersion.html) in the *Amazon RDS API Reference*.
         */
        featureName: pulumi.Input<string>;
        /**
         * The Amazon Resource Name (ARN) of the IAM role that is associated with the DB instance.
         */
        roleArn: pulumi.Input<string>;
    }
    /**
     * The ``MasterUserSecret`` return value specifies the secret managed by RDS in AWS Secrets Manager for the master user password.
     *  For more information, see [Password management with Secrets Manager](https://docs.aws.amazon.com/AmazonRDS/latest/UserGuide/rds-secrets-manager.html) in the *Amazon RDS User Guide* and [Password management with Secrets Manager](https://docs.aws.amazon.com/AmazonRDS/latest/AuroraUserGuide/rds-secrets-manager.html) in the *Amazon Aurora User Guide.*
     */
    interface DbInstanceMasterUserSecretArgs {
        /**
         * The AWS KMS key identifier that is used to encrypt the secret.
         */
        kmsKeyId?: pulumi.Input<string>;
        /**
         * The Amazon Resource Name (ARN) of the secret. This parameter is a return value that you can retrieve using the ``Fn::GetAtt`` intrinsic function. For more information, see [Return values](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-rds-dbinstance.html#aws-resource-rds-dbinstance-return-values).
         */
        secretArn?: pulumi.Input<string>;
    }
    /**
     * The ``ProcessorFeature`` property type specifies the processor features of a DB instance class.
     */
    interface DbInstanceProcessorFeatureArgs {
        /**
         * The name of the processor feature. Valid names are ``coreCount`` and ``threadsPerCore``.
         */
        name?: pulumi.Input<enums.rds.DbInstanceProcessorFeatureName>;
        /**
         * The value of a processor feature.
         */
        value?: pulumi.Input<string>;
    }
    interface DbProxyAuthFormatArgs {
        /**
         * The type of authentication that the proxy uses for connections from the proxy to the underlying database.
         */
        authScheme?: pulumi.Input<enums.rds.DbProxyAuthFormatAuthScheme>;
        /**
         * The type of authentication the proxy uses for connections from clients.
         */
        clientPasswordAuthType?: pulumi.Input<enums.rds.DbProxyAuthFormatClientPasswordAuthType>;
        /**
         * A user-specified description about the authentication used by a proxy to log in as a specific database user.
         */
        description?: pulumi.Input<string>;
        /**
         * Whether to require or disallow Amazon Web Services Identity and Access Management (IAM) authentication for connections to the proxy. The ENABLED value is valid only for proxies with RDS for Microsoft SQL Server.
         */
        iamAuth?: pulumi.Input<enums.rds.DbProxyAuthFormatIamAuth>;
        /**
         * The Amazon Resource Name (ARN) representing the secret that the proxy uses to authenticate to the RDS DB instance or Aurora DB cluster. These secrets are stored within Amazon Secrets Manager.
         */
        secretArn?: pulumi.Input<string>;
    }
    interface DbProxyTargetGroupConnectionPoolConfigurationInfoFormatArgs {
        /**
         * The number of seconds for a proxy to wait for a connection to become available in the connection pool.
         */
        connectionBorrowTimeout?: pulumi.Input<number>;
        /**
         * One or more SQL statements for the proxy to run when opening each new database connection.
         */
        initQuery?: pulumi.Input<string>;
        /**
         * The maximum size of the connection pool for each target in a target group.
         */
        maxConnectionsPercent?: pulumi.Input<number>;
        /**
         * Controls how actively the proxy closes idle database connections in the connection pool.
         */
        maxIdleConnectionsPercent?: pulumi.Input<number>;
        /**
         * Each item in the list represents a class of SQL operations that normally cause all later statements in a session using a proxy to be pinned to the same underlying database connection.
         */
        sessionPinningFilters?: pulumi.Input<pulumi.Input<string>[]>;
    }
    /**
     * The ``OptionConfiguration`` property type specifies an individual option, and its settings, within an ``AWS::RDS::OptionGroup`` resource.
     */
    interface OptionGroupOptionConfigurationArgs {
        /**
         * A list of DB security groups used for this option.
         */
        dbSecurityGroupMemberships?: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * The configuration of options to include in a group.
         */
        optionName: pulumi.Input<string>;
        /**
         * The option settings to include in an option group.
         */
        optionSettings?: pulumi.Input<pulumi.Input<inputs.rds.OptionGroupOptionSettingArgs>[]>;
        /**
         * The version for the option.
         */
        optionVersion?: pulumi.Input<string>;
        /**
         * The optional port for the option.
         */
        port?: pulumi.Input<number>;
        /**
         * A list of VPC security group names used for this option.
         */
        vpcSecurityGroupMemberships?: pulumi.Input<pulumi.Input<string>[]>;
    }
    /**
     * The ``OptionSetting`` property type specifies the value for an option within an ``OptionSetting`` property.
     */
    interface OptionGroupOptionSettingArgs {
        /**
         * The name of the option that has settings that you can set.
         */
        name?: pulumi.Input<string>;
        /**
         * The current value of the option setting.
         */
        value?: pulumi.Input<string>;
    }
}
export declare namespace redshift {
    interface ClusterEndpointArgs {
        /**
         * The DNS address of the cluster. This property is read only.
         */
        address?: pulumi.Input<string>;
        /**
         * The port that the database engine is listening on. This property is read only.
         */
        port?: pulumi.Input<string>;
    }
    interface ClusterLoggingPropertiesArgs {
        /**
         * The name of an existing S3 bucket where the log files are to be stored.
         *
         * Constraints:
         *
         * - Must be in the same region as the cluster
         * - The cluster must have read bucket and put object permissions
         */
        bucketName?: pulumi.Input<string>;
        /**
         * The log destination type. An enum with possible values of `s3` and `cloudwatch` .
         */
        logDestinationType?: pulumi.Input<string>;
        /**
         * The collection of exported log types. Possible values are `connectionlog` , `useractivitylog` , and `userlog` .
         */
        logExports?: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * The prefix applied to the log file names.
         *
         * Valid characters are any letter from any language, any whitespace character, any numeric character, and the following characters: underscore ( `_` ), period ( `.` ), colon ( `:` ), slash ( `/` ), equal ( `=` ), plus ( `+` ), backslash ( `\` ), hyphen ( `-` ), at symbol ( `@` ).
         */
        s3KeyPrefix?: pulumi.Input<string>;
    }
    interface ClusterParameterGroupParameterArgs {
        /**
         * The name of the parameter.
         */
        parameterName: pulumi.Input<string>;
        /**
         * The value of the parameter. If `ParameterName` is `wlm_json_configuration`, then the maximum size of `ParameterValue` is 8000 characters.
         */
        parameterValue: pulumi.Input<string>;
    }
    interface ScheduledActionTypeArgs {
    }
}
export declare namespace redshiftserverless {
    interface NamespaceSnapshotCopyConfigurationArgs {
        /**
         * The ID of the KMS key to use to encrypt your snapshots in the destination AWS Region .
         */
        destinationKmsKeyId?: pulumi.Input<string>;
        /**
         * The destination AWS Region to copy snapshots to.
         */
        destinationRegion: pulumi.Input<string>;
        /**
         * The retention period of snapshots that are copied to the destination AWS Region .
         */
        snapshotRetentionPeriod?: pulumi.Input<number>;
    }
    interface WorkgroupArgs {
        /**
         * The base data warehouse capacity of the workgroup in Redshift Processing Units (RPUs).
         */
        baseCapacity?: pulumi.Input<number>;
        /**
         * An array of parameters to set for advanced control over a database. The options are `auto_mv` , `datestyle` , `enable_case_sensitive_identifier` , `enable_user_activity_logging` , `query_group` , `search_path` , `require_ssl` , `use_fips_ssl` , and query monitoring metrics that let you define performance boundaries. For more information about query monitoring rules and available metrics, see [Query monitoring metrics for Amazon Redshift Serverless](https://docs.aws.amazon.com/redshift/latest/dg/cm-c-wlm-query-monitoring-rules.html#cm-c-wlm-query-monitoring-metrics-serverless) .
         */
        configParameters?: pulumi.Input<pulumi.Input<inputs.redshiftserverless.WorkgroupConfigParameterArgs>[]>;
        /**
         * The creation date of the workgroup.
         */
        creationDate?: pulumi.Input<string>;
        /**
         * The endpoint that is created from the workgroup.
         */
        endpoint?: pulumi.Input<inputs.redshiftserverless.WorkgroupEndpointArgs>;
        /**
         * The value that specifies whether to enable enhanced virtual private cloud (VPC) routing, which forces Amazon Redshift Serverless to route traffic through your VPC.
         */
        enhancedVpcRouting?: pulumi.Input<boolean>;
        /**
         * The maximum data-warehouse capacity Amazon Redshift Serverless uses to serve queries. The max capacity is specified in RPUs.
         */
        maxCapacity?: pulumi.Input<number>;
        /**
         * The namespace the workgroup is associated with.
         */
        namespaceName?: pulumi.Input<string>;
        /**
         * An object that represents the price performance target settings for the workgroup.
         */
        pricePerformanceTarget?: pulumi.Input<inputs.redshiftserverless.WorkgroupPerformanceTargetArgs>;
        /**
         * A value that specifies whether the workgroup can be accessible from a public network.
         */
        publiclyAccessible?: pulumi.Input<boolean>;
        /**
         * An array of security group IDs to associate with the workgroup.
         */
        securityGroupIds?: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * The status of the workgroup.
         */
        status?: pulumi.Input<enums.redshiftserverless.WorkgroupStatus>;
        /**
         * An array of subnet IDs the workgroup is associated with.
         */
        subnetIds?: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * The name of the track for the workgroup.
         */
        trackName?: pulumi.Input<string>;
        /**
         * The Amazon Resource Name (ARN) that links to the workgroup.
         */
        workgroupArn?: pulumi.Input<string>;
        /**
         * The unique identifier of the workgroup.
         */
        workgroupId?: pulumi.Input<string>;
        /**
         * The name of the workgroup.
         */
        workgroupName?: pulumi.Input<string>;
    }
    interface WorkgroupConfigParameterArgs {
        /**
         * The key of the parameter. The options are `datestyle` , `enable_user_activity_logging` , `query_group` , `search_path` , `max_query_execution_time` , and `require_ssl` .
         */
        parameterKey?: pulumi.Input<string>;
        /**
         * The value of the parameter to set.
         */
        parameterValue?: pulumi.Input<string>;
    }
    interface WorkgroupEndpointArgs {
        /**
         * The DNS address of the VPC endpoint.
         */
        address?: pulumi.Input<string>;
        /**
         * The port that Amazon Redshift Serverless listens on.
         */
        port?: pulumi.Input<number>;
        /**
         * An array of `VpcEndpoint` objects.
         */
        vpcEndpoints?: pulumi.Input<pulumi.Input<inputs.redshiftserverless.WorkgroupVpcEndpointArgs>[]>;
    }
    interface WorkgroupNetworkInterfaceArgs {
        /**
         * The availability Zone.
         */
        availabilityZone?: pulumi.Input<string>;
        /**
         * The unique identifier of the network interface.
         */
        networkInterfaceId?: pulumi.Input<string>;
        /**
         * The IPv4 address of the network interface within the subnet.
         */
        privateIpAddress?: pulumi.Input<string>;
        /**
         * The unique identifier of the subnet.
         */
        subnetId?: pulumi.Input<string>;
    }
    interface WorkgroupPerformanceTargetArgs {
        /**
         * The target price performance level for the workgroup. Valid values include 1, 25, 50, 75, and 100. These correspond to the price performance levels LOW_COST, ECONOMICAL, BALANCED, RESOURCEFUL, and HIGH_PERFORMANCE.
         */
        level?: pulumi.Input<number>;
        /**
         * Whether the price performance target is enabled for the workgroup.
         */
        status?: pulumi.Input<enums.redshiftserverless.WorkgroupPerformanceTargetStatus>;
    }
    interface WorkgroupVpcEndpointArgs {
        /**
         * One or more network interfaces of the endpoint. Also known as an interface endpoint.
         */
        networkInterfaces?: pulumi.Input<pulumi.Input<inputs.redshiftserverless.WorkgroupNetworkInterfaceArgs>[]>;
        /**
         * The connection endpoint ID for connecting to Amazon Redshift Serverless.
         */
        vpcEndpointId?: pulumi.Input<string>;
        /**
         * The VPC identifier that the endpoint is associated with.
         */
        vpcId?: pulumi.Input<string>;
    }
}
export declare namespace refactorspaces {
    interface ApplicationApiGatewayProxyInputArgs {
        /**
         * The type of endpoint to use for the API Gateway proxy. If no value is specified in the request, the value is set to `REGIONAL` by default.
         *
         * If the value is set to `PRIVATE` in the request, this creates a private API endpoint that is isolated from the public internet. The private endpoint can only be accessed by using Amazon Virtual Private Cloud (Amazon VPC) interface endpoints for the Amazon API Gateway that has been granted access. For more information about creating a private connection with Refactor Spaces and interface endpoint ( AWS PrivateLink ) availability, see [Access Refactor Spaces using an interface endpoint ( AWS PrivateLink )](https://docs.aws.amazon.com/migrationhub-refactor-spaces/latest/userguide/vpc-interface-endpoints.html) .
         */
        endpointType?: pulumi.Input<enums.refactorspaces.ApplicationApiGatewayEndpointType>;
        /**
         * The name of the API Gateway stage. The name defaults to `prod` .
         */
        stageName?: pulumi.Input<string>;
    }
    interface RouteDefaultRouteInputArgs {
        /**
         * If set to `ACTIVE` , traffic is forwarded to this route’s service after the route is created.
         */
        activationState: pulumi.Input<enums.refactorspaces.RouteActivationState>;
    }
    interface RouteUriPathRouteInputArgs {
        /**
         * If set to `ACTIVE` , traffic is forwarded to this route’s service after the route is created.
         */
        activationState: pulumi.Input<enums.refactorspaces.RouteActivationState>;
        /**
         * If set to `true` , this option appends the source path to the service URL endpoint.
         */
        appendSourcePath?: pulumi.Input<boolean>;
        /**
         * Indicates whether to match all subpaths of the given source path. If this value is `false` , requests must match the source path exactly before they are forwarded to this route's service.
         */
        includeChildPaths?: pulumi.Input<boolean>;
        /**
         * A list of HTTP methods to match. An empty list matches all values. If a method is present, only HTTP requests using that method are forwarded to this route’s service.
         */
        methods?: pulumi.Input<pulumi.Input<enums.refactorspaces.RouteMethod>[]>;
        /**
         * This is the path that Refactor Spaces uses to match traffic. Paths must start with `/` and are relative to the base of the application. To use path parameters in the source path, add a variable in curly braces. For example, the resource path {user} represents a path parameter called 'user'.
         */
        sourcePath?: pulumi.Input<string>;
    }
    interface ServiceLambdaEndpointInputArgs {
        /**
         * The Amazon Resource Name (ARN) of the Lambda function or alias.
         */
        arn: pulumi.Input<string>;
    }
    interface ServiceUrlEndpointInputArgs {
        /**
         * The health check URL of the URL endpoint type. If the URL is a public endpoint, the `HealthUrl` must also be a public endpoint. If the URL is a private endpoint inside a virtual private cloud (VPC), the health URL must also be a private endpoint, and the host must be the same as the URL.
         */
        healthUrl?: pulumi.Input<string>;
        /**
         * The URL to route traffic to. The URL must be an [rfc3986-formatted URL](https://docs.aws.amazon.com/https://datatracker.ietf.org/doc/html/rfc3986) . If the host is a domain name, the name must be resolvable over the public internet. If the scheme is `https` , the top level domain of the host must be listed in the [IANA root zone database](https://docs.aws.amazon.com/https://www.iana.org/domains/root/db) .
         */
        url: pulumi.Input<string>;
    }
}
export declare namespace rekognition {
    /**
     * A bounding box denoting a region of interest in the frame to be analyzed.
     */
    interface StreamProcessorBoundingBoxArgs {
        /**
         * Height of the bounding box as a ratio of the overall image height.
         */
        height: pulumi.Input<number>;
        /**
         * Left coordinate of the bounding box as a ratio of overall image width.
         */
        left: pulumi.Input<number>;
        /**
         * Top coordinate of the bounding box as a ratio of overall image height.
         */
        top: pulumi.Input<number>;
        /**
         * Width of the bounding box as a ratio of the overall image width.
         */
        width: pulumi.Input<number>;
    }
    /**
     * Connected home settings to use on a streaming video. Note that either ConnectedHomeSettings or FaceSearchSettings should be set. Not both
     */
    interface StreamProcessorConnectedHomeSettingsArgs {
        /**
         * Specifies what you want to detect in the video, such as people, packages, or pets. The current valid labels you can include in this list are: "PERSON", "PET", "PACKAGE", and "ALL".
         */
        labels: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * Minimum object class match confidence score that must be met to return a result for a recognized object.
         */
        minConfidence?: pulumi.Input<number>;
    }
    /**
     * Indicates whether Rekognition is allowed to store the video stream data for model-training.
     */
    interface StreamProcessorDataSharingPreferenceArgs {
        /**
         * Flag to enable data-sharing
         */
        optIn: pulumi.Input<boolean>;
    }
    /**
     * Face search settings to use on a streaming video. Note that either FaceSearchSettings or ConnectedHomeSettings should be set. Not both
     */
    interface StreamProcessorFaceSearchSettingsArgs {
        /**
         * The ID of a collection that contains faces that you want to search for.
         */
        collectionId: pulumi.Input<string>;
        /**
         * Minimum face match confidence score percentage that must be met to return a result for a recognized face. The default is 80. 0 is the lowest confidence. 100 is the highest confidence. Values between 0 and 100 are accepted.
         */
        faceMatchThreshold?: pulumi.Input<number>;
    }
    /**
     * The Amazon Kinesis Data Stream stream to which the Amazon Rekognition stream processor streams the analysis results, as part of face search feature.
     */
    interface StreamProcessorKinesisDataStreamArgs {
        /**
         * ARN of the Kinesis Data Stream stream.
         */
        arn: pulumi.Input<string>;
    }
    /**
     * The Kinesis Video Stream that streams the source video.
     */
    interface StreamProcessorKinesisVideoStreamArgs {
        /**
         * ARN of the Kinesis Video Stream that streams the source video.
         */
        arn: pulumi.Input<string>;
    }
    /**
     * The ARN of the SNS notification channel where events of interests are published, as part of connected home feature.
     */
    interface StreamProcessorNotificationChannelArgs {
        /**
         * ARN of the SNS topic.
         */
        arn: pulumi.Input<string>;
    }
    /**
     * An (X, Y) cartesian coordinate denoting a point on the frame
     */
    interface StreamProcessorPointArgs {
        /**
         * The X coordinate of the point.
         */
        x: pulumi.Input<number>;
        /**
         * The Y coordinate of the point.
         */
        y: pulumi.Input<number>;
    }
    /**
     * The S3 location in customer's account where inference output & artifacts are stored, as part of connected home feature.
     */
    interface StreamProcessorS3DestinationArgs {
        /**
         * Name of the S3 bucket.
         */
        bucketName: pulumi.Input<string>;
        /**
         * The object key prefix path where the results will be stored. Default is no prefix path
         */
        objectKeyPrefix?: pulumi.Input<string>;
    }
}
export declare namespace resiliencehub {
    /**
     * Indicates an event you would like to subscribe and get notification for.
     */
    interface AppEventSubscriptionArgs {
        /**
         * The type of event you would like to subscribe and get notification for.
         */
        eventType: pulumi.Input<enums.resiliencehub.AppEventSubscriptionEventType>;
        /**
         * Unique name to identify an event subscription.
         */
        name: pulumi.Input<string>;
        /**
         * Amazon Resource Name (ARN) of the Amazon Simple Notification Service topic.
         */
        snsTopicArn?: pulumi.Input<string>;
    }
    /**
     * Defines the roles and credentials that AWS Resilience Hub would use while creating the application, importing its resources, and running an assessment.
     */
    interface AppPermissionModelArgs {
        /**
         * Defines a list of role Amazon Resource Names (ARNs) to be used in other accounts. These ARNs are used for querying purposes while importing resources and assessing your application.
         */
        crossAccountRoleArns?: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * Existing AWS IAM role name in the primary AWS account that will be assumed by AWS Resilience Hub Service Principle to obtain a read-only access to your application resources while running an assessment.
         */
        invokerRoleName?: pulumi.Input<string>;
        /**
         * Defines how AWS Resilience Hub scans your resources. It can scan for the resources by using a pre-existing role in your AWS account, or by using the credentials of the current IAM user.
         */
        type: pulumi.Input<enums.resiliencehub.AppPermissionModelType>;
    }
    interface AppPhysicalResourceIdArgs {
        /**
         * The AWS account that owns the physical resource.
         */
        awsAccountId?: pulumi.Input<string>;
        /**
         * The AWS Region that the physical resource is located in.
         */
        awsRegion?: pulumi.Input<string>;
        /**
         * Identifier of the physical resource.
         */
        identifier: pulumi.Input<string>;
        /**
         * Specifies the type of physical resource identifier.
         *
         * - **Arn** - The resource identifier is an Amazon Resource Name (ARN) and it can identify the following list of resources:
         *
         * - `AWS::ECS::Service`
         * - `AWS::EFS::FileSystem`
         * - `AWS::ElasticLoadBalancingV2::LoadBalancer`
         * - `AWS::Lambda::Function`
         * - `AWS::SNS::Topic`
         * - **Native** - The resource identifier is an AWS Resilience Hub -native identifier and it can identify the following list of resources:
         *
         * - `AWS::ApiGateway::RestApi`
         * - `AWS::ApiGatewayV2::Api`
         * - `AWS::AutoScaling::AutoScalingGroup`
         * - `AWS::DocDB::DBCluster`
         * - `AWS::DocDB::DBGlobalCluster`
         * - `AWS::DocDB::DBInstance`
         * - `AWS::DynamoDB::GlobalTable`
         * - `AWS::DynamoDB::Table`
         * - `AWS::EC2::EC2Fleet`
         * - `AWS::EC2::Instance`
         * - `AWS::EC2::NatGateway`
         * - `AWS::EC2::Volume`
         * - `AWS::ElasticLoadBalancing::LoadBalancer`
         * - `AWS::RDS::DBCluster`
         * - `AWS::RDS::DBInstance`
         * - `AWS::RDS::GlobalCluster`
         * - `AWS::Route53::RecordSet`
         * - `AWS::S3::Bucket`
         * - `AWS::SQS::Queue`
         */
        type: pulumi.Input<string>;
    }
    /**
     * Resource mapping is used to map logical resources from template to physical resource
     */
    interface AppResourceMappingArgs {
        /**
         * Name of the Amazon Elastic Kubernetes Service cluster and namespace that this resource is mapped to when the `mappingType` is `EKS` .
         *
         * > This parameter accepts values in "eks-cluster/namespace" format.
         */
        eksSourceName?: pulumi.Input<string>;
        /**
         * Name of the AWS CloudFormation stack this resource is mapped to when the `mappingType` is `CfnStack` .
         */
        logicalStackName?: pulumi.Input<string>;
        /**
         * Specifies the type of resource mapping.
         */
        mappingType: pulumi.Input<string>;
        /**
         * Identifier of the physical resource.
         */
        physicalResourceId: pulumi.Input<inputs.resiliencehub.AppPhysicalResourceIdArgs>;
        /**
         * Name of the resource that this resource is mapped to when the `mappingType` is `Resource` .
         */
        resourceName?: pulumi.Input<string>;
        /**
         * Name of the Terraform source that this resource is mapped to when the `mappingType` is `Terraform` .
         */
        terraformSourceName?: pulumi.Input<string>;
    }
    /**
     * Failure Policy.
     */
    interface ResiliencyPolicyFailurePolicyArgs {
        /**
         * RPO in seconds.
         */
        rpoInSecs: pulumi.Input<number>;
        /**
         * RTO in seconds.
         */
        rtoInSecs: pulumi.Input<number>;
    }
    interface ResiliencyPolicyPolicyMapArgs {
        /**
         * Defines the RTO and RPO targets for Availability Zone disruption.
         */
        az: pulumi.Input<inputs.resiliencehub.ResiliencyPolicyFailurePolicyArgs>;
        /**
         * Defines the RTO and RPO targets for hardware disruption.
         */
        hardware: pulumi.Input<inputs.resiliencehub.ResiliencyPolicyFailurePolicyArgs>;
        /**
         * Defines the RTO and RPO targets for Regional disruption.
         */
        region?: pulumi.Input<inputs.resiliencehub.ResiliencyPolicyFailurePolicyArgs>;
        /**
         * Defines the RTO and RPO targets for software disruption.
         */
        software: pulumi.Input<inputs.resiliencehub.ResiliencyPolicyFailurePolicyArgs>;
    }
}
export declare namespace resourceexplorer2 {
    interface ViewIncludedPropertyArgs {
        /**
         * The name of the property that is included in this view.
         */
        name: pulumi.Input<string>;
    }
    interface ViewSearchFilterArgs {
        /**
         * The string that contains the search keywords, prefixes, and operators to control the results that can be returned by a Search operation.
         *
         * For information about the supported syntax, see [Search query reference](https://docs.aws.amazon.com/resource-explorer/latest/userguide/using-search-query-syntax.html) in the *AWS Resource Explorer User Guide* .
         *
         * > This query string in the context of this operation supports only [filter prefixes](https://docs.aws.amazon.com/resource-explorer/latest/userguide/using-search-query-syntax.html#query-syntax-filters) with optional [operators](https://docs.aws.amazon.com/resource-explorer/latest/userguide/using-search-query-syntax.html#query-syntax-operators) . It doesn't support free-form text. For example, the string `region:us* service:ec2 -tag:stage=prod` includes all Amazon EC2 resources in any AWS Region that begin with the letters `us` and are *not* tagged with a key `Stage` that has the value `prod` .
         */
        filterString: pulumi.Input<string>;
    }
}
export declare namespace resourcegroups {
    interface GroupConfigurationItemArgs {
        parameters?: pulumi.Input<pulumi.Input<inputs.resourcegroups.GroupConfigurationParameterArgs>[]>;
        type?: pulumi.Input<string>;
    }
    interface GroupConfigurationParameterArgs {
        name?: pulumi.Input<string>;
        values?: pulumi.Input<pulumi.Input<string>[]>;
    }
    interface GroupQueryArgs {
        /**
         * Specifies limits to the types of resources that can be included in the resource group. For example, if `ResourceTypeFilters` is `["AWS::EC2::Instance", "AWS::DynamoDB::Table"]` , only EC2 instances or DynamoDB tables can be members of this resource group. The default value is `["AWS::AllSupported"]` .
         */
        resourceTypeFilters?: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * Specifies the ARN of a CloudFormation stack. All supported resources of the CloudFormation stack are members of the resource group. If you don't specify an ARN, this parameter defaults to the current stack that you are defining, which means that all the resources of the current stack are grouped.
         *
         * You can specify a value for `StackIdentifier` only when the `ResourceQuery.Type` property is `CLOUDFORMATION_STACK_1_0.`
         */
        stackIdentifier?: pulumi.Input<string>;
        /**
         * A list of key-value pair objects that limit which resources can be members of the resource group. This property is required when the `ResourceQuery.Type` property is `TAG_FILTERS_1_0` .
         *
         * A resource must have a tag that matches every filter that is provided in the `TagFilters` list.
         */
        tagFilters?: pulumi.Input<pulumi.Input<inputs.resourcegroups.GroupTagFilterArgs>[]>;
    }
    interface GroupResourceQueryArgs {
        /**
         * The query that defines the membership of the group. This is a structure with properties that depend on the `Type` .
         *
         * The `Query` structure must be included in the following scenarios:
         *
         * - When the `Type` is `TAG_FILTERS_1_0` , you must specify a `Query` structure that contains a `TagFilters` list of tags. Resources with tags that match those in the `TagFilter` list become members of the resource group.
         * - When the `Type` is `CLOUDFORMATION_STACK_1_0` then this field is required only when you must specify a CloudFormation stack other than the one you are defining. To do this, the `Query` structure must contain the `StackIdentifier` property. If you don't specify either a `Query` structure or a `StackIdentifier` within that `Query` , then it defaults to the CloudFormation stack that you're currently constructing.
         */
        query?: pulumi.Input<inputs.resourcegroups.GroupQueryArgs>;
        /**
         * Specifies the type of resource query that determines this group's membership. There are two valid query types:
         *
         * - `TAG_FILTERS_1_0` indicates that the group is a tag-based group. To complete the group membership, you must include the `TagFilters` property to specify the tag filters to use in the query.
         * - `CLOUDFORMATION_STACK_1_0` , the default, indicates that the group is a CloudFormation stack-based group. Group membership is based on the CloudFormation stack. You must specify the `StackIdentifier` property in the query to define which stack to associate the group with, or leave it empty to default to the stack where the group is defined.
         */
        type?: pulumi.Input<enums.resourcegroups.GroupResourceQueryType>;
    }
    interface GroupTagFilterArgs {
        /**
         * A string that defines a tag key. Only resources in the account that are tagged with a specified tag key are members of the tag-based resource group.
         *
         * This field is required when the `ResourceQuery` structure's `Type` property is `TAG_FILTERS_1_0` . You must specify at least one tag key.
         */
        key?: pulumi.Input<string>;
        /**
         * A list of tag values that can be included in the tag-based resource group. This is optional. If you don't specify a value or values for a key, then an AWS resource with any value for that key is a member.
         */
        values?: pulumi.Input<pulumi.Input<string>[]>;
    }
}
export declare namespace robomaker {
    /**
     * The robot software suite used by the robot application.
     */
    interface RobotApplicationRobotSoftwareSuiteArgs {
        /**
         * The name of robot software suite.
         */
        name: pulumi.Input<enums.robomaker.RobotApplicationRobotSoftwareSuiteName>;
        /**
         * The version of robot software suite.
         */
        version?: pulumi.Input<enums.robomaker.RobotApplicationRobotSoftwareSuiteVersion>;
    }
    interface RobotApplicationSourceConfigArgs {
        /**
         * The architecture of robot application.
         */
        architecture: pulumi.Input<enums.robomaker.RobotApplicationSourceConfigArchitecture>;
        /**
         * The Arn of the S3Bucket that stores the robot application source.
         */
        s3Bucket: pulumi.Input<string>;
        /**
         * The s3 key of robot application source.
         */
        s3Key: pulumi.Input<string>;
    }
    /**
     * Information about a rendering engine.
     */
    interface SimulationApplicationRenderingEngineArgs {
        /**
         * The name of the rendering engine.
         */
        name: pulumi.Input<enums.robomaker.SimulationApplicationRenderingEngineName>;
        /**
         * The version of the rendering engine.
         */
        version: pulumi.Input<string>;
    }
    /**
     * Information about a robot software suite.
     */
    interface SimulationApplicationRobotSoftwareSuiteArgs {
        /**
         * The name of the robot software suite.
         */
        name: pulumi.Input<enums.robomaker.SimulationApplicationRobotSoftwareSuiteName>;
        /**
         * The version of the robot software suite.
         */
        version?: pulumi.Input<enums.robomaker.SimulationApplicationRobotSoftwareSuiteVersion>;
    }
    /**
     * Information about a simulation software suite.
     */
    interface SimulationApplicationSimulationSoftwareSuiteArgs {
        /**
         * The name of the simulation software suite.
         */
        name: pulumi.Input<enums.robomaker.SimulationApplicationSimulationSoftwareSuiteName>;
        /**
         * The version of the simulation software suite.
         */
        version?: pulumi.Input<enums.robomaker.SimulationApplicationSimulationSoftwareSuiteVersion>;
    }
    /**
     * Information about a source configuration.
     */
    interface SimulationApplicationSourceConfigArgs {
        /**
         * The target processor architecture for the application.
         */
        architecture: pulumi.Input<enums.robomaker.SimulationApplicationSourceConfigArchitecture>;
        /**
         * The Amazon S3 bucket name.
         */
        s3Bucket: pulumi.Input<string>;
        /**
         * The s3 object key.
         */
        s3Key: pulumi.Input<string>;
    }
}
export declare namespace rolesanywhere {
    interface ProfileAttributeMappingArgs {
        /**
         * Fields (x509Subject, x509Issuer and x509SAN) within X.509 certificates.
         */
        certificateField: pulumi.Input<enums.rolesanywhere.ProfileCertificateField>;
        /**
         * A list of mapping entries for every supported specifier or sub-field.
         */
        mappingRules: pulumi.Input<pulumi.Input<inputs.rolesanywhere.ProfileMappingRuleArgs>[]>;
    }
    interface ProfileMappingRuleArgs {
        /**
         * Specifier within a certificate field, such as CN, OU, or UID from the Subject field.
         */
        specifier: pulumi.Input<string>;
    }
    interface TrustAnchorNotificationSettingArgs {
        /**
         * The specified channel of notification. IAM Roles Anywhere uses CloudWatch metrics, EventBridge, and AWS Health Dashboard to notify for an event.
         *
         * > In the absence of a specific channel, IAM Roles Anywhere applies this setting to 'ALL' channels.
         */
        channel?: pulumi.Input<enums.rolesanywhere.TrustAnchorNotificationChannel>;
        /**
         * Indicates whether the notification setting is enabled.
         */
        enabled: pulumi.Input<boolean>;
        /**
         * The event to which this notification setting is applied.
         */
        event: pulumi.Input<enums.rolesanywhere.TrustAnchorNotificationEvent>;
        /**
         * The number of days before a notification event. This value is required for a notification setting that is enabled.
         */
        threshold?: pulumi.Input<number>;
    }
    interface TrustAnchorSourceArgs {
        /**
         * A union object representing the data field of the TrustAnchor depending on its type
         */
        sourceData?: pulumi.Input<inputs.rolesanywhere.TrustAnchorSourceData0PropertiesArgs | inputs.rolesanywhere.TrustAnchorSourceData1PropertiesArgs>;
        /**
         * The type of the TrustAnchor.
         */
        sourceType?: pulumi.Input<enums.rolesanywhere.TrustAnchorType>;
    }
    interface TrustAnchorSourceData0PropertiesArgs {
        x509CertificateData: pulumi.Input<string>;
    }
    interface TrustAnchorSourceData1PropertiesArgs {
        acmPcaArn: pulumi.Input<string>;
    }
}
export declare namespace route53 {
    interface CidrCollectionLocationArgs {
        /**
         * A list of CIDR blocks.
         */
        cidrList: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * The name of the location that is associated with the CIDR collection.
         */
        locationName: pulumi.Input<string>;
    }
    /**
     * A complex type that identifies the CloudWatch alarm that you want Amazon Route 53 health checkers to use to determine whether the specified health check is healthy.
     */
    interface HealthCheckAlarmIdentifierArgs {
        /**
         * The name of the CloudWatch alarm that you want Amazon Route 53 health checkers to use to determine whether this health check is healthy.
         */
        name: pulumi.Input<string>;
        /**
         * For the CloudWatch alarm that you want Route 53 health checkers to use to determine whether this health check is healthy, the region that the alarm was created in.
         */
        region: pulumi.Input<string>;
    }
    /**
     * A complex type that contains information about the health check.
     */
    interface HealthCheckConfigPropertiesArgs {
        /**
         * A complex type that identifies the CloudWatch alarm that you want Amazon Route 53 health checkers to use to determine whether the specified health check is healthy.
         */
        alarmIdentifier?: pulumi.Input<inputs.route53.HealthCheckAlarmIdentifierArgs>;
        /**
         * (CALCULATED Health Checks Only) A complex type that contains one `ChildHealthCheck` element for each health check that you want to associate with a `CALCULATED` health check.
         */
        childHealthChecks?: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * Specify whether you want Amazon Route 53 to send the value of `FullyQualifiedDomainName` to the endpoint in the `client_hello` message during TLS negotiation. This allows the endpoint to respond to `HTTPS` health check requests with the applicable SSL/TLS certificate.
         *
         * Some endpoints require that `HTTPS` requests include the host name in the `client_hello` message. If you don't enable SNI, the status of the health check will be `SSL alert handshake_failure` . A health check can also have that status for other reasons. If SNI is enabled and you're still getting the error, check the SSL/TLS configuration on your endpoint and confirm that your certificate is valid.
         *
         * The SSL/TLS certificate on your endpoint includes a domain name in the `Common Name` field and possibly several more in the `Subject Alternative Names` field. One of the domain names in the certificate should match the value that you specify for `FullyQualifiedDomainName` . If the endpoint responds to the `client_hello` message with a certificate that does not include the domain name that you specified in `FullyQualifiedDomainName` , a health checker will retry the handshake. In the second attempt, the health checker will omit `FullyQualifiedDomainName` from the `client_hello` message.
         */
        enableSni?: pulumi.Input<boolean>;
        /**
         * The number of consecutive health checks that an endpoint must pass or fail for Amazon Route 53 to change the current status of the endpoint from unhealthy to healthy or vice versa. For more information, see [How Amazon Route 53 Determines Whether an Endpoint Is Healthy](https://docs.aws.amazon.com/Route53/latest/DeveloperGuide/dns-failover-determining-health-of-endpoints.html) in the *Amazon Route 53 Developer Guide* .
         *
         * If you don't specify a value for `FailureThreshold` , the default value is three health checks.
         */
        failureThreshold?: pulumi.Input<number>;
        /**
         * Amazon Route 53 behavior depends on whether you specify a value for `IPAddress` .
         *
         * *If you specify a value for* `IPAddress` :
         *
         * Amazon Route 53 sends health check requests to the specified IPv4 or IPv6 address and passes the value of `FullyQualifiedDomainName` in the `Host` header for all health checks except TCP health checks. This is typically the fully qualified DNS name of the endpoint on which you want Route 53 to perform health checks.
         *
         * When Route 53 checks the health of an endpoint, here is how it constructs the `Host` header:
         *
         * - If you specify a value of `80` for `Port` and `HTTP` or `HTTP_STR_MATCH` for `Type` , Route 53 passes the value of `FullyQualifiedDomainName` to the endpoint in the Host header.
         * - If you specify a value of `443` for `Port` and `HTTPS` or `HTTPS_STR_MATCH` for `Type` , Route 53 passes the value of `FullyQualifiedDomainName` to the endpoint in the `Host` header.
         * - If you specify another value for `Port` and any value except `TCP` for `Type` , Route 53 passes `FullyQualifiedDomainName:Port` to the endpoint in the `Host` header.
         *
         * If you don't specify a value for `FullyQualifiedDomainName` , Route 53 substitutes the value of `IPAddress` in the `Host` header in each of the preceding cases.
         *
         * *If you don't specify a value for `IPAddress`* :
         *
         * Route 53 sends a DNS request to the domain that you specify for `FullyQualifiedDomainName` at the interval that you specify for `RequestInterval` . Using an IPv4 address that DNS returns, Route 53 then checks the health of the endpoint.
         *
         * > If you don't specify a value for `IPAddress` , Route 53 uses only IPv4 to send health checks to the endpoint. If there's no record with a type of A for the name that you specify for `FullyQualifiedDomainName` , the health check fails with a "DNS resolution failed" error.
         *
         * If you want to check the health of multiple records that have the same name and type, such as multiple weighted records, and if you choose to specify the endpoint only by `FullyQualifiedDomainName` , we recommend that you create a separate health check for each endpoint. For example, create a health check for each HTTP server that is serving content for www.example.com. For the value of `FullyQualifiedDomainName` , specify the domain name of the server (such as us-east-2-www.example.com), not the name of the records (www.example.com).
         *
         * > In this configuration, if you create a health check for which the value of `FullyQualifiedDomainName` matches the name of the records and you then associate the health check with those records, health check results will be unpredictable.
         *
         * In addition, if the value that you specify for `Type` is `HTTP` , `HTTPS` , `HTTP_STR_MATCH` , or `HTTPS_STR_MATCH` , Route 53 passes the value of `FullyQualifiedDomainName` in the `Host` header, as it does when you specify a value for `IPAddress` . If the value of `Type` is `TCP` , Route 53 doesn't pass a `Host` header.
         */
        fullyQualifiedDomainName?: pulumi.Input<string>;
        /**
         * The number of child health checks that are associated with a `CALCULATED` health check that Amazon Route 53 must consider healthy for the `CALCULATED` health check to be considered healthy. To specify the child health checks that you want to associate with a `CALCULATED` health check, use the [ChildHealthChecks](https://docs.aws.amazon.com/Route53/latest/APIReference/API_UpdateHealthCheck.html#Route53-UpdateHealthCheck-request-ChildHealthChecks) element.
         *
         * Note the following:
         *
         * - If you specify a number greater than the number of child health checks, Route 53 always considers this health check to be unhealthy.
         * - If you specify `0` , Route 53 always considers this health check to be healthy.
         */
        healthThreshold?: pulumi.Input<number>;
        /**
         * When CloudWatch has insufficient data about the metric to determine the alarm state, the status that you want Amazon Route 53 to assign to the health check:
         *
         * - `Healthy` : Route 53 considers the health check to be healthy.
         * - `Unhealthy` : Route 53 considers the health check to be unhealthy.
         * - `LastKnownStatus` : Route 53 uses the status of the health check from the last time that CloudWatch had sufficient data to determine the alarm state. For new health checks that have no last known status, the default status for the health check is healthy.
         */
        insufficientDataHealthStatus?: pulumi.Input<enums.route53.HealthCheckConfigPropertiesInsufficientDataHealthStatus>;
        /**
         * Specify whether you want Amazon Route 53 to invert the status of a health check, for example, to consider a health check unhealthy when it otherwise would be considered healthy.
         */
        inverted?: pulumi.Input<boolean>;
        /**
         * The IPv4 or IPv6 IP address of the endpoint that you want Amazon Route 53 to perform health checks on. If you don't specify a value for `IPAddress` , Route 53 sends a DNS request to resolve the domain name that you specify in `FullyQualifiedDomainName` at the interval that you specify in `RequestInterval` . Using an IP address returned by DNS, Route 53 then checks the health of the endpoint.
         *
         * Use one of the following formats for the value of `IPAddress` :
         *
         * - *IPv4 address* : four values between 0 and 255, separated by periods (.), for example, `192.0.2.44` .
         * - *IPv6 address* : eight groups of four hexadecimal values, separated by colons (:), for example, `2001:0db8:85a3:0000:0000:abcd:0001:2345` . You can also shorten IPv6 addresses as described in RFC 5952, for example, `2001:db8:85a3::abcd:1:2345` .
         *
         * If the endpoint is an EC2 instance, we recommend that you create an Elastic IP address, associate it with your EC2 instance, and specify the Elastic IP address for `IPAddress` . This ensures that the IP address of your instance will never change.
         *
         * For more information, see [FullyQualifiedDomainName](https://docs.aws.amazon.com/Route53/latest/APIReference/API_UpdateHealthCheck.html#Route53-UpdateHealthCheck-request-FullyQualifiedDomainName) .
         *
         * Constraints: Route 53 can't check the health of endpoints for which the IP address is in local, private, non-routable, or multicast ranges. For more information about IP addresses for which you can't create health checks, see the following documents:
         *
         * - [RFC 5735, Special Use IPv4 Addresses](https://docs.aws.amazon.com/https://tools.ietf.org/html/rfc5735)
         * - [RFC 6598, IANA-Reserved IPv4 Prefix for Shared Address Space](https://docs.aws.amazon.com/https://tools.ietf.org/html/rfc6598)
         * - [RFC 5156, Special-Use IPv6 Addresses](https://docs.aws.amazon.com/https://tools.ietf.org/html/rfc5156)
         *
         * When the value of `Type` is `CALCULATED` or `CLOUDWATCH_METRIC` , omit `IPAddress` .
         */
        ipAddress?: pulumi.Input<string>;
        /**
         * Specify whether you want Amazon Route 53 to measure the latency between health checkers in multiple AWS regions and your endpoint, and to display CloudWatch latency graphs on the *Health Checks* page in the Route 53 console.
         *
         * > You can't change the value of `MeasureLatency` after you create a health check.
         */
        measureLatency?: pulumi.Input<boolean>;
        /**
         * The port on the endpoint that you want Amazon Route 53 to perform health checks on.
         *
         * > Don't specify a value for `Port` when you specify a value for [Type](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-route53-healthcheck-healthcheckconfig.html#cfn-route53-healthcheck-healthcheckconfig-type) of `CLOUDWATCH_METRIC` or `CALCULATED` .
         */
        port?: pulumi.Input<number>;
        /**
         * A complex type that contains one `Region` element for each region from which you want Amazon Route 53 health checkers to check the specified endpoint.
         *
         * If you don't specify any regions, Route 53 health checkers automatically performs checks from all of the regions that are listed under *Valid Values* .
         *
         * If you update a health check to remove a region that has been performing health checks, Route 53 will briefly continue to perform checks from that region to ensure that some health checkers are always checking the endpoint (for example, if you replace three regions with four different regions).
         */
        regions?: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * The number of seconds between the time that Amazon Route 53 gets a response from your endpoint and the time that it sends the next health check request. Each Route 53 health checker makes requests at this interval.
         *
         * > You can't change the value of `RequestInterval` after you create a health check.
         *
         * If you don't specify a value for `RequestInterval` , the default value is `30` seconds.
         */
        requestInterval?: pulumi.Input<number>;
        /**
         * The path, if any, that you want Amazon Route 53 to request when performing health checks. The path can be any value for which your endpoint will return an HTTP status code of 2xx or 3xx when the endpoint is healthy, for example, the file /docs/route53-health-check.html. You can also include query string parameters, for example, `/welcome.html?language=jp&login=y` .
         */
        resourcePath?: pulumi.Input<string>;
        /**
         * The Amazon Resource Name (ARN) for the Route 53 Application Recovery Controller routing control.
         *
         * For more information about Route 53 Application Recovery Controller, see [Route 53 Application Recovery Controller Developer Guide.](https://docs.aws.amazon.com/r53recovery/latest/dg/what-is-route-53-recovery.html) .
         */
        routingControlArn?: pulumi.Input<string>;
        /**
         * If the value of Type is `HTTP_STR_MATCH` or `HTTPS_STR_MATCH` , the string that you want Amazon Route 53 to search for in the response body from the specified resource. If the string appears in the response body, Route 53 considers the resource healthy.
         *
         * Route 53 considers case when searching for `SearchString` in the response body.
         */
        searchString?: pulumi.Input<string>;
        /**
         * The type of health check that you want to create, which indicates how Amazon Route 53 determines whether an endpoint is healthy.
         *
         * > You can't change the value of `Type` after you create a health check.
         *
         * You can create the following types of health checks:
         *
         * - *HTTP* : Route 53 tries to establish a TCP connection. If successful, Route 53 submits an HTTP request and waits for an HTTP status code of 200 or greater and less than 400.
         * - *HTTPS* : Route 53 tries to establish a TCP connection. If successful, Route 53 submits an HTTPS request and waits for an HTTP status code of 200 or greater and less than 400.
         *
         * > If you specify `HTTPS` for the value of `Type` , the endpoint must support TLS v1.0 or later.
         * - *HTTP_STR_MATCH* : Route 53 tries to establish a TCP connection. If successful, Route 53 submits an HTTP request and searches the first 5,120 bytes of the response body for the string that you specify in `SearchString` .
         * - *HTTPS_STR_MATCH* : Route 53 tries to establish a TCP connection. If successful, Route 53 submits an `HTTPS` request and searches the first 5,120 bytes of the response body for the string that you specify in `SearchString` .
         * - *TCP* : Route 53 tries to establish a TCP connection.
         * - *CLOUDWATCH_METRIC* : The health check is associated with a CloudWatch alarm. If the state of the alarm is `OK` , the health check is considered healthy. If the state is `ALARM` , the health check is considered unhealthy. If CloudWatch doesn't have sufficient data to determine whether the state is `OK` or `ALARM` , the health check status depends on the setting for `InsufficientDataHealthStatus` : `Healthy` , `Unhealthy` , or `LastKnownStatus` .
         *
         * > Route 53 supports CloudWatch alarms with the following features:
         * >
         * > - Standard-resolution metrics. High-resolution metrics aren't supported. For more information, see [High-Resolution Metrics](https://docs.aws.amazon.com/AmazonCloudWatch/latest/DeveloperGuide/publishingMetrics.html#high-resolution-metrics) in the *Amazon CloudWatch User Guide* .
         * > - Statistics: Average, Minimum, Maximum, Sum, and SampleCount. Extended statistics aren't supported.
         * - *CALCULATED* : For health checks that monitor the status of other health checks, Route 53 adds up the number of health checks that Route 53 health checkers consider to be healthy and compares that number with the value of `HealthThreshold` .
         * - *RECOVERY_CONTROL* : The health check is assocated with a Route53 Application Recovery Controller routing control. If the routing control state is `ON` , the health check is considered healthy. If the state is `OFF` , the health check is considered unhealthy.
         *
         * For more information, see [How Route 53 Determines Whether an Endpoint Is Healthy](https://docs.aws.amazon.com/Route53/latest/DeveloperGuide/dns-failover-determining-health-of-endpoints.html) in the *Amazon Route 53 Developer Guide* .
         */
        type: pulumi.Input<enums.route53.HealthCheckConfigPropertiesType>;
    }
    /**
     * A key-value pair to associate with a resource.
     */
    interface HealthCheckTagArgs {
        /**
         * The key name of the tag.
         */
        key: pulumi.Input<string>;
        /**
         * The value for the tag.
         */
        value: pulumi.Input<string>;
    }
    /**
     * A complex type that contains an optional comment about your hosted zone. If you don't want to specify a comment, omit both the ``HostedZoneConfig`` and ``Comment`` elements.
     */
    interface HostedZoneConfigArgs {
        /**
         * Any comments that you want to include about the hosted zone.
         */
        comment?: pulumi.Input<string>;
    }
    /**
     * A complex type that contains information about a configuration for DNS query logging.
     */
    interface HostedZoneQueryLoggingConfigArgs {
        /**
         * The Amazon Resource Name (ARN) of the CloudWatch Logs log group that Amazon Route 53 is publishing logs to.
         */
        cloudWatchLogsLogGroupArn: pulumi.Input<string>;
    }
    /**
     * *Private hosted zones only:* A complex type that contains information about an Amazon VPC. Route 53 Resolver uses the records in the private hosted zone to route traffic in that VPC.
     *   For public hosted zones, omit ``VPCs``, ``VPCId``, and ``VPCRegion``.
     */
    interface HostedZoneVpcArgs {
        /**
         * *Private hosted zones only:* The ID of an Amazon VPC.
         *   For public hosted zones, omit ``VPCs``, ``VPCId``, and ``VPCRegion``.
         */
        vpcId: pulumi.Input<string>;
        /**
         * *Private hosted zones only:* The region that an Amazon VPC was created in.
         *   For public hosted zones, omit ``VPCs``, ``VPCId``, and ``VPCRegion``.
         */
        vpcRegion: pulumi.Input<string>;
    }
}
export declare namespace route53profiles {
}
export declare namespace route53recoverycontrol {
    /**
     * An assertion rule enforces that, when a routing control state is changed, that the criteria set by the rule configuration is met. Otherwise, the change to the routing control is not accepted.
     */
    interface SafetyRuleAssertionRuleArgs {
        /**
         * The routing controls that are part of transactions that are evaluated to determine if a request to change a routing control state is allowed. For example, you might include three routing controls, one for each of three AWS Regions.
         */
        assertedControls: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * An evaluation period, in milliseconds (ms), during which any request against the target routing controls will fail. This helps prevent "flapping" of state. The wait period is 5000 ms by default, but you can choose a custom value.
         */
        waitPeriodMs: pulumi.Input<number>;
    }
    /**
     * A gating rule verifies that a set of gating controls evaluates as true, based on a rule configuration that you specify. If the gating rule evaluates to true, Amazon Route 53 Application Recovery Controller allows a set of routing control state changes to run and complete against the set of target controls.
     */
    interface SafetyRuleGatingRuleArgs {
        /**
         * The gating controls for the gating rule. That is, routing controls that are evaluated by the rule configuration that you specify.
         */
        gatingControls: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * Routing controls that can only be set or unset if the specified RuleConfig evaluates to true for the specified GatingControls. For example, say you have three gating controls, one for each of three AWS Regions. Now you specify AtLeast 2 as your RuleConfig. With these settings, you can only change (set or unset) the routing controls that you have specified as TargetControls if that rule evaluates to true.
         * In other words, your ability to change the routing controls that you have specified as TargetControls is gated by the rule that you set for the routing controls in GatingControls.
         */
        targetControls: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * An evaluation period, in milliseconds (ms), during which any request against the target routing controls will fail. This helps prevent "flapping" of state. The wait period is 5000 ms by default, but you can choose a custom value.
         */
        waitPeriodMs: pulumi.Input<number>;
    }
    /**
     * The rule configuration for an assertion rule or gating rule. This is the criteria that you set for specific assertion controls (routing controls) or gating controls. This configuration specifies how many controls must be enabled after a transaction completes.
     */
    interface SafetyRuleRuleConfigArgs {
        /**
         * Logical negation of the rule. If the rule would usually evaluate true, it's evaluated as false, and vice versa.
         */
        inverted: pulumi.Input<boolean>;
        /**
         * The value of N, when you specify an ATLEAST rule type. That is, Threshold is the number of controls that must be set when you specify an ATLEAST type.
         */
        threshold: pulumi.Input<number>;
        /**
         * A rule can be one of the following: `ATLEAST` , `AND` , or `OR` .
         */
        type: pulumi.Input<enums.route53recoverycontrol.SafetyRuleRuleType>;
    }
}
export declare namespace route53recoveryreadiness {
    /**
     * A component for DNS/routing control readiness checks.
     */
    interface ResourceSetDnsTargetResourceArgs {
        /**
         * The domain name that acts as an ingress point to a portion of the customer application.
         */
        domainName?: pulumi.Input<string>;
        /**
         * The hosted zone Amazon Resource Name (ARN) that contains the DNS record with the provided name of the target resource.
         */
        hostedZoneArn?: pulumi.Input<string>;
        /**
         * The Route 53 record set ID that will uniquely identify a DNS record, given a name and a type.
         */
        recordSetId?: pulumi.Input<string>;
        /**
         * The type of DNS record of the target resource.
         */
        recordType?: pulumi.Input<string>;
        /**
         * The target resource that the Route 53 record points to.
         */
        targetResource?: pulumi.Input<inputs.route53recoveryreadiness.ResourceSetTargetResourceArgs>;
    }
    /**
     * The Network Load Balancer resource that a DNS target resource points to.
     */
    interface ResourceSetNlbResourceArgs {
        /**
         * A Network Load Balancer resource Amazon Resource Name (ARN).
         */
        arn?: pulumi.Input<string>;
    }
    /**
     * The Route 53 resource that a DNS target resource record points to.
     */
    interface ResourceSetR53ResourceRecordArgs {
        /**
         * The DNS target domain name.
         */
        domainName?: pulumi.Input<string>;
        /**
         * The Resource Record set id.
         */
        recordSetId?: pulumi.Input<string>;
    }
    /**
     * The resource element of a ResourceSet
     */
    interface ResourceSetResourceArgs {
        /**
         * The component identifier of the resource, generated when DNS target resource is used.
         */
        componentId?: pulumi.Input<string>;
        /**
         * A component for DNS/routing control readiness checks. This is a required setting when `ResourceSet` `ResourceSetType` is set to `AWS::Route53RecoveryReadiness::DNSTargetResource` . Do not set it for any other `ResourceSetType` setting.
         */
        dnsTargetResource?: pulumi.Input<inputs.route53recoveryreadiness.ResourceSetDnsTargetResourceArgs>;
        /**
         * A list of recovery group Amazon Resource Names (ARNs) and cell ARNs that this resource is contained within.
         */
        readinessScopes?: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * The Amazon Resource Name (ARN) of the AWS resource.
         */
        resourceArn?: pulumi.Input<string>;
    }
    /**
     * The target resource that the Route 53 record points to.
     */
    interface ResourceSetTargetResourceArgs {
        /**
         * The Network Load Balancer resource that a DNS target resource points to.
         */
        nlbResource?: pulumi.Input<inputs.route53recoveryreadiness.ResourceSetNlbResourceArgs>;
        /**
         * The Route 53 resource that a DNS target resource record points to.
         */
        r53Resource?: pulumi.Input<inputs.route53recoveryreadiness.ResourceSetR53ResourceRecordArgs>;
    }
}
export declare namespace route53resolver {
    /**
     * Firewall Rule associating the Rule Group to a Domain List
     */
    interface FirewallRuleGroupFirewallRuleArgs {
        /**
         * Rule Action
         */
        action: pulumi.Input<enums.route53resolver.FirewallRuleGroupFirewallRuleAction>;
        /**
         * BlockOverrideDnsType
         */
        blockOverrideDnsType?: pulumi.Input<enums.route53resolver.FirewallRuleGroupFirewallRuleBlockOverrideDnsType>;
        /**
         * BlockOverrideDomain
         */
        blockOverrideDomain?: pulumi.Input<string>;
        /**
         * BlockOverrideTtl
         */
        blockOverrideTtl?: pulumi.Input<number>;
        /**
         * BlockResponse
         */
        blockResponse?: pulumi.Input<enums.route53resolver.FirewallRuleGroupFirewallRuleBlockResponse>;
        /**
         * FirewallDomainRedirectionAction
         */
        confidenceThreshold?: pulumi.Input<enums.route53resolver.FirewallRuleGroupFirewallRuleConfidenceThreshold>;
        /**
         * FirewallDomainRedirectionAction
         */
        dnsThreatProtection?: pulumi.Input<enums.route53resolver.FirewallRuleGroupFirewallRuleDnsThreatProtection>;
        /**
         * ResourceId
         */
        firewallDomainListId?: pulumi.Input<string>;
        /**
         * FirewallDomainRedirectionAction
         */
        firewallDomainRedirectionAction?: pulumi.Input<enums.route53resolver.FirewallRuleGroupFirewallRuleFirewallDomainRedirectionAction>;
        /**
         * ResourceId
         */
        firewallThreatProtectionId?: pulumi.Input<string>;
        /**
         * Rule Priority
         */
        priority: pulumi.Input<number>;
        /**
         * Qtype
         */
        qtype?: pulumi.Input<string>;
    }
    interface ResolverRuleTargetAddressArgs {
        /**
         * One IP address that you want to forward DNS queries to. You can specify only IPv4 addresses.
         */
        ip?: pulumi.Input<string>;
        /**
         * One IPv6 address that you want to forward DNS queries to. You can specify only IPv6 addresses.
         */
        ipv6?: pulumi.Input<string>;
        /**
         * The port at Ip that you want to forward DNS queries to.
         */
        port?: pulumi.Input<string>;
        /**
         * The protocol that you want to use to forward DNS queries.
         */
        protocol?: pulumi.Input<enums.route53resolver.ResolverRuleTargetAddressProtocol>;
        /**
         * The SNI of the target name servers for DoH/DoH-FIPS outbound endpoints
         */
        serverNameIndication?: pulumi.Input<string>;
    }
}
export declare namespace rum {
    /**
     * AppMonitor configuration
     */
    interface AppMonitorConfigurationArgs {
        /**
         * If you set this to true, the RUM web client sets two cookies, a session cookie and a user cookie. The cookies allow the RUM web client to collect data relating to the number of users an application has and the behavior of the application across a sequence of events. Cookies are stored in the top-level domain of the current page.
         */
        allowCookies?: pulumi.Input<boolean>;
        /**
         * If you set this to true, RUM enables xray tracing for the user sessions that RUM samples. RUM adds an xray trace header to allowed HTTP requests. It also records an xray segment for allowed HTTP requests. You can see traces and segments from these user sessions in the xray console and the CW ServiceLens console.
         */
        enableXRay?: pulumi.Input<boolean>;
        /**
         * A list of URLs in your website or application to exclude from RUM data collection. You can't include both ExcludedPages and IncludedPages in the same operation.
         */
        excludedPages?: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * A list of pages in the RUM console that are to be displayed with a favorite icon.
         */
        favoritePages?: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * The ARN of the guest IAM role that is attached to the identity pool that is used to authorize the sending of data to RUM.
         */
        guestRoleArn?: pulumi.Input<string>;
        /**
         * The ID of the identity pool that is used to authorize the sending of data to RUM.
         */
        identityPoolId?: pulumi.Input<string>;
        /**
         * If this app monitor is to collect data from only certain pages in your application, this structure lists those pages. You can't include both ExcludedPages and IncludedPages in the same operation.
         */
        includedPages?: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * An array of structures which define the destinations and the metrics that you want to send.
         */
        metricDestinations?: pulumi.Input<pulumi.Input<inputs.rum.AppMonitorMetricDestinationArgs>[]>;
        /**
         * Specifies the percentage of user sessions to use for RUM data collection. Choosing a higher percentage gives you more data but also incurs more costs. The number you specify is the percentage of user sessions that will be used. If you omit this parameter, the default of 10 is used.
         */
        sessionSampleRate?: pulumi.Input<number>;
        /**
         * An array that lists the types of telemetry data that this app monitor is to collect.
         */
        telemetries?: pulumi.Input<pulumi.Input<enums.rum.AppMonitorTelemetry>[]>;
    }
    /**
     * AppMonitor custom events configuration
     */
    interface AppMonitorCustomEventsArgs {
        /**
         * Indicates whether AppMonitor accepts custom events.
         */
        status?: pulumi.Input<enums.rum.AppMonitorCustomEventsStatus>;
    }
    /**
     * A structure that contains the configuration for how an app monitor can deobfuscate stack traces.
     */
    interface AppMonitorDeobfuscationConfigurationArgs {
        /**
         * A structure that contains the configuration for how an app monitor can unminify JavaScript error stack traces using source maps.
         */
        javaScriptSourceMaps?: pulumi.Input<inputs.rum.AppMonitorDeobfuscationConfigurationJavaScriptSourceMapsPropertiesArgs>;
    }
    /**
     * A structure that contains the configuration for how an app monitor can unminify JavaScript error stack traces using source maps.
     */
    interface AppMonitorDeobfuscationConfigurationJavaScriptSourceMapsPropertiesArgs {
        /**
         * The S3Uri of the bucket or folder that stores the source map files. It is required if status is ENABLED.
         */
        s3Uri?: pulumi.Input<string>;
        /**
         * Specifies whether JavaScript error stack traces should be unminified for this app monitor. The default is for JavaScript error stack trace unminification to be DISABLED
         */
        status: pulumi.Input<enums.rum.AppMonitorDeobfuscationConfigurationJavaScriptSourceMapsPropertiesStatus>;
    }
    /**
     * A single metric definition
     */
    interface AppMonitorMetricDefinitionArgs {
        /**
         * Use this field only if you are sending the metric to CloudWatch.
         *
         * This field is a map of field paths to dimension names. It defines the dimensions to associate with this metric in CloudWatch. For extended metrics, valid values for the entries in this field are the following:
         *
         * "metadata.pageId": "PageId"
         *
         * "metadata.browserName": "BrowserName"
         *
         * "metadata.deviceType": "DeviceType"
         *
         * "metadata.osName": "OSName"
         *
         * "metadata.countryCode": "CountryCode"
         *
         * "event_details.fileType": "FileType"
         *
         * All dimensions listed in this field must also be included in EventPattern.
         */
        dimensionKeys?: pulumi.Input<{
            [key: string]: pulumi.Input<string>;
        }>;
        /**
         * The pattern that defines the metric, specified as a JSON object. RUM checks events that happen in a user's session against the pattern, and events that match the pattern are sent to the metric destination.
         *
         * When you define extended metrics, the metric definition is not valid if EventPattern is omitted.
         *
         * Example event patterns:
         *
         * '{ "event_type": ["com.amazon.rum.js_error_event"], "metadata": { "browserName": [ "Chrome", "Safari" ], } }'
         *
         * '{ "event_type": ["com.amazon.rum.performance_navigation_event"], "metadata": { "browserName": [ "Chrome", "Firefox" ] }, "event_details": { "duration": [{ "numeric": [ "<", 2000 ] }] } }'
         *
         * '{ "event_type": ["com.amazon.rum.performance_navigation_event"], "metadata": { "browserName": [ "Chrome", "Safari" ], "countryCode": [ "US" ] }, "event_details": { "duration": [{ "numeric": [ ">=", 2000, "<", 8000 ] }] } }'
         *
         * If the metrics destination' is CloudWatch and the event also matches a value in DimensionKeys, then the metric is published with the specified dimensions.
         */
        eventPattern?: pulumi.Input<string>;
        /**
         * The name for the metric that is defined in this structure. For extended metrics, valid values are the following:
         *
         * PerformanceNavigationDuration
         *
         * PerformanceResourceDuration
         *
         * NavigationSatisfiedTransaction
         *
         * NavigationToleratedTransaction
         *
         * NavigationFrustratedTransaction
         *
         * WebVitalsCumulativeLayoutShift
         *
         * WebVitalsFirstInputDelay
         *
         * WebVitalsLargestContentfulPaint
         *
         * JsErrorCount
         *
         * HttpErrorCount
         *
         * SessionCount
         */
        name: pulumi.Input<string>;
        /**
         * The namespace used by CloudWatch Metrics for the metric that is defined in this structure
         */
        namespace?: pulumi.Input<string>;
        /**
         * The CloudWatch metric unit to use for this metric. If you omit this field, the metric is recorded with no unit.
         */
        unitLabel?: pulumi.Input<string>;
        /**
         * The field within the event object that the metric value is sourced from.
         *
         * If you omit this field, a hardcoded value of 1 is pushed as the metric value. This is useful if you just want to count the number of events that the filter catches.
         *
         * If this metric is sent to Evidently, this field will be passed to Evidently raw and Evidently will handle data extraction from the event.
         */
        valueKey?: pulumi.Input<string>;
    }
    /**
     * An structure which defines the destination and the metrics that you want to send.
     */
    interface AppMonitorMetricDestinationArgs {
        /**
         * Defines the destination to send the metrics to. Valid values are CloudWatch and Evidently. If you specify Evidently, you must also specify the ARN of the Evidently experiment that is to be the destination and an IAM role that has permission to write to the experiment.
         */
        destination: pulumi.Input<enums.rum.AppMonitorMetricDestinationDestination>;
        /**
         * Use this parameter only if Destination is Evidently. This parameter specifies the ARN of the Evidently experiment that will receive the extended metrics.
         */
        destinationArn?: pulumi.Input<string>;
        /**
         * This parameter is required if Destination is Evidently. If Destination is CloudWatch, do not use this parameter.
         *
         * This parameter specifies the ARN of an IAM role that RUM will assume to write to the Evidently experiment that you are sending metrics to. This role must have permission to write to that experiment.
         */
        iamRoleArn?: pulumi.Input<string>;
        /**
         * An array of structures which define the metrics that you want to send.
         */
        metricDefinitions?: pulumi.Input<pulumi.Input<inputs.rum.AppMonitorMetricDefinitionArgs>[]>;
    }
    /**
     * A structure that defines resource policy attached to your app monitor.
     */
    interface AppMonitorResourcePolicyArgs {
        /**
         * The JSON to use as the resource policy. The document can be up to 4 KB in size.
         */
        policyDocument: pulumi.Input<string>;
        /**
         * A string value that you can use to conditionally update your policy. You can provide the revision ID of your existing policy to make mutating requests against that policy.
         *
         *  When you assign a policy revision ID, then later requests about that policy will be rejected with an InvalidPolicyRevisionIdException error if they don't provide the correct current revision ID.
         */
        policyRevisionId?: pulumi.Input<string>;
    }
}
export declare namespace s3 {
    interface AccessGrantGranteeArgs {
        /**
         * The unique identifier of the Grantee
         */
        granteeIdentifier: pulumi.Input<string>;
        /**
         * Configures the transfer acceleration state for an Amazon S3 bucket.
         */
        granteeType: pulumi.Input<enums.s3.AccessGrantGranteeGranteeType>;
    }
    interface AccessGrantsLocationConfigurationArgs {
        /**
         * The S3 sub prefix of a registered location in your S3 Access Grants instance
         */
        s3SubPrefix: pulumi.Input<string>;
    }
    interface AccessPointPublicAccessBlockConfigurationArgs {
        /**
         * Specifies whether Amazon S3 should block public access control lists (ACLs) for buckets in this account. Setting this element to TRUE causes the following behavior:
         * - PUT Bucket acl and PUT Object acl calls fail if the specified ACL is public.
         *  - PUT Object calls fail if the request includes a public ACL.
         * . - PUT Bucket calls fail if the request includes a public ACL.
         * Enabling this setting doesn't affect existing policies or ACLs.
         */
        blockPublicAcls?: pulumi.Input<boolean>;
        /**
         * Specifies whether Amazon S3 should block public bucket policies for buckets in this account. Setting this element to TRUE causes Amazon S3 to reject calls to PUT Bucket policy if the specified bucket policy allows public access. Enabling this setting doesn't affect existing bucket policies.
         */
        blockPublicPolicy?: pulumi.Input<boolean>;
        /**
         * Specifies whether Amazon S3 should ignore public ACLs for buckets in this account. Setting this element to TRUE causes Amazon S3 to ignore all public ACLs on buckets in this account and any objects that they contain. Enabling this setting doesn't affect the persistence of any existing ACLs and doesn't prevent new public ACLs from being set.
         */
        ignorePublicAcls?: pulumi.Input<boolean>;
        /**
         * Specifies whether Amazon S3 should restrict public bucket policies for this bucket. Setting this element to TRUE restricts access to this bucket to only AWS services and authorized users within this account if the bucket has a public policy.
         * Enabling this setting doesn't affect previously stored bucket policies, except that public and cross-account access within any public bucket policy, including non-public delegation to specific accounts, is blocked.
         */
        restrictPublicBuckets?: pulumi.Input<boolean>;
    }
    /**
     * The Virtual Private Cloud (VPC) configuration for a bucket access point.
     */
    interface AccessPointVpcConfigurationArgs {
        /**
         * If this field is specified, this access point will only allow connections from the specified VPC ID.
         */
        vpcId?: pulumi.Input<string>;
    }
    /**
     * Specifies the days since the initiation of an incomplete multipart upload that Amazon S3 will wait before permanently removing all parts of the upload. For more information, see [Stopping Incomplete Multipart Uploads Using a Bucket Lifecycle Policy](https://docs.aws.amazon.com/AmazonS3/latest/dev/mpuoverview.html#mpu-abort-incomplete-mpu-lifecycle-config) in the *Amazon S3 User Guide*.
     */
    interface BucketAbortIncompleteMultipartUploadArgs {
        /**
         * Specifies the number of days after which Amazon S3 stops an incomplete multipart upload.
         */
        daysAfterInitiation: pulumi.Input<number>;
    }
    /**
     * Configures the transfer acceleration state for an Amazon S3 bucket. For more information, see [Amazon S3 Transfer Acceleration](https://docs.aws.amazon.com/AmazonS3/latest/dev/transfer-acceleration.html) in the *Amazon S3 User Guide*.
     */
    interface BucketAccelerateConfigurationArgs {
        /**
         * Specifies the transfer acceleration status of the bucket.
         */
        accelerationStatus: pulumi.Input<enums.s3.BucketAccelerateConfigurationAccelerationStatus>;
    }
    /**
     * Specify this only in a cross-account scenario (where source and destination bucket owners are not the same), and you want to change replica ownership to the AWS-account that owns the destination bucket. If this is not specified in the replication configuration, the replicas are owned by same AWS-account that owns the source object.
     */
    interface BucketAccessControlTranslationArgs {
        /**
         * Specifies the replica ownership. For default and valid values, see [PUT bucket replication](https://docs.aws.amazon.com/AmazonS3/latest/API/RESTBucketPUTreplication.html) in the *Amazon S3 API Reference*.
         */
        owner: pulumi.Input<string>;
    }
    /**
     * Specifies the configuration and any analyses for the analytics filter of an Amazon S3 bucket.
     */
    interface BucketAnalyticsConfigurationArgs {
        /**
         * The ID that identifies the analytics configuration.
         */
        id: pulumi.Input<string>;
        /**
         * The prefix that an object must have to be included in the analytics results.
         */
        prefix?: pulumi.Input<string>;
        /**
         * Contains data related to access patterns to be collected and made available to analyze the tradeoffs between different storage classes.
         */
        storageClassAnalysis: pulumi.Input<inputs.s3.BucketStorageClassAnalysisArgs>;
        /**
         * The tags to use when evaluating an analytics filter.
         *  The analytics only includes objects that meet the filter's criteria. If no filter is specified, all of the contents of the bucket are included in the analysis.
         */
        tagFilters?: pulumi.Input<pulumi.Input<inputs.s3.BucketTagFilterArgs>[]>;
    }
    /**
     * Describes the cross-origin access configuration for objects in an Amazon S3 bucket. For more information, see [Enabling Cross-Origin Resource Sharing](https://docs.aws.amazon.com/AmazonS3/latest/dev/cors.html) in the *Amazon S3 User Guide*.
     */
    interface BucketCorsConfigurationArgs {
        /**
         * A set of origins and methods (cross-origin access that you want to allow). You can add up to 100 rules to the configuration.
         */
        corsRules: pulumi.Input<pulumi.Input<inputs.s3.BucketCorsRuleArgs>[]>;
    }
    /**
     * Specifies a cross-origin access rule for an Amazon S3 bucket.
     */
    interface BucketCorsRuleArgs {
        /**
         * Headers that are specified in the ``Access-Control-Request-Headers`` header. These headers are allowed in a preflight OPTIONS request. In response to any preflight OPTIONS request, Amazon S3 returns any requested headers that are allowed.
         */
        allowedHeaders?: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * An HTTP method that you allow the origin to run.
         *   *Allowed values*: ``GET`` | ``PUT`` | ``HEAD`` | ``POST`` | ``DELETE``
         */
        allowedMethods: pulumi.Input<pulumi.Input<enums.s3.BucketCorsRuleAllowedMethodsItem>[]>;
        /**
         * One or more origins you want customers to be able to access the bucket from.
         */
        allowedOrigins: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * One or more headers in the response that you want customers to be able to access from their applications (for example, from a JavaScript ``XMLHttpRequest`` object).
         */
        exposedHeaders?: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * A unique identifier for this rule. The value must be no more than 255 characters.
         */
        id?: pulumi.Input<string>;
        /**
         * The time in seconds that your browser is to cache the preflight response for the specified resource.
         */
        maxAge?: pulumi.Input<number>;
    }
    /**
     * Specifies how data related to the storage class analysis for an Amazon S3 bucket should be exported.
     */
    interface BucketDataExportArgs {
        /**
         * The place to store the data for an analysis.
         */
        destination: pulumi.Input<inputs.s3.BucketDestinationArgs>;
        /**
         * The version of the output schema to use when exporting data. Must be ``V_1``.
         */
        outputSchemaVersion: pulumi.Input<string>;
    }
    /**
     * The container element for optionally specifying the default Object Lock retention settings for new objects placed in the specified bucket.
     *    +  The ``DefaultRetention`` settings require both a mode and a period.
     *   +  The ``DefaultRetention`` period can be either ``Days`` or ``Years`` but you must select one. You cannot specify ``Days`` and ``Years`` at the same time.
     */
    interface BucketDefaultRetentionArgs {
        /**
         * The number of days that you want to specify for the default retention period. If Object Lock is turned on, you must specify ``Mode`` and specify either ``Days`` or ``Years``.
         */
        days?: pulumi.Input<number>;
        /**
         * The default Object Lock retention mode you want to apply to new objects placed in the specified bucket. If Object Lock is turned on, you must specify ``Mode`` and specify either ``Days`` or ``Years``.
         */
        mode?: pulumi.Input<enums.s3.BucketDefaultRetentionMode>;
        /**
         * The number of years that you want to specify for the default retention period. If Object Lock is turned on, you must specify ``Mode`` and specify either ``Days`` or ``Years``.
         */
        years?: pulumi.Input<number>;
    }
    /**
     * Specifies whether Amazon S3 replicates delete markers. If you specify a ``Filter`` in your replication configuration, you must also include a ``DeleteMarkerReplication`` element. If your ``Filter`` includes a ``Tag`` element, the ``DeleteMarkerReplication`` ``Status`` must be set to Disabled, because Amazon S3 does not support replicating delete markers for tag-based rules. For an example configuration, see [Basic Rule Configuration](https://docs.aws.amazon.com/AmazonS3/latest/dev/replication-add-config.html#replication-config-min-rule-config).
     *  For more information about delete marker replication, see [Basic Rule Configuration](https://docs.aws.amazon.com/AmazonS3/latest/dev/delete-marker-replication.html).
     *   If you are using an earlier version of the replication configuration, Amazon S3 handles replication of delete markers differently. For more information, see [Backward Compatibility](https://docs.aws.amazon.com/AmazonS3/latest/dev/replication-add-config.html#replication-backward-compat-considerations).
     */
    interface BucketDeleteMarkerReplicationArgs {
        /**
         * Indicates whether to replicate delete markers. Disabled by default.
         */
        status?: pulumi.Input<enums.s3.BucketDeleteMarkerReplicationStatus>;
    }
    /**
     * Specifies information about where to publish analysis or configuration results for an Amazon S3 bucket.
     */
    interface BucketDestinationArgs {
        /**
         * The account ID that owns the destination S3 bucket. If no account ID is provided, the owner is not validated before exporting data.
         *    Although this value is optional, we strongly recommend that you set it to help prevent problems if the destination bucket ownership changes.
         */
        bucketAccountId?: pulumi.Input<string>;
        /**
         * The Amazon Resource Name (ARN) of the bucket to which data is exported.
         */
        bucketArn: pulumi.Input<string>;
        /**
         * Specifies the file format used when exporting data to Amazon S3.
         *   *Allowed values*: ``CSV`` | ``ORC`` | ``Parquet``
         */
        format: pulumi.Input<enums.s3.BucketDestinationFormat>;
        /**
         * The prefix to use when exporting data. The prefix is prepended to all results.
         */
        prefix?: pulumi.Input<string>;
    }
    /**
     * Specifies default encryption for a bucket using server-side encryption with Amazon S3-managed keys (SSE-S3), AWS KMS-managed keys (SSE-KMS), or dual-layer server-side encryption with KMS-managed keys (DSSE-KMS). For information about the Amazon S3 default encryption feature, see [Amazon S3 Default Encryption for S3 Buckets](https://docs.aws.amazon.com/AmazonS3/latest/dev/bucket-encryption.html) in the *Amazon S3 User Guide*.
     */
    interface BucketEncryptionArgs {
        /**
         * Specifies the default server-side-encryption configuration.
         */
        serverSideEncryptionConfiguration: pulumi.Input<pulumi.Input<inputs.s3.BucketServerSideEncryptionRuleArgs>[]>;
    }
    /**
     * Specifies encryption-related information for an Amazon S3 bucket that is a destination for replicated objects.
     *   If you're specifying a customer managed KMS key, we recommend using a fully qualified KMS key ARN. If you use a KMS key alias instead, then KMS resolves the key within the requester’s account. This behavior can result in data that's encrypted with a KMS key that belongs to the requester, and not the bucket owner.
     */
    interface BucketEncryptionConfigurationArgs {
        /**
         * Specifies the ID (Key ARN or Alias ARN) of the customer managed AWS KMS key stored in AWS Key Management Service (KMS) for the destination bucket. Amazon S3 uses this key to encrypt replica objects. Amazon S3 only supports symmetric encryption KMS keys. For more information, see [Asymmetric keys in KMS](https://docs.aws.amazon.com//kms/latest/developerguide/symmetric-asymmetric.html) in the *Key Management Service Developer Guide*.
         */
        replicaKmsKeyId: pulumi.Input<string>;
    }
    /**
     * Amazon S3 can send events to Amazon EventBridge whenever certain events happen in your bucket, see [Using EventBridge](https://docs.aws.amazon.com/AmazonS3/latest/userguide/EventBridge.html) in the *Amazon S3 User Guide*.
     *  Unlike other destinations, delivery of events to EventBridge can be either enabled or disabled for a bucket. If enabled, all events will be sent to EventBridge and you can use EventBridge rules to route events to additional targets. For more information, see [What Is Amazon EventBridge](https://docs.aws.amazon.com/eventbridge/latest/userguide/eb-what-is.html) in the *Amazon EventBridge User Guide*
     */
    interface BucketEventBridgeConfigurationArgs {
        /**
         * Enables delivery of events to Amazon EventBridge.
         */
        eventBridgeEnabled: pulumi.Input<boolean>;
    }
    /**
     * Specifies the Amazon S3 object key name to filter on. An object key name is the name assigned to an object in your Amazon S3 bucket. You specify whether to filter on the suffix or prefix of the object key name. A prefix is a specific string of characters at the beginning of an object key name, which you can use to organize objects. For example, you can start the key names of related objects with a prefix, such as ``2023-`` or ``engineering/``. Then, you can use ``FilterRule`` to find objects in a bucket with key names that have the same prefix. A suffix is similar to a prefix, but it is at the end of the object key name instead of at the beginning.
     */
    interface BucketFilterRuleArgs {
        /**
         * The object key name prefix or suffix identifying one or more objects to which the filtering rule applies. The maximum length is 1,024 characters. Overlapping prefixes and suffixes are not supported. For more information, see [Configuring Event Notifications](https://docs.aws.amazon.com/AmazonS3/latest/dev/NotificationHowTo.html) in the *Amazon S3 User Guide*.
         */
        name: pulumi.Input<string>;
        /**
         * The value that the filter searches for in object key names.
         */
        value: pulumi.Input<string>;
    }
    /**
     * Specifies the S3 Intelligent-Tiering configuration for an Amazon S3 bucket.
     *  For information about the S3 Intelligent-Tiering storage class, see [Storage class for automatically optimizing frequently and infrequently accessed objects](https://docs.aws.amazon.com/AmazonS3/latest/dev/storage-class-intro.html#sc-dynamic-data-access).
     */
    interface BucketIntelligentTieringConfigurationArgs {
        /**
         * The ID used to identify the S3 Intelligent-Tiering configuration.
         */
        id: pulumi.Input<string>;
        /**
         * An object key name prefix that identifies the subset of objects to which the rule applies.
         */
        prefix?: pulumi.Input<string>;
        /**
         * Specifies the status of the configuration.
         */
        status: pulumi.Input<enums.s3.BucketIntelligentTieringConfigurationStatus>;
        /**
         * A container for a key-value pair.
         */
        tagFilters?: pulumi.Input<pulumi.Input<inputs.s3.BucketTagFilterArgs>[]>;
        /**
         * Specifies a list of S3 Intelligent-Tiering storage class tiers in the configuration. At least one tier must be defined in the list. At most, you can specify two tiers in the list, one for each available AccessTier: ``ARCHIVE_ACCESS`` and ``DEEP_ARCHIVE_ACCESS``.
         *   You only need Intelligent Tiering Configuration enabled on a bucket if you want to automatically move objects stored in the Intelligent-Tiering storage class to Archive Access or Deep Archive Access tiers.
         */
        tierings: pulumi.Input<pulumi.Input<inputs.s3.BucketTieringArgs>[]>;
    }
    /**
     * Specifies the inventory configuration for an Amazon S3 bucket. For more information, see [GET Bucket inventory](https://docs.aws.amazon.com/AmazonS3/latest/API/RESTBucketGETInventoryConfig.html) in the *Amazon S3 API Reference*.
     */
    interface BucketInventoryConfigurationArgs {
        /**
         * Contains information about where to publish the inventory results.
         */
        destination: pulumi.Input<inputs.s3.BucketDestinationArgs>;
        /**
         * Specifies whether the inventory is enabled or disabled. If set to ``True``, an inventory list is generated. If set to ``False``, no inventory list is generated.
         */
        enabled: pulumi.Input<boolean>;
        /**
         * The ID used to identify the inventory configuration.
         */
        id: pulumi.Input<string>;
        /**
         * Object versions to include in the inventory list. If set to ``All``, the list includes all the object versions, which adds the version-related fields ``VersionId``, ``IsLatest``, and ``DeleteMarker`` to the list. If set to ``Current``, the list does not contain these version-related fields.
         */
        includedObjectVersions: pulumi.Input<enums.s3.BucketInventoryConfigurationIncludedObjectVersions>;
        /**
         * Contains the optional fields that are included in the inventory results.
         */
        optionalFields?: pulumi.Input<pulumi.Input<enums.s3.BucketInventoryConfigurationOptionalFieldsItem>[]>;
        /**
         * Specifies the inventory filter prefix.
         */
        prefix?: pulumi.Input<string>;
        /**
         * Specifies the schedule for generating inventory results.
         */
        scheduleFrequency: pulumi.Input<enums.s3.BucketInventoryConfigurationScheduleFrequency>;
    }
    /**
     * Describes the LAMlong functions to invoke and the events for which to invoke them.
     */
    interface BucketLambdaConfigurationArgs {
        /**
         * The Amazon S3 bucket event for which to invoke the LAMlong function. For more information, see [Supported Event Types](https://docs.aws.amazon.com/AmazonS3/latest/dev/NotificationHowTo.html) in the *Amazon S3 User Guide*.
         */
        event: pulumi.Input<string>;
        /**
         * The filtering rules that determine which objects invoke the AWS Lambda function. For example, you can create a filter so that only image files with a ``.jpg`` extension invoke the function when they are added to the Amazon S3 bucket.
         */
        filter?: pulumi.Input<inputs.s3.BucketNotificationFilterArgs>;
        /**
         * The Amazon Resource Name (ARN) of the LAMlong function that Amazon S3 invokes when the specified event type occurs.
         */
        function: pulumi.Input<string>;
    }
    /**
     * Specifies the lifecycle configuration for objects in an Amazon S3 bucket. For more information, see [Object Lifecycle Management](https://docs.aws.amazon.com/AmazonS3/latest/dev/object-lifecycle-mgmt.html) in the *Amazon S3 User Guide*.
     */
    interface BucketLifecycleConfigurationArgs {
        /**
         * A lifecycle rule for individual objects in an Amazon S3 bucket.
         */
        rules: pulumi.Input<pulumi.Input<inputs.s3.BucketRuleArgs>[]>;
        /**
         * Indicates which default minimum object size behavior is applied to the lifecycle configuration.
         *   This parameter applies to general purpose buckets only. It isn't supported for directory bucket lifecycle configurations.
         *    +   ``all_storage_classes_128K`` - Objects smaller than 128 KB will not transition to any storage class by default.
         *   +   ``varies_by_storage_class`` - Objects smaller than 128 KB will transition to Glacier Flexible Retrieval or Glacier Deep Archive storage classes. By default, all other storage classes will prevent transitions smaller than 128 KB.
         *
         *  To customize the minimum object size for any transition you can add a filter that specifies a custom ``ObjectSizeGreaterThan`` or ``ObjectSizeLessThan`` in the body of your transition rule. Custom filters always take precedence over the default transition behavior.
         */
        transitionDefaultMinimumObjectSize?: pulumi.Input<enums.s3.BucketLifecycleConfigurationTransitionDefaultMinimumObjectSize>;
    }
    /**
     * Describes where logs are stored and the prefix that Amazon S3 assigns to all log object keys for a bucket. For examples and more information, see [PUT Bucket logging](https://docs.aws.amazon.com/AmazonS3/latest/API/RESTBucketPUTlogging.html) in the *Amazon S3 API Reference*.
     *   To successfully complete the ``AWS::S3::Bucket LoggingConfiguration`` request, you must have ``s3:PutObject`` and ``s3:PutObjectAcl`` in your IAM permissions.
     */
    interface BucketLoggingConfigurationArgs {
        /**
         * The name of the bucket where Amazon S3 should store server access log files. You can store log files in any bucket that you own. By default, logs are stored in the bucket where the ``LoggingConfiguration`` property is defined.
         */
        destinationBucketName?: pulumi.Input<string>;
        /**
         * A prefix for all log object keys. If you store log files from multiple Amazon S3 buckets in a single bucket, you can use a prefix to distinguish which log files came from which bucket.
         */
        logFilePrefix?: pulumi.Input<string>;
        /**
         * Amazon S3 key format for log objects. Only one format, either PartitionedPrefix or SimplePrefix, is allowed.
         */
        targetObjectKeyFormat?: pulumi.Input<inputs.s3.BucketTargetObjectKeyFormatArgs>;
    }
    /**
     * The metadata table configuration of an S3 general purpose bucket. For more information, see [Accelerating data discovery with S3 Metadata](https://docs.aws.amazon.com/AmazonS3/latest/userguide/metadata-tables-overview.html) and [Setting up permissions for configuring metadata tables](https://docs.aws.amazon.com/AmazonS3/latest/userguide/metadata-tables-permissions.html).
     */
    interface BucketMetadataTableConfigurationArgs {
        /**
         * The destination information for the metadata table configuration. The destination table bucket must be in the same Region and AWS-account as the general purpose bucket. The specified metadata table name must be unique within the ``aws_s3_metadata`` namespace in the destination table bucket.
         */
        s3TablesDestination: pulumi.Input<inputs.s3.BucketS3TablesDestinationArgs>;
    }
    /**
     * A container specifying replication metrics-related settings enabling replication metrics and events.
     */
    interface BucketMetricsArgs {
        /**
         * A container specifying the time threshold for emitting the ``s3:Replication:OperationMissedThreshold`` event.
         */
        eventThreshold?: pulumi.Input<inputs.s3.BucketReplicationTimeValueArgs>;
        /**
         * Specifies whether the replication metrics are enabled.
         */
        status: pulumi.Input<enums.s3.BucketMetricsStatus>;
    }
    /**
     * Specifies a metrics configuration for the CloudWatch request metrics (specified by the metrics configuration ID) from an Amazon S3 bucket. If you're updating an existing metrics configuration, note that this is a full replacement of the existing metrics configuration. If you don't include the elements you want to keep, they are erased. For examples, see [AWS::S3::Bucket](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-s3-bucket.html#aws-properties-s3-bucket--examples). For more information, see [PUT Bucket metrics](https://docs.aws.amazon.com/AmazonS3/latest/API/RESTBucketPUTMetricConfiguration.html) in the *Amazon S3 API Reference*.
     */
    interface BucketMetricsConfigurationArgs {
        /**
         * The access point that was used while performing operations on the object. The metrics configuration only includes objects that meet the filter's criteria.
         */
        accessPointArn?: pulumi.Input<string>;
        /**
         * The ID used to identify the metrics configuration. This can be any value you choose that helps you identify your metrics configuration.
         */
        id: pulumi.Input<string>;
        /**
         * The prefix that an object must have to be included in the metrics results.
         */
        prefix?: pulumi.Input<string>;
        /**
         * Specifies a list of tag filters to use as a metrics configuration filter. The metrics configuration includes only objects that meet the filter's criteria.
         */
        tagFilters?: pulumi.Input<pulumi.Input<inputs.s3.BucketTagFilterArgs>[]>;
    }
    /**
     * Specifies when noncurrent object versions expire. Upon expiration, S3 permanently deletes the noncurrent object versions. You set this lifecycle configuration action on a bucket that has versioning enabled (or suspended) to request that S3 delete noncurrent object versions at a specific period in the object's lifetime. For more information about setting a lifecycle rule configuration, see [AWS::S3::Bucket Rule](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-s3-bucket-lifecycleconfig-rule.html).
     */
    interface BucketNoncurrentVersionExpirationArgs {
        /**
         * Specifies how many noncurrent versions S3 will retain. If there are this many more recent noncurrent versions, S3 will take the associated action. For more information about noncurrent versions, see [Lifecycle configuration elements](https://docs.aws.amazon.com/AmazonS3/latest/userguide/intro-lifecycle-rules.html) in the *Amazon S3 User Guide*.
         */
        newerNoncurrentVersions?: pulumi.Input<number>;
        /**
         * Specifies the number of days an object is noncurrent before S3 can perform the associated action. For information about the noncurrent days calculations, see [How Amazon S3 Calculates When an Object Became Noncurrent](https://docs.aws.amazon.com/AmazonS3/latest/dev/intro-lifecycle-rules.html#non-current-days-calculations) in the *Amazon S3 User Guide*.
         */
        noncurrentDays: pulumi.Input<number>;
    }
    /**
     * Container for the transition rule that describes when noncurrent objects transition to the ``STANDARD_IA``, ``ONEZONE_IA``, ``INTELLIGENT_TIERING``, ``GLACIER_IR``, ``GLACIER``, or ``DEEP_ARCHIVE`` storage class. If your bucket is versioning-enabled (or versioning is suspended), you can set this action to request that Amazon S3 transition noncurrent object versions to the ``STANDARD_IA``, ``ONEZONE_IA``, ``INTELLIGENT_TIERING``, ``GLACIER_IR``, ``GLACIER``, or ``DEEP_ARCHIVE`` storage class at a specific period in the object's lifetime. If you specify this property, don't specify the ``NoncurrentVersionTransitions`` property.
     */
    interface BucketNoncurrentVersionTransitionArgs {
        /**
         * Specifies how many noncurrent versions S3 will retain. If there are this many more recent noncurrent versions, S3 will take the associated action. For more information about noncurrent versions, see [Lifecycle configuration elements](https://docs.aws.amazon.com/AmazonS3/latest/userguide/intro-lifecycle-rules.html) in the *Amazon S3 User Guide*.
         */
        newerNoncurrentVersions?: pulumi.Input<number>;
        /**
         * The class of storage used to store the object.
         */
        storageClass: pulumi.Input<enums.s3.BucketNoncurrentVersionTransitionStorageClass>;
        /**
         * Specifies the number of days an object is noncurrent before Amazon S3 can perform the associated action. For information about the noncurrent days calculations, see [How Amazon S3 Calculates How Long an Object Has Been Noncurrent](https://docs.aws.amazon.com/AmazonS3/latest/dev/intro-lifecycle-rules.html#non-current-days-calculations) in the *Amazon S3 User Guide*.
         */
        transitionInDays: pulumi.Input<number>;
    }
    /**
     * Describes the notification configuration for an Amazon S3 bucket.
     *   If you create the target resource and related permissions in the same template, you might have a circular dependency.
     *  For example, you might use the ``AWS::Lambda::Permission`` resource to grant the bucket permission to invoke an AWS Lambda function. However, AWS CloudFormation can't create the bucket until the bucket has permission to invoke the function (AWS CloudFormation checks whether the bucket can invoke the function). If you're using Refs to pass the bucket name, this leads to a circular dependency.
     *  To avoid this dependency, you can create all resources without specifying the notification configuration. Then, update the stack with a notification configuration.
     *  For more information on permissions, see [AWS::Lambda::Permission](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-lambda-permission.html) and [Granting Permissions to Publish Event Notification Messages to a Destination](https://docs.aws.amazon.com/AmazonS3/latest/dev/NotificationHowTo.html#grant-destinations-permissions-to-s3).
     */
    interface BucketNotificationConfigurationArgs {
        /**
         * Enables delivery of events to Amazon EventBridge.
         */
        eventBridgeConfiguration?: pulumi.Input<inputs.s3.BucketEventBridgeConfigurationArgs>;
        /**
         * Describes the LAMlong functions to invoke and the events for which to invoke them.
         */
        lambdaConfigurations?: pulumi.Input<pulumi.Input<inputs.s3.BucketLambdaConfigurationArgs>[]>;
        /**
         * The Amazon Simple Queue Service queues to publish messages to and the events for which to publish messages.
         */
        queueConfigurations?: pulumi.Input<pulumi.Input<inputs.s3.BucketQueueConfigurationArgs>[]>;
        /**
         * The topic to which notifications are sent and the events for which notifications are generated.
         */
        topicConfigurations?: pulumi.Input<pulumi.Input<inputs.s3.BucketTopicConfigurationArgs>[]>;
    }
    /**
     * Specifies object key name filtering rules. For information about key name filtering, see [Configuring event notifications using object key name filtering](https://docs.aws.amazon.com/AmazonS3/latest/userguide/notification-how-to-filtering.html) in the *Amazon S3 User Guide*.
     */
    interface BucketNotificationFilterArgs {
        /**
         * A container for object key name prefix and suffix filtering rules.
         */
        s3Key: pulumi.Input<inputs.s3.BucketS3KeyFilterArgs>;
    }
    /**
     * Places an Object Lock configuration on the specified bucket. The rule specified in the Object Lock configuration will be applied by default to every new object placed in the specified bucket. For more information, see [Locking Objects](https://docs.aws.amazon.com/AmazonS3/latest/dev/object-lock.html).
     */
    interface BucketObjectLockConfigurationArgs {
        /**
         * Indicates whether this bucket has an Object Lock configuration enabled. Enable ``ObjectLockEnabled`` when you apply ``ObjectLockConfiguration`` to a bucket.
         */
        objectLockEnabled?: pulumi.Input<string>;
        /**
         * Specifies the Object Lock rule for the specified object. Enable this rule when you apply ``ObjectLockConfiguration`` to a bucket. If Object Lock is turned on, bucket settings require both ``Mode`` and a period of either ``Days`` or ``Years``. You cannot specify ``Days`` and ``Years`` at the same time. For more information, see [ObjectLockRule](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-s3-bucket-objectlockrule.html) and [DefaultRetention](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-s3-bucket-defaultretention.html).
         */
        rule?: pulumi.Input<inputs.s3.BucketObjectLockRuleArgs>;
    }
    /**
     * Specifies the Object Lock rule for the specified object. Enable the this rule when you apply ``ObjectLockConfiguration`` to a bucket.
     */
    interface BucketObjectLockRuleArgs {
        /**
         * The default Object Lock retention mode and period that you want to apply to new objects placed in the specified bucket. If Object Lock is turned on, bucket settings require both ``Mode`` and a period of either ``Days`` or ``Years``. You cannot specify ``Days`` and ``Years`` at the same time. For more information about allowable values for mode and period, see [DefaultRetention](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-s3-bucket-defaultretention.html).
         */
        defaultRetention?: pulumi.Input<inputs.s3.BucketDefaultRetentionArgs>;
    }
    /**
     * Specifies the container element for Object Ownership rules.
     *  S3 Object Ownership is an Amazon S3 bucket-level setting that you can use to disable access control lists (ACLs) and take ownership of every object in your bucket, simplifying access management for data stored in Amazon S3. For more information, see [Controlling ownership of objects and disabling ACLs](https://docs.aws.amazon.com/AmazonS3/latest/userguide/about-object-ownership.html) in the *Amazon S3 User Guide*.
     */
    interface BucketOwnershipControlsArgs {
        /**
         * Specifies the container element for Object Ownership rules.
         */
        rules: pulumi.Input<pulumi.Input<inputs.s3.BucketOwnershipControlsRuleArgs>[]>;
    }
    /**
     * Specifies an Object Ownership rule.
     *  S3 Object Ownership is an Amazon S3 bucket-level setting that you can use to disable access control lists (ACLs) and take ownership of every object in your bucket, simplifying access management for data stored in Amazon S3. For more information, see [Controlling ownership of objects and disabling ACLs](https://docs.aws.amazon.com/AmazonS3/latest/userguide/about-object-ownership.html) in the *Amazon S3 User Guide*.
     */
    interface BucketOwnershipControlsRuleArgs {
        /**
         * Specifies an object ownership rule.
         */
        objectOwnership?: pulumi.Input<enums.s3.BucketOwnershipControlsRuleObjectOwnership>;
    }
    /**
     * The PublicAccessBlock configuration that you want to apply to this Amazon S3 bucket. You can enable the configuration options in any combination. For more information about when Amazon S3 considers a bucket or object public, see [The Meaning of "Public"](https://docs.aws.amazon.com/AmazonS3/latest/dev/access-control-block-public-access.html#access-control-block-public-access-policy-status) in the *Amazon S3 User Guide*.
     */
    interface BucketPublicAccessBlockConfigurationArgs {
        /**
         * Specifies whether Amazon S3 should block public access control lists (ACLs) for this bucket and objects in this bucket. Setting this element to ``TRUE`` causes the following behavior:
         *   +  PUT Bucket ACL and PUT Object ACL calls fail if the specified ACL is public.
         *   +  PUT Object calls fail if the request includes a public ACL.
         *   +  PUT Bucket calls fail if the request includes a public ACL.
         *
         *  Enabling this setting doesn't affect existing policies or ACLs.
         */
        blockPublicAcls?: pulumi.Input<boolean>;
        /**
         * Specifies whether Amazon S3 should block public bucket policies for this bucket. Setting this element to ``TRUE`` causes Amazon S3 to reject calls to PUT Bucket policy if the specified bucket policy allows public access.
         *  Enabling this setting doesn't affect existing bucket policies.
         */
        blockPublicPolicy?: pulumi.Input<boolean>;
        /**
         * Specifies whether Amazon S3 should ignore public ACLs for this bucket and objects in this bucket. Setting this element to ``TRUE`` causes Amazon S3 to ignore all public ACLs on this bucket and objects in this bucket.
         *  Enabling this setting doesn't affect the persistence of any existing ACLs and doesn't prevent new public ACLs from being set.
         */
        ignorePublicAcls?: pulumi.Input<boolean>;
        /**
         * Specifies whether Amazon S3 should restrict public bucket policies for this bucket. Setting this element to ``TRUE`` restricts access to this bucket to only AWS-service principals and authorized users within this account if the bucket has a public policy.
         *  Enabling this setting doesn't affect previously stored bucket policies, except that public and cross-account access within any public bucket policy, including non-public delegation to specific accounts, is blocked.
         */
        restrictPublicBuckets?: pulumi.Input<boolean>;
    }
    /**
     * Specifies the configuration for publishing messages to an Amazon Simple Queue Service (Amazon SQS) queue when Amazon S3 detects specified events.
     */
    interface BucketQueueConfigurationArgs {
        /**
         * The Amazon S3 bucket event about which you want to publish messages to Amazon SQS. For more information, see [Supported Event Types](https://docs.aws.amazon.com/AmazonS3/latest/dev/NotificationHowTo.html) in the *Amazon S3 User Guide*.
         */
        event: pulumi.Input<string>;
        /**
         * The filtering rules that determine which objects trigger notifications. For example, you can create a filter so that Amazon S3 sends notifications only when image files with a ``.jpg`` extension are added to the bucket. For more information, see [Configuring event notifications using object key name filtering](https://docs.aws.amazon.com/AmazonS3/latest/user-guide/notification-how-to-filtering.html) in the *Amazon S3 User Guide*.
         */
        filter?: pulumi.Input<inputs.s3.BucketNotificationFilterArgs>;
        /**
         * The Amazon Resource Name (ARN) of the Amazon SQS queue to which Amazon S3 publishes a message when it detects events of the specified type. FIFO queues are not allowed when enabling an SQS queue as the event notification destination.
         */
        queue: pulumi.Input<string>;
    }
    /**
     * Specifies the redirect behavior of all requests to a website endpoint of an Amazon S3 bucket.
     */
    interface BucketRedirectAllRequestsToArgs {
        /**
         * Name of the host where requests are redirected.
         */
        hostName: pulumi.Input<string>;
        /**
         * Protocol to use when redirecting requests. The default is the protocol that is used in the original request.
         */
        protocol?: pulumi.Input<enums.s3.BucketRedirectAllRequestsToProtocol>;
    }
    /**
     * Specifies how requests are redirected. In the event of an error, you can specify a different error code to return.
     */
    interface BucketRedirectRuleArgs {
        /**
         * The host name to use in the redirect request.
         */
        hostName?: pulumi.Input<string>;
        /**
         * The HTTP redirect code to use on the response. Not required if one of the siblings is present.
         */
        httpRedirectCode?: pulumi.Input<string>;
        /**
         * Protocol to use when redirecting requests. The default is the protocol that is used in the original request.
         */
        protocol?: pulumi.Input<enums.s3.BucketRedirectRuleProtocol>;
        /**
         * The object key prefix to use in the redirect request. For example, to redirect requests for all pages with prefix ``docs/`` (objects in the ``docs/`` folder) to ``documents/``, you can set a condition block with ``KeyPrefixEquals`` set to ``docs/`` and in the Redirect set ``ReplaceKeyPrefixWith`` to ``/documents``. Not required if one of the siblings is present. Can be present only if ``ReplaceKeyWith`` is not provided.
         *   Replacement must be made for object keys containing special characters (such as carriage returns) when using XML requests. For more information, see [XML related object key constraints](https://docs.aws.amazon.com/AmazonS3/latest/userguide/object-keys.html#object-key-xml-related-constraints).
         */
        replaceKeyPrefixWith?: pulumi.Input<string>;
        /**
         * The specific object key to use in the redirect request. For example, redirect request to ``error.html``. Not required if one of the siblings is present. Can be present only if ``ReplaceKeyPrefixWith`` is not provided.
         *   Replacement must be made for object keys containing special characters (such as carriage returns) when using XML requests. For more information, see [XML related object key constraints](https://docs.aws.amazon.com/AmazonS3/latest/userguide/object-keys.html#object-key-xml-related-constraints).
         */
        replaceKeyWith?: pulumi.Input<string>;
    }
    /**
     * A filter that you can specify for selection for modifications on replicas.
     */
    interface BucketReplicaModificationsArgs {
        /**
         * Specifies whether Amazon S3 replicates modifications on replicas.
         *   *Allowed values*: ``Enabled`` | ``Disabled``
         */
        status: pulumi.Input<enums.s3.BucketReplicaModificationsStatus>;
    }
    /**
     * A container for replication rules. You can add up to 1,000 rules. The maximum size of a replication configuration is 2 MB. The latest version of the replication configuration XML is V2. For more information about XML V2 replication configurations, see [Replication configuration](https://docs.aws.amazon.com/AmazonS3/latest/userguide/replication-add-config.html) in the *Amazon S3 User Guide*.
     */
    interface BucketReplicationConfigurationArgs {
        /**
         * The Amazon Resource Name (ARN) of the IAMlong (IAM) role that Amazon S3 assumes when replicating objects. For more information, see [How to Set Up Replication](https://docs.aws.amazon.com/AmazonS3/latest/dev/replication-how-setup.html) in the *Amazon S3 User Guide*.
         */
        role: pulumi.Input<string>;
        /**
         * A container for one or more replication rules. A replication configuration must have at least one rule and can contain a maximum of 1,000 rules.
         */
        rules: pulumi.Input<pulumi.Input<inputs.s3.BucketReplicationRuleArgs>[]>;
    }
    /**
     * A container for information about the replication destination and its configurations including enabling the S3 Replication Time Control (S3 RTC).
     */
    interface BucketReplicationDestinationArgs {
        /**
         * Specify this only in a cross-account scenario (where source and destination bucket owners are not the same), and you want to change replica ownership to the AWS-account that owns the destination bucket. If this is not specified in the replication configuration, the replicas are owned by same AWS-account that owns the source object.
         */
        accessControlTranslation?: pulumi.Input<inputs.s3.BucketAccessControlTranslationArgs>;
        /**
         * Destination bucket owner account ID. In a cross-account scenario, if you direct Amazon S3 to change replica ownership to the AWS-account that owns the destination bucket by specifying the ``AccessControlTranslation`` property, this is the account ID of the destination bucket owner. For more information, see [Cross-Region Replication Additional Configuration: Change Replica Owner](https://docs.aws.amazon.com/AmazonS3/latest/dev/crr-change-owner.html) in the *Amazon S3 User Guide*.
         *  If you specify the ``AccessControlTranslation`` property, the ``Account`` property is required.
         */
        account?: pulumi.Input<string>;
        /**
         * The Amazon Resource Name (ARN) of the bucket where you want Amazon S3 to store the results.
         */
        bucket: pulumi.Input<string>;
        /**
         * Specifies encryption-related information.
         */
        encryptionConfiguration?: pulumi.Input<inputs.s3.BucketEncryptionConfigurationArgs>;
        /**
         * A container specifying replication metrics-related settings enabling replication metrics and events.
         */
        metrics?: pulumi.Input<inputs.s3.BucketMetricsArgs>;
        /**
         * A container specifying S3 Replication Time Control (S3 RTC), including whether S3 RTC is enabled and the time when all objects and operations on objects must be replicated. Must be specified together with a ``Metrics`` block.
         */
        replicationTime?: pulumi.Input<inputs.s3.BucketReplicationTimeArgs>;
        /**
         * The storage class to use when replicating objects, such as S3 Standard or reduced redundancy. By default, Amazon S3 uses the storage class of the source object to create the object replica.
         *  For valid values, see the ``StorageClass`` element of the [PUT Bucket replication](https://docs.aws.amazon.com/AmazonS3/latest/API/RESTBucketPUTreplication.html) action in the *Amazon S3 API Reference*.
         */
        storageClass?: pulumi.Input<enums.s3.BucketReplicationDestinationStorageClass>;
    }
    /**
     * Specifies which Amazon S3 objects to replicate and where to store the replicas.
     */
    interface BucketReplicationRuleArgs {
        /**
         * Specifies whether Amazon S3 replicates delete markers. If you specify a ``Filter`` in your replication configuration, you must also include a ``DeleteMarkerReplication`` element. If your ``Filter`` includes a ``Tag`` element, the ``DeleteMarkerReplication`` ``Status`` must be set to Disabled, because Amazon S3 does not support replicating delete markers for tag-based rules. For an example configuration, see [Basic Rule Configuration](https://docs.aws.amazon.com/AmazonS3/latest/dev/replication-add-config.html#replication-config-min-rule-config).
         *  For more information about delete marker replication, see [Basic Rule Configuration](https://docs.aws.amazon.com/AmazonS3/latest/dev/delete-marker-replication.html).
         *   If you are using an earlier version of the replication configuration, Amazon S3 handles replication of delete markers differently. For more information, see [Backward Compatibility](https://docs.aws.amazon.com/AmazonS3/latest/dev/replication-add-config.html#replication-backward-compat-considerations).
         */
        deleteMarkerReplication?: pulumi.Input<inputs.s3.BucketDeleteMarkerReplicationArgs>;
        /**
         * A container for information about the replication destination and its configurations including enabling the S3 Replication Time Control (S3 RTC).
         */
        destination: pulumi.Input<inputs.s3.BucketReplicationDestinationArgs>;
        /**
         * A filter that identifies the subset of objects to which the replication rule applies. A ``Filter`` must specify exactly one ``Prefix``, ``TagFilter``, or an ``And`` child element. The use of the filter field indicates that this is a V2 replication configuration. This field isn't supported in a V1 replication configuration.
         *   V1 replication configuration only supports filtering by key prefix. To filter using a V1 replication configuration, add the ``Prefix`` directly as a child element of the ``Rule`` element.
         */
        filter?: pulumi.Input<inputs.s3.BucketReplicationRuleFilterArgs>;
        /**
         * A unique identifier for the rule. The maximum value is 255 characters. If you don't specify a value, AWS CloudFormation generates a random ID. When using a V2 replication configuration this property is capitalized as "ID".
         */
        id?: pulumi.Input<string>;
        /**
         * An object key name prefix that identifies the object or objects to which the rule applies. The maximum prefix length is 1,024 characters. To include all objects in a bucket, specify an empty string. To filter using a V1 replication configuration, add the ``Prefix`` directly as a child element of the ``Rule`` element.
         *   Replacement must be made for object keys containing special characters (such as carriage returns) when using XML requests. For more information, see [XML related object key constraints](https://docs.aws.amazon.com/AmazonS3/latest/userguide/object-keys.html#object-key-xml-related-constraints).
         */
        prefix?: pulumi.Input<string>;
        /**
         * The priority indicates which rule has precedence whenever two or more replication rules conflict. Amazon S3 will attempt to replicate objects according to all replication rules. However, if there are two or more rules with the same destination bucket, then objects will be replicated according to the rule with the highest priority. The higher the number, the higher the priority.
         *  For more information, see [Replication](https://docs.aws.amazon.com/AmazonS3/latest/dev/replication.html) in the *Amazon S3 User Guide*.
         */
        priority?: pulumi.Input<number>;
        /**
         * A container that describes additional filters for identifying the source objects that you want to replicate. You can choose to enable or disable the replication of these objects.
         */
        sourceSelectionCriteria?: pulumi.Input<inputs.s3.BucketSourceSelectionCriteriaArgs>;
        /**
         * Specifies whether the rule is enabled.
         */
        status: pulumi.Input<enums.s3.BucketReplicationRuleStatus>;
    }
    /**
     * A container for specifying rule filters. The filters determine the subset of objects to which the rule applies. This element is required only if you specify more than one filter.
     *  For example:
     *   +  If you specify both a ``Prefix`` and a ``TagFilter``, wrap these filters in an ``And`` tag.
     *   +  If you specify a filter based on multiple tags, wrap the ``TagFilter`` elements in an ``And`` tag
     */
    interface BucketReplicationRuleAndOperatorArgs {
        /**
         * An object key name prefix that identifies the subset of objects to which the rule applies.
         */
        prefix?: pulumi.Input<string>;
        /**
         * An array of tags containing key and value pairs.
         */
        tagFilters?: pulumi.Input<pulumi.Input<inputs.s3.BucketTagFilterArgs>[]>;
    }
    /**
     * A filter that identifies the subset of objects to which the replication rule applies. A ``Filter`` must specify exactly one ``Prefix``, ``TagFilter``, or an ``And`` child element.
     */
    interface BucketReplicationRuleFilterArgs {
        /**
         * A container for specifying rule filters. The filters determine the subset of objects to which the rule applies. This element is required only if you specify more than one filter. For example:
         *   +  If you specify both a ``Prefix`` and a ``TagFilter``, wrap these filters in an ``And`` tag.
         *   +  If you specify a filter based on multiple tags, wrap the ``TagFilter`` elements in an ``And`` tag.
         */
        and?: pulumi.Input<inputs.s3.BucketReplicationRuleAndOperatorArgs>;
        /**
         * An object key name prefix that identifies the subset of objects to which the rule applies.
         *   Replacement must be made for object keys containing special characters (such as carriage returns) when using XML requests. For more information, see [XML related object key constraints](https://docs.aws.amazon.com/AmazonS3/latest/userguide/object-keys.html#object-key-xml-related-constraints).
         */
        prefix?: pulumi.Input<string>;
        /**
         * A container for specifying a tag key and value.
         *  The rule applies only to objects that have the tag in their tag set.
         */
        tagFilter?: pulumi.Input<inputs.s3.BucketTagFilterArgs>;
    }
    /**
     * A container specifying S3 Replication Time Control (S3 RTC) related information, including whether S3 RTC is enabled and the time when all objects and operations on objects must be replicated. Must be specified together with a ``Metrics`` block.
     */
    interface BucketReplicationTimeArgs {
        /**
         * Specifies whether the replication time is enabled.
         */
        status: pulumi.Input<enums.s3.BucketReplicationTimeStatus>;
        /**
         * A container specifying the time by which replication should be complete for all objects and operations on objects.
         */
        time: pulumi.Input<inputs.s3.BucketReplicationTimeValueArgs>;
    }
    /**
     * A container specifying the time value for S3 Replication Time Control (S3 RTC) and replication metrics ``EventThreshold``.
     */
    interface BucketReplicationTimeValueArgs {
        /**
         * Contains an integer specifying time in minutes.
         *   Valid value: 15
         */
        minutes: pulumi.Input<number>;
    }
    /**
     * Specifies the redirect behavior and when a redirect is applied. For more information about routing rules, see [Configuring advanced conditional redirects](https://docs.aws.amazon.com/AmazonS3/latest/dev/how-to-page-redirect.html#advanced-conditional-redirects) in the *Amazon S3 User Guide*.
     */
    interface BucketRoutingRuleArgs {
        /**
         * Container for redirect information. You can redirect requests to another host, to another page, or with another protocol. In the event of an error, you can specify a different error code to return.
         */
        redirectRule: pulumi.Input<inputs.s3.BucketRedirectRuleArgs>;
        /**
         * A container for describing a condition that must be met for the specified redirect to apply. For example, 1. If request is for pages in the ``/docs`` folder, redirect to the ``/documents`` folder. 2. If request results in HTTP error 4xx, redirect request to another host where you might process the error.
         */
        routingRuleCondition?: pulumi.Input<inputs.s3.BucketRoutingRuleConditionArgs>;
    }
    /**
     * A container for describing a condition that must be met for the specified redirect to apply. For example, 1. If request is for pages in the ``/docs`` folder, redirect to the ``/documents`` folder. 2. If request results in HTTP error 4xx, redirect request to another host where you might process the error.
     */
    interface BucketRoutingRuleConditionArgs {
        /**
         * The HTTP error code when the redirect is applied. In the event of an error, if the error code equals this value, then the specified redirect is applied.
         *  Required when parent element ``Condition`` is specified and sibling ``KeyPrefixEquals`` is not specified. If both are specified, then both must be true for the redirect to be applied.
         */
        httpErrorCodeReturnedEquals?: pulumi.Input<string>;
        /**
         * The object key name prefix when the redirect is applied. For example, to redirect requests for ``ExamplePage.html``, the key prefix will be ``ExamplePage.html``. To redirect request for all pages with the prefix ``docs/``, the key prefix will be ``/docs``, which identifies all objects in the docs/ folder.
         *  Required when the parent element ``Condition`` is specified and sibling ``HttpErrorCodeReturnedEquals`` is not specified. If both conditions are specified, both must be true for the redirect to be applied.
         */
        keyPrefixEquals?: pulumi.Input<string>;
    }
    /**
     * Specifies lifecycle rules for an Amazon S3 bucket. For more information, see [Put Bucket Lifecycle Configuration](https://docs.aws.amazon.com/AmazonS3/latest/API/RESTBucketPUTlifecycle.html) in the *Amazon S3 API Reference*.
     *  You must specify at least one of the following properties: ``AbortIncompleteMultipartUpload``, ``ExpirationDate``, ``ExpirationInDays``, ``NoncurrentVersionExpirationInDays``, ``NoncurrentVersionTransition``, ``NoncurrentVersionTransitions``, ``Transition``, or ``Transitions``.
     */
    interface BucketRuleArgs {
        /**
         * Specifies a lifecycle rule that stops incomplete multipart uploads to an Amazon S3 bucket.
         */
        abortIncompleteMultipartUpload?: pulumi.Input<inputs.s3.BucketAbortIncompleteMultipartUploadArgs>;
        /**
         * Indicates when objects are deleted from Amazon S3 and Amazon S3 Glacier. The date value must be in ISO 8601 format. The time is always midnight UTC. If you specify an expiration and transition time, you must use the same time unit for both properties (either in days or by date). The expiration time must also be later than the transition time.
         */
        expirationDate?: pulumi.Input<string>;
        /**
         * Indicates the number of days after creation when objects are deleted from Amazon S3 and Amazon S3 Glacier. If you specify an expiration and transition time, you must use the same time unit for both properties (either in days or by date). The expiration time must also be later than the transition time.
         */
        expirationInDays?: pulumi.Input<number>;
        /**
         * Indicates whether Amazon S3 will remove a delete marker without any noncurrent versions. If set to true, the delete marker will be removed if there are no noncurrent versions. This cannot be specified with ``ExpirationInDays``, ``ExpirationDate``, or ``TagFilters``.
         */
        expiredObjectDeleteMarker?: pulumi.Input<boolean>;
        /**
         * Unique identifier for the rule. The value can't be longer than 255 characters.
         */
        id?: pulumi.Input<string>;
        /**
         * Specifies when noncurrent object versions expire. Upon expiration, S3 permanently deletes the noncurrent object versions. You set this lifecycle configuration action on a bucket that has versioning enabled (or suspended) to request that S3 delete noncurrent object versions at a specific period in the object's lifetime.
         */
        noncurrentVersionExpiration?: pulumi.Input<inputs.s3.BucketNoncurrentVersionExpirationArgs>;
        /**
         * (Deprecated.) For buckets with versioning enabled (or suspended), specifies the time, in days, between when a new version of the object is uploaded to the bucket and when old versions of the object expire. When object versions expire, Amazon S3 permanently deletes them. If you specify a transition and expiration time, the expiration time must be later than the transition time.
         */
        noncurrentVersionExpirationInDays?: pulumi.Input<number>;
        /**
         * (Deprecated.) For buckets with versioning enabled (or suspended), specifies when non-current objects transition to a specified storage class. If you specify a transition and expiration time, the expiration time must be later than the transition time. If you specify this property, don't specify the ``NoncurrentVersionTransitions`` property.
         */
        noncurrentVersionTransition?: pulumi.Input<inputs.s3.BucketNoncurrentVersionTransitionArgs>;
        /**
         * For buckets with versioning enabled (or suspended), one or more transition rules that specify when non-current objects transition to a specified storage class. If you specify a transition and expiration time, the expiration time must be later than the transition time. If you specify this property, don't specify the ``NoncurrentVersionTransition`` property.
         */
        noncurrentVersionTransitions?: pulumi.Input<pulumi.Input<inputs.s3.BucketNoncurrentVersionTransitionArgs>[]>;
        /**
         * Specifies the minimum object size in bytes for this rule to apply to. Objects must be larger than this value in bytes. For more information about size based rules, see [Lifecycle configuration using size-based rules](https://docs.aws.amazon.com/AmazonS3/latest/userguide/lifecycle-configuration-examples.html#lc-size-rules) in the *Amazon S3 User Guide*.
         */
        objectSizeGreaterThan?: pulumi.Input<string>;
        /**
         * Specifies the maximum object size in bytes for this rule to apply to. Objects must be smaller than this value in bytes. For more information about sized based rules, see [Lifecycle configuration using size-based rules](https://docs.aws.amazon.com/AmazonS3/latest/userguide/lifecycle-configuration-examples.html#lc-size-rules) in the *Amazon S3 User Guide*.
         */
        objectSizeLessThan?: pulumi.Input<string>;
        /**
         * Object key prefix that identifies one or more objects to which this rule applies.
         *   Replacement must be made for object keys containing special characters (such as carriage returns) when using XML requests. For more information, see [XML related object key constraints](https://docs.aws.amazon.com/AmazonS3/latest/userguide/object-keys.html#object-key-xml-related-constraints).
         */
        prefix?: pulumi.Input<string>;
        /**
         * If ``Enabled``, the rule is currently being applied. If ``Disabled``, the rule is not currently being applied.
         */
        status: pulumi.Input<enums.s3.BucketRuleStatus>;
        /**
         * Tags to use to identify a subset of objects to which the lifecycle rule applies.
         */
        tagFilters?: pulumi.Input<pulumi.Input<inputs.s3.BucketTagFilterArgs>[]>;
        /**
         * (Deprecated.) Specifies when an object transitions to a specified storage class. If you specify an expiration and transition time, you must use the same time unit for both properties (either in days or by date). The expiration time must also be later than the transition time. If you specify this property, don't specify the ``Transitions`` property.
         */
        transition?: pulumi.Input<inputs.s3.BucketTransitionArgs>;
        /**
         * One or more transition rules that specify when an object transitions to a specified storage class. If you specify an expiration and transition time, you must use the same time unit for both properties (either in days or by date). The expiration time must also be later than the transition time. If you specify this property, don't specify the ``Transition`` property.
         */
        transitions?: pulumi.Input<pulumi.Input<inputs.s3.BucketTransitionArgs>[]>;
    }
    /**
     * A container for object key name prefix and suffix filtering rules. For more information about object key name filtering, see [Configuring event notifications using object key name filtering](https://docs.aws.amazon.com/AmazonS3/latest/userguide/notification-how-to-filtering.html) in the *Amazon S3 User Guide*.
     *   The same type of filter rule cannot be used more than once. For example, you cannot specify two prefix rules.
     */
    interface BucketS3KeyFilterArgs {
        /**
         * A list of containers for the key-value pair that defines the criteria for the filter rule.
         */
        rules: pulumi.Input<pulumi.Input<inputs.s3.BucketFilterRuleArgs>[]>;
    }
    /**
     * The destination information for the metadata table configuration. The destination table bucket must be in the same Region and AWS-account as the general purpose bucket. The specified metadata table name must be unique within the ``aws_s3_metadata`` namespace in the destination table bucket.
     */
    interface BucketS3TablesDestinationArgs {
        /**
         * The Amazon Resource Name (ARN) for the metadata table in the metadata table configuration. The specified metadata table name must be unique within the ``aws_s3_metadata`` namespace in the destination table bucket.
         */
        tableArn?: pulumi.Input<string>;
        /**
         * The Amazon Resource Name (ARN) for the table bucket that's specified as the destination in the metadata table configuration. The destination table bucket must be in the same Region and AWS-account as the general purpose bucket.
         */
        tableBucketArn: pulumi.Input<string>;
        /**
         * The name for the metadata table in your metadata table configuration. The specified metadata table name must be unique within the ``aws_s3_metadata`` namespace in the destination table bucket.
         */
        tableName: pulumi.Input<string>;
        /**
         * The table bucket namespace for the metadata table in your metadata table configuration. This value is always ``aws_s3_metadata``.
         */
        tableNamespace?: pulumi.Input<string>;
    }
    /**
     * Describes the default server-side encryption to apply to new objects in the bucket. If a PUT Object request doesn't specify any server-side encryption, this default encryption will be applied. For more information, see [PutBucketEncryption](https://docs.aws.amazon.com/AmazonS3/latest/API/RESTBucketPUTencryption.html).
     *    +   *General purpose buckets* - If you don't specify a customer managed key at configuration, Amazon S3 automatically creates an AWS KMS key (``aws/s3``) in your AWS account the first time that you add an object encrypted with SSE-KMS to a bucket. By default, Amazon S3 uses this KMS key for SSE-KMS.
     *   +   *Directory buckets* - Your SSE-KMS configuration can only support 1 [customer managed key](https://docs.aws.amazon.com/kms/latest/developerguide/concepts.html#customer-cmk) per directory bucket's lifetime. The [managed key](https://docs.aws.amazon.com/kms/latest/developerguide/concepts.html#aws-managed-cmk) (``aws/s3``) isn't supported.
     *   +   *Directory buckets* - For directory buckets, there are only two supported options for server-side encryption: SSE-S3 and SSE-KMS.
     */
    interface BucketServerSideEncryptionByDefaultArgs {
        /**
         * AWS Key Management Service (KMS) customer managed key ID to use for the default encryption.
         *    +   *General purpose buckets* - This parameter is allowed if and only if ``SSEAlgorithm`` is set to ``aws:kms`` or ``aws:kms:dsse``.
         *   +   *Directory buckets* - This parameter is allowed if and only if ``SSEAlgorithm`` is set to ``aws:kms``.
         *
         *   You can specify the key ID, key alias, or the Amazon Resource Name (ARN) of the KMS key.
         *   +  Key ID: ``1234abcd-12ab-34cd-56ef-1234567890ab``
         *   +  Key ARN: ``arn:aws:kms:us-east-2:111122223333:key/1234abcd-12ab-34cd-56ef-1234567890ab``
         *   +  Key Alias: ``alias/alias-name``
         *
         *  If you are using encryption with cross-account or AWS service operations, you must use a fully qualified KMS key ARN. For more information, see [Using encryption for cross-account operations](https://docs.aws.amazon.com/AmazonS3/latest/dev/bucket-encryption.html#bucket-encryption-update-bucket-policy).
         *    +   *General purpose buckets* - If you're specifying a customer managed KMS key, we recommend using a fully qualified KMS key ARN. If you use a KMS key alias instead, then KMS resolves the key within the requester’s account. This behavior can result in data that's encrypted with a KMS key that belongs to the requester, and not the bucket owner. Also, if you use a key ID, you can run into a LogDestination undeliverable error when creating a VPC flow log.
         *   +   *Directory buckets* - When you specify an [customer managed key](https://docs.aws.amazon.com/kms/latest/developerguide/concepts.html#customer-cmk) for encryption in your directory bucket, only use the key ID or key ARN. The key alias format of the KMS key isn't supported.
         *
         *    Amazon S3 only supports symmetric encryption KMS keys. For more information, see [Asymmetric keys in KMS](https://docs.aws.amazon.com//kms/latest/developerguide/symmetric-asymmetric.html) in the *Key Management Service Developer Guide*.
         */
        kmsMasterKeyId?: pulumi.Input<string>;
        /**
         * Server-side encryption algorithm to use for the default encryption.
         *   For directory buckets, there are only two supported values for server-side encryption: ``AES256`` and ``aws:kms``.
         */
        sseAlgorithm: pulumi.Input<enums.s3.BucketServerSideEncryptionByDefaultSseAlgorithm>;
    }
    /**
     * Specifies the default server-side encryption configuration.
     *    +   *General purpose buckets* - If you're specifying a customer managed KMS key, we recommend using a fully qualified KMS key ARN. If you use a KMS key alias instead, then KMS resolves the key within the requester’s account. This behavior can result in data that's encrypted with a KMS key that belongs to the requester, and not the bucket owner.
     *   +   *Directory buckets* - When you specify an [customer managed key](https://docs.aws.amazon.com/kms/latest/developerguide/concepts.html#customer-cmk) for encryption in your directory bucket, only use the key ID or key ARN. The key alias format of the KMS key isn't supported.
     */
    interface BucketServerSideEncryptionRuleArgs {
        /**
         * Specifies whether Amazon S3 should use an S3 Bucket Key with server-side encryption using KMS (SSE-KMS) for new objects in the bucket. Existing objects are not affected. Setting the ``BucketKeyEnabled`` element to ``true`` causes Amazon S3 to use an S3 Bucket Key. By default, S3 Bucket Key is not enabled.
         *  For more information, see [Amazon S3 Bucket Keys](https://docs.aws.amazon.com/AmazonS3/latest/dev/bucket-key.html) in the *Amazon S3 User Guide*.
         */
        bucketKeyEnabled?: pulumi.Input<boolean>;
        /**
         * Specifies the default server-side encryption to apply to new objects in the bucket. If a PUT Object request doesn't specify any server-side encryption, this default encryption will be applied.
         */
        serverSideEncryptionByDefault?: pulumi.Input<inputs.s3.BucketServerSideEncryptionByDefaultArgs>;
    }
    /**
     * A container that describes additional filters for identifying the source objects that you want to replicate. You can choose to enable or disable the replication of these objects.
     */
    interface BucketSourceSelectionCriteriaArgs {
        /**
         * A filter that you can specify for selection for modifications on replicas.
         */
        replicaModifications?: pulumi.Input<inputs.s3.BucketReplicaModificationsArgs>;
        /**
         * A container for filter information for the selection of Amazon S3 objects encrypted with AWS KMS.
         */
        sseKmsEncryptedObjects?: pulumi.Input<inputs.s3.BucketSseKmsEncryptedObjectsArgs>;
    }
    /**
     * A container for filter information for the selection of S3 objects encrypted with AWS KMS.
     */
    interface BucketSseKmsEncryptedObjectsArgs {
        /**
         * Specifies whether Amazon S3 replicates objects created with server-side encryption using an AWS KMS key stored in AWS Key Management Service.
         */
        status: pulumi.Input<enums.s3.BucketSseKmsEncryptedObjectsStatus>;
    }
    /**
     * Specifies data related to access patterns to be collected and made available to analyze the tradeoffs between different storage classes for an Amazon S3 bucket.
     */
    interface BucketStorageClassAnalysisArgs {
        /**
         * Specifies how data related to the storage class analysis for an Amazon S3 bucket should be exported.
         */
        dataExport?: pulumi.Input<inputs.s3.BucketDataExportArgs>;
    }
    /**
     * Specifies tags to use to identify a subset of objects for an Amazon S3 bucket. For more information, see [Categorizing your storage using tags](https://docs.aws.amazon.com/AmazonS3/latest/userguide/object-tagging.html) in the *Amazon Simple Storage Service User Guide*.
     */
    interface BucketTagFilterArgs {
        /**
         * The tag key.
         */
        key: pulumi.Input<string>;
        /**
         * The tag value.
         */
        value: pulumi.Input<string>;
    }
    /**
     * Describes the key format for server access log file in the target bucket. You can choose between SimplePrefix and PartitionedPrefix.
     */
    interface BucketTargetObjectKeyFormatArgs {
    }
    /**
     * The S3 Intelligent-Tiering storage class is designed to optimize storage costs by automatically moving data to the most cost-effective storage access tier, without additional operational overhead.
     */
    interface BucketTieringArgs {
        /**
         * S3 Intelligent-Tiering access tier. See [Storage class for automatically optimizing frequently and infrequently accessed objects](https://docs.aws.amazon.com/AmazonS3/latest/dev/storage-class-intro.html#sc-dynamic-data-access) for a list of access tiers in the S3 Intelligent-Tiering storage class.
         */
        accessTier: pulumi.Input<enums.s3.BucketTieringAccessTier>;
        /**
         * The number of consecutive days of no access after which an object will be eligible to be transitioned to the corresponding tier. The minimum number of days specified for Archive Access tier must be at least 90 days and Deep Archive Access tier must be at least 180 days. The maximum can be up to 2 years (730 days).
         */
        days: pulumi.Input<number>;
    }
    /**
     * A container for specifying the configuration for publication of messages to an Amazon Simple Notification Service (Amazon SNS) topic when Amazon S3 detects specified events.
     */
    interface BucketTopicConfigurationArgs {
        /**
         * The Amazon S3 bucket event about which to send notifications. For more information, see [Supported Event Types](https://docs.aws.amazon.com/AmazonS3/latest/dev/NotificationHowTo.html) in the *Amazon S3 User Guide*.
         */
        event: pulumi.Input<string>;
        /**
         * The filtering rules that determine for which objects to send notifications. For example, you can create a filter so that Amazon S3 sends notifications only when image files with a ``.jpg`` extension are added to the bucket.
         */
        filter?: pulumi.Input<inputs.s3.BucketNotificationFilterArgs>;
        /**
         * The Amazon Resource Name (ARN) of the Amazon SNS topic to which Amazon S3 publishes a message when it detects events of the specified type.
         */
        topic: pulumi.Input<string>;
    }
    /**
     * Specifies when an object transitions to a specified storage class. For more information about Amazon S3 lifecycle configuration rules, see [Transitioning Objects Using Amazon S3 Lifecycle](https://docs.aws.amazon.com/AmazonS3/latest/dev/lifecycle-transition-general-considerations.html) in the *Amazon S3 User Guide*.
     */
    interface BucketTransitionArgs {
        /**
         * The storage class to which you want the object to transition.
         */
        storageClass: pulumi.Input<enums.s3.BucketTransitionStorageClass>;
        /**
         * Indicates when objects are transitioned to the specified storage class. The date value must be in ISO 8601 format. The time is always midnight UTC.
         */
        transitionDate?: pulumi.Input<string>;
        /**
         * Indicates the number of days after creation when objects are transitioned to the specified storage class. If the specified storage class is ``INTELLIGENT_TIERING``, ``GLACIER_IR``, ``GLACIER``, or ``DEEP_ARCHIVE``, valid values are ``0`` or positive integers. If the specified storage class is ``STANDARD_IA`` or ``ONEZONE_IA``, valid values are positive integers greater than ``30``. Be aware that some storage classes have a minimum storage duration and that you're charged for transitioning objects before their minimum storage duration. For more information, see [Constraints and considerations for transitions](https://docs.aws.amazon.com/AmazonS3/latest/userguide/lifecycle-transition-general-considerations.html#lifecycle-configuration-constraints) in the *Amazon S3 User Guide*.
         */
        transitionInDays?: pulumi.Input<number>;
    }
    /**
     * Describes the versioning state of an Amazon S3 bucket. For more information, see [PUT Bucket versioning](https://docs.aws.amazon.com/AmazonS3/latest/API/RESTBucketPUTVersioningStatus.html) in the *Amazon S3 API Reference*.
     *   When you enable versioning on a bucket for the first time, it might take a short amount of time for the change to be fully propagated. We recommend that you wait for 15 minutes after enabling versioning before issuing write operations (``PUT`` or ``DELETE``) on objects in the bucket.
     */
    interface BucketVersioningConfigurationArgs {
        /**
         * The versioning state of the bucket.
         */
        status: pulumi.Input<enums.s3.BucketVersioningConfigurationStatus>;
    }
    /**
     * Specifies website configuration parameters for an Amazon S3 bucket.
     */
    interface BucketWebsiteConfigurationArgs {
        /**
         * The name of the error document for the website.
         */
        errorDocument?: pulumi.Input<string>;
        /**
         * The name of the index document for the website.
         */
        indexDocument?: pulumi.Input<string>;
        /**
         * The redirect behavior for every request to this bucket's website endpoint.
         *   If you specify this property, you can't specify any other property.
         */
        redirectAllRequestsTo?: pulumi.Input<inputs.s3.BucketRedirectAllRequestsToArgs>;
        /**
         * Rules that define when a redirect is applied and the redirect behavior.
         */
        routingRules?: pulumi.Input<pulumi.Input<inputs.s3.BucketRoutingRuleArgs>[]>;
    }
    interface MultiRegionAccessPointPublicAccessBlockConfigurationArgs {
        /**
         * Specifies whether Amazon S3 should block public access control lists (ACLs) for buckets in this account. Setting this element to TRUE causes the following behavior:
         * - PUT Bucket acl and PUT Object acl calls fail if the specified ACL is public.
         *  - PUT Object calls fail if the request includes a public ACL.
         * . - PUT Bucket calls fail if the request includes a public ACL.
         * Enabling this setting doesn't affect existing policies or ACLs.
         */
        blockPublicAcls?: pulumi.Input<boolean>;
        /**
         * Specifies whether Amazon S3 should block public bucket policies for buckets in this account. Setting this element to TRUE causes Amazon S3 to reject calls to PUT Bucket policy if the specified bucket policy allows public access. Enabling this setting doesn't affect existing bucket policies.
         */
        blockPublicPolicy?: pulumi.Input<boolean>;
        /**
         * Specifies whether Amazon S3 should ignore public ACLs for buckets in this account. Setting this element to TRUE causes Amazon S3 to ignore all public ACLs on buckets in this account and any objects that they contain. Enabling this setting doesn't affect the persistence of any existing ACLs and doesn't prevent new public ACLs from being set.
         */
        ignorePublicAcls?: pulumi.Input<boolean>;
        /**
         * Specifies whether Amazon S3 should restrict public bucket policies for this bucket. Setting this element to TRUE restricts access to this bucket to only AWS services and authorized users within this account if the bucket has a public policy.
         * Enabling this setting doesn't affect previously stored bucket policies, except that public and cross-account access within any public bucket policy, including non-public delegation to specific accounts, is blocked.
         */
        restrictPublicBuckets?: pulumi.Input<boolean>;
    }
    interface MultiRegionAccessPointRegionArgs {
        /**
         * The name of the associated bucket for the Region.
         */
        bucket: pulumi.Input<string>;
        /**
         * The AWS account ID that owns the Amazon S3 bucket that's associated with this Multi-Region Access Point.
         */
        bucketAccountId?: pulumi.Input<string>;
    }
    /**
     * Account-level metrics configurations.
     */
    interface StorageLensAccountLevelArgs {
        /**
         * This property contains the details of account-level activity metrics for S3 Storage Lens.
         */
        activityMetrics?: pulumi.Input<inputs.s3.StorageLensActivityMetricsArgs>;
        /**
         * This property contains the details of account-level advanced cost optimization metrics for S3 Storage Lens.
         */
        advancedCostOptimizationMetrics?: pulumi.Input<inputs.s3.StorageLensAdvancedCostOptimizationMetricsArgs>;
        /**
         * This property contains the details of account-level advanced data protection metrics for S3 Storage Lens.
         */
        advancedDataProtectionMetrics?: pulumi.Input<inputs.s3.StorageLensAdvancedDataProtectionMetricsArgs>;
        /**
         * This property contains the details of the account-level bucket-level configurations for Amazon S3 Storage Lens. To enable bucket-level configurations, make sure to also set the same metrics at the account level.
         */
        bucketLevel: pulumi.Input<inputs.s3.StorageLensBucketLevelArgs>;
        /**
         * This property contains the details of account-level detailed status code metrics for S3 Storage Lens.
         */
        detailedStatusCodesMetrics?: pulumi.Input<inputs.s3.StorageLensDetailedStatusCodesMetricsArgs>;
        /**
         * This property determines the scope of Storage Lens group data that is displayed in the Storage Lens dashboard.
         */
        storageLensGroupLevel?: pulumi.Input<inputs.s3.StorageLensGroupLevelArgs>;
    }
    /**
     * Enables activity metrics.
     */
    interface StorageLensActivityMetricsArgs {
        /**
         * Specifies whether activity metrics are enabled or disabled.
         */
        isEnabled?: pulumi.Input<boolean>;
    }
    /**
     * Enables advanced cost optimization metrics.
     */
    interface StorageLensAdvancedCostOptimizationMetricsArgs {
        /**
         * Specifies whether advanced cost optimization metrics are enabled or disabled.
         */
        isEnabled?: pulumi.Input<boolean>;
    }
    /**
     * Enables advanced data protection metrics.
     */
    interface StorageLensAdvancedDataProtectionMetricsArgs {
        /**
         * Specifies whether advanced data protection metrics are enabled or disabled.
         */
        isEnabled?: pulumi.Input<boolean>;
    }
    /**
     * The AWS Organizations ARN to use in the Amazon S3 Storage Lens configuration.
     */
    interface StorageLensAwsOrgArgs {
        /**
         * This resource contains the ARN of the AWS Organization.
         */
        arn: pulumi.Input<string>;
    }
    /**
     * Bucket-level metrics configurations.
     */
    interface StorageLensBucketLevelArgs {
        /**
         * A property for bucket-level activity metrics for S3 Storage Lens.
         */
        activityMetrics?: pulumi.Input<inputs.s3.StorageLensActivityMetricsArgs>;
        /**
         * A property for bucket-level advanced cost optimization metrics for S3 Storage Lens.
         */
        advancedCostOptimizationMetrics?: pulumi.Input<inputs.s3.StorageLensAdvancedCostOptimizationMetricsArgs>;
        /**
         * A property for bucket-level advanced data protection metrics for S3 Storage Lens.
         */
        advancedDataProtectionMetrics?: pulumi.Input<inputs.s3.StorageLensAdvancedDataProtectionMetricsArgs>;
        /**
         * A property for bucket-level detailed status code metrics for S3 Storage Lens.
         */
        detailedStatusCodesMetrics?: pulumi.Input<inputs.s3.StorageLensDetailedStatusCodesMetricsArgs>;
        /**
         * A property for bucket-level prefix-level storage metrics for S3 Storage Lens.
         */
        prefixLevel?: pulumi.Input<inputs.s3.StorageLensPrefixLevelArgs>;
    }
    /**
     * S3 buckets and Regions to include/exclude in the Amazon S3 Storage Lens configuration.
     */
    interface StorageLensBucketsAndRegionsArgs {
        /**
         * This property contains the details of the buckets for the Amazon S3 Storage Lens configuration. This should be the bucket Amazon Resource Name(ARN). For valid values, see [Buckets ARN format here](https://docs.aws.amazon.com/AmazonS3/latest/API/API_control_Include.html#API_control_Include_Contents) in the *Amazon S3 API Reference* .
         */
        buckets?: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * This property contains the details of the Regions for the S3 Storage Lens configuration.
         */
        regions?: pulumi.Input<pulumi.Input<string>[]>;
    }
    /**
     * CloudWatch metrics settings for the Amazon S3 Storage Lens metrics export.
     */
    interface StorageLensCloudWatchMetricsArgs {
        /**
         * Specifies whether CloudWatch metrics are enabled or disabled.
         */
        isEnabled: pulumi.Input<boolean>;
    }
    /**
     * Specifies the details of Amazon S3 Storage Lens configuration.
     */
    interface StorageLensConfigurationArgs {
        /**
         * This property contains the details of the account-level metrics for Amazon S3 Storage Lens configuration.
         */
        accountLevel: pulumi.Input<inputs.s3.StorageLensAccountLevelArgs>;
        /**
         * This property contains the details of the AWS Organization for the S3 Storage Lens configuration.
         */
        awsOrg?: pulumi.Input<inputs.s3.StorageLensAwsOrgArgs>;
        /**
         * This property contains the details of this S3 Storage Lens configuration's metrics export.
         */
        dataExport?: pulumi.Input<inputs.s3.StorageLensDataExportArgs>;
        /**
         * This property contains the details of the bucket and or Regions excluded for Amazon S3 Storage Lens configuration.
         */
        exclude?: pulumi.Input<inputs.s3.StorageLensBucketsAndRegionsArgs>;
        /**
         * This property contains the details of the ID of the S3 Storage Lens configuration.
         */
        id: pulumi.Input<string>;
        /**
         * This property contains the details of the bucket and or Regions included for Amazon S3 Storage Lens configuration.
         */
        include?: pulumi.Input<inputs.s3.StorageLensBucketsAndRegionsArgs>;
        /**
         * Specifies whether the Amazon S3 Storage Lens configuration is enabled or disabled.
         */
        isEnabled: pulumi.Input<boolean>;
        /**
         * The ARN for the Amazon S3 Storage Lens configuration.
         */
        storageLensArn?: pulumi.Input<string>;
    }
    /**
     * Specifies how Amazon S3 Storage Lens metrics should be exported.
     */
    interface StorageLensDataExportArgs {
        /**
         * This property enables the Amazon CloudWatch publishing option for S3 Storage Lens metrics.
         */
        cloudWatchMetrics?: pulumi.Input<inputs.s3.StorageLensCloudWatchMetricsArgs>;
        /**
         * This property contains the details of the bucket where the S3 Storage Lens metrics export will be placed.
         */
        s3BucketDestination?: pulumi.Input<inputs.s3.StorageLensS3BucketDestinationArgs>;
    }
    /**
     * Enables detailed status codes metrics.
     */
    interface StorageLensDetailedStatusCodesMetricsArgs {
        /**
         * Specifies whether detailed status codes metrics are enabled or disabled.
         */
        isEnabled?: pulumi.Input<boolean>;
    }
    /**
     * Configures the server-side encryption for Amazon S3 Storage Lens report files with either S3-managed keys (SSE-S3) or KMS-managed keys (SSE-KMS).
     */
    interface StorageLensEncryptionArgs {
    }
    /**
     * The Storage Lens group will include objects that match all of the specified filter values.
     */
    interface StorageLensGroupAndArgs {
        /**
         * This property contains a list of prefixes. At least one prefix must be specified. Up to 10 prefixes are allowed.
         */
        matchAnyPrefix?: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * This property contains a list of suffixes. At least one suffix must be specified. Up to 10 suffixes are allowed.
         */
        matchAnySuffix?: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * This property contains the list of object tags. At least one object tag must be specified. Up to 10 object tags are allowed.
         */
        matchAnyTag?: pulumi.Input<pulumi.Input<inputs.s3.StorageLensGroupTagArgs>[]>;
        /**
         * This property contains `DaysGreaterThan` and `DaysLessThan` properties to define the object age range (minimum and maximum number of days).
         */
        matchObjectAge?: pulumi.Input<inputs.s3.StorageLensGroupMatchObjectAgeArgs>;
        /**
         * This property contains `BytesGreaterThan` and `BytesLessThan` to define the object size range (minimum and maximum number of Bytes).
         */
        matchObjectSize?: pulumi.Input<inputs.s3.StorageLensGroupMatchObjectSizeArgs>;
    }
    /**
     * Sets the Storage Lens Group filter.
     */
    interface StorageLensGroupFilterArgs {
        /**
         * This property contains the `And` logical operator, which allows multiple filter conditions to be joined for more complex comparisons of Storage Lens group data. Objects must match all of the listed filter conditions that are joined by the `And` logical operator. Only one of each filter condition is allowed.
         */
        and?: pulumi.Input<inputs.s3.StorageLensGroupAndArgs>;
        /**
         * This property contains a list of prefixes. At least one prefix must be specified. Up to 10 prefixes are allowed.
         */
        matchAnyPrefix?: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * This property contains a list of suffixes. At least one suffix must be specified. Up to 10 suffixes are allowed.
         */
        matchAnySuffix?: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * This property contains the list of S3 object tags. At least one object tag must be specified. Up to 10 object tags are allowed.
         */
        matchAnyTag?: pulumi.Input<pulumi.Input<inputs.s3.StorageLensGroupTagArgs>[]>;
        /**
         * This property contains `DaysGreaterThan` and `DaysLessThan` to define the object age range (minimum and maximum number of days).
         */
        matchObjectAge?: pulumi.Input<inputs.s3.StorageLensGroupMatchObjectAgeArgs>;
        /**
         * This property contains `BytesGreaterThan` and `BytesLessThan` to define the object size range (minimum and maximum number of Bytes).
         */
        matchObjectSize?: pulumi.Input<inputs.s3.StorageLensGroupMatchObjectSizeArgs>;
        /**
         * This property contains the `Or` logical operator, which allows multiple filter conditions to be joined. Objects can match any of the listed filter conditions, which are joined by the `Or` logical operator. Only one of each filter condition is allowed.
         */
        or?: pulumi.Input<inputs.s3.StorageLensGroupOrArgs>;
    }
    /**
     * Specifies the details of Amazon S3 Storage Lens Group configuration.
     */
    interface StorageLensGroupLevelArgs {
        /**
         * This property indicates which Storage Lens group ARNs to include or exclude in the Storage Lens group aggregation. If this value is left null, then all Storage Lens groups are selected.
         */
        storageLensGroupSelectionCriteria?: pulumi.Input<inputs.s3.StorageLensGroupSelectionCriteriaArgs>;
    }
    /**
     * Filter to match all of the specified values for the minimum and maximum object age.
     */
    interface StorageLensGroupMatchObjectAgeArgs {
        /**
         * Minimum object age to which the rule applies.
         */
        daysGreaterThan?: pulumi.Input<number>;
        /**
         * Maximum object age to which the rule applies.
         */
        daysLessThan?: pulumi.Input<number>;
    }
    /**
     * Filter to match all of the specified values for the minimum and maximum object size.
     */
    interface StorageLensGroupMatchObjectSizeArgs {
        /**
         * Minimum object size to which the rule applies.
         */
        bytesGreaterThan?: pulumi.Input<number>;
        /**
         * Maximum object size to which the rule applies.
         */
        bytesLessThan?: pulumi.Input<number>;
    }
    /**
     * The Storage Lens group will include objects that match any of the specified filter values.
     */
    interface StorageLensGroupOrArgs {
        /**
         * This property contains a list of prefixes. At least one prefix must be specified. Up to 10 prefixes are allowed.
         */
        matchAnyPrefix?: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * This property contains the list of suffixes. At least one suffix must be specified. Up to 10 suffixes are allowed.
         */
        matchAnySuffix?: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * This property contains the list of S3 object tags. At least one object tag must be specified. Up to 10 object tags are allowed.
         */
        matchAnyTag?: pulumi.Input<pulumi.Input<inputs.s3.StorageLensGroupTagArgs>[]>;
        /**
         * This property filters objects that match the specified object age range.
         */
        matchObjectAge?: pulumi.Input<inputs.s3.StorageLensGroupMatchObjectAgeArgs>;
        /**
         * This property contains the `BytesGreaterThan` and `BytesLessThan` values to define the object size range (minimum and maximum number of Bytes).
         */
        matchObjectSize?: pulumi.Input<inputs.s3.StorageLensGroupMatchObjectSizeArgs>;
    }
    /**
     * Selection criteria for Storage Lens Group level metrics
     */
    interface StorageLensGroupSelectionCriteriaArgs {
        /**
         * This property indicates which Storage Lens group ARNs to exclude from the Storage Lens group aggregation.
         */
        exclude?: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * This property indicates which Storage Lens group ARNs to include in the Storage Lens group aggregation.
         */
        include?: pulumi.Input<pulumi.Input<string>[]>;
    }
    interface StorageLensGroupTagArgs {
        key: pulumi.Input<string>;
        value: pulumi.Input<string>;
    }
    /**
     * Prefix-level metrics configurations.
     */
    interface StorageLensPrefixLevelArgs {
        /**
         * A property for the prefix-level storage metrics for Amazon S3 Storage Lens.
         */
        storageMetrics: pulumi.Input<inputs.s3.StorageLensPrefixLevelStorageMetricsArgs>;
    }
    interface StorageLensPrefixLevelStorageMetricsArgs {
        /**
         * Specifies whether prefix-level storage metrics are enabled or disabled.
         */
        isEnabled?: pulumi.Input<boolean>;
        /**
         * This property identifies whether the details of the prefix-level storage metrics for S3 Storage Lens are enabled.
         */
        selectionCriteria?: pulumi.Input<inputs.s3.StorageLensSelectionCriteriaArgs>;
    }
    /**
     * S3 bucket destination settings for the Amazon S3 Storage Lens metrics export.
     */
    interface StorageLensS3BucketDestinationArgs {
        /**
         * The AWS account ID that owns the destination S3 bucket.
         */
        accountId: pulumi.Input<string>;
        /**
         * The ARN of the bucket to which Amazon S3 Storage Lens exports will be placed.
         */
        arn: pulumi.Input<string>;
        /**
         * This property contains the details of the encryption of the bucket destination of the Amazon S3 Storage Lens metrics export.
         */
        encryption?: pulumi.Input<inputs.s3.StorageLensEncryptionArgs>;
        /**
         * Specifies the file format to use when exporting Amazon S3 Storage Lens metrics export.
         */
        format: pulumi.Input<enums.s3.StorageLensS3BucketDestinationFormat>;
        /**
         * The version of the output schema to use when exporting Amazon S3 Storage Lens metrics.
         */
        outputSchemaVersion: pulumi.Input<enums.s3.StorageLensS3BucketDestinationOutputSchemaVersion>;
        /**
         * The prefix to use for Amazon S3 Storage Lens export.
         */
        prefix?: pulumi.Input<string>;
    }
    /**
     * Selection criteria for prefix-level metrics.
     */
    interface StorageLensSelectionCriteriaArgs {
        /**
         * Delimiter to divide S3 key into hierarchy of prefixes.
         */
        delimiter?: pulumi.Input<string>;
        /**
         * Max depth of prefixes of S3 key that Amazon S3 Storage Lens will analyze.
         */
        maxDepth?: pulumi.Input<number>;
        /**
         * The minimum storage bytes threshold for the prefixes to be included in the analysis.
         */
        minStorageBytesPercentage?: pulumi.Input<number>;
    }
}
export declare namespace s3express {
    /**
     * Specifies the days since the initiation of an incomplete multipart upload that Amazon S3 will wait before permanently removing all parts of the upload.
     */
    interface DirectoryBucketAbortIncompleteMultipartUploadArgs {
        /**
         * Specifies the number of days after which Amazon S3 aborts an incomplete multipart upload.
         */
        daysAfterInitiation: pulumi.Input<number>;
    }
    /**
     * Specifies default encryption for a bucket using server-side encryption with Amazon S3 managed keys (SSE-S3) or AWS KMS keys (SSE-KMS).
     */
    interface DirectoryBucketBucketEncryptionArgs {
        /**
         * Specifies the default server-side-encryption configuration.
         */
        serverSideEncryptionConfiguration: pulumi.Input<pulumi.Input<inputs.s3express.DirectoryBucketServerSideEncryptionRuleArgs>[]>;
    }
    interface DirectoryBucketLifecycleConfigurationArgs {
        /**
         * A lifecycle rule for individual objects in an Amazon S3 Express bucket.
         */
        rules: pulumi.Input<pulumi.Input<inputs.s3express.DirectoryBucketRuleArgs>[]>;
    }
    /**
     * You must specify at least one of the following properties: AbortIncompleteMultipartUpload, or ExpirationInDays.
     */
    interface DirectoryBucketRuleArgs {
        /**
         * Specifies the days since the initiation of an incomplete multipart upload that Amazon S3 will wait before permanently removing all parts of the upload.
         */
        abortIncompleteMultipartUpload?: pulumi.Input<inputs.s3express.DirectoryBucketAbortIncompleteMultipartUploadArgs>;
        /**
         * Indicates the number of days after creation when objects are deleted from Amazon S3 and Amazon S3 Glacier. If you specify an expiration and transition time, you must use the same time unit for both properties (either in days or by date). The expiration time must also be later than the transition time.
         */
        expirationInDays?: pulumi.Input<number>;
        /**
         * Unique identifier for the rule. The value can't be longer than 255 characters.
         */
        id?: pulumi.Input<string>;
        /**
         * Specifies the minimum object size in bytes for this rule to apply to. Objects must be larger than this value in bytes. For more information about size based rules, see [Lifecycle configuration using size-based rules](https://docs.aws.amazon.com/AmazonS3/latest/userguide/lifecycle-configuration-examples.html#lc-size-rules) in the *Amazon S3 User Guide* .
         */
        objectSizeGreaterThan?: pulumi.Input<string>;
        /**
         * Specifies the maximum object size in bytes for this rule to apply to. Objects must be smaller than this value in bytes. For more information about sized based rules, see [Lifecycle configuration using size-based rules](https://docs.aws.amazon.com/AmazonS3/latest/userguide/lifecycle-configuration-examples.html#lc-size-rules) in the *Amazon S3 User Guide* .
         */
        objectSizeLessThan?: pulumi.Input<string>;
        /**
         * Object key prefix that identifies one or more objects to which this rule applies.
         *
         * > Replacement must be made for object keys containing special characters (such as carriage returns) when using XML requests. For more information, see [XML related object key constraints](https://docs.aws.amazon.com/AmazonS3/latest/userguide/object-keys.html#object-key-xml-related-constraints) .
         */
        prefix?: pulumi.Input<string>;
        /**
         * If `Enabled` , the rule is currently being applied. If `Disabled` , the rule is not currently being applied.
         */
        status: pulumi.Input<enums.s3express.DirectoryBucketRuleStatus>;
    }
    /**
     * Specifies the default server-side encryption to apply to new objects in the bucket. If a PUT Object request doesn't specify any server-side encryption, this default encryption will be applied.
     */
    interface DirectoryBucketServerSideEncryptionByDefaultArgs {
        /**
         * AWS Key Management Service (KMS) customer managed key ID to use for the default encryption. This parameter is allowed only if SSEAlgorithm is set to aws:kms. You can specify this parameter with the key ID or the Amazon Resource Name (ARN) of the KMS key
         */
        kmsMasterKeyId?: pulumi.Input<string>;
        /**
         * Server-side encryption algorithm to use for the default encryption.
         *
         * > For directory buckets, there are only two supported values for server-side encryption: `AES256` and `aws:kms` .
         */
        sseAlgorithm: pulumi.Input<enums.s3express.DirectoryBucketServerSideEncryptionByDefaultSseAlgorithm>;
    }
    /**
     * Specifies the default server-side encryption configuration.
     */
    interface DirectoryBucketServerSideEncryptionRuleArgs {
        /**
         * Specifies whether Amazon S3 should use an S3 Bucket Key with server-side encryption using KMS (SSE-KMS) for new objects in the bucket. Existing objects are not affected. Amazon S3 Express One Zone uses an S3 Bucket Key with SSE-KMS and S3 Bucket Key cannot be disabled. It's only allowed to set the BucketKeyEnabled element to true.
         */
        bucketKeyEnabled?: pulumi.Input<boolean>;
        /**
         * Specifies the default server-side encryption to apply to new objects in the bucket. If a PUT Object request doesn't specify any server-side encryption, this default encryption will be applied.
         */
        serverSideEncryptionByDefault?: pulumi.Input<inputs.s3express.DirectoryBucketServerSideEncryptionByDefaultArgs>;
    }
}
export declare namespace s3objectlambda {
    interface AccessPointAwsLambdaArgs {
        functionArn: pulumi.Input<string>;
        functionPayload?: pulumi.Input<string>;
    }
    /**
     * Configuration to be applied to this Object lambda Access Point. It specifies Supporting Access Point, Transformation Configurations. Customers can also set if they like to enable Cloudwatch metrics for accesses to this Object lambda Access Point. Default setting for Cloudwatch metrics is disable.
     */
    interface AccessPointObjectLambdaConfigurationArgs {
        /**
         * A container for allowed features. Valid inputs are `GetObject-Range` , `GetObject-PartNumber` , `HeadObject-Range` , and `HeadObject-PartNumber` .
         */
        allowedFeatures?: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * A container for whether the CloudWatch metrics configuration is enabled.
         */
        cloudWatchMetricsEnabled?: pulumi.Input<boolean>;
        /**
         * Standard access point associated with the Object Lambda Access Point.
         */
        supportingAccessPoint: pulumi.Input<string>;
        /**
         * A container for transformation configurations for an Object Lambda Access Point.
         */
        transformationConfigurations: pulumi.Input<pulumi.Input<inputs.s3objectlambda.AccessPointTransformationConfigurationArgs>[]>;
    }
    /**
     * Configuration to define what content transformation will be applied on which S3 Action.
     */
    interface AccessPointTransformationConfigurationArgs {
        /**
         * A container for the action of an Object Lambda Access Point configuration. Valid inputs are `GetObject` , `HeadObject` , `ListObject` , and `ListObjectV2` .
         */
        actions: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * A container for the content transformation of an Object Lambda Access Point configuration. Can include the FunctionArn and FunctionPayload. For more information, see [AwsLambdaTransformation](https://docs.aws.amazon.com/AmazonS3/latest/API/API_control_AwsLambdaTransformation.html) in the *Amazon S3 API Reference* .
         */
        contentTransformation: pulumi.Input<inputs.s3objectlambda.AccessPointTransformationConfigurationContentTransformationPropertiesArgs>;
    }
    /**
     * A container for the content transformation of an Object Lambda Access Point configuration. Can include the FunctionArn and FunctionPayload. For more information, see [AwsLambdaTransformation](https://docs.aws.amazon.com/AmazonS3/latest/API/API_control_AwsLambdaTransformation.html) in the *Amazon S3 API Reference* .
     */
    interface AccessPointTransformationConfigurationContentTransformationPropertiesArgs {
        awsLambda: pulumi.Input<inputs.s3objectlambda.AccessPointAwsLambdaArgs>;
    }
}
export declare namespace s3outposts {
    interface AccessPointVpcConfigurationArgs {
        /**
         * Virtual Private Cloud (VPC) Id from which AccessPoint will allow requests.
         */
        vpcId?: pulumi.Input<string>;
    }
    /**
     * Specifies the days since the initiation of an incomplete multipart upload that Amazon S3Outposts will wait before permanently removing all parts of the upload.
     */
    interface BucketAbortIncompleteMultipartUploadArgs {
        /**
         * Specifies the number of days after which Amazon S3Outposts aborts an incomplete multipart upload.
         */
        daysAfterInitiation: pulumi.Input<number>;
    }
    interface BucketFilterAndOperatorPropertiesArgs {
        /**
         * Prefix identifies one or more objects to which the rule applies.
         */
        prefix?: pulumi.Input<string>;
        /**
         * All of these tags must exist in the object's tag set in order for the rule to apply.
         */
        tags: pulumi.Input<pulumi.Input<inputs.s3outposts.BucketFilterTagArgs>[]>;
    }
    /**
     * Tag used to identify a subset of objects for an Amazon S3Outposts bucket.
     */
    interface BucketFilterTagArgs {
        key: pulumi.Input<string>;
        value: pulumi.Input<string>;
    }
    interface BucketLifecycleConfigurationArgs {
        /**
         * A list of lifecycle rules for individual objects in an Amazon S3Outposts bucket.
         */
        rules: pulumi.Input<pulumi.Input<inputs.s3outposts.BucketRuleArgs>[]>;
    }
    /**
     * Specifies lifecycle rules for an Amazon S3Outposts bucket. You must specify at least one of the following: AbortIncompleteMultipartUpload, ExpirationDate, ExpirationInDays.
     */
    interface BucketRuleArgs {
        /**
         * Specifies a lifecycle rule that stops incomplete multipart uploads to an Amazon S3Outposts bucket.
         */
        abortIncompleteMultipartUpload?: pulumi.Input<inputs.s3outposts.BucketAbortIncompleteMultipartUploadArgs>;
        /**
         * Indicates when objects are deleted from Amazon S3Outposts. The date value must be in ISO 8601 format. The time is always midnight UTC.
         */
        expirationDate?: pulumi.Input<string>;
        /**
         * Indicates the number of days after creation when objects are deleted from Amazon S3Outposts.
         */
        expirationInDays?: pulumi.Input<number>;
        /**
         * The container for the filter of the lifecycle rule.
         */
        filter?: pulumi.Input<inputs.s3outposts.BucketRuleFilterPropertiesArgs>;
        /**
         * Unique identifier for the lifecycle rule. The value can't be longer than 255 characters.
         */
        id?: pulumi.Input<string>;
        /**
         * If `Enabled` , the rule is currently being applied. If `Disabled` , the rule is not currently being applied.
         */
        status?: pulumi.Input<enums.s3outposts.BucketRuleStatus>;
    }
    /**
     * The container for the filter of the lifecycle rule.
     */
    interface BucketRuleFilterPropertiesArgs {
        /**
         * The container for the AND condition for the lifecycle rule. A combination of Prefix and 1 or more Tags OR a minimum of 2 or more tags.
         */
        andOperator?: pulumi.Input<inputs.s3outposts.BucketFilterAndOperatorPropertiesArgs>;
        /**
         * Object key prefix that identifies one or more objects to which this rule applies.
         */
        prefix?: pulumi.Input<string>;
        /**
         * Specifies a tag used to identify a subset of objects for an Amazon S3Outposts bucket.
         */
        tag?: pulumi.Input<inputs.s3outposts.BucketFilterTagArgs>;
    }
    interface EndpointFailedReasonArgs {
        /**
         * The failure code, if any, for a create or delete endpoint operation.
         */
        errorCode?: pulumi.Input<string>;
        /**
         * Additional error details describing the endpoint failure and recommended action.
         */
        message?: pulumi.Input<string>;
    }
}
export declare namespace s3tables {
    /**
     * Specifies encryption settings for the table bucket
     */
    interface TableBucketEncryptionConfigurationArgs {
        /**
         * ARN of the KMS key to use for encryption
         */
        kmsKeyArn?: pulumi.Input<string>;
        /**
         * Server-side encryption algorithm
         */
        sseAlgorithm?: pulumi.Input<enums.s3tables.TableBucketEncryptionConfigurationSseAlgorithm>;
    }
    /**
     * A policy document containing permissions to add to the specified table bucket. In IAM, you must provide policy documents in JSON format. However, in CloudFormation you can provide the policy in JSON or YAML format because CloudFormation converts YAML to JSON before submitting it to IAM.
     */
    interface TableBucketPolicyResourcePolicyArgs {
    }
    /**
     * Settings governing the Unreferenced File Removal maintenance action. Unreferenced file removal identifies and deletes all objects that are not referenced by any table snapshots.
     */
    interface TableBucketUnreferencedFileRemovalArgs {
        /**
         * S3 permanently deletes noncurrent objects after the number of days specified by the NoncurrentDays property.
         */
        noncurrentDays?: pulumi.Input<number>;
        /**
         * Indicates whether the Unreferenced File Removal maintenance action is enabled.
         */
        status?: pulumi.Input<enums.s3tables.TableBucketUnreferencedFileRemovalStatus>;
        /**
         * For any object not referenced by your table and older than the UnreferencedDays property, S3 creates a delete marker and marks the object version as noncurrent.
         */
        unreferencedDays?: pulumi.Input<number>;
    }
}
export declare namespace sagemaker {
    /**
     * The configuration for the kernels in a SageMaker image running as a CodeEditor app.
     */
    interface AppImageConfigCodeEditorAppImageConfigArgs {
        /**
         * The container configuration for a SageMaker image.
         */
        containerConfig?: pulumi.Input<inputs.sagemaker.AppImageConfigContainerConfigArgs>;
    }
    /**
     * The container configuration for a SageMaker image.
     */
    interface AppImageConfigContainerConfigArgs {
        /**
         * A list of arguments to apply to the container.
         */
        containerArguments?: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * The custom entry point to use on container.
         */
        containerEntrypoint?: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * A list of variables to apply to the custom container.
         */
        containerEnvironmentVariables?: pulumi.Input<pulumi.Input<inputs.sagemaker.AppImageConfigCustomImageContainerEnvironmentVariableArgs>[]>;
    }
    interface AppImageConfigCustomImageContainerEnvironmentVariableArgs {
        /**
         * The key that identifies a container environment variable.
         */
        key: pulumi.Input<string>;
        /**
         * The value of the container environment variable.
         */
        value: pulumi.Input<string>;
    }
    /**
     * The Amazon Elastic File System (EFS) storage configuration for a SageMaker image.
     */
    interface AppImageConfigFileSystemConfigArgs {
        /**
         * The default POSIX group ID (GID). If not specified, defaults to 100.
         */
        defaultGid?: pulumi.Input<number>;
        /**
         * The default POSIX user ID (UID). If not specified, defaults to 1000.
         */
        defaultUid?: pulumi.Input<number>;
        /**
         * The path within the image to mount the user's EFS home directory. The directory should be empty. If not specified, defaults to /home/sagemaker-user.
         */
        mountPath?: pulumi.Input<string>;
    }
    /**
     * The configuration for the kernels in a SageMaker image running as a JupyterLab app.
     */
    interface AppImageConfigJupyterLabAppImageConfigArgs {
        /**
         * The container configuration for a SageMaker image.
         */
        containerConfig?: pulumi.Input<inputs.sagemaker.AppImageConfigContainerConfigArgs>;
    }
    /**
     * The configuration for the file system and kernels in a SageMaker image running as a KernelGateway app.
     */
    interface AppImageConfigKernelGatewayImageConfigArgs {
        /**
         * The Amazon Elastic File System (EFS) storage configuration for a SageMaker image.
         */
        fileSystemConfig?: pulumi.Input<inputs.sagemaker.AppImageConfigFileSystemConfigArgs>;
        /**
         * The specification of the Jupyter kernels in the image.
         */
        kernelSpecs: pulumi.Input<pulumi.Input<inputs.sagemaker.AppImageConfigKernelSpecArgs>[]>;
    }
    interface AppImageConfigKernelSpecArgs {
        /**
         * The display name of the kernel.
         */
        displayName?: pulumi.Input<string>;
        /**
         * The name of the kernel.
         */
        name: pulumi.Input<string>;
    }
    interface AppResourceSpecArgs {
        /**
         * The instance type that the image version runs on.
         */
        instanceType?: pulumi.Input<enums.sagemaker.AppResourceSpecInstanceType>;
        /**
         * The Amazon Resource Name (ARN) of the Lifecycle Configuration to attach to the Resource.
         */
        lifecycleConfigArn?: pulumi.Input<string>;
        /**
         * The ARN of the SageMaker image that the image version belongs to.
         */
        sageMakerImageArn?: pulumi.Input<string>;
        /**
         * The ARN of the image version created on the instance.
         */
        sageMakerImageVersionArn?: pulumi.Input<string>;
    }
    /**
     * Details of an instance group in a SageMaker HyperPod cluster.
     */
    interface ClusterInstanceGroupArgs {
        /**
         * The number of instances that are currently in the instance group of a SageMaker HyperPod cluster.
         */
        currentCount?: pulumi.Input<number>;
        executionRole: pulumi.Input<string>;
        /**
         * The number of instances you specified to add to the instance group of a SageMaker HyperPod cluster.
         */
        instanceCount: pulumi.Input<number>;
        instanceGroupName: pulumi.Input<string>;
        instanceStorageConfigs?: pulumi.Input<pulumi.Input<inputs.sagemaker.ClusterInstanceStorageConfigArgs>[]>;
        instanceType: pulumi.Input<string>;
        lifeCycleConfig: pulumi.Input<inputs.sagemaker.ClusterLifeCycleConfigArgs>;
        onStartDeepHealthChecks?: pulumi.Input<pulumi.Input<enums.sagemaker.ClusterDeepHealthCheckType>[]>;
        overrideVpcConfig?: pulumi.Input<inputs.sagemaker.ClusterVpcConfigArgs>;
        /**
         * The number you specified to TreadsPerCore in CreateCluster for enabling or disabling multithreading. For instance types that support multithreading, you can specify 1 for disabling multithreading and 2 for enabling multithreading.
         */
        threadsPerCore?: pulumi.Input<number>;
    }
    /**
     * Defines the configuration for attaching additional storage to the instances in the SageMaker HyperPod cluster instance group.
     */
    interface ClusterInstanceStorageConfigArgs {
    }
    /**
     * The lifecycle configuration for a SageMaker HyperPod cluster.
     */
    interface ClusterLifeCycleConfigArgs {
        /**
         * The file name of the entrypoint script of lifecycle scripts under SourceS3Uri. This entrypoint script runs during cluster creation.
         */
        onCreate: pulumi.Input<string>;
        /**
         * An Amazon S3 bucket path where your lifecycle scripts are stored.
         */
        sourceS3Uri: pulumi.Input<string>;
    }
    /**
     * Specifies parameter(s) specific to the orchestrator, e.g. specify the EKS cluster.
     */
    interface ClusterOrchestratorArgs {
        /**
         * The configuration of the Amazon EKS orchestrator cluster for the SageMaker HyperPod cluster.
         */
        eks: pulumi.Input<inputs.sagemaker.ClusterOrchestratorEksConfigArgs>;
    }
    /**
     * Specifies parameter(s) related to EKS as orchestrator, e.g. the EKS cluster nodes will attach to,
     */
    interface ClusterOrchestratorEksConfigArgs {
        /**
         * The ARN of the EKS cluster, such as arn:aws:eks:us-west-2:123456789012:cluster/my-eks-cluster
         */
        clusterArn: pulumi.Input<string>;
    }
    /**
     * Specifies an Amazon Virtual Private Cloud (VPC) that your SageMaker jobs, hosted models, and compute resources have access to. You can control access to and from your resources by configuring a VPC.
     */
    interface ClusterVpcConfigArgs {
        /**
         * The VPC security group IDs, in the form sg-xxxxxxxx. Specify the security groups for the VPC that is specified in the Subnets field.
         */
        securityGroupIds: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * The ID of the subnets in the VPC to which you want to connect your training job or model.
         */
        subnets: pulumi.Input<pulumi.Input<string>[]>;
    }
    /**
     * The batch transform input for a monitoring job.
     */
    interface DataQualityJobDefinitionBatchTransformInputArgs {
        /**
         * A URI that identifies the Amazon S3 storage location where Batch Transform Job captures data.
         */
        dataCapturedDestinationS3Uri: pulumi.Input<string>;
        /**
         * The dataset format for your batch transform job.
         */
        datasetFormat: pulumi.Input<inputs.sagemaker.DataQualityJobDefinitionDatasetFormatArgs>;
        /**
         * Indexes or names of the features to be excluded from analysis
         */
        excludeFeaturesAttribute?: pulumi.Input<string>;
        /**
         * Path to the filesystem where the endpoint data is available to the container.
         */
        localPath: pulumi.Input<string>;
        /**
         * Whether input data distributed in Amazon S3 is fully replicated or sharded by an S3 key. Defauts to FullyReplicated
         */
        s3DataDistributionType?: pulumi.Input<enums.sagemaker.DataQualityJobDefinitionBatchTransformInputS3DataDistributionType>;
        /**
         * Whether the Pipe or File is used as the input mode for transfering data for the monitoring job. Pipe mode is recommended for large datasets. File mode is useful for small files that fit in memory. Defaults to File.
         */
        s3InputMode?: pulumi.Input<enums.sagemaker.DataQualityJobDefinitionBatchTransformInputS3InputMode>;
    }
    /**
     * Configuration for the cluster used to run model monitoring jobs.
     */
    interface DataQualityJobDefinitionClusterConfigArgs {
        /**
         * The number of ML compute instances to use in the model monitoring job. For distributed processing jobs, specify a value greater than 1. The default value is 1.
         */
        instanceCount: pulumi.Input<number>;
        /**
         * The ML compute instance type for the processing job.
         */
        instanceType: pulumi.Input<string>;
        /**
         * The AWS Key Management Service (AWS KMS) key that Amazon SageMaker uses to encrypt data on the storage volume attached to the ML compute instance(s) that run the model monitoring job.
         */
        volumeKmsKeyId?: pulumi.Input<string>;
        /**
         * The size of the ML storage volume, in gigabytes, that you want to provision. You must specify sufficient ML storage for your scenario.
         */
        volumeSizeInGb: pulumi.Input<number>;
    }
    /**
     * The baseline constraints resource for a monitoring job.
     */
    interface DataQualityJobDefinitionConstraintsResourceArgs {
        /**
         * The Amazon S3 URI for baseline constraint file in Amazon S3 that the current monitoring job should validated against.
         */
        s3Uri?: pulumi.Input<string>;
    }
    /**
     * The CSV format
     */
    interface DataQualityJobDefinitionCsvArgs {
        /**
         * A boolean flag indicating if given CSV has header
         */
        header?: pulumi.Input<boolean>;
    }
    /**
     * Container image configuration object for the monitoring job.
     */
    interface DataQualityJobDefinitionDataQualityAppSpecificationArgs {
        /**
         * An array of arguments for the container used to run the monitoring job.
         */
        containerArguments?: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * Specifies the entrypoint for a container used to run the monitoring job.
         */
        containerEntrypoint?: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * Sets the environment variables in the Docker container
         */
        environment?: any;
        /**
         * The container image to be run by the monitoring job.
         */
        imageUri: pulumi.Input<string>;
        /**
         * An Amazon S3 URI to a script that is called after analysis has been performed. Applicable only for the built-in (first party) containers.
         */
        postAnalyticsProcessorSourceUri?: pulumi.Input<string>;
        /**
         * An Amazon S3 URI to a script that is called per row prior to running analysis. It can base64 decode the payload and convert it into a flatted json so that the built-in container can use the converted data. Applicable only for the built-in (first party) containers
         */
        recordPreprocessorSourceUri?: pulumi.Input<string>;
    }
    /**
     * Baseline configuration used to validate that the data conforms to the specified constraints and statistics.
     */
    interface DataQualityJobDefinitionDataQualityBaselineConfigArgs {
        /**
         * The name of the job that performs baselining for the data quality monitoring job.
         */
        baseliningJobName?: pulumi.Input<string>;
        /**
         * The constraints resource for a monitoring job.
         */
        constraintsResource?: pulumi.Input<inputs.sagemaker.DataQualityJobDefinitionConstraintsResourceArgs>;
        /**
         * Configuration for monitoring constraints and monitoring statistics. These baseline resources are compared against the results of the current job from the series of jobs scheduled to collect data periodically.
         */
        statisticsResource?: pulumi.Input<inputs.sagemaker.DataQualityJobDefinitionStatisticsResourceArgs>;
    }
    /**
     * The inputs for a monitoring job.
     */
    interface DataQualityJobDefinitionDataQualityJobInputArgs {
        /**
         * Input object for the batch transform job.
         */
        batchTransformInput?: pulumi.Input<inputs.sagemaker.DataQualityJobDefinitionBatchTransformInputArgs>;
        /**
         * Input object for the endpoint
         */
        endpointInput?: pulumi.Input<inputs.sagemaker.DataQualityJobDefinitionEndpointInputArgs>;
    }
    /**
     * The dataset format of the data to monitor
     */
    interface DataQualityJobDefinitionDatasetFormatArgs {
        csv?: pulumi.Input<inputs.sagemaker.DataQualityJobDefinitionCsvArgs>;
        json?: pulumi.Input<inputs.sagemaker.DataQualityJobDefinitionJsonArgs>;
        parquet?: pulumi.Input<boolean>;
    }
    /**
     * The endpoint for a monitoring job.
     */
    interface DataQualityJobDefinitionEndpointInputArgs {
        /**
         * An endpoint in customer's account which has enabled `DataCaptureConfig` enabled.
         */
        endpointName: pulumi.Input<string>;
        /**
         * Indexes or names of the features to be excluded from analysis
         */
        excludeFeaturesAttribute?: pulumi.Input<string>;
        /**
         * Path to the filesystem where the endpoint data is available to the container.
         */
        localPath: pulumi.Input<string>;
        /**
         * Whether input data distributed in Amazon S3 is fully replicated or sharded by an S3 key. Defauts to FullyReplicated
         */
        s3DataDistributionType?: pulumi.Input<enums.sagemaker.DataQualityJobDefinitionEndpointInputS3DataDistributionType>;
        /**
         * Whether the Pipe or File is used as the input mode for transfering data for the monitoring job. Pipe mode is recommended for large datasets. File mode is useful for small files that fit in memory. Defaults to File.
         */
        s3InputMode?: pulumi.Input<enums.sagemaker.DataQualityJobDefinitionEndpointInputS3InputMode>;
    }
    /**
     * The Json format
     */
    interface DataQualityJobDefinitionJsonArgs {
        /**
         * A boolean flag indicating if it is JSON line format
         */
        line?: pulumi.Input<boolean>;
    }
    /**
     * The output object for a monitoring job.
     */
    interface DataQualityJobDefinitionMonitoringOutputArgs {
        /**
         * The Amazon S3 storage location where the results of a monitoring job are saved.
         */
        s3Output: pulumi.Input<inputs.sagemaker.DataQualityJobDefinitionS3OutputArgs>;
    }
    /**
     * The output configuration for monitoring jobs.
     */
    interface DataQualityJobDefinitionMonitoringOutputConfigArgs {
        /**
         * The AWS Key Management Service (AWS KMS) key that Amazon SageMaker uses to encrypt the model artifacts at rest using Amazon S3 server-side encryption.
         */
        kmsKeyId?: pulumi.Input<string>;
        /**
         * Monitoring outputs for monitoring jobs. This is where the output of the periodic monitoring jobs is uploaded.
         */
        monitoringOutputs: pulumi.Input<pulumi.Input<inputs.sagemaker.DataQualityJobDefinitionMonitoringOutputArgs>[]>;
    }
    /**
     * Identifies the resources to deploy for a monitoring job.
     */
    interface DataQualityJobDefinitionMonitoringResourcesArgs {
        /**
         * The configuration for the cluster resources used to run the processing job.
         */
        clusterConfig: pulumi.Input<inputs.sagemaker.DataQualityJobDefinitionClusterConfigArgs>;
    }
    /**
     * Networking options for a job, such as network traffic encryption between containers, whether to allow inbound and outbound network calls to and from containers, and the VPC subnets and security groups to use for VPC-enabled jobs.
     */
    interface DataQualityJobDefinitionNetworkConfigArgs {
        /**
         * Whether to encrypt all communications between distributed processing jobs. Choose True to encrypt communications. Encryption provides greater security for distributed processing jobs, but the processing might take longer.
         */
        enableInterContainerTrafficEncryption?: pulumi.Input<boolean>;
        /**
         * Whether to allow inbound and outbound network calls to and from the containers used for the processing job.
         */
        enableNetworkIsolation?: pulumi.Input<boolean>;
        /**
         * Specifies a VPC that your training jobs and hosted models have access to. Control access to and from your training and model containers by configuring the VPC.
         */
        vpcConfig?: pulumi.Input<inputs.sagemaker.DataQualityJobDefinitionVpcConfigArgs>;
    }
    /**
     * Information about where and how to store the results of a monitoring job.
     */
    interface DataQualityJobDefinitionS3OutputArgs {
        /**
         * The local path to the Amazon S3 storage location where Amazon SageMaker saves the results of a monitoring job. LocalPath is an absolute path for the output data.
         */
        localPath: pulumi.Input<string>;
        /**
         * Whether to upload the results of the monitoring job continuously or after the job completes.
         */
        s3UploadMode?: pulumi.Input<enums.sagemaker.DataQualityJobDefinitionS3OutputS3UploadMode>;
        /**
         * A URI that identifies the Amazon S3 storage location where Amazon SageMaker saves the results of a monitoring job.
         */
        s3Uri: pulumi.Input<string>;
    }
    /**
     * The baseline statistics resource for a monitoring job.
     */
    interface DataQualityJobDefinitionStatisticsResourceArgs {
        /**
         * The Amazon S3 URI for the baseline statistics file in Amazon S3 that the current monitoring job should be validated against.
         */
        s3Uri?: pulumi.Input<string>;
    }
    /**
     * Specifies a time limit for how long the monitoring job is allowed to run.
     */
    interface DataQualityJobDefinitionStoppingConditionArgs {
        /**
         * The maximum runtime allowed in seconds.
         */
        maxRuntimeInSeconds: pulumi.Input<number>;
    }
    /**
     * Specifies a VPC that your training jobs and hosted models have access to. Control access to and from your training and model containers by configuring the VPC.
     */
    interface DataQualityJobDefinitionVpcConfigArgs {
        /**
         * The VPC security group IDs, in the form sg-xxxxxxxx. Specify the security groups for the VPC that is specified in the Subnets field.
         */
        securityGroupIds: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * The ID of the subnets in the VPC to which you want to connect to your monitoring jobs.
         */
        subnets: pulumi.Input<pulumi.Input<string>[]>;
    }
    /**
     * Edge device you want to create
     */
    interface DeviceArgs {
        /**
         * Description of the device
         */
        description?: pulumi.Input<string>;
        /**
         * The name of the device
         */
        deviceName: pulumi.Input<string>;
        /**
         * AWS Internet of Things (IoT) object name.
         */
        iotThingName?: pulumi.Input<string>;
    }
    interface DeviceFleetEdgeOutputConfigArgs {
        /**
         * The KMS key id used for encryption on the S3 bucket
         */
        kmsKeyId?: pulumi.Input<string>;
        /**
         * The Amazon Simple Storage (S3) bucket URI
         */
        s3OutputLocation: pulumi.Input<string>;
    }
    interface DomainAppLifecycleManagementArgs {
        /**
         * Settings related to idle shutdown of Studio applications.
         */
        idleSettings?: pulumi.Input<inputs.sagemaker.DomainIdleSettingsArgs>;
    }
    /**
     * The CodeEditor app settings.
     */
    interface DomainCodeEditorAppSettingsArgs {
        /**
         * Settings that are used to configure and manage the lifecycle of CodeEditor applications.
         */
        appLifecycleManagement?: pulumi.Input<inputs.sagemaker.DomainAppLifecycleManagementArgs>;
        /**
         * A list of custom images for use for CodeEditor apps.
         */
        customImages?: pulumi.Input<pulumi.Input<inputs.sagemaker.DomainCustomImageArgs>[]>;
        /**
         * The default instance type and the Amazon Resource Name (ARN) of the default SageMaker image used by the CodeEditor app.
         */
        defaultResourceSpec?: pulumi.Input<inputs.sagemaker.DomainResourceSpecArgs>;
        /**
         * A list of LifecycleConfigArns available for use with CodeEditor apps.
         */
        lifecycleConfigArns?: pulumi.Input<pulumi.Input<string>[]>;
    }
    interface DomainCodeRepositoryArgs {
        /**
         * A CodeRepository (valid URL) to be used within Jupyter's Git extension.
         */
        repositoryUrl: pulumi.Input<string>;
    }
    interface DomainCustomFileSystemConfigArgs {
        /**
         * The settings for a custom Amazon EFS file system.
         */
        efsFileSystemConfig?: pulumi.Input<inputs.sagemaker.DomainEfsFileSystemConfigArgs>;
        /**
         * The settings for a custom Amazon FSx for Lustre file system.
         */
        fSxLustreFileSystemConfig?: pulumi.Input<inputs.sagemaker.DomainFSxLustreFileSystemConfigArgs>;
    }
    /**
     * A custom SageMaker image.
     */
    interface DomainCustomImageArgs {
        /**
         * The Name of the AppImageConfig.
         */
        appImageConfigName: pulumi.Input<string>;
        /**
         * The name of the CustomImage. Must be unique to your account.
         */
        imageName: pulumi.Input<string>;
        /**
         * The version number of the CustomImage.
         */
        imageVersionNumber?: pulumi.Input<number>;
    }
    interface DomainCustomPosixUserConfigArgs {
        /**
         * The POSIX group ID.
         */
        gid: pulumi.Input<number>;
        /**
         * The POSIX user ID.
         */
        uid: pulumi.Input<number>;
    }
    /**
     * Properties related to the Amazon Elastic Block Store volume. Must be provided if storage type is Amazon EBS and must not be provided if storage type is not Amazon EBS
     */
    interface DomainDefaultEbsStorageSettingsArgs {
        /**
         * Default size of the Amazon EBS volume in Gb
         */
        defaultEbsVolumeSizeInGb: pulumi.Input<number>;
        /**
         * Maximum size of the Amazon EBS volume in Gb. Must be greater than or equal to the DefaultEbsVolumeSizeInGb.
         */
        maximumEbsVolumeSizeInGb: pulumi.Input<number>;
    }
    /**
     * A collection of settings that apply to spaces of Amazon SageMaker Studio. These settings are specified when the Create/Update Domain API is called.
     */
    interface DomainDefaultSpaceSettingsArgs {
        /**
         * The settings for assigning a custom file system to a domain. Permitted users can access this file system in Amazon SageMaker AI Studio.
         */
        customFileSystemConfigs?: pulumi.Input<pulumi.Input<inputs.sagemaker.DomainCustomFileSystemConfigArgs>[]>;
        /**
         * The Jupyter lab's custom posix user configurations.
         */
        customPosixUserConfig?: pulumi.Input<inputs.sagemaker.DomainCustomPosixUserConfigArgs>;
        /**
         * The execution role for the space.
         */
        executionRole: pulumi.Input<string>;
        /**
         * The Jupyter lab's app settings.
         */
        jupyterLabAppSettings?: pulumi.Input<inputs.sagemaker.DomainJupyterLabAppSettingsArgs>;
        /**
         * The Jupyter server's app settings.
         */
        jupyterServerAppSettings?: pulumi.Input<inputs.sagemaker.DomainJupyterServerAppSettingsArgs>;
        /**
         * The kernel gateway app settings.
         */
        kernelGatewayAppSettings?: pulumi.Input<inputs.sagemaker.DomainKernelGatewayAppSettingsArgs>;
        /**
         * The security groups for the Amazon Virtual Private Cloud (VPC) that Studio uses for communication.
         */
        securityGroups?: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * The Jupyter lab's space storage settings.
         */
        spaceStorageSettings?: pulumi.Input<inputs.sagemaker.DomainDefaultSpaceStorageSettingsArgs>;
    }
    /**
     * Default storage settings for a space.
     */
    interface DomainDefaultSpaceStorageSettingsArgs {
        /**
         * The default EBS storage settings for a space.
         */
        defaultEbsStorageSettings?: pulumi.Input<inputs.sagemaker.DomainDefaultEbsStorageSettingsArgs>;
    }
    /**
     * A collection of settings that are required to start docker-proxy server.
     */
    interface DomainDockerSettingsArgs {
        /**
         * The flag to enable/disable docker-proxy server
         */
        enableDockerAccess?: pulumi.Input<enums.sagemaker.DomainDockerSettingsEnableDockerAccess>;
        /**
         * A list of account id's that would be used to pull images from in VpcOnly mode
         */
        vpcOnlyTrustedAccounts?: pulumi.Input<pulumi.Input<string>[]>;
    }
    interface DomainEfsFileSystemConfigArgs {
        /**
         * The ID of your Amazon EFS file system.
         */
        fileSystemId: pulumi.Input<string>;
        /**
         * The path to the file system directory that is accessible in Amazon SageMaker AI Studio. Permitted users can access only this directory and below.
         */
        fileSystemPath?: pulumi.Input<string>;
    }
    interface DomainFSxLustreFileSystemConfigArgs {
        /**
         * The globally unique, 17-digit, ID of the file system, assigned by Amazon FSx for Lustre.
         */
        fileSystemId: pulumi.Input<string>;
        /**
         * The path to the file system directory that is accessible in Amazon SageMaker Studio. Permitted users can access only this directory and below.
         */
        fileSystemPath?: pulumi.Input<string>;
    }
    interface DomainIdleSettingsArgs {
        /**
         * The time that SageMaker waits after the application becomes idle before shutting it down.
         */
        idleTimeoutInMinutes?: pulumi.Input<number>;
        /**
         * Indicates whether idle shutdown is activated for the application type.
         */
        lifecycleManagement?: pulumi.Input<enums.sagemaker.DomainLifecycleManagement>;
        /**
         * The maximum value in minutes that custom idle shutdown can be set to by the user.
         */
        maxIdleTimeoutInMinutes?: pulumi.Input<number>;
        /**
         * The minimum value in minutes that custom idle shutdown can be set to by the user.
         */
        minIdleTimeoutInMinutes?: pulumi.Input<number>;
    }
    /**
     * The JupyterLab app settings.
     */
    interface DomainJupyterLabAppSettingsArgs {
        /**
         * Indicates whether idle shutdown is activated for JupyterLab applications.
         */
        appLifecycleManagement?: pulumi.Input<inputs.sagemaker.DomainAppLifecycleManagementArgs>;
        /**
         * A list of CodeRepositories available for use with JupyterLab apps.
         */
        codeRepositories?: pulumi.Input<pulumi.Input<inputs.sagemaker.DomainCodeRepositoryArgs>[]>;
        /**
         * A list of custom images for use for JupyterLab apps.
         */
        customImages?: pulumi.Input<pulumi.Input<inputs.sagemaker.DomainCustomImageArgs>[]>;
        /**
         * The default instance type and the Amazon Resource Name (ARN) of the default SageMaker image used by the JupyterLab app.
         */
        defaultResourceSpec?: pulumi.Input<inputs.sagemaker.DomainResourceSpecArgs>;
        /**
         * A list of LifecycleConfigArns available for use with JupyterLab apps.
         */
        lifecycleConfigArns?: pulumi.Input<pulumi.Input<string>[]>;
    }
    /**
     * The JupyterServer app settings.
     */
    interface DomainJupyterServerAppSettingsArgs {
        /**
         * The default instance type and the Amazon Resource Name (ARN) of the default SageMaker image used by the JupyterServer app.
         */
        defaultResourceSpec?: pulumi.Input<inputs.sagemaker.DomainResourceSpecArgs>;
        /**
         * A list of LifecycleConfigArns available for use with JupyterServer apps.
         */
        lifecycleConfigArns?: pulumi.Input<pulumi.Input<string>[]>;
    }
    /**
     * The kernel gateway app settings.
     */
    interface DomainKernelGatewayAppSettingsArgs {
        /**
         * A list of custom SageMaker images that are configured to run as a KernelGateway app.
         */
        customImages?: pulumi.Input<pulumi.Input<inputs.sagemaker.DomainCustomImageArgs>[]>;
        /**
         * The default instance type and the Amazon Resource Name (ARN) of the default SageMaker image used by the KernelGateway app.
         */
        defaultResourceSpec?: pulumi.Input<inputs.sagemaker.DomainResourceSpecArgs>;
        /**
         * A list of LifecycleConfigArns available for use with KernelGateway apps.
         */
        lifecycleConfigArns?: pulumi.Input<pulumi.Input<string>[]>;
    }
    /**
     * A collection of settings that apply to an RSessionGateway app.
     */
    interface DomainRSessionAppSettingsArgs {
        /**
         * A list of custom SageMaker images that are configured to run as a KernelGateway app.
         */
        customImages?: pulumi.Input<pulumi.Input<inputs.sagemaker.DomainCustomImageArgs>[]>;
        /**
         * Specifies the ARNs of a SageMaker image and SageMaker image version, and the instance type that the version runs on.
         */
        defaultResourceSpec?: pulumi.Input<inputs.sagemaker.DomainResourceSpecArgs>;
    }
    /**
     * A collection of settings that configure user interaction with the RStudioServerPro app.
     */
    interface DomainRStudioServerProAppSettingsArgs {
        /**
         * Indicates whether the current user has access to the RStudioServerPro app.
         */
        accessStatus?: pulumi.Input<enums.sagemaker.DomainRStudioServerProAppSettingsAccessStatus>;
        /**
         * The level of permissions that the user has within the RStudioServerPro app. This value defaults to User. The Admin value allows the user access to the RStudio Administrative Dashboard.
         */
        userGroup?: pulumi.Input<enums.sagemaker.DomainRStudioServerProAppSettingsUserGroup>;
    }
    /**
     * A collection of settings that update the current configuration for the RStudioServerPro Domain-level app.
     */
    interface DomainRStudioServerProDomainSettingsArgs {
        /**
         * A collection that defines the default `InstanceType` , `SageMakerImageArn` , and `SageMakerImageVersionArn` for the Domain.
         */
        defaultResourceSpec?: pulumi.Input<inputs.sagemaker.DomainResourceSpecArgs>;
        /**
         * The ARN of the execution role for the RStudioServerPro Domain-level app.
         */
        domainExecutionRoleArn: pulumi.Input<string>;
        /**
         * A URL pointing to an RStudio Connect server.
         */
        rStudioConnectUrl?: pulumi.Input<string>;
        /**
         * A URL pointing to an RStudio Package Manager server.
         */
        rStudioPackageManagerUrl?: pulumi.Input<string>;
    }
    interface DomainResourceSpecArgs {
        /**
         * The instance type that the image version runs on.
         */
        instanceType?: pulumi.Input<enums.sagemaker.DomainResourceSpecInstanceType>;
        /**
         * The Amazon Resource Name (ARN) of the Lifecycle Configuration to attach to the Resource.
         */
        lifecycleConfigArn?: pulumi.Input<string>;
        /**
         * The Amazon Resource Name (ARN) of the SageMaker image that the image version belongs to.
         */
        sageMakerImageArn?: pulumi.Input<string>;
        /**
         * The Amazon Resource Name (ARN) of the image version created on the instance.
         */
        sageMakerImageVersionArn?: pulumi.Input<string>;
    }
    /**
     * A collection of Domain settings.
     */
    interface DomainSettingsArgs {
        /**
         * A collection of settings that configure the domain's Docker interaction.
         */
        dockerSettings?: pulumi.Input<inputs.sagemaker.DomainDockerSettingsArgs>;
        /**
         * The configuration for attaching a SageMaker user profile name to the execution role as a sts:SourceIdentity key.
         */
        executionRoleIdentityConfig?: pulumi.Input<enums.sagemaker.DomainSettingsExecutionRoleIdentityConfig>;
        /**
         * A collection of settings that configure the `RStudioServerPro` Domain-level app.
         */
        rStudioServerProDomainSettings?: pulumi.Input<inputs.sagemaker.DomainRStudioServerProDomainSettingsArgs>;
        /**
         * The security groups for the Amazon Virtual Private Cloud that the Domain uses for communication between Domain-level apps and user apps.
         */
        securityGroupIds?: pulumi.Input<pulumi.Input<string>[]>;
    }
    /**
     * Specifies options when sharing an Amazon SageMaker Studio notebook. These settings are specified as part of DefaultUserSettings when the CreateDomain API is called, and as part of UserSettings when the CreateUserProfile API is called.
     */
    interface DomainSharingSettingsArgs {
        /**
         * Whether to include the notebook cell output when sharing the notebook. The default is Disabled.
         */
        notebookOutputOption?: pulumi.Input<enums.sagemaker.DomainSharingSettingsNotebookOutputOption>;
        /**
         * When NotebookOutputOption is Allowed, the AWS Key Management Service (KMS) encryption key ID used to encrypt the notebook cell output in the Amazon S3 bucket.
         */
        s3KmsKeyId?: pulumi.Input<string>;
        /**
         * When NotebookOutputOption is Allowed, the Amazon S3 bucket used to store the shared notebook snapshots.
         */
        s3OutputPath?: pulumi.Input<string>;
    }
    /**
     * Studio settings. If these settings are applied on a user level, they take priority over the settings applied on a domain level.
     */
    interface DomainStudioWebPortalSettingsArgs {
        /**
         * Applications supported in Studio that are hidden from the Studio left navigation pane.
         */
        hiddenAppTypes?: pulumi.Input<pulumi.Input<enums.sagemaker.DomainAppType>[]>;
        /**
         * The machine learning tools that are hidden from the Studio left navigation pane.
         */
        hiddenMlTools?: pulumi.Input<pulumi.Input<enums.sagemaker.DomainMlTools>[]>;
    }
    /**
     * A collection of settings that apply to users of Amazon SageMaker Studio. These settings are specified when the CreateUserProfile API is called, and as DefaultUserSettings when the CreateDomain API is called.
     */
    interface DomainUserSettingsArgs {
        /**
         * The Code Editor application settings.
         *
         * SageMaker applies these settings only to private spaces that the user creates in the domain. SageMaker doesn't apply these settings to shared spaces.
         */
        codeEditorAppSettings?: pulumi.Input<inputs.sagemaker.DomainCodeEditorAppSettingsArgs>;
        /**
         * The settings for assigning a custom file system to a user profile. Permitted users can access this file system in Amazon SageMaker AI Studio.
         *
         * SageMaker applies these settings only to private spaces that the user creates in the domain. SageMaker doesn't apply these settings to shared spaces.
         */
        customFileSystemConfigs?: pulumi.Input<pulumi.Input<inputs.sagemaker.DomainCustomFileSystemConfigArgs>[]>;
        /**
         * Details about the POSIX identity that is used for file system operations.
         *
         * SageMaker applies these settings only to private spaces that the user creates in the domain. SageMaker doesn't apply these settings to shared spaces.
         */
        customPosixUserConfig?: pulumi.Input<inputs.sagemaker.DomainCustomPosixUserConfigArgs>;
        /**
         * Defines which Amazon SageMaker application users are directed to by default.
         */
        defaultLandingUri?: pulumi.Input<string>;
        /**
         * The execution role for the user.
         */
        executionRole: pulumi.Input<string>;
        /**
         * The settings for the JupyterLab application.
         *
         * SageMaker applies these settings only to private spaces that the user creates in the domain. SageMaker doesn't apply these settings to shared spaces.
         */
        jupyterLabAppSettings?: pulumi.Input<inputs.sagemaker.DomainJupyterLabAppSettingsArgs>;
        /**
         * The Jupyter server's app settings.
         */
        jupyterServerAppSettings?: pulumi.Input<inputs.sagemaker.DomainJupyterServerAppSettingsArgs>;
        /**
         * The kernel gateway app settings.
         */
        kernelGatewayAppSettings?: pulumi.Input<inputs.sagemaker.DomainKernelGatewayAppSettingsArgs>;
        /**
         * A collection of settings that configure the `RSessionGateway` app.
         */
        rSessionAppSettings?: pulumi.Input<inputs.sagemaker.DomainRSessionAppSettingsArgs>;
        /**
         * A collection of settings that configure user interaction with the `RStudioServerPro` app.
         */
        rStudioServerProAppSettings?: pulumi.Input<inputs.sagemaker.DomainRStudioServerProAppSettingsArgs>;
        /**
         * The security groups for the Amazon Virtual Private Cloud (VPC) that Studio uses for communication.
         */
        securityGroups?: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * The sharing settings.
         */
        sharingSettings?: pulumi.Input<inputs.sagemaker.DomainSharingSettingsArgs>;
        /**
         * The storage settings for a space.
         *
         * SageMaker applies these settings only to private spaces that the user creates in the domain. SageMaker doesn't apply these settings to shared spaces.
         */
        spaceStorageSettings?: pulumi.Input<inputs.sagemaker.DomainDefaultSpaceStorageSettingsArgs>;
        /**
         * Indicates whether the Studio experience is available to users. If not, users cannot access Studio.
         */
        studioWebPortal?: pulumi.Input<enums.sagemaker.DomainUserSettingsStudioWebPortal>;
        /**
         * Studio settings. If these settings are applied on a user level, they take priority over the settings applied on a domain level.
         */
        studioWebPortalSettings?: pulumi.Input<inputs.sagemaker.DomainStudioWebPortalSettingsArgs>;
    }
    interface EndpointAlarmArgs {
        /**
         * The name of the CloudWatch alarm.
         */
        alarmName: pulumi.Input<string>;
    }
    interface EndpointAutoRollbackConfigArgs {
        /**
         * List of CloudWatch alarms to monitor during the deployment. If any alarm goes off, the deployment is rolled back.
         */
        alarms: pulumi.Input<pulumi.Input<inputs.sagemaker.EndpointAlarmArgs>[]>;
    }
    interface EndpointBlueGreenUpdatePolicyArgs {
        /**
         * The maximum time allowed for the blue/green update, in seconds.
         */
        maximumExecutionTimeoutInSeconds?: pulumi.Input<number>;
        /**
         * The wait time before terminating the old endpoint during a blue/green deployment.
         */
        terminationWaitInSeconds?: pulumi.Input<number>;
        /**
         * The traffic routing configuration for the blue/green deployment.
         */
        trafficRoutingConfiguration: pulumi.Input<inputs.sagemaker.EndpointTrafficRoutingConfigArgs>;
    }
    interface EndpointCapacitySizeArgs {
        /**
         * Specifies whether the `Value` is an instance count or a capacity unit.
         */
        type: pulumi.Input<string>;
        /**
         * The value representing either the number of instances or the number of capacity units.
         */
        value: pulumi.Input<number>;
    }
    interface EndpointDeploymentConfigArgs {
        /**
         * Configuration for automatic rollback if an error occurs during deployment.
         */
        autoRollbackConfiguration?: pulumi.Input<inputs.sagemaker.EndpointAutoRollbackConfigArgs>;
        /**
         * Configuration for blue-green update deployment policies.
         */
        blueGreenUpdatePolicy?: pulumi.Input<inputs.sagemaker.EndpointBlueGreenUpdatePolicyArgs>;
        /**
         * Configuration for rolling update deployment policies.
         */
        rollingUpdatePolicy?: pulumi.Input<inputs.sagemaker.EndpointRollingUpdatePolicyArgs>;
    }
    interface EndpointRollingUpdatePolicyArgs {
        /**
         * Specifies the maximum batch size for each rolling update.
         */
        maximumBatchSize: pulumi.Input<inputs.sagemaker.EndpointCapacitySizeArgs>;
        /**
         * The maximum time allowed for the rolling update, in seconds.
         */
        maximumExecutionTimeoutInSeconds?: pulumi.Input<number>;
        /**
         * The maximum batch size for rollback during an update failure.
         */
        rollbackMaximumBatchSize?: pulumi.Input<inputs.sagemaker.EndpointCapacitySizeArgs>;
        /**
         * The time to wait between steps during the rolling update, in seconds.
         */
        waitIntervalInSeconds: pulumi.Input<number>;
    }
    interface EndpointTrafficRoutingConfigArgs {
        /**
         * Specifies the size of the canary traffic in a canary deployment.
         */
        canarySize?: pulumi.Input<inputs.sagemaker.EndpointCapacitySizeArgs>;
        /**
         * Specifies the step size for linear traffic routing.
         */
        linearStepSize?: pulumi.Input<inputs.sagemaker.EndpointCapacitySizeArgs>;
        /**
         * Specifies the type of traffic routing (e.g., 'AllAtOnce', 'Canary', 'Linear').
         */
        type: pulumi.Input<string>;
        /**
         * Specifies the wait interval between traffic shifts, in seconds.
         */
        waitIntervalInSeconds?: pulumi.Input<number>;
    }
    interface EndpointVariantPropertyArgs {
        /**
         * The type of variant property (e.g., 'DesiredInstanceCount', 'DesiredWeight', 'DataCaptureConfig').
         */
        variantPropertyType?: pulumi.Input<string>;
    }
    interface FeatureGroupDataCatalogConfigArgs {
        /**
         * The name of the Glue table catalog.
         */
        catalog: pulumi.Input<string>;
        /**
         * The name of the Glue table database.
         */
        database: pulumi.Input<string>;
        /**
         * The name of the Glue table.
         */
        tableName: pulumi.Input<string>;
    }
    interface FeatureGroupFeatureDefinitionArgs {
        /**
         * The name of a feature. The type must be a string. `FeatureName` cannot be any of the following: `is_deleted` , `write_time` , `api_invocation_time` .
         *
         * The name:
         *
         * - Must start with an alphanumeric character.
         * - Can only include alphanumeric characters, underscores, and hyphens. Spaces are not allowed.
         */
        featureName: pulumi.Input<string>;
        /**
         * The value type of a feature. Valid values are Integral, Fractional, or String.
         */
        featureType: pulumi.Input<enums.sagemaker.FeatureGroupFeatureDefinitionFeatureType>;
    }
    interface FeatureGroupOnlineStoreSecurityConfigArgs {
        /**
         * The AWS Key Management Service (KMS) key ARN that SageMaker Feature Store uses to encrypt the Amazon S3 objects at rest using Amazon S3 server-side encryption.
         *
         * The caller (either user or IAM role) of `CreateFeatureGroup` must have below permissions to the `OnlineStore` `KmsKeyId` :
         *
         * - `"kms:Encrypt"`
         * - `"kms:Decrypt"`
         * - `"kms:DescribeKey"`
         * - `"kms:CreateGrant"`
         * - `"kms:RetireGrant"`
         * - `"kms:ReEncryptFrom"`
         * - `"kms:ReEncryptTo"`
         * - `"kms:GenerateDataKey"`
         * - `"kms:ListAliases"`
         * - `"kms:ListGrants"`
         * - `"kms:RevokeGrant"`
         *
         * The caller (either user or IAM role) to all DataPlane operations ( `PutRecord` , `GetRecord` , `DeleteRecord` ) must have the following permissions to the `KmsKeyId` :
         *
         * - `"kms:Decrypt"`
         */
        kmsKeyId?: pulumi.Input<string>;
    }
    interface FeatureGroupS3StorageConfigArgs {
        /**
         * The AWS Key Management Service (KMS) key ARN of the key used to encrypt any objects written into the `OfflineStore` S3 location.
         *
         * The IAM `roleARN` that is passed as a parameter to `CreateFeatureGroup` must have below permissions to the `KmsKeyId` :
         *
         * - `"kms:GenerateDataKey"`
         */
        kmsKeyId?: pulumi.Input<string>;
        /**
         * The S3 URI, or location in Amazon S3, of `OfflineStore` .
         *
         * S3 URIs have a format similar to the following: `s3://example-bucket/prefix/` .
         */
        s3Uri: pulumi.Input<string>;
    }
    interface FeatureGroupThroughputConfigArgs {
        /**
         * For provisioned feature groups with online store enabled, this indicates the read throughput you are billed for and can consume without throttling.
         */
        provisionedReadCapacityUnits?: pulumi.Input<number>;
        /**
         * For provisioned feature groups, this indicates the write throughput you are billed for and can consume without throttling.
         */
        provisionedWriteCapacityUnits?: pulumi.Input<number>;
        /**
         * The mode used for your feature group throughput: `ON_DEMAND` or `PROVISIONED` .
         */
        throughputMode: pulumi.Input<enums.sagemaker.FeatureGroupThroughputMode>;
    }
    /**
     * TTL configuration of the feature group
     */
    interface FeatureGroupTtlDurationArgs {
        /**
         * `TtlDuration` time unit.
         */
        unit?: pulumi.Input<enums.sagemaker.FeatureGroupUnit>;
        /**
         * `TtlDuration` time value.
         */
        value?: pulumi.Input<number>;
    }
    interface InferenceComponentAlarmArgs {
        /**
         * The name of a CloudWatch alarm in your account.
         */
        alarmName: pulumi.Input<string>;
    }
    interface InferenceComponentAutoRollbackConfigurationArgs {
        alarms: pulumi.Input<pulumi.Input<inputs.sagemaker.InferenceComponentAlarmArgs>[]>;
    }
    /**
     * Capacity size configuration for the inference component
     */
    interface InferenceComponentCapacitySizeArgs {
        /**
         * Specifies the endpoint capacity type.
         *
         * - **COPY_COUNT** - The endpoint activates based on the number of inference component copies.
         * - **CAPACITY_PERCENT** - The endpoint activates based on the specified percentage of capacity.
         */
        type: pulumi.Input<enums.sagemaker.InferenceComponentCapacitySizeType>;
        /**
         * Defines the capacity size, either as a number of inference component copies or a capacity percentage.
         */
        value: pulumi.Input<number>;
    }
    interface InferenceComponentComputeResourceRequirementsArgs {
        /**
         * The maximum MB of memory to allocate to run a model that you assign to an inference component.
         */
        maxMemoryRequiredInMb?: pulumi.Input<number>;
        /**
         * The minimum MB of memory to allocate to run a model that you assign to an inference component.
         */
        minMemoryRequiredInMb?: pulumi.Input<number>;
        /**
         * The number of accelerators to allocate to run a model that you assign to an inference component. Accelerators include GPUs and AWS Inferentia.
         */
        numberOfAcceleratorDevicesRequired?: pulumi.Input<number>;
        /**
         * The number of CPU cores to allocate to run a model that you assign to an inference component.
         */
        numberOfCpuCoresRequired?: pulumi.Input<number>;
    }
    interface InferenceComponentContainerSpecificationArgs {
        /**
         * The Amazon S3 path where the model artifacts, which result from model training, are stored. This path must point to a single gzip compressed tar archive (.tar.gz suffix).
         */
        artifactUrl?: pulumi.Input<string>;
        deployedImage?: pulumi.Input<inputs.sagemaker.InferenceComponentDeployedImageArgs>;
        /**
         * The environment variables to set in the Docker container. Each key and value in the Environment string-to-string map can have length of up to 1024. We support up to 16 entries in the map.
         */
        environment?: pulumi.Input<{
            [key: string]: pulumi.Input<string>;
        }>;
        /**
         * The Amazon Elastic Container Registry (Amazon ECR) path where the Docker image for the model is stored.
         */
        image?: pulumi.Input<string>;
    }
    interface InferenceComponentDeployedImageArgs {
        /**
         * The date and time when the image path for the model resolved to the `ResolvedImage`
         */
        resolutionTime?: pulumi.Input<string>;
        /**
         * The specific digest path of the image hosted in this `ProductionVariant` .
         */
        resolvedImage?: pulumi.Input<string>;
        /**
         * The image path you specified when you created the model.
         */
        specifiedImage?: pulumi.Input<string>;
    }
    /**
     * The deployment config for the inference component
     */
    interface InferenceComponentDeploymentConfigArgs {
        autoRollbackConfiguration?: pulumi.Input<inputs.sagemaker.InferenceComponentAutoRollbackConfigurationArgs>;
        /**
         * Specifies a rolling deployment strategy for updating a SageMaker AI endpoint.
         */
        rollingUpdatePolicy?: pulumi.Input<inputs.sagemaker.InferenceComponentRollingUpdatePolicyArgs>;
    }
    /**
     * The rolling update policy for the inference component
     */
    interface InferenceComponentRollingUpdatePolicyArgs {
        /**
         * The batch size for each rolling step in the deployment process. For each step, SageMaker AI provisions capacity on the new endpoint fleet, routes traffic to that fleet, and terminates capacity on the old endpoint fleet. The value must be between 5% to 50% of the copy count of the inference component.
         */
        maximumBatchSize?: pulumi.Input<inputs.sagemaker.InferenceComponentCapacitySizeArgs>;
        /**
         * The time limit for the total deployment. Exceeding this limit causes a timeout.
         */
        maximumExecutionTimeoutInSeconds?: pulumi.Input<number>;
        /**
         * The batch size for a rollback to the old endpoint fleet. If this field is absent, the value is set to the default, which is 100% of the total capacity. When the default is used, SageMaker AI provisions the entire capacity of the old fleet at once during rollback.
         */
        rollbackMaximumBatchSize?: pulumi.Input<inputs.sagemaker.InferenceComponentCapacitySizeArgs>;
        /**
         * The length of the baking period, during which SageMaker AI monitors alarms for each batch on the new fleet.
         */
        waitIntervalInSeconds?: pulumi.Input<number>;
    }
    /**
     * The runtime config for the inference component
     */
    interface InferenceComponentRuntimeConfigArgs {
        /**
         * The number of runtime copies of the model container to deploy with the inference component. Each copy can serve inference requests.
         */
        copyCount?: pulumi.Input<number>;
        currentCopyCount?: pulumi.Input<number>;
        desiredCopyCount?: pulumi.Input<number>;
    }
    /**
     * The specification for the inference component
     */
    interface InferenceComponentSpecificationArgs {
        /**
         * The name of an existing inference component that is to contain the inference component that you're creating with your request.
         *
         * Specify this parameter only if your request is meant to create an adapter inference component. An adapter inference component contains the path to an adapter model. The purpose of the adapter model is to tailor the inference output of a base foundation model, which is hosted by the base inference component. The adapter inference component uses the compute resources that you assigned to the base inference component.
         *
         * When you create an adapter inference component, use the `Container` parameter to specify the location of the adapter artifacts. In the parameter value, use the `ArtifactUrl` parameter of the `InferenceComponentContainerSpecification` data type.
         *
         * Before you can create an adapter inference component, you must have an existing inference component that contains the foundation model that you want to adapt.
         */
        baseInferenceComponentName?: pulumi.Input<string>;
        /**
         * The compute resources allocated to run the model, plus any adapter models, that you assign to the inference component.
         *
         * Omit this parameter if your request is meant to create an adapter inference component. An adapter inference component is loaded by a base inference component, and it uses the compute resources of the base inference component.
         */
        computeResourceRequirements?: pulumi.Input<inputs.sagemaker.InferenceComponentComputeResourceRequirementsArgs>;
        /**
         * Defines a container that provides the runtime environment for a model that you deploy with an inference component.
         */
        container?: pulumi.Input<inputs.sagemaker.InferenceComponentContainerSpecificationArgs>;
        /**
         * The name of an existing SageMaker AI model object in your account that you want to deploy with the inference component.
         */
        modelName?: pulumi.Input<string>;
        /**
         * Settings that take effect while the model container starts up.
         */
        startupParameters?: pulumi.Input<inputs.sagemaker.InferenceComponentStartupParametersArgs>;
    }
    interface InferenceComponentStartupParametersArgs {
        /**
         * The timeout value, in seconds, for your inference container to pass health check by Amazon S3 Hosting. For more information about health check, see [How Your Container Should Respond to Health Check (Ping) Requests](https://docs.aws.amazon.com/sagemaker/latest/dg/your-algorithms-inference-code.html#your-algorithms-inference-algo-ping-requests) .
         */
        containerStartupHealthCheckTimeoutInSeconds?: pulumi.Input<number>;
        /**
         * The timeout value, in seconds, to download and extract the model that you want to host from Amazon S3 to the individual inference instance associated with this inference component.
         */
        modelDataDownloadTimeoutInSeconds?: pulumi.Input<number>;
    }
    /**
     * Configuration specifying how to treat different headers. If no headers are specified SageMaker will by default base64 encode when capturing the data.
     */
    interface InferenceExperimentCaptureContentTypeHeaderArgs {
        /**
         * The list of all content type headers that SageMaker will treat as CSV and capture accordingly.
         */
        csvContentTypes?: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * The list of all content type headers that SageMaker will treat as JSON and capture accordingly.
         */
        jsonContentTypes?: pulumi.Input<pulumi.Input<string>[]>;
    }
    /**
     * The Amazon S3 location and configuration for storing inference request and response data.
     */
    interface InferenceExperimentDataStorageConfigArgs {
        /**
         * Configuration specifying how to treat different headers. If no headers are specified SageMaker will by default base64 encode when capturing the data.
         */
        contentType?: pulumi.Input<inputs.sagemaker.InferenceExperimentCaptureContentTypeHeaderArgs>;
        /**
         * The Amazon S3 bucket where the inference request and response data is stored.
         */
        destination: pulumi.Input<string>;
        /**
         * The AWS Key Management Service key that Amazon SageMaker uses to encrypt captured data at rest using Amazon S3 server-side encryption.
         */
        kmsKey?: pulumi.Input<string>;
    }
    /**
     * The configuration for the infrastructure that the model will be deployed to.
     */
    interface InferenceExperimentModelInfrastructureConfigArgs {
        /**
         * The type of the inference experiment that you want to run.
         */
        infrastructureType: pulumi.Input<enums.sagemaker.InferenceExperimentModelInfrastructureConfigInfrastructureType>;
        /**
         * The infrastructure configuration for deploying the model to real-time inference.
         */
        realTimeInferenceConfig: pulumi.Input<inputs.sagemaker.InferenceExperimentRealTimeInferenceConfigArgs>;
    }
    /**
     * Contains information about the deployment options of a model.
     */
    interface InferenceExperimentModelVariantConfigArgs {
        /**
         * The configuration for the infrastructure that the model will be deployed to.
         */
        infrastructureConfig: pulumi.Input<inputs.sagemaker.InferenceExperimentModelInfrastructureConfigArgs>;
        /**
         * The name of the Amazon SageMaker Model entity.
         */
        modelName: pulumi.Input<string>;
        /**
         * The name of the variant.
         */
        variantName: pulumi.Input<string>;
    }
    /**
     * The infrastructure configuration for deploying the model to a real-time inference endpoint.
     */
    interface InferenceExperimentRealTimeInferenceConfigArgs {
        /**
         * The number of instances of the type specified by InstanceType.
         */
        instanceCount: pulumi.Input<number>;
        /**
         * The instance type the model is deployed to.
         */
        instanceType: pulumi.Input<string>;
    }
    /**
     * The duration for which you want the inference experiment to run.
     */
    interface InferenceExperimentScheduleArgs {
        /**
         * The timestamp at which the inference experiment ended or will end.
         */
        endTime?: pulumi.Input<string>;
        /**
         * The timestamp at which the inference experiment started or will start.
         */
        startTime?: pulumi.Input<string>;
    }
    /**
     * The configuration of ShadowMode inference experiment type. Use this field to specify a production variant which takes all the inference requests, and a shadow variant to which Amazon SageMaker replicates a percentage of the inference requests. For the shadow variant also specify the percentage of requests that Amazon SageMaker replicates.
     */
    interface InferenceExperimentShadowModeConfigArgs {
        /**
         * List of shadow variant configurations.
         */
        shadowModelVariants: pulumi.Input<pulumi.Input<inputs.sagemaker.InferenceExperimentShadowModelVariantConfigArgs>[]>;
        /**
         * The name of the production variant, which takes all the inference requests.
         */
        sourceModelVariantName: pulumi.Input<string>;
    }
    /**
     * The name and sampling percentage of a shadow variant.
     */
    interface InferenceExperimentShadowModelVariantConfigArgs {
        /**
         * The percentage of inference requests that Amazon SageMaker replicates from the production variant to the shadow variant.
         */
        samplingPercentage: pulumi.Input<number>;
        /**
         * The name of the shadow variant.
         */
        shadowModelVariantName: pulumi.Input<string>;
    }
    /**
     * The batch transform input for a monitoring job.
     */
    interface ModelBiasJobDefinitionBatchTransformInputArgs {
        /**
         * A URI that identifies the Amazon S3 storage location where Batch Transform Job captures data.
         */
        dataCapturedDestinationS3Uri: pulumi.Input<string>;
        /**
         * The dataset format for your batch transform job.
         */
        datasetFormat: pulumi.Input<inputs.sagemaker.ModelBiasJobDefinitionDatasetFormatArgs>;
        /**
         * Monitoring end time offset, e.g. PT0H
         */
        endTimeOffset?: pulumi.Input<string>;
        /**
         * JSONpath to locate features in JSONlines dataset
         */
        featuresAttribute?: pulumi.Input<string>;
        /**
         * Index or JSONpath to locate predicted label(s)
         */
        inferenceAttribute?: pulumi.Input<string>;
        /**
         * Path to the filesystem where the endpoint data is available to the container.
         */
        localPath: pulumi.Input<string>;
        /**
         * Index or JSONpath to locate probabilities
         */
        probabilityAttribute?: pulumi.Input<string>;
        /**
         * The threshold for the class probability to be evaluated as a positive result.
         */
        probabilityThresholdAttribute?: pulumi.Input<number>;
        /**
         * Whether input data distributed in Amazon S3 is fully replicated or sharded by an S3 key. Defauts to FullyReplicated
         */
        s3DataDistributionType?: pulumi.Input<enums.sagemaker.ModelBiasJobDefinitionBatchTransformInputS3DataDistributionType>;
        /**
         * Whether the Pipe or File is used as the input mode for transfering data for the monitoring job. Pipe mode is recommended for large datasets. File mode is useful for small files that fit in memory. Defaults to File.
         */
        s3InputMode?: pulumi.Input<enums.sagemaker.ModelBiasJobDefinitionBatchTransformInputS3InputMode>;
        /**
         * Monitoring start time offset, e.g. -PT1H
         */
        startTimeOffset?: pulumi.Input<string>;
    }
    /**
     * Configuration for the cluster used to run model monitoring jobs.
     */
    interface ModelBiasJobDefinitionClusterConfigArgs {
        /**
         * The number of ML compute instances to use in the model monitoring job. For distributed processing jobs, specify a value greater than 1. The default value is 1.
         */
        instanceCount: pulumi.Input<number>;
        /**
         * The ML compute instance type for the processing job.
         */
        instanceType: pulumi.Input<string>;
        /**
         * The AWS Key Management Service (AWS KMS) key that Amazon SageMaker uses to encrypt data on the storage volume attached to the ML compute instance(s) that run the model monitoring job.
         */
        volumeKmsKeyId?: pulumi.Input<string>;
        /**
         * The size of the ML storage volume, in gigabytes, that you want to provision. You must specify sufficient ML storage for your scenario.
         */
        volumeSizeInGb: pulumi.Input<number>;
    }
    /**
     * The baseline constraints resource for a monitoring job.
     */
    interface ModelBiasJobDefinitionConstraintsResourceArgs {
        /**
         * The Amazon S3 URI for baseline constraint file in Amazon S3 that the current monitoring job should validated against.
         */
        s3Uri?: pulumi.Input<string>;
    }
    /**
     * The CSV format
     */
    interface ModelBiasJobDefinitionCsvArgs {
        /**
         * A boolean flag indicating if given CSV has header
         */
        header?: pulumi.Input<boolean>;
    }
    /**
     * The dataset format of the data to monitor
     */
    interface ModelBiasJobDefinitionDatasetFormatArgs {
        csv?: pulumi.Input<inputs.sagemaker.ModelBiasJobDefinitionCsvArgs>;
        json?: pulumi.Input<inputs.sagemaker.ModelBiasJobDefinitionJsonArgs>;
        parquet?: pulumi.Input<boolean>;
    }
    /**
     * The endpoint for a monitoring job.
     */
    interface ModelBiasJobDefinitionEndpointInputArgs {
        /**
         * Monitoring end time offset, e.g. PT0H
         */
        endTimeOffset?: pulumi.Input<string>;
        /**
         * An endpoint in customer's account which has enabled `DataCaptureConfig` enabled.
         */
        endpointName: pulumi.Input<string>;
        /**
         * JSONpath to locate features in JSONlines dataset
         */
        featuresAttribute?: pulumi.Input<string>;
        /**
         * Index or JSONpath to locate predicted label(s)
         */
        inferenceAttribute?: pulumi.Input<string>;
        /**
         * Path to the filesystem where the endpoint data is available to the container.
         */
        localPath: pulumi.Input<string>;
        /**
         * Index or JSONpath to locate probabilities
         */
        probabilityAttribute?: pulumi.Input<string>;
        /**
         * The threshold for the class probability to be evaluated as a positive result.
         */
        probabilityThresholdAttribute?: pulumi.Input<number>;
        /**
         * Whether input data distributed in Amazon S3 is fully replicated or sharded by an S3 key. Defauts to FullyReplicated
         */
        s3DataDistributionType?: pulumi.Input<enums.sagemaker.ModelBiasJobDefinitionEndpointInputS3DataDistributionType>;
        /**
         * Whether the Pipe or File is used as the input mode for transfering data for the monitoring job. Pipe mode is recommended for large datasets. File mode is useful for small files that fit in memory. Defaults to File.
         */
        s3InputMode?: pulumi.Input<enums.sagemaker.ModelBiasJobDefinitionEndpointInputS3InputMode>;
        /**
         * Monitoring start time offset, e.g. -PT1H
         */
        startTimeOffset?: pulumi.Input<string>;
    }
    /**
     * The Json format
     */
    interface ModelBiasJobDefinitionJsonArgs {
        /**
         * A boolean flag indicating if it is JSON line format
         */
        line?: pulumi.Input<boolean>;
    }
    /**
     * Container image configuration object for the monitoring job.
     */
    interface ModelBiasJobDefinitionModelBiasAppSpecificationArgs {
        /**
         * The S3 URI to an analysis configuration file
         */
        configUri: pulumi.Input<string>;
        /**
         * Sets the environment variables in the Docker container
         */
        environment?: any;
        /**
         * The container image to be run by the monitoring job.
         */
        imageUri: pulumi.Input<string>;
    }
    /**
     * Baseline configuration used to validate that the data conforms to the specified constraints and statistics.
     */
    interface ModelBiasJobDefinitionModelBiasBaselineConfigArgs {
        /**
         * The name of the baseline model bias job.
         */
        baseliningJobName?: pulumi.Input<string>;
        /**
         * The constraints resource for a monitoring job.
         */
        constraintsResource?: pulumi.Input<inputs.sagemaker.ModelBiasJobDefinitionConstraintsResourceArgs>;
    }
    /**
     * The inputs for a monitoring job.
     */
    interface ModelBiasJobDefinitionModelBiasJobInputArgs {
        /**
         * Input object for the batch transform job.
         */
        batchTransformInput?: pulumi.Input<inputs.sagemaker.ModelBiasJobDefinitionBatchTransformInputArgs>;
        /**
         * Input object for the endpoint
         */
        endpointInput?: pulumi.Input<inputs.sagemaker.ModelBiasJobDefinitionEndpointInputArgs>;
        /**
         * Location of ground truth labels to use in model bias job.
         */
        groundTruthS3Input: pulumi.Input<inputs.sagemaker.ModelBiasJobDefinitionMonitoringGroundTruthS3InputArgs>;
    }
    /**
     * Ground truth input provided in S3
     */
    interface ModelBiasJobDefinitionMonitoringGroundTruthS3InputArgs {
        /**
         * A URI that identifies the Amazon S3 storage location where Amazon SageMaker saves the results of a monitoring job.
         */
        s3Uri: pulumi.Input<string>;
    }
    /**
     * The output object for a monitoring job.
     */
    interface ModelBiasJobDefinitionMonitoringOutputArgs {
        /**
         * The Amazon S3 storage location where the results of a monitoring job are saved.
         */
        s3Output: pulumi.Input<inputs.sagemaker.ModelBiasJobDefinitionS3OutputArgs>;
    }
    /**
     * The output configuration for monitoring jobs.
     */
    interface ModelBiasJobDefinitionMonitoringOutputConfigArgs {
        /**
         * The AWS Key Management Service (AWS KMS) key that Amazon SageMaker uses to encrypt the model artifacts at rest using Amazon S3 server-side encryption.
         */
        kmsKeyId?: pulumi.Input<string>;
        /**
         * Monitoring outputs for monitoring jobs. This is where the output of the periodic monitoring jobs is uploaded.
         */
        monitoringOutputs: pulumi.Input<pulumi.Input<inputs.sagemaker.ModelBiasJobDefinitionMonitoringOutputArgs>[]>;
    }
    /**
     * Identifies the resources to deploy for a monitoring job.
     */
    interface ModelBiasJobDefinitionMonitoringResourcesArgs {
        /**
         * The configuration for the cluster resources used to run the processing job.
         */
        clusterConfig: pulumi.Input<inputs.sagemaker.ModelBiasJobDefinitionClusterConfigArgs>;
    }
    /**
     * Networking options for a job, such as network traffic encryption between containers, whether to allow inbound and outbound network calls to and from containers, and the VPC subnets and security groups to use for VPC-enabled jobs.
     */
    interface ModelBiasJobDefinitionNetworkConfigArgs {
        /**
         * Whether to encrypt all communications between distributed processing jobs. Choose True to encrypt communications. Encryption provides greater security for distributed processing jobs, but the processing might take longer.
         */
        enableInterContainerTrafficEncryption?: pulumi.Input<boolean>;
        /**
         * Whether to allow inbound and outbound network calls to and from the containers used for the processing job.
         */
        enableNetworkIsolation?: pulumi.Input<boolean>;
        /**
         * Specifies a VPC that your training jobs and hosted models have access to. Control access to and from your training and model containers by configuring the VPC.
         */
        vpcConfig?: pulumi.Input<inputs.sagemaker.ModelBiasJobDefinitionVpcConfigArgs>;
    }
    /**
     * Information about where and how to store the results of a monitoring job.
     */
    interface ModelBiasJobDefinitionS3OutputArgs {
        /**
         * The local path to the Amazon S3 storage location where Amazon SageMaker saves the results of a monitoring job. LocalPath is an absolute path for the output data.
         */
        localPath: pulumi.Input<string>;
        /**
         * Whether to upload the results of the monitoring job continuously or after the job completes.
         */
        s3UploadMode?: pulumi.Input<enums.sagemaker.ModelBiasJobDefinitionS3OutputS3UploadMode>;
        /**
         * A URI that identifies the Amazon S3 storage location where Amazon SageMaker saves the results of a monitoring job.
         */
        s3Uri: pulumi.Input<string>;
    }
    /**
     * Specifies a time limit for how long the monitoring job is allowed to run.
     */
    interface ModelBiasJobDefinitionStoppingConditionArgs {
        /**
         * The maximum runtime allowed in seconds.
         */
        maxRuntimeInSeconds: pulumi.Input<number>;
    }
    /**
     * Specifies a VPC that your training jobs and hosted models have access to. Control access to and from your training and model containers by configuring the VPC.
     */
    interface ModelBiasJobDefinitionVpcConfigArgs {
        /**
         * The VPC security group IDs, in the form sg-xxxxxxxx. Specify the security groups for the VPC that is specified in the Subnets field.
         */
        securityGroupIds: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * The ID of the subnets in the VPC to which you want to connect to your monitoring jobs.
         */
        subnets: pulumi.Input<pulumi.Input<string>[]>;
    }
    interface ModelCardAdditionalInformationArgs {
        /**
         * Caveats and recommendations for people who might use this model in their applications.
         */
        caveatsAndRecommendations?: pulumi.Input<string>;
        /**
         * customer details.
         */
        customDetails?: pulumi.Input<{
            [key: string]: pulumi.Input<string>;
        }>;
        /**
         * Any ethical considerations that the author wants to provide.
         */
        ethicalConsiderations?: pulumi.Input<string>;
    }
    interface ModelCardBarChartMetricArgs {
        name: pulumi.Input<string>;
        notes?: pulumi.Input<string>;
        type: pulumi.Input<enums.sagemaker.ModelCardBarChartMetricType>;
        value: pulumi.Input<pulumi.Input<number>[]>;
        xAxisName?: pulumi.Input<pulumi.Input<string>[]>;
        yAxisName?: pulumi.Input<string>;
    }
    /**
     * Business details.
     */
    interface ModelCardBusinessDetailsArgs {
        /**
         * What business problem does the model solve?
         */
        businessProblem?: pulumi.Input<string>;
        /**
         * Business stakeholders.
         */
        businessStakeholders?: pulumi.Input<string>;
        /**
         * Line of business.
         */
        lineOfBusiness?: pulumi.Input<string>;
    }
    interface ModelCardContainerArgs {
        /**
         * Inference environment path. The Amazon EC2 Container Registry (Amazon ECR) path where inference code is stored.
         */
        image: pulumi.Input<string>;
        /**
         * The Amazon S3 path where the model artifacts, which result from model training, are stored.
         */
        modelDataUrl?: pulumi.Input<string>;
        /**
         * The name of a pre-trained machine learning benchmarked by Amazon SageMaker Inference Recommender model that matches your model.
         */
        nearestModelName?: pulumi.Input<string>;
    }
    /**
     * The content of the model card.
     */
    interface ModelCardContentArgs {
        /**
         * Additional information about the model.
         */
        additionalInformation?: pulumi.Input<inputs.sagemaker.ModelCardAdditionalInformationArgs>;
        /**
         * Information about how the model supports business goals.
         */
        businessDetails?: pulumi.Input<inputs.sagemaker.ModelCardBusinessDetailsArgs>;
        /**
         * An overview about the model's evaluation.
         */
        evaluationDetails?: pulumi.Input<pulumi.Input<inputs.sagemaker.ModelCardEvaluationDetailArgs>[]>;
        /**
         * The intended usage of the model.
         */
        intendedUses?: pulumi.Input<inputs.sagemaker.ModelCardIntendedUsesArgs>;
        /**
         * An overview about the model
         */
        modelOverview?: pulumi.Input<inputs.sagemaker.ModelCardModelOverviewArgs>;
        modelPackageDetails?: pulumi.Input<inputs.sagemaker.ModelCardModelPackageDetailsArgs>;
        /**
         * An overview about model training.
         */
        trainingDetails?: pulumi.Input<inputs.sagemaker.ModelCardTrainingDetailsArgs>;
    }
    /**
     * item of evaluation details
     */
    interface ModelCardEvaluationDetailArgs {
        datasets?: pulumi.Input<pulumi.Input<string>[]>;
        evaluationJobArn?: pulumi.Input<string>;
        evaluationObservation?: pulumi.Input<string>;
        /**
         * additional attributes associated with the evaluation results.
         */
        metadata?: pulumi.Input<{
            [key: string]: pulumi.Input<string>;
        }>;
        metricGroups?: pulumi.Input<pulumi.Input<inputs.sagemaker.ModelCardMetricGroupArgs>[]>;
        name: pulumi.Input<string>;
    }
    interface ModelCardInferenceSpecificationArgs {
        /**
         * Contains inference related information which were used to create model package.
         */
        containers: pulumi.Input<pulumi.Input<inputs.sagemaker.ModelCardContainerArgs>[]>;
    }
    /**
     * Intended usage of model.
     */
    interface ModelCardIntendedUsesArgs {
        /**
         * An explanation of why your organization categorizes the model with its risk rating.
         */
        explanationsForRiskRating?: pulumi.Input<string>;
        /**
         * Factors affecting model efficacy.
         */
        factorsAffectingModelEfficiency?: pulumi.Input<string>;
        /**
         * intended use cases.
         */
        intendedUses?: pulumi.Input<string>;
        /**
         * Why the model was developed?
         */
        purposeOfModel?: pulumi.Input<string>;
        /**
         * Your organization's risk rating. You can specify one the following values as the risk rating:
         *
         * - High
         * - Medium
         * - Low
         * - Unknown
         */
        riskRating?: pulumi.Input<enums.sagemaker.ModelCardRiskRating>;
    }
    /**
     * Linear graph metric.
     */
    interface ModelCardLinearGraphMetricArgs {
        name: pulumi.Input<string>;
        notes?: pulumi.Input<string>;
        type: pulumi.Input<enums.sagemaker.ModelCardLinearGraphMetricType>;
        value: pulumi.Input<pulumi.Input<pulumi.Input<number>[]>[]>;
        xAxisName?: pulumi.Input<string>;
        yAxisName?: pulumi.Input<string>;
    }
    interface ModelCardMatrixMetricArgs {
        name: pulumi.Input<string>;
        notes?: pulumi.Input<string>;
        type: pulumi.Input<enums.sagemaker.ModelCardMatrixMetricType>;
        value: pulumi.Input<pulumi.Input<pulumi.Input<number>[]>[]>;
        xAxisName?: pulumi.Input<pulumi.Input<string>[]>;
        yAxisName?: pulumi.Input<pulumi.Input<string>[]>;
    }
    /**
     * item in metric groups
     */
    interface ModelCardMetricGroupArgs {
        metricData: pulumi.Input<pulumi.Input<inputs.sagemaker.ModelCardSimpleMetricArgs | inputs.sagemaker.ModelCardLinearGraphMetricArgs | inputs.sagemaker.ModelCardBarChartMetricArgs | inputs.sagemaker.ModelCardMatrixMetricArgs>[]>;
        name: pulumi.Input<string>;
    }
    /**
     * Overview about the model.
     */
    interface ModelCardModelOverviewArgs {
        /**
         * Algorithm used to solve the problem.
         */
        algorithmType?: pulumi.Input<string>;
        /**
         * Overview about the inference.
         */
        inferenceEnvironment?: pulumi.Input<inputs.sagemaker.ModelCardModelOverviewInferenceEnvironmentPropertiesArgs>;
        /**
         * Location of the model artifact.
         */
        modelArtifact?: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * Creator of model.
         */
        modelCreator?: pulumi.Input<string>;
        /**
         * description of model.
         */
        modelDescription?: pulumi.Input<string>;
        /**
         * SageMaker Model Arn or Non SageMaker Model id.
         */
        modelId?: pulumi.Input<string>;
        /**
         * Name of the model.
         */
        modelName?: pulumi.Input<string>;
        /**
         * Owner of model.
         */
        modelOwner?: pulumi.Input<string>;
        /**
         * Version of the model.
         */
        modelVersion?: pulumi.Input<number>;
        /**
         * Problem being solved with the model.
         */
        problemType?: pulumi.Input<string>;
    }
    /**
     * Overview about the inference.
     */
    interface ModelCardModelOverviewInferenceEnvironmentPropertiesArgs {
        /**
         * SageMaker inference image uri.
         */
        containerImage?: pulumi.Input<pulumi.Input<string>[]>;
    }
    interface ModelCardModelPackageCreatorArgs {
        /**
         * The name of the user's profile in Studio
         */
        userProfileName?: pulumi.Input<string>;
    }
    /**
     * Metadata information related to model package version
     */
    interface ModelCardModelPackageDetailsArgs {
        /**
         * A description provided for the model approval
         */
        approvalDescription?: pulumi.Input<string>;
        /**
         * Information about the user who created model package.
         */
        createdBy?: pulumi.Input<inputs.sagemaker.ModelCardModelPackageCreatorArgs>;
        /**
         * The machine learning domain of the model package you specified. Common machine learning domains include computer vision and natural language processing.
         */
        domain?: pulumi.Input<string>;
        /**
         * Details about inference jobs that can be run with models based on this model package.
         */
        inferenceSpecification?: pulumi.Input<inputs.sagemaker.ModelCardInferenceSpecificationArgs>;
        /**
         * Current approval status of model package
         */
        modelApprovalStatus?: pulumi.Input<enums.sagemaker.ModelCardModelPackageDetailsModelApprovalStatus>;
        /**
         * The Amazon Resource Name (ARN) of the model package
         */
        modelPackageArn?: pulumi.Input<string>;
        /**
         * A brief summary of the model package
         */
        modelPackageDescription?: pulumi.Input<string>;
        /**
         * If the model is a versioned model, the name of the model group that the versioned model belongs to.
         */
        modelPackageGroupName?: pulumi.Input<string>;
        /**
         * Name of the model package
         */
        modelPackageName?: pulumi.Input<string>;
        /**
         * Current status of model package
         */
        modelPackageStatus?: pulumi.Input<enums.sagemaker.ModelCardModelPackageDetailsModelPackageStatus>;
        /**
         * Version of the model package
         */
        modelPackageVersion?: pulumi.Input<number>;
        /**
         * A list of algorithms that were used to create a model package.
         */
        sourceAlgorithms?: pulumi.Input<pulumi.Input<inputs.sagemaker.ModelCardSourceAlgorithmArgs>[]>;
        /**
         * The machine learning task you specified that your model package accomplishes. Common machine learning tasks include object detection and image classification.
         */
        task?: pulumi.Input<string>;
    }
    /**
     * the objective function the model will optimize for.
     */
    interface ModelCardObjectiveFunctionArgs {
        /**
         * objective function that training job is optimized for.
         */
        function?: pulumi.Input<inputs.sagemaker.ModelCardObjectiveFunctionFunctionPropertiesArgs>;
        /**
         * Notes about the object function, including other considerations for possible objective functions.
         */
        notes?: pulumi.Input<string>;
    }
    /**
     * objective function that training job is optimized for.
     */
    interface ModelCardObjectiveFunctionFunctionPropertiesArgs {
        condition?: pulumi.Input<string>;
        facet?: pulumi.Input<string>;
        function?: pulumi.Input<enums.sagemaker.ModelCardObjectiveFunctionFunctionPropertiesFunction>;
    }
    /**
     * An optional Key Management Service key to encrypt, decrypt, and re-encrypt model card content for regulated workloads with highly sensitive data.
     */
    interface ModelCardSecurityConfigArgs {
        /**
         * A Key Management Service key ID to use for encrypting a model card.
         */
        kmsKeyId?: pulumi.Input<string>;
    }
    /**
     * metric data
     */
    interface ModelCardSimpleMetricArgs {
        name: pulumi.Input<string>;
        notes?: pulumi.Input<string>;
        type: pulumi.Input<enums.sagemaker.ModelCardSimpleMetricType>;
        value: pulumi.Input<number | string | boolean>;
        xAxisName?: pulumi.Input<string>;
        yAxisName?: pulumi.Input<string>;
    }
    interface ModelCardSourceAlgorithmArgs {
        /**
         * The name of an algorithm that was used to create the model package. The algorithm must be either an algorithm resource in your SageMaker account or an algorithm in AWS Marketplace that you are subscribed to.
         */
        algorithmName: pulumi.Input<string>;
        /**
         * The Amazon S3 path where the model artifacts, which result from model training, are stored.
         */
        modelDataUrl?: pulumi.Input<string>;
    }
    /**
     * Overview about the training.
     */
    interface ModelCardTrainingDetailsArgs {
        /**
         * The function that is optimized during model training.
         */
        objectiveFunction?: pulumi.Input<inputs.sagemaker.ModelCardObjectiveFunctionArgs>;
        /**
         * Details about any associated training jobs.
         */
        trainingJobDetails?: pulumi.Input<inputs.sagemaker.ModelCardTrainingDetailsTrainingJobDetailsPropertiesArgs>;
        /**
         * Any observations about training.
         */
        trainingObservations?: pulumi.Input<string>;
    }
    /**
     * Details about any associated training jobs.
     */
    interface ModelCardTrainingDetailsTrainingJobDetailsPropertiesArgs {
        hyperParameters?: pulumi.Input<pulumi.Input<inputs.sagemaker.ModelCardTrainingHyperParameterArgs>[]>;
        /**
         * SageMaker Training job arn.
         */
        trainingArn?: pulumi.Input<string>;
        /**
         * Location of the model datasets.
         */
        trainingDatasets?: pulumi.Input<pulumi.Input<string>[]>;
        trainingEnvironment?: pulumi.Input<inputs.sagemaker.ModelCardTrainingDetailsTrainingJobDetailsPropertiesTrainingEnvironmentPropertiesArgs>;
        trainingMetrics?: pulumi.Input<pulumi.Input<inputs.sagemaker.ModelCardTrainingMetricArgs>[]>;
        userProvidedHyperParameters?: pulumi.Input<pulumi.Input<inputs.sagemaker.ModelCardTrainingHyperParameterArgs>[]>;
        userProvidedTrainingMetrics?: pulumi.Input<pulumi.Input<inputs.sagemaker.ModelCardTrainingMetricArgs>[]>;
    }
    interface ModelCardTrainingDetailsTrainingJobDetailsPropertiesTrainingEnvironmentPropertiesArgs {
        /**
         * SageMaker training image uri.
         */
        containerImage?: pulumi.Input<pulumi.Input<string>[]>;
    }
    /**
     * training hyper parameter
     */
    interface ModelCardTrainingHyperParameterArgs {
        /**
         * The name of the hyper parameter.
         */
        name: pulumi.Input<string>;
        /**
         * The value specified for the hyper parameter.
         */
        value: pulumi.Input<string>;
    }
    /**
     * training metric data.
     */
    interface ModelCardTrainingMetricArgs {
        /**
         * The name of the result from the SageMaker AI training job.
         */
        name: pulumi.Input<string>;
        /**
         * Any additional notes describing the result of the training job.
         */
        notes?: pulumi.Input<string>;
        /**
         * The value of a result from the SageMaker AI training job.
         */
        value: pulumi.Input<number>;
    }
    /**
     * Information about the user who created or modified an experiment, trial, trial component, lineage group, project, or model card.
     */
    interface ModelCardUserContextArgs {
        /**
         * The domain associated with the user.
         */
        domainId?: pulumi.Input<string>;
        /**
         * The Amazon Resource Name (ARN) of the user's profile.
         */
        userProfileArn?: pulumi.Input<string>;
        /**
         * The name of the user's profile.
         */
        userProfileName?: pulumi.Input<string>;
    }
    /**
     * The batch transform input for a monitoring job.
     */
    interface ModelExplainabilityJobDefinitionBatchTransformInputArgs {
        /**
         * A URI that identifies the Amazon S3 storage location where Batch Transform Job captures data.
         */
        dataCapturedDestinationS3Uri: pulumi.Input<string>;
        /**
         * The dataset format for your batch transform job.
         */
        datasetFormat: pulumi.Input<inputs.sagemaker.ModelExplainabilityJobDefinitionDatasetFormatArgs>;
        /**
         * JSONpath to locate features in JSONlines dataset
         */
        featuresAttribute?: pulumi.Input<string>;
        /**
         * Index or JSONpath to locate predicted label(s)
         */
        inferenceAttribute?: pulumi.Input<string>;
        /**
         * Path to the filesystem where the endpoint data is available to the container.
         */
        localPath: pulumi.Input<string>;
        /**
         * Index or JSONpath to locate probabilities
         */
        probabilityAttribute?: pulumi.Input<string>;
        /**
         * Whether input data distributed in Amazon S3 is fully replicated or sharded by an S3 key. Defauts to FullyReplicated
         */
        s3DataDistributionType?: pulumi.Input<enums.sagemaker.ModelExplainabilityJobDefinitionBatchTransformInputS3DataDistributionType>;
        /**
         * Whether the Pipe or File is used as the input mode for transfering data for the monitoring job. Pipe mode is recommended for large datasets. File mode is useful for small files that fit in memory. Defaults to File.
         */
        s3InputMode?: pulumi.Input<enums.sagemaker.ModelExplainabilityJobDefinitionBatchTransformInputS3InputMode>;
    }
    /**
     * Configuration for the cluster used to run model monitoring jobs.
     */
    interface ModelExplainabilityJobDefinitionClusterConfigArgs {
        /**
         * The number of ML compute instances to use in the model monitoring job. For distributed processing jobs, specify a value greater than 1. The default value is 1.
         */
        instanceCount: pulumi.Input<number>;
        /**
         * The ML compute instance type for the processing job.
         */
        instanceType: pulumi.Input<string>;
        /**
         * The AWS Key Management Service (AWS KMS) key that Amazon SageMaker uses to encrypt data on the storage volume attached to the ML compute instance(s) that run the model monitoring job.
         */
        volumeKmsKeyId?: pulumi.Input<string>;
        /**
         * The size of the ML storage volume, in gigabytes, that you want to provision. You must specify sufficient ML storage for your scenario.
         */
        volumeSizeInGb: pulumi.Input<number>;
    }
    /**
     * The baseline constraints resource for a monitoring job.
     */
    interface ModelExplainabilityJobDefinitionConstraintsResourceArgs {
        /**
         * The Amazon S3 URI for baseline constraint file in Amazon S3 that the current monitoring job should validated against.
         */
        s3Uri?: pulumi.Input<string>;
    }
    /**
     * The CSV format
     */
    interface ModelExplainabilityJobDefinitionCsvArgs {
        /**
         * A boolean flag indicating if given CSV has header
         */
        header?: pulumi.Input<boolean>;
    }
    /**
     * The dataset format of the data to monitor
     */
    interface ModelExplainabilityJobDefinitionDatasetFormatArgs {
        csv?: pulumi.Input<inputs.sagemaker.ModelExplainabilityJobDefinitionCsvArgs>;
        json?: pulumi.Input<inputs.sagemaker.ModelExplainabilityJobDefinitionJsonArgs>;
        parquet?: pulumi.Input<boolean>;
    }
    /**
     * The endpoint for a monitoring job.
     */
    interface ModelExplainabilityJobDefinitionEndpointInputArgs {
        /**
         * An endpoint in customer's account which has enabled `DataCaptureConfig` enabled.
         */
        endpointName: pulumi.Input<string>;
        /**
         * JSONpath to locate features in JSONlines dataset
         */
        featuresAttribute?: pulumi.Input<string>;
        /**
         * Index or JSONpath to locate predicted label(s)
         */
        inferenceAttribute?: pulumi.Input<string>;
        /**
         * Path to the filesystem where the endpoint data is available to the container.
         */
        localPath: pulumi.Input<string>;
        /**
         * Index or JSONpath to locate probabilities
         */
        probabilityAttribute?: pulumi.Input<string>;
        /**
         * Whether input data distributed in Amazon S3 is fully replicated or sharded by an S3 key. Defauts to FullyReplicated
         */
        s3DataDistributionType?: pulumi.Input<enums.sagemaker.ModelExplainabilityJobDefinitionEndpointInputS3DataDistributionType>;
        /**
         * Whether the Pipe or File is used as the input mode for transfering data for the monitoring job. Pipe mode is recommended for large datasets. File mode is useful for small files that fit in memory. Defaults to File.
         */
        s3InputMode?: pulumi.Input<enums.sagemaker.ModelExplainabilityJobDefinitionEndpointInputS3InputMode>;
    }
    /**
     * The Json format
     */
    interface ModelExplainabilityJobDefinitionJsonArgs {
        /**
         * A boolean flag indicating if it is JSON line format
         */
        line?: pulumi.Input<boolean>;
    }
    /**
     * Container image configuration object for the monitoring job.
     */
    interface ModelExplainabilityJobDefinitionModelExplainabilityAppSpecificationArgs {
        /**
         * The S3 URI to an analysis configuration file
         */
        configUri: pulumi.Input<string>;
        /**
         * Sets the environment variables in the Docker container
         */
        environment?: any;
        /**
         * The container image to be run by the monitoring job.
         */
        imageUri: pulumi.Input<string>;
    }
    /**
     * Baseline configuration used to validate that the data conforms to the specified constraints and statistics.
     */
    interface ModelExplainabilityJobDefinitionModelExplainabilityBaselineConfigArgs {
        /**
         * The name of the baseline model explainability job.
         */
        baseliningJobName?: pulumi.Input<string>;
        /**
         * The constraints resource for a model explainability job.
         */
        constraintsResource?: pulumi.Input<inputs.sagemaker.ModelExplainabilityJobDefinitionConstraintsResourceArgs>;
    }
    /**
     * The inputs for a monitoring job.
     */
    interface ModelExplainabilityJobDefinitionModelExplainabilityJobInputArgs {
        /**
         * Input object for the batch transform job.
         */
        batchTransformInput?: pulumi.Input<inputs.sagemaker.ModelExplainabilityJobDefinitionBatchTransformInputArgs>;
        /**
         * Input object for the endpoint
         */
        endpointInput?: pulumi.Input<inputs.sagemaker.ModelExplainabilityJobDefinitionEndpointInputArgs>;
    }
    /**
     * The output object for a monitoring job.
     */
    interface ModelExplainabilityJobDefinitionMonitoringOutputArgs {
        /**
         * The Amazon S3 storage location where the results of a monitoring job are saved.
         */
        s3Output: pulumi.Input<inputs.sagemaker.ModelExplainabilityJobDefinitionS3OutputArgs>;
    }
    /**
     * The output configuration for monitoring jobs.
     */
    interface ModelExplainabilityJobDefinitionMonitoringOutputConfigArgs {
        /**
         * The AWS Key Management Service (AWS KMS) key that Amazon SageMaker uses to encrypt the model artifacts at rest using Amazon S3 server-side encryption.
         */
        kmsKeyId?: pulumi.Input<string>;
        /**
         * Monitoring outputs for monitoring jobs. This is where the output of the periodic monitoring jobs is uploaded.
         */
        monitoringOutputs: pulumi.Input<pulumi.Input<inputs.sagemaker.ModelExplainabilityJobDefinitionMonitoringOutputArgs>[]>;
    }
    /**
     * Identifies the resources to deploy for a monitoring job.
     */
    interface ModelExplainabilityJobDefinitionMonitoringResourcesArgs {
        /**
         * The configuration for the cluster resources used to run the processing job.
         */
        clusterConfig: pulumi.Input<inputs.sagemaker.ModelExplainabilityJobDefinitionClusterConfigArgs>;
    }
    /**
     * Networking options for a job, such as network traffic encryption between containers, whether to allow inbound and outbound network calls to and from containers, and the VPC subnets and security groups to use for VPC-enabled jobs.
     */
    interface ModelExplainabilityJobDefinitionNetworkConfigArgs {
        /**
         * Whether to encrypt all communications between distributed processing jobs. Choose True to encrypt communications. Encryption provides greater security for distributed processing jobs, but the processing might take longer.
         */
        enableInterContainerTrafficEncryption?: pulumi.Input<boolean>;
        /**
         * Whether to allow inbound and outbound network calls to and from the containers used for the processing job.
         */
        enableNetworkIsolation?: pulumi.Input<boolean>;
        /**
         * Specifies a VPC that your training jobs and hosted models have access to. Control access to and from your training and model containers by configuring the VPC.
         */
        vpcConfig?: pulumi.Input<inputs.sagemaker.ModelExplainabilityJobDefinitionVpcConfigArgs>;
    }
    /**
     * Information about where and how to store the results of a monitoring job.
     */
    interface ModelExplainabilityJobDefinitionS3OutputArgs {
        /**
         * The local path to the Amazon S3 storage location where Amazon SageMaker saves the results of a monitoring job. LocalPath is an absolute path for the output data.
         */
        localPath: pulumi.Input<string>;
        /**
         * Whether to upload the results of the monitoring job continuously or after the job completes.
         */
        s3UploadMode?: pulumi.Input<enums.sagemaker.ModelExplainabilityJobDefinitionS3OutputS3UploadMode>;
        /**
         * A URI that identifies the Amazon S3 storage location where Amazon SageMaker saves the results of a monitoring job.
         */
        s3Uri: pulumi.Input<string>;
    }
    /**
     * Specifies a time limit for how long the monitoring job is allowed to run.
     */
    interface ModelExplainabilityJobDefinitionStoppingConditionArgs {
        /**
         * The maximum runtime allowed in seconds.
         */
        maxRuntimeInSeconds: pulumi.Input<number>;
    }
    /**
     * Specifies a VPC that your training jobs and hosted models have access to. Control access to and from your training and model containers by configuring the VPC.
     */
    interface ModelExplainabilityJobDefinitionVpcConfigArgs {
        /**
         * The VPC security group IDs, in the form sg-xxxxxxxx. Specify the security groups for the VPC that is specified in the Subnets field.
         */
        securityGroupIds: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * The ID of the subnets in the VPC to which you want to connect to your monitoring jobs.
         */
        subnets: pulumi.Input<pulumi.Input<string>[]>;
    }
    /**
     * Additional Inference Specification specifies details about inference jobs that can be run with models based on this model package.AdditionalInferenceSpecifications can be added to existing model packages using AdditionalInferenceSpecificationsToAdd.
     */
    interface ModelPackageAdditionalInferenceSpecificationDefinitionArgs {
        /**
         * The Amazon ECR registry path of the Docker image that contains the inference code.
         */
        containers: pulumi.Input<pulumi.Input<inputs.sagemaker.ModelPackageContainerDefinitionArgs>[]>;
        /**
         * A description of the additional Inference specification.
         */
        description?: pulumi.Input<string>;
        /**
         * A unique name to identify the additional inference specification. The name must be unique within the list of your additional inference specifications for a particular model package.
         */
        name: pulumi.Input<string>;
        /**
         * The supported MIME types for the input data.
         */
        supportedContentTypes?: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * A list of the instance types that are used to generate inferences in real-time
         */
        supportedRealtimeInferenceInstanceTypes?: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * The supported MIME types for the output data.
         */
        supportedResponseMimeTypes?: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * A list of the instance types on which a transformation job can be run or on which an endpoint can be deployed.
         */
        supportedTransformInstanceTypes?: pulumi.Input<pulumi.Input<string>[]>;
    }
    /**
     * Contains bias metrics for a model.
     */
    interface ModelPackageBiasArgs {
        /**
         * The post-training bias report for a model.
         */
        postTrainingReport?: pulumi.Input<inputs.sagemaker.ModelPackageMetricsSourceArgs>;
        /**
         * The pre-training bias report for a model.
         */
        preTrainingReport?: pulumi.Input<inputs.sagemaker.ModelPackageMetricsSourceArgs>;
        /**
         * The bias report for a model
         */
        report?: pulumi.Input<inputs.sagemaker.ModelPackageMetricsSourceArgs>;
    }
    /**
     * Describes the Docker container for the model package.
     */
    interface ModelPackageContainerDefinitionArgs {
        /**
         * The DNS host name for the Docker container.
         */
        containerHostname?: pulumi.Input<string>;
        environment?: pulumi.Input<inputs.sagemaker.ModelPackageEnvironmentArgs>;
        /**
         * The machine learning framework of the model package container image.
         */
        framework?: pulumi.Input<string>;
        /**
         * The framework version of the Model Package Container Image.
         */
        frameworkVersion?: pulumi.Input<string>;
        /**
         * The Amazon EC2 Container Registry (Amazon ECR) path where inference code is stored.
         */
        image: pulumi.Input<string>;
        /**
         * An MD5 hash of the training algorithm that identifies the Docker image used for training.
         */
        imageDigest?: pulumi.Input<string>;
        modelDataSource?: pulumi.Input<inputs.sagemaker.ModelPackageModelDataSourceArgs>;
        /**
         * A structure with Model Input details.
         */
        modelDataUrl?: pulumi.Input<string>;
        modelInput?: pulumi.Input<inputs.sagemaker.ModelPackageContainerDefinitionModelInputPropertiesArgs>;
        /**
         * The name of a pre-trained machine learning benchmarked by Amazon SageMaker Inference Recommender model that matches your model.
         */
        nearestModelName?: pulumi.Input<string>;
    }
    interface ModelPackageContainerDefinitionModelInputPropertiesArgs {
        /**
         * The input configuration object for the model.
         */
        dataInputConfig: pulumi.Input<string>;
    }
    /**
     * The metadata properties associated with the model package versions.
     */
    interface ModelPackageCustomerMetadataPropertiesArgs {
    }
    /**
     * Describes the input source of a transform job and the way the transform job consumes it.
     */
    interface ModelPackageDataSourceArgs {
        /**
         * The S3 location of the data source that is associated with a channel.
         */
        s3DataSource: pulumi.Input<inputs.sagemaker.ModelPackageS3DataSourceArgs>;
    }
    /**
     * Represents the drift check baselines that can be used when the model monitor is set using the model package.
     */
    interface ModelPackageDriftCheckBaselinesArgs {
        /**
         * Represents the drift check bias baselines that can be used when the model monitor is set using the model package.
         */
        bias?: pulumi.Input<inputs.sagemaker.ModelPackageDriftCheckBiasArgs>;
        /**
         * Represents the drift check explainability baselines that can be used when the model monitor is set using the model package.
         */
        explainability?: pulumi.Input<inputs.sagemaker.ModelPackageDriftCheckExplainabilityArgs>;
        /**
         * Represents the drift check model data quality baselines that can be used when the model monitor is set using the model package.
         */
        modelDataQuality?: pulumi.Input<inputs.sagemaker.ModelPackageDriftCheckModelDataQualityArgs>;
        /**
         * Represents the drift check model quality baselines that can be used when the model monitor is set using the model package.
         */
        modelQuality?: pulumi.Input<inputs.sagemaker.ModelPackageDriftCheckModelQualityArgs>;
    }
    /**
     * Represents the drift check bias baselines that can be used when the model monitor is set using the model package.
     */
    interface ModelPackageDriftCheckBiasArgs {
        /**
         * The bias config file for a model.
         */
        configFile?: pulumi.Input<inputs.sagemaker.ModelPackageFileSourceArgs>;
        /**
         * The post-training constraints.
         */
        postTrainingConstraints?: pulumi.Input<inputs.sagemaker.ModelPackageMetricsSourceArgs>;
        /**
         * The pre-training constraints.
         */
        preTrainingConstraints?: pulumi.Input<inputs.sagemaker.ModelPackageMetricsSourceArgs>;
    }
    /**
     * Contains explainability metrics for a model.
     */
    interface ModelPackageDriftCheckExplainabilityArgs {
        /**
         * The explainability config file for the model.
         */
        configFile?: pulumi.Input<inputs.sagemaker.ModelPackageFileSourceArgs>;
        /**
         * The drift check explainability constraints.
         */
        constraints?: pulumi.Input<inputs.sagemaker.ModelPackageMetricsSourceArgs>;
    }
    /**
     * Represents the drift check data quality baselines that can be used when the model monitor is set using the model package.
     */
    interface ModelPackageDriftCheckModelDataQualityArgs {
        /**
         * The drift check model data quality constraints.
         */
        constraints?: pulumi.Input<inputs.sagemaker.ModelPackageMetricsSourceArgs>;
        /**
         * The drift check model data quality statistics.
         */
        statistics?: pulumi.Input<inputs.sagemaker.ModelPackageMetricsSourceArgs>;
    }
    /**
     * Represents the drift check model quality baselines that can be used when the model monitor is set using the model package.
     */
    interface ModelPackageDriftCheckModelQualityArgs {
        /**
         * The drift check model quality constraints.
         */
        constraints?: pulumi.Input<inputs.sagemaker.ModelPackageMetricsSourceArgs>;
        /**
         * The drift check model quality statistics.
         */
        statistics?: pulumi.Input<inputs.sagemaker.ModelPackageMetricsSourceArgs>;
    }
    /**
     * Sets the environment variables in the Docker container
     */
    interface ModelPackageEnvironmentArgs {
    }
    /**
     * Contains explainability metrics for a model.
     */
    interface ModelPackageExplainabilityArgs {
        /**
         * The explainability report for a model.
         */
        report?: pulumi.Input<inputs.sagemaker.ModelPackageMetricsSourceArgs>;
    }
    /**
     * Represents a File Source Object.
     */
    interface ModelPackageFileSourceArgs {
        /**
         * The digest of the file source.
         */
        contentDigest?: pulumi.Input<string>;
        /**
         * The type of content stored in the file source.
         */
        contentType?: pulumi.Input<string>;
        /**
         * The Amazon S3 URI for the file source.
         */
        s3Uri: pulumi.Input<string>;
    }
    /**
     * Details about inference jobs that can be run with models based on this model package.
     */
    interface ModelPackageInferenceSpecificationArgs {
        /**
         * The Amazon ECR registry path of the Docker image that contains the inference code.
         */
        containers: pulumi.Input<pulumi.Input<inputs.sagemaker.ModelPackageContainerDefinitionArgs>[]>;
        /**
         * The supported MIME types for the input data.
         */
        supportedContentTypes: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * A list of the instance types that are used to generate inferences in real-time
         */
        supportedRealtimeInferenceInstanceTypes?: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * The supported MIME types for the output data.
         */
        supportedResponseMimeTypes: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * A list of the instance types on which a transformation job can be run or on which an endpoint can be deployed.
         */
        supportedTransformInstanceTypes?: pulumi.Input<pulumi.Input<string>[]>;
    }
    /**
     * Metadata properties of the tracking entity, trial, or trial component.
     */
    interface ModelPackageMetadataPropertiesArgs {
        /**
         * The commit ID.
         */
        commitId?: pulumi.Input<string>;
        /**
         * The entity this entity was generated by.
         */
        generatedBy?: pulumi.Input<string>;
        /**
         * The project ID metadata.
         */
        projectId?: pulumi.Input<string>;
        /**
         * The repository metadata.
         */
        repository?: pulumi.Input<string>;
    }
    /**
     * Represents a Metric Source Object.
     */
    interface ModelPackageMetricsSourceArgs {
        /**
         * The digest of the metric source.
         */
        contentDigest?: pulumi.Input<string>;
        /**
         * The type of content stored in the metric source.
         */
        contentType: pulumi.Input<string>;
        /**
         * The Amazon S3 URI for the metric source.
         */
        s3Uri: pulumi.Input<string>;
    }
    /**
     * Specifies the access configuration file for the ML model.
     */
    interface ModelPackageModelAccessConfigArgs {
        /**
         * Specifies agreement to the model end-user license agreement (EULA).
         */
        acceptEula: pulumi.Input<boolean>;
    }
    /**
     * The model card associated with the model package.
     */
    interface ModelPackageModelCardArgs {
        /**
         * The content of the model card.
         */
        modelCardContent: pulumi.Input<string>;
        /**
         * The approval status of the model card within your organization.
         */
        modelCardStatus: pulumi.Input<enums.sagemaker.ModelPackageModelCardModelCardStatus>;
    }
    /**
     * Metrics that measure the quality of the input data for a model.
     */
    interface ModelPackageModelDataQualityArgs {
        /**
         * Data quality constraints for a model.
         */
        constraints?: pulumi.Input<inputs.sagemaker.ModelPackageMetricsSourceArgs>;
        /**
         * Data quality statistics for a model.
         */
        statistics?: pulumi.Input<inputs.sagemaker.ModelPackageMetricsSourceArgs>;
    }
    /**
     * Specifies the location of ML model data to deploy during endpoint creation.
     */
    interface ModelPackageModelDataSourceArgs {
        s3DataSource?: pulumi.Input<inputs.sagemaker.ModelPackageS3ModelDataSourceArgs>;
    }
    /**
     * A structure that contains model metrics reports.
     */
    interface ModelPackageModelMetricsArgs {
        /**
         * Metrics that measure bias in a model.
         */
        bias?: pulumi.Input<inputs.sagemaker.ModelPackageBiasArgs>;
        /**
         * Metrics that help explain a model.
         */
        explainability?: pulumi.Input<inputs.sagemaker.ModelPackageExplainabilityArgs>;
        /**
         * Metrics that measure the quality of the input data for a model.
         */
        modelDataQuality?: pulumi.Input<inputs.sagemaker.ModelPackageModelDataQualityArgs>;
        /**
         * Metrics that measure the quality of a model.
         */
        modelQuality?: pulumi.Input<inputs.sagemaker.ModelPackageModelQualityArgs>;
    }
    /**
     * Metrics that measure the quality of a model.
     */
    interface ModelPackageModelQualityArgs {
        /**
         * Model quality constraints.
         */
        constraints?: pulumi.Input<inputs.sagemaker.ModelPackageMetricsSourceArgs>;
        /**
         * Model quality statistics.
         */
        statistics?: pulumi.Input<inputs.sagemaker.ModelPackageMetricsSourceArgs>;
    }
    /**
     * Describes the S3 data source.
     */
    interface ModelPackageS3DataSourceArgs {
        /**
         * The S3 Data Source Type
         */
        s3DataType: pulumi.Input<enums.sagemaker.ModelPackageS3DataSourceS3DataType>;
        /**
         * Depending on the value specified for the S3DataType, identifies either a key name prefix or a manifest.
         */
        s3Uri: pulumi.Input<string>;
    }
    /**
     * Specifies the S3 location of ML model data to deploy.
     */
    interface ModelPackageS3ModelDataSourceArgs {
        /**
         * Specifies how the ML model data is prepared.
         */
        compressionType: pulumi.Input<enums.sagemaker.ModelPackageS3ModelDataSourceCompressionType>;
        modelAccessConfig?: pulumi.Input<inputs.sagemaker.ModelPackageModelAccessConfigArgs>;
        /**
         * Specifies the type of ML model data to deploy.
         */
        s3DataType: pulumi.Input<enums.sagemaker.ModelPackageS3ModelDataSourceS3DataType>;
        /**
         * Specifies the S3 path of ML model data to deploy.
         */
        s3Uri: pulumi.Input<string>;
    }
    /**
     * An optional AWS Key Management Service key to encrypt, decrypt, and re-encrypt model package information for regulated workloads with highly sensitive data.
     */
    interface ModelPackageSecurityConfigArgs {
        /**
         * The AWS KMS Key ID (KMSKeyId) used for encryption of model package information.
         */
        kmsKeyId: pulumi.Input<string>;
    }
    /**
     * Specifies an algorithm that was used to create the model package. The algorithm must be either an algorithm resource in your Amazon SageMaker account or an algorithm in AWS Marketplace that you are subscribed to.
     */
    interface ModelPackageSourceAlgorithmArgs {
        /**
         * The name of an algorithm that was used to create the model package. The algorithm must be either an algorithm resource in your Amazon SageMaker account or an algorithm in AWS Marketplace that you are subscribed to.
         */
        algorithmName: pulumi.Input<string>;
        /**
         * The Amazon S3 path where the model artifacts, which result from model training, are stored. This path must point to a single gzip compressed tar archive (.tar.gz suffix).
         */
        modelDataUrl?: pulumi.Input<string>;
    }
    /**
     * Details about the algorithm that was used to create the model package.
     */
    interface ModelPackageSourceAlgorithmSpecificationArgs {
        /**
         * A list of algorithms that were used to create a model package.
         */
        sourceAlgorithms: pulumi.Input<pulumi.Input<inputs.sagemaker.ModelPackageSourceAlgorithmArgs>[]>;
    }
    /**
     * Details about the current status of the model package.
     */
    interface ModelPackageStatusDetailsArgs {
        /**
         * The validation status of the model package.
         */
        validationStatuses?: pulumi.Input<pulumi.Input<inputs.sagemaker.ModelPackageStatusItemArgs>[]>;
    }
    /**
     * Represents the overall status of a model package.
     */
    interface ModelPackageStatusItemArgs {
        /**
         * If the overall status is Failed, the reason for the failure.
         */
        failureReason?: pulumi.Input<string>;
        /**
         * The name of the model package for which the overall status is being reported.
         */
        name: pulumi.Input<string>;
        /**
         * The current status.
         */
        status: pulumi.Input<enums.sagemaker.ModelPackageStatusItemStatus>;
    }
    /**
     * Describes the input source of a transform job and the way the transform job consumes it.
     */
    interface ModelPackageTransformInputArgs {
        /**
         * If your transform data is compressed, specify the compression type. Amazon SageMaker automatically decompresses the data for the transform job accordingly. The default value is None.
         */
        compressionType?: pulumi.Input<enums.sagemaker.ModelPackageTransformInputCompressionType>;
        /**
         * The multipurpose internet mail extension (MIME) type of the data. Amazon SageMaker uses the MIME type with each http call to transfer data to the transform job.
         */
        contentType?: pulumi.Input<string>;
        /**
         * Describes the location of the channel data, which is, the S3 location of the input data that the model can consume.
         */
        dataSource: pulumi.Input<inputs.sagemaker.ModelPackageDataSourceArgs>;
        /**
         * The method to use to split the transform job's data files into smaller batches.
         */
        splitType?: pulumi.Input<enums.sagemaker.ModelPackageTransformInputSplitType>;
    }
    /**
     * Defines the input needed to run a transform job using the inference specification specified in the algorithm.
     */
    interface ModelPackageTransformJobDefinitionArgs {
        /**
         * A string that determines the number of records included in a single mini-batch.
         */
        batchStrategy?: pulumi.Input<enums.sagemaker.ModelPackageTransformJobDefinitionBatchStrategy>;
        /**
         * The environment variables to set in the Docker container. We support up to 16 key and values entries in the map.
         */
        environment?: pulumi.Input<inputs.sagemaker.ModelPackageEnvironmentArgs>;
        /**
         * The maximum number of parallel requests that can be sent to each instance in a transform job. The default value is 1.
         */
        maxConcurrentTransforms?: pulumi.Input<number>;
        /**
         * The maximum payload size allowed, in MB. A payload is the data portion of a record (without metadata).
         */
        maxPayloadInMb?: pulumi.Input<number>;
        /**
         * A description of the input source and the way the transform job consumes it.
         */
        transformInput: pulumi.Input<inputs.sagemaker.ModelPackageTransformInputArgs>;
        /**
         * Identifies the Amazon S3 location where you want Amazon SageMaker to save the results from the transform job.
         */
        transformOutput: pulumi.Input<inputs.sagemaker.ModelPackageTransformOutputArgs>;
        /**
         * Identifies the ML compute instances for the transform job.
         */
        transformResources: pulumi.Input<inputs.sagemaker.ModelPackageTransformResourcesArgs>;
    }
    /**
     * Describes the results of a transform job.
     */
    interface ModelPackageTransformOutputArgs {
        /**
         * The MIME type used to specify the output data. Amazon SageMaker uses the MIME type with each http call to transfer data from the transform job.
         */
        accept?: pulumi.Input<string>;
        /**
         * Defines how to assemble the results of the transform job as a single S3 object.
         */
        assembleWith?: pulumi.Input<enums.sagemaker.ModelPackageTransformOutputAssembleWith>;
        /**
         * The AWS Key Management Service (AWS KMS) key that Amazon SageMaker uses to encrypt the model artifacts at rest using Amazon S3 server-side encryption.
         */
        kmsKeyId?: pulumi.Input<string>;
        /**
         * The Amazon S3 path where you want Amazon SageMaker to store the results of the transform job.
         */
        s3OutputPath: pulumi.Input<string>;
    }
    /**
     * Describes the resources, including ML instance types and ML instance count, to use for transform job.
     */
    interface ModelPackageTransformResourcesArgs {
        /**
         * The number of ML compute instances to use in the transform job. For distributed transform jobs, specify a value greater than 1. The default value is 1.
         */
        instanceCount: pulumi.Input<number>;
        /**
         * The ML compute instance type for the transform job.
         */
        instanceType: pulumi.Input<string>;
        /**
         * The AWS Key Management Service (AWS KMS) key that Amazon SageMaker uses to encrypt model data on the storage volume attached to the ML compute instance(s) that run the batch transform job.
         */
        volumeKmsKeyId?: pulumi.Input<string>;
    }
    /**
     * Contains data, such as the inputs and targeted instance types that are used in the process of validating the model package.
     */
    interface ModelPackageValidationProfileArgs {
        /**
         * The name of the profile for the model package.
         */
        profileName: pulumi.Input<string>;
        /**
         * The `TransformJobDefinition` object that describes the transform job used for the validation of the model package.
         */
        transformJobDefinition: pulumi.Input<inputs.sagemaker.ModelPackageTransformJobDefinitionArgs>;
    }
    /**
     * Specifies configurations for one or more transform jobs that Amazon SageMaker runs to test the model package.
     */
    interface ModelPackageValidationSpecificationArgs {
        /**
         * An array of `ModelPackageValidationProfile` objects, each of which specifies a batch transform job that SageMaker runs to validate your model package.
         */
        validationProfiles: pulumi.Input<pulumi.Input<inputs.sagemaker.ModelPackageValidationProfileArgs>[]>;
        /**
         * The IAM roles to be used for the validation of the model package.
         */
        validationRole: pulumi.Input<string>;
    }
    /**
     * The batch transform input for a monitoring job.
     */
    interface ModelQualityJobDefinitionBatchTransformInputArgs {
        /**
         * A URI that identifies the Amazon S3 storage location where Batch Transform Job captures data.
         */
        dataCapturedDestinationS3Uri: pulumi.Input<string>;
        /**
         * The dataset format for your batch transform job.
         */
        datasetFormat: pulumi.Input<inputs.sagemaker.ModelQualityJobDefinitionDatasetFormatArgs>;
        /**
         * Monitoring end time offset, e.g. PT0H
         */
        endTimeOffset?: pulumi.Input<string>;
        /**
         * Index or JSONpath to locate predicted label(s)
         */
        inferenceAttribute?: pulumi.Input<string>;
        /**
         * Path to the filesystem where the endpoint data is available to the container.
         */
        localPath: pulumi.Input<string>;
        /**
         * Index or JSONpath to locate probabilities
         */
        probabilityAttribute?: pulumi.Input<string>;
        /**
         * The threshold for the class probability to be evaluated as a positive result.
         */
        probabilityThresholdAttribute?: pulumi.Input<number>;
        /**
         * Whether input data distributed in Amazon S3 is fully replicated or sharded by an S3 key. Defauts to FullyReplicated
         */
        s3DataDistributionType?: pulumi.Input<enums.sagemaker.ModelQualityJobDefinitionBatchTransformInputS3DataDistributionType>;
        /**
         * Whether the Pipe or File is used as the input mode for transfering data for the monitoring job. Pipe mode is recommended for large datasets. File mode is useful for small files that fit in memory. Defaults to File.
         */
        s3InputMode?: pulumi.Input<enums.sagemaker.ModelQualityJobDefinitionBatchTransformInputS3InputMode>;
        /**
         * Monitoring start time offset, e.g. -PT1H
         */
        startTimeOffset?: pulumi.Input<string>;
    }
    /**
     * Configuration for the cluster used to run model monitoring jobs.
     */
    interface ModelQualityJobDefinitionClusterConfigArgs {
        /**
         * The number of ML compute instances to use in the model monitoring job. For distributed processing jobs, specify a value greater than 1. The default value is 1.
         */
        instanceCount: pulumi.Input<number>;
        /**
         * The ML compute instance type for the processing job.
         */
        instanceType: pulumi.Input<string>;
        /**
         * The AWS Key Management Service (AWS KMS) key that Amazon SageMaker uses to encrypt data on the storage volume attached to the ML compute instance(s) that run the model monitoring job.
         */
        volumeKmsKeyId?: pulumi.Input<string>;
        /**
         * The size of the ML storage volume, in gigabytes, that you want to provision. You must specify sufficient ML storage for your scenario.
         */
        volumeSizeInGb: pulumi.Input<number>;
    }
    /**
     * The baseline constraints resource for a monitoring job.
     */
    interface ModelQualityJobDefinitionConstraintsResourceArgs {
        /**
         * The Amazon S3 URI for baseline constraint file in Amazon S3 that the current monitoring job should validated against.
         */
        s3Uri?: pulumi.Input<string>;
    }
    /**
     * The CSV format
     */
    interface ModelQualityJobDefinitionCsvArgs {
        /**
         * A boolean flag indicating if given CSV has header
         */
        header?: pulumi.Input<boolean>;
    }
    /**
     * The dataset format of the data to monitor
     */
    interface ModelQualityJobDefinitionDatasetFormatArgs {
        csv?: pulumi.Input<inputs.sagemaker.ModelQualityJobDefinitionCsvArgs>;
        json?: pulumi.Input<inputs.sagemaker.ModelQualityJobDefinitionJsonArgs>;
        parquet?: pulumi.Input<boolean>;
    }
    /**
     * The endpoint for a monitoring job.
     */
    interface ModelQualityJobDefinitionEndpointInputArgs {
        /**
         * Monitoring end time offset, e.g. PT0H
         */
        endTimeOffset?: pulumi.Input<string>;
        /**
         * An endpoint in customer's account which has enabled `DataCaptureConfig` enabled.
         */
        endpointName: pulumi.Input<string>;
        /**
         * Index or JSONpath to locate predicted label(s)
         */
        inferenceAttribute?: pulumi.Input<string>;
        /**
         * Path to the filesystem where the endpoint data is available to the container.
         */
        localPath: pulumi.Input<string>;
        /**
         * Index or JSONpath to locate probabilities
         */
        probabilityAttribute?: pulumi.Input<string>;
        /**
         * The threshold for the class probability to be evaluated as a positive result.
         */
        probabilityThresholdAttribute?: pulumi.Input<number>;
        /**
         * Whether input data distributed in Amazon S3 is fully replicated or sharded by an S3 key. Defauts to FullyReplicated
         */
        s3DataDistributionType?: pulumi.Input<enums.sagemaker.ModelQualityJobDefinitionEndpointInputS3DataDistributionType>;
        /**
         * Whether the Pipe or File is used as the input mode for transfering data for the monitoring job. Pipe mode is recommended for large datasets. File mode is useful for small files that fit in memory. Defaults to File.
         */
        s3InputMode?: pulumi.Input<enums.sagemaker.ModelQualityJobDefinitionEndpointInputS3InputMode>;
        /**
         * Monitoring start time offset, e.g. -PT1H
         */
        startTimeOffset?: pulumi.Input<string>;
    }
    /**
     * The Json format
     */
    interface ModelQualityJobDefinitionJsonArgs {
        /**
         * A boolean flag indicating if it is JSON line format
         */
        line?: pulumi.Input<boolean>;
    }
    /**
     * Container image configuration object for the monitoring job.
     */
    interface ModelQualityJobDefinitionModelQualityAppSpecificationArgs {
        /**
         * An array of arguments for the container used to run the monitoring job.
         */
        containerArguments?: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * Specifies the entrypoint for a container used to run the monitoring job.
         */
        containerEntrypoint?: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * Sets the environment variables in the Docker container
         */
        environment?: any;
        /**
         * The container image to be run by the monitoring job.
         */
        imageUri: pulumi.Input<string>;
        /**
         * An Amazon S3 URI to a script that is called after analysis has been performed. Applicable only for the built-in (first party) containers.
         */
        postAnalyticsProcessorSourceUri?: pulumi.Input<string>;
        /**
         * The machine learning problem type of the model that the monitoring job monitors.
         */
        problemType: pulumi.Input<enums.sagemaker.ModelQualityJobDefinitionProblemType>;
        /**
         * An Amazon S3 URI to a script that is called per row prior to running analysis. It can base64 decode the payload and convert it into a flatted json so that the built-in container can use the converted data. Applicable only for the built-in (first party) containers
         */
        recordPreprocessorSourceUri?: pulumi.Input<string>;
    }
    /**
     * Baseline configuration used to validate that the data conforms to the specified constraints and statistics.
     */
    interface ModelQualityJobDefinitionModelQualityBaselineConfigArgs {
        /**
         * The name of the job that performs baselining for the monitoring job.
         */
        baseliningJobName?: pulumi.Input<string>;
        /**
         * The constraints resource for a monitoring job.
         */
        constraintsResource?: pulumi.Input<inputs.sagemaker.ModelQualityJobDefinitionConstraintsResourceArgs>;
    }
    /**
     * The inputs for a monitoring job.
     */
    interface ModelQualityJobDefinitionModelQualityJobInputArgs {
        /**
         * Input object for the batch transform job.
         */
        batchTransformInput?: pulumi.Input<inputs.sagemaker.ModelQualityJobDefinitionBatchTransformInputArgs>;
        /**
         * Input object for the endpoint
         */
        endpointInput?: pulumi.Input<inputs.sagemaker.ModelQualityJobDefinitionEndpointInputArgs>;
        /**
         * The ground truth label provided for the model.
         */
        groundTruthS3Input: pulumi.Input<inputs.sagemaker.ModelQualityJobDefinitionMonitoringGroundTruthS3InputArgs>;
    }
    /**
     * Ground truth input provided in S3
     */
    interface ModelQualityJobDefinitionMonitoringGroundTruthS3InputArgs {
        /**
         * A URI that identifies the Amazon S3 storage location where Amazon SageMaker saves the results of a monitoring job.
         */
        s3Uri: pulumi.Input<string>;
    }
    /**
     * The output object for a monitoring job.
     */
    interface ModelQualityJobDefinitionMonitoringOutputArgs {
        /**
         * The Amazon S3 storage location where the results of a monitoring job are saved.
         */
        s3Output: pulumi.Input<inputs.sagemaker.ModelQualityJobDefinitionS3OutputArgs>;
    }
    /**
     * The output configuration for monitoring jobs.
     */
    interface ModelQualityJobDefinitionMonitoringOutputConfigArgs {
        /**
         * The AWS Key Management Service (AWS KMS) key that Amazon SageMaker uses to encrypt the model artifacts at rest using Amazon S3 server-side encryption.
         */
        kmsKeyId?: pulumi.Input<string>;
        /**
         * Monitoring outputs for monitoring jobs. This is where the output of the periodic monitoring jobs is uploaded.
         */
        monitoringOutputs: pulumi.Input<pulumi.Input<inputs.sagemaker.ModelQualityJobDefinitionMonitoringOutputArgs>[]>;
    }
    /**
     * Identifies the resources to deploy for a monitoring job.
     */
    interface ModelQualityJobDefinitionMonitoringResourcesArgs {
        /**
         * The configuration for the cluster resources used to run the processing job.
         */
        clusterConfig: pulumi.Input<inputs.sagemaker.ModelQualityJobDefinitionClusterConfigArgs>;
    }
    /**
     * Networking options for a job, such as network traffic encryption between containers, whether to allow inbound and outbound network calls to and from containers, and the VPC subnets and security groups to use for VPC-enabled jobs.
     */
    interface ModelQualityJobDefinitionNetworkConfigArgs {
        /**
         * Whether to encrypt all communications between distributed processing jobs. Choose True to encrypt communications. Encryption provides greater security for distributed processing jobs, but the processing might take longer.
         */
        enableInterContainerTrafficEncryption?: pulumi.Input<boolean>;
        /**
         * Whether to allow inbound and outbound network calls to and from the containers used for the processing job.
         */
        enableNetworkIsolation?: pulumi.Input<boolean>;
        /**
         * Specifies a VPC that your training jobs and hosted models have access to. Control access to and from your training and model containers by configuring the VPC.
         */
        vpcConfig?: pulumi.Input<inputs.sagemaker.ModelQualityJobDefinitionVpcConfigArgs>;
    }
    /**
     * Information about where and how to store the results of a monitoring job.
     */
    interface ModelQualityJobDefinitionS3OutputArgs {
        /**
         * The local path to the Amazon S3 storage location where Amazon SageMaker saves the results of a monitoring job. LocalPath is an absolute path for the output data.
         */
        localPath: pulumi.Input<string>;
        /**
         * Whether to upload the results of the monitoring job continuously or after the job completes.
         */
        s3UploadMode?: pulumi.Input<enums.sagemaker.ModelQualityJobDefinitionS3OutputS3UploadMode>;
        /**
         * A URI that identifies the Amazon S3 storage location where Amazon SageMaker saves the results of a monitoring job.
         */
        s3Uri: pulumi.Input<string>;
    }
    /**
     * Specifies a time limit for how long the monitoring job is allowed to run.
     */
    interface ModelQualityJobDefinitionStoppingConditionArgs {
        /**
         * The maximum runtime allowed in seconds.
         */
        maxRuntimeInSeconds: pulumi.Input<number>;
    }
    /**
     * Specifies a VPC that your training jobs and hosted models have access to. Control access to and from your training and model containers by configuring the VPC.
     */
    interface ModelQualityJobDefinitionVpcConfigArgs {
        /**
         * The VPC security group IDs, in the form sg-xxxxxxxx. Specify the security groups for the VPC that is specified in the Subnets field.
         */
        securityGroupIds: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * The ID of the subnets in the VPC to which you want to connect to your monitoring jobs.
         */
        subnets: pulumi.Input<pulumi.Input<string>[]>;
    }
    /**
     * Baseline configuration used to validate that the data conforms to the specified constraints and statistics.
     */
    interface MonitoringScheduleBaselineConfigArgs {
        /**
         * The Amazon S3 URI for the constraints resource.
         */
        constraintsResource?: pulumi.Input<inputs.sagemaker.MonitoringScheduleConstraintsResourceArgs>;
        /**
         * The baseline statistics file in Amazon S3 that the current monitoring job should be validated against.
         */
        statisticsResource?: pulumi.Input<inputs.sagemaker.MonitoringScheduleStatisticsResourceArgs>;
    }
    /**
     * The batch transform input for a monitoring job.
     */
    interface MonitoringScheduleBatchTransformInputArgs {
        /**
         * A URI that identifies the Amazon S3 storage location where Batch Transform Job captures data.
         */
        dataCapturedDestinationS3Uri: pulumi.Input<string>;
        datasetFormat: pulumi.Input<inputs.sagemaker.MonitoringScheduleDatasetFormatArgs>;
        /**
         * Indexes or names of the features to be excluded from analysis
         */
        excludeFeaturesAttribute?: pulumi.Input<string>;
        /**
         * Path to the filesystem where the endpoint data is available to the container.
         */
        localPath: pulumi.Input<string>;
        /**
         * Whether input data distributed in Amazon S3 is fully replicated or sharded by an S3 key. Defauts to FullyReplicated
         */
        s3DataDistributionType?: pulumi.Input<enums.sagemaker.MonitoringScheduleBatchTransformInputS3DataDistributionType>;
        /**
         * Whether the Pipe or File is used as the input mode for transfering data for the monitoring job. Pipe mode is recommended for large datasets. File mode is useful for small files that fit in memory. Defaults to File.
         */
        s3InputMode?: pulumi.Input<enums.sagemaker.MonitoringScheduleBatchTransformInputS3InputMode>;
    }
    /**
     * Configuration for the cluster used to run model monitoring jobs.
     */
    interface MonitoringScheduleClusterConfigArgs {
        /**
         * The number of ML compute instances to use in the model monitoring job. For distributed processing jobs, specify a value greater than 1. The default value is 1.
         */
        instanceCount: pulumi.Input<number>;
        /**
         * The ML compute instance type for the processing job.
         */
        instanceType: pulumi.Input<string>;
        /**
         * The AWS Key Management Service (AWS KMS) key that Amazon SageMaker uses to encrypt data on the storage volume attached to the ML compute instance(s) that run the model monitoring job.
         */
        volumeKmsKeyId?: pulumi.Input<string>;
        /**
         * The size of the ML storage volume, in gigabytes, that you want to provision. You must specify sufficient ML storage for your scenario.
         */
        volumeSizeInGb: pulumi.Input<number>;
    }
    /**
     * The configuration object that specifies the monitoring schedule and defines the monitoring job.
     */
    interface MonitoringScheduleConfigArgs {
        /**
         * Defines the monitoring job.
         */
        monitoringJobDefinition?: pulumi.Input<inputs.sagemaker.MonitoringScheduleMonitoringJobDefinitionArgs>;
        /**
         * Name of the job definition
         */
        monitoringJobDefinitionName?: pulumi.Input<string>;
        /**
         * The type of the monitoring job definition to schedule.
         */
        monitoringType?: pulumi.Input<enums.sagemaker.MonitoringScheduleMonitoringType>;
        /**
         * Configures the monitoring schedule.
         */
        scheduleConfig?: pulumi.Input<inputs.sagemaker.MonitoringScheduleScheduleConfigArgs>;
    }
    /**
     * The baseline constraints resource for a monitoring job.
     */
    interface MonitoringScheduleConstraintsResourceArgs {
        /**
         * The Amazon S3 URI for baseline constraint file in Amazon S3 that the current monitoring job should validated against.
         */
        s3Uri?: pulumi.Input<string>;
    }
    /**
     * The CSV format
     */
    interface MonitoringScheduleCsvArgs {
        /**
         * A boolean flag indicating if given CSV has header
         */
        header?: pulumi.Input<boolean>;
    }
    /**
     * The dataset format of the data to monitor
     */
    interface MonitoringScheduleDatasetFormatArgs {
        csv?: pulumi.Input<inputs.sagemaker.MonitoringScheduleCsvArgs>;
        json?: pulumi.Input<inputs.sagemaker.MonitoringScheduleJsonArgs>;
        parquet?: pulumi.Input<boolean>;
    }
    /**
     * The endpoint for a monitoring job.
     */
    interface MonitoringScheduleEndpointInputArgs {
        endpointName: pulumi.Input<string>;
        /**
         * Indexes or names of the features to be excluded from analysis
         */
        excludeFeaturesAttribute?: pulumi.Input<string>;
        /**
         * Path to the filesystem where the endpoint data is available to the container.
         */
        localPath: pulumi.Input<string>;
        /**
         * Whether input data distributed in Amazon S3 is fully replicated or sharded by an S3 key. Defauts to FullyReplicated
         */
        s3DataDistributionType?: pulumi.Input<enums.sagemaker.MonitoringScheduleEndpointInputS3DataDistributionType>;
        /**
         * Whether the Pipe or File is used as the input mode for transfering data for the monitoring job. Pipe mode is recommended for large datasets. File mode is useful for small files that fit in memory. Defaults to File.
         */
        s3InputMode?: pulumi.Input<enums.sagemaker.MonitoringScheduleEndpointInputS3InputMode>;
    }
    /**
     * The Json format
     */
    interface MonitoringScheduleJsonArgs {
        /**
         * A boolean flag indicating if it is JSON line format
         */
        line?: pulumi.Input<boolean>;
    }
    /**
     * Container image configuration object for the monitoring job.
     */
    interface MonitoringScheduleMonitoringAppSpecificationArgs {
        /**
         * An array of arguments for the container used to run the monitoring job.
         */
        containerArguments?: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * Specifies the entrypoint for a container used to run the monitoring job.
         */
        containerEntrypoint?: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * The container image to be run by the monitoring job.
         */
        imageUri: pulumi.Input<string>;
        /**
         * An Amazon S3 URI to a script that is called after analysis has been performed. Applicable only for the built-in (first party) containers.
         */
        postAnalyticsProcessorSourceUri?: pulumi.Input<string>;
        /**
         * An Amazon S3 URI to a script that is called per row prior to running analysis. It can base64 decode the payload and convert it into a flatted json so that the built-in container can use the converted data. Applicable only for the built-in (first party) containers
         */
        recordPreprocessorSourceUri?: pulumi.Input<string>;
    }
    /**
     * Summary of information about monitoring job
     */
    interface MonitoringScheduleMonitoringExecutionSummaryArgs {
        /**
         * The time at which the monitoring job was created.
         */
        creationTime: pulumi.Input<string>;
        /**
         * The name of the endpoint used to run the monitoring job.
         */
        endpointName?: pulumi.Input<string>;
        /**
         * Contains the reason a monitoring job failed, if it failed.
         */
        failureReason?: pulumi.Input<string>;
        /**
         * A timestamp that indicates the last time the monitoring job was modified.
         */
        lastModifiedTime: pulumi.Input<string>;
        /**
         * The status of the monitoring job.
         */
        monitoringExecutionStatus: pulumi.Input<enums.sagemaker.MonitoringScheduleMonitoringExecutionSummaryMonitoringExecutionStatus>;
        /**
         * The name of the monitoring schedule.
         */
        monitoringScheduleName: pulumi.Input<string>;
        /**
         * The Amazon Resource Name (ARN) of the monitoring job.
         */
        processingJobArn?: pulumi.Input<string>;
        /**
         * The time the monitoring job was scheduled.
         */
        scheduledTime: pulumi.Input<string>;
    }
    /**
     * The inputs for a monitoring job.
     */
    interface MonitoringScheduleMonitoringInputArgs {
        batchTransformInput?: pulumi.Input<inputs.sagemaker.MonitoringScheduleBatchTransformInputArgs>;
        endpointInput?: pulumi.Input<inputs.sagemaker.MonitoringScheduleEndpointInputArgs>;
    }
    /**
     * Defines the monitoring job.
     */
    interface MonitoringScheduleMonitoringJobDefinitionArgs {
        /**
         * Baseline configuration used to validate that the data conforms to the specified constraints and statistics
         */
        baselineConfig?: pulumi.Input<inputs.sagemaker.MonitoringScheduleBaselineConfigArgs>;
        /**
         * Sets the environment variables in the Docker container
         */
        environment?: any;
        /**
         * Configures the monitoring job to run a specified Docker container image.
         */
        monitoringAppSpecification: pulumi.Input<inputs.sagemaker.MonitoringScheduleMonitoringAppSpecificationArgs>;
        /**
         * The array of inputs for the monitoring job. Currently we support monitoring an Amazon SageMaker AI Endpoint.
         */
        monitoringInputs: pulumi.Input<pulumi.Input<inputs.sagemaker.MonitoringScheduleMonitoringInputArgs>[]>;
        /**
         * The array of outputs from the monitoring job to be uploaded to Amazon S3.
         */
        monitoringOutputConfig: pulumi.Input<inputs.sagemaker.MonitoringScheduleMonitoringOutputConfigArgs>;
        /**
         * Identifies the resources, ML compute instances, and ML storage volumes to deploy for a monitoring job. In distributed processing, you specify more than one instance.
         */
        monitoringResources: pulumi.Input<inputs.sagemaker.MonitoringScheduleMonitoringResourcesArgs>;
        /**
         * Specifies networking options for an monitoring job.
         */
        networkConfig?: pulumi.Input<inputs.sagemaker.MonitoringScheduleNetworkConfigArgs>;
        /**
         * The Amazon Resource Name (ARN) of an IAM role that Amazon SageMaker can assume to perform tasks on your behalf.
         */
        roleArn: pulumi.Input<string>;
        /**
         * Specifies a time limit for how long the monitoring job is allowed to run.
         */
        stoppingCondition?: pulumi.Input<inputs.sagemaker.MonitoringScheduleStoppingConditionArgs>;
    }
    /**
     * The output object for a monitoring job.
     */
    interface MonitoringScheduleMonitoringOutputArgs {
        /**
         * The Amazon S3 storage location where the results of a monitoring job are saved.
         */
        s3Output: pulumi.Input<inputs.sagemaker.MonitoringScheduleS3OutputArgs>;
    }
    /**
     * The output configuration for monitoring jobs.
     */
    interface MonitoringScheduleMonitoringOutputConfigArgs {
        /**
         * The AWS Key Management Service (AWS KMS) key that Amazon SageMaker uses to encrypt the model artifacts at rest using Amazon S3 server-side encryption.
         */
        kmsKeyId?: pulumi.Input<string>;
        /**
         * Monitoring outputs for monitoring jobs. This is where the output of the periodic monitoring jobs is uploaded.
         */
        monitoringOutputs: pulumi.Input<pulumi.Input<inputs.sagemaker.MonitoringScheduleMonitoringOutputArgs>[]>;
    }
    /**
     * Identifies the resources to deploy for a monitoring job.
     */
    interface MonitoringScheduleMonitoringResourcesArgs {
        /**
         * The configuration for the cluster resources used to run the processing job.
         */
        clusterConfig: pulumi.Input<inputs.sagemaker.MonitoringScheduleClusterConfigArgs>;
    }
    /**
     * Networking options for a job, such as network traffic encryption between containers, whether to allow inbound and outbound network calls to and from containers, and the VPC subnets and security groups to use for VPC-enabled jobs.
     */
    interface MonitoringScheduleNetworkConfigArgs {
        /**
         * Whether to encrypt all communications between distributed processing jobs. Choose True to encrypt communications. Encryption provides greater security for distributed processing jobs, but the processing might take longer.
         */
        enableInterContainerTrafficEncryption?: pulumi.Input<boolean>;
        /**
         * Whether to allow inbound and outbound network calls to and from the containers used for the processing job.
         */
        enableNetworkIsolation?: pulumi.Input<boolean>;
        /**
         * Specifies a VPC that your training jobs and hosted models have access to. Control access to and from your training and model containers by configuring the VPC. For more information, see [Protect Endpoints by Using an Amazon Virtual Private Cloud](https://docs.aws.amazon.com/sagemaker/latest/dg/host-vpc.html) and [Protect Training Jobs by Using an Amazon Virtual Private Cloud](https://docs.aws.amazon.com/sagemaker/latest/dg/train-vpc.html) .
         */
        vpcConfig?: pulumi.Input<inputs.sagemaker.MonitoringScheduleVpcConfigArgs>;
    }
    /**
     * Information about where and how to store the results of a monitoring job.
     */
    interface MonitoringScheduleS3OutputArgs {
        /**
         * The local path to the Amazon S3 storage location where Amazon SageMaker saves the results of a monitoring job. LocalPath is an absolute path for the output data.
         */
        localPath: pulumi.Input<string>;
        /**
         * Whether to upload the results of the monitoring job continuously or after the job completes.
         */
        s3UploadMode?: pulumi.Input<enums.sagemaker.MonitoringScheduleS3OutputS3UploadMode>;
        /**
         * A URI that identifies the Amazon S3 storage location where Amazon SageMaker saves the results of a monitoring job.
         */
        s3Uri: pulumi.Input<string>;
    }
    /**
     * Configuration details about the monitoring schedule.
     */
    interface MonitoringScheduleScheduleConfigArgs {
        /**
         * Data Analysis end time, e.g. PT0H
         */
        dataAnalysisEndTime?: pulumi.Input<string>;
        /**
         * Data Analysis start time, e.g. -PT1H
         */
        dataAnalysisStartTime?: pulumi.Input<string>;
        /**
         * A cron expression or 'NOW' that describes details about the monitoring schedule.
         */
        scheduleExpression: pulumi.Input<string>;
    }
    /**
     * The baseline statistics resource for a monitoring job.
     */
    interface MonitoringScheduleStatisticsResourceArgs {
        /**
         * The Amazon S3 URI for the baseline statistics file in Amazon S3 that the current monitoring job should be validated against.
         */
        s3Uri?: pulumi.Input<string>;
    }
    /**
     * Specifies a time limit for how long the monitoring job is allowed to run.
     */
    interface MonitoringScheduleStoppingConditionArgs {
        /**
         * The maximum runtime allowed in seconds.
         */
        maxRuntimeInSeconds: pulumi.Input<number>;
    }
    /**
     * Specifies a VPC that your training jobs and hosted models have access to. Control access to and from your training and model containers by configuring the VPC.
     */
    interface MonitoringScheduleVpcConfigArgs {
        /**
         * The VPC security group IDs, in the form sg-xxxxxxxx. Specify the security groups for the VPC that is specified in the Subnets field.
         */
        securityGroupIds: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * The ID of the subnets in the VPC to which you want to connect to your monitoring jobs.
         */
        subnets: pulumi.Input<pulumi.Input<string>[]>;
    }
    /**
     * The configuration of an `OfflineStore` .
     */
    interface OfflineStoreConfigPropertiesArgs {
        /**
         * The meta data of the Glue table that is autogenerated when an `OfflineStore` is created.
         */
        dataCatalogConfig?: pulumi.Input<inputs.sagemaker.FeatureGroupDataCatalogConfigArgs>;
        /**
         * Set to `True` to disable the automatic creation of an AWS Glue table when configuring an `OfflineStore` . If set to `False` , Feature Store will name the `OfflineStore` Glue table following [Athena's naming recommendations](https://docs.aws.amazon.com/athena/latest/ug/tables-databases-columns-names.html) .
         *
         * The default value is `False` .
         */
        disableGlueTableCreation?: pulumi.Input<boolean>;
        /**
         * The Amazon Simple Storage (Amazon S3) location of `OfflineStore` .
         */
        s3StorageConfig: pulumi.Input<inputs.sagemaker.FeatureGroupS3StorageConfigArgs>;
        /**
         * Format for the offline store table. Supported formats are Glue (Default) and [Apache Iceberg](https://docs.aws.amazon.com/https://iceberg.apache.org/) .
         */
        tableFormat?: pulumi.Input<enums.sagemaker.FeatureGroupTableFormat>;
    }
    /**
     * The configuration of an `OnlineStore` .
     */
    interface OnlineStoreConfigPropertiesArgs {
        /**
         * Turn `OnlineStore` off by specifying `False` for the `EnableOnlineStore` flag. Turn `OnlineStore` on by specifying `True` for the `EnableOnlineStore` flag.
         *
         * The default value is `False` .
         */
        enableOnlineStore?: pulumi.Input<boolean>;
        /**
         * Use to specify KMS Key ID ( `KMSKeyId` ) for at-rest encryption of your `OnlineStore` .
         */
        securityConfig?: pulumi.Input<inputs.sagemaker.FeatureGroupOnlineStoreSecurityConfigArgs>;
        /**
         * Option for different tiers of low latency storage for real-time data retrieval.
         *
         * - `Standard` : A managed low latency data store for feature groups.
         * - `InMemory` : A managed data store for feature groups that supports very low latency retrieval.
         */
        storageType?: pulumi.Input<enums.sagemaker.FeatureGroupStorageType>;
        /**
         * Time to live duration, where the record is hard deleted after the expiration time is reached; `ExpiresAt` = `EventTime` + `TtlDuration` . For information on HardDelete, see the [DeleteRecord](https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_feature_store_DeleteRecord.html) API in the Amazon SageMaker API Reference guide.
         */
        ttlDuration?: pulumi.Input<inputs.sagemaker.FeatureGroupTtlDurationArgs>;
    }
    /**
     * The parallelism configuration applied to the pipeline.
     */
    interface ParallelismConfigurationPropertiesArgs {
        /**
         * Maximum parallel execution steps
         */
        maxParallelExecutionSteps: pulumi.Input<number>;
    }
    /**
     * A collection of configuration settings for the PartnerApp.
     */
    interface PartnerAppConfigArgs {
        /**
         * A list of users with administrator privileges for the PartnerApp.
         */
        adminUsers?: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * A list of arguments to pass to the PartnerApp.
         */
        arguments?: pulumi.Input<{
            [key: string]: pulumi.Input<string>;
        }>;
    }
    /**
     * A collection of settings that specify the maintenance schedule for the PartnerApp.
     */
    interface PartnerAppMaintenanceConfigArgs {
        /**
         * The maintenance window start day and time for the PartnerApp.
         */
        maintenanceWindowStart: pulumi.Input<string>;
    }
    /**
     * The definition of the pipeline. This can be either a JSON string or an Amazon S3 location.
     */
    interface PipelineDefinition0PropertiesArgs {
        /**
         * A specification that defines the pipeline in JSON format.
         */
        pipelineDefinitionBody: pulumi.Input<string>;
    }
    /**
     * The definition of the pipeline. This can be either a JSON string or an Amazon S3 location.
     */
    interface PipelineDefinition1PropertiesArgs {
        pipelineDefinitionS3Location: pulumi.Input<inputs.sagemaker.PipelineS3LocationArgs>;
    }
    interface PipelineS3LocationArgs {
        /**
         * The name of the S3 bucket where the PipelineDefinition file is stored.
         */
        bucket: pulumi.Input<string>;
        /**
         * The Amazon S3 ETag (a file checksum) of the PipelineDefinition file. If you don't specify a value, SageMaker skips ETag validation of your PipelineDefinition file.
         */
        eTag?: pulumi.Input<string>;
        /**
         * The file name of the PipelineDefinition file (Amazon S3 object name).
         */
        key: pulumi.Input<string>;
        /**
         * For versioning-enabled buckets, a specific version of the PipelineDefinition file.
         */
        version?: pulumi.Input<string>;
    }
    /**
     * Information about a parameter used to provision a product.
     */
    interface ProjectProvisioningParameterArgs {
        /**
         * The parameter key.
         */
        key: pulumi.Input<string>;
        /**
         * The parameter value.
         */
        value: pulumi.Input<string>;
    }
    /**
     * Provisioned ServiceCatalog  Details
     */
    interface ServiceCatalogProvisionedProductDetailsPropertiesArgs {
        /**
         * The ID of the provisioned product.
         */
        provisionedProductId?: pulumi.Input<string>;
        /**
         * The current status of the product.
         *
         * - `AVAILABLE` - Stable state, ready to perform any operation. The most recent operation succeeded and completed.
         * - `UNDER_CHANGE` - Transitive state. Operations performed might not have valid results. Wait for an AVAILABLE status before performing operations.
         * - `TAINTED` - Stable state, ready to perform any operation. The stack has completed the requested operation but is not exactly what was requested. For example, a request to update to a new version failed and the stack rolled back to the current version.
         * - `ERROR` - An unexpected error occurred. The provisioned product exists but the stack is not running. For example, CloudFormation received a parameter value that was not valid and could not launch the stack.
         * - `PLAN_IN_PROGRESS` - Transitive state. The plan operations were performed to provision a new product, but resources have not yet been created. After reviewing the list of resources to be created, execute the plan. Wait for an AVAILABLE status before performing operations.
         */
        provisionedProductStatusMessage?: pulumi.Input<string>;
    }
    /**
     * Input ServiceCatalog Provisioning Details
     */
    interface ServiceCatalogProvisioningDetailsPropertiesArgs {
        /**
         * The path identifier of the product. This value is optional if the product has a default path, and required if the product has more than one path.
         */
        pathId?: pulumi.Input<string>;
        /**
         * The ID of the product to provision.
         */
        productId: pulumi.Input<string>;
        /**
         * The ID of the provisioning artifact.
         */
        provisioningArtifactId?: pulumi.Input<string>;
        /**
         * Parameters specified by the administrator that are required for provisioning the product.
         */
        provisioningParameters?: pulumi.Input<pulumi.Input<inputs.sagemaker.ProjectProvisioningParameterArgs>[]>;
    }
    interface SpaceAppLifecycleManagementArgs {
        /**
         * Settings related to idle shutdown of Studio applications.
         */
        idleSettings?: pulumi.Input<inputs.sagemaker.SpaceIdleSettingsArgs>;
    }
    /**
     * The CodeEditor app settings.
     */
    interface SpaceCodeEditorAppSettingsArgs {
        /**
         * Settings that are used to configure and manage the lifecycle of CodeEditor applications in a space.
         */
        appLifecycleManagement?: pulumi.Input<inputs.sagemaker.SpaceAppLifecycleManagementArgs>;
        /**
         * Specifies the ARNs of a SageMaker image and SageMaker image version, and the instance type that the version runs on.
         */
        defaultResourceSpec?: pulumi.Input<inputs.sagemaker.SpaceResourceSpecArgs>;
    }
    interface SpaceCodeRepositoryArgs {
        /**
         * A CodeRepository (valid URL) to be used within Jupyter's Git extension.
         */
        repositoryUrl: pulumi.Input<string>;
    }
    interface SpaceCustomFileSystemArgs {
        efsFileSystem?: pulumi.Input<inputs.sagemaker.SpaceEfsFileSystemArgs>;
        fSxLustreFileSystem?: pulumi.Input<inputs.sagemaker.SpaceFSxLustreFileSystemArgs>;
    }
    /**
     * A custom SageMaker image.
     */
    interface SpaceCustomImageArgs {
        /**
         * The Name of the AppImageConfig.
         */
        appImageConfigName: pulumi.Input<string>;
        /**
         * The name of the CustomImage. Must be unique to your account.
         */
        imageName: pulumi.Input<string>;
        /**
         * The version number of the CustomImage.
         */
        imageVersionNumber?: pulumi.Input<number>;
    }
    /**
     * Properties related to the space's Amazon Elastic Block Store volume.
     */
    interface SpaceEbsStorageSettingsArgs {
        /**
         * Size of the Amazon EBS volume in Gb
         */
        ebsVolumeSizeInGb: pulumi.Input<number>;
    }
    interface SpaceEfsFileSystemArgs {
        fileSystemId: pulumi.Input<string>;
    }
    interface SpaceFSxLustreFileSystemArgs {
        fileSystemId: pulumi.Input<string>;
    }
    interface SpaceIdleSettingsArgs {
        /**
         * The space idle timeout value set in minutes
         */
        idleTimeoutInMinutes?: pulumi.Input<number>;
    }
    /**
     * The JupyterServer app settings.
     */
    interface SpaceJupyterLabAppSettingsArgs {
        /**
         * Settings that are used to configure and manage the lifecycle of JupyterLab applications in a space.
         */
        appLifecycleManagement?: pulumi.Input<inputs.sagemaker.SpaceAppLifecycleManagementArgs>;
        /**
         * A list of CodeRepositories available for use with JupyterLab apps.
         */
        codeRepositories?: pulumi.Input<pulumi.Input<inputs.sagemaker.SpaceCodeRepositoryArgs>[]>;
        /**
         * Specifies the ARNs of a SageMaker image and SageMaker image version, and the instance type that the version runs on.
         */
        defaultResourceSpec?: pulumi.Input<inputs.sagemaker.SpaceResourceSpecArgs>;
    }
    /**
     * The JupyterServer app settings.
     */
    interface SpaceJupyterServerAppSettingsArgs {
        /**
         * The default instance type and the Amazon Resource Name (ARN) of the default SageMaker AI image used by the JupyterServer app. If you use the `LifecycleConfigArns` parameter, then this parameter is also required.
         */
        defaultResourceSpec?: pulumi.Input<inputs.sagemaker.SpaceResourceSpecArgs>;
        /**
         * A list of LifecycleConfigArns available for use with JupyterServer apps.
         */
        lifecycleConfigArns?: pulumi.Input<pulumi.Input<string>[]>;
    }
    /**
     * The kernel gateway app settings.
     */
    interface SpaceKernelGatewayAppSettingsArgs {
        /**
         * A list of custom SageMaker images that are configured to run as a KernelGateway app.
         */
        customImages?: pulumi.Input<pulumi.Input<inputs.sagemaker.SpaceCustomImageArgs>[]>;
        /**
         * The default instance type and the Amazon Resource Name (ARN) of the default SageMaker image used by the KernelGateway app.
         */
        defaultResourceSpec?: pulumi.Input<inputs.sagemaker.SpaceResourceSpecArgs>;
        /**
         * A list of LifecycleConfigArns available for use with KernelGateway apps.
         */
        lifecycleConfigArns?: pulumi.Input<pulumi.Input<string>[]>;
    }
    interface SpaceOwnershipSettingsArgs {
        /**
         * The user profile who is the owner of the space.
         */
        ownerUserProfileName: pulumi.Input<string>;
    }
    interface SpaceResourceSpecArgs {
        /**
         * The instance type that the image version runs on.
         */
        instanceType?: pulumi.Input<enums.sagemaker.SpaceResourceSpecInstanceType>;
        /**
         * The Amazon Resource Name (ARN) of the Lifecycle Configuration to attach to the Resource.
         */
        lifecycleConfigArn?: pulumi.Input<string>;
        /**
         * The ARN of the SageMaker image that the image version belongs to.
         */
        sageMakerImageArn?: pulumi.Input<string>;
        /**
         * The ARN of the image version created on the instance.
         */
        sageMakerImageVersionArn?: pulumi.Input<string>;
    }
    /**
     * A collection of settings that apply to spaces of Amazon SageMaker Studio. These settings are specified when the CreateSpace API is called.
     */
    interface SpaceSettingsArgs {
        /**
         * The type of app created within the space.
         *
         * If using the [UpdateSpace](https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_UpdateSpace.html) API, you can't change the app type of your space by specifying a different value for this field.
         */
        appType?: pulumi.Input<enums.sagemaker.SpaceAppType>;
        /**
         * The CodeEditor app settings.
         */
        codeEditorAppSettings?: pulumi.Input<inputs.sagemaker.SpaceCodeEditorAppSettingsArgs>;
        /**
         * A file system, created by you, that you assign to a space for an Amazon SageMaker AI Domain. Permitted users can access this file system in Amazon SageMaker AI Studio.
         */
        customFileSystems?: pulumi.Input<pulumi.Input<inputs.sagemaker.SpaceCustomFileSystemArgs>[]>;
        /**
         * The JupyterLab app settings.
         */
        jupyterLabAppSettings?: pulumi.Input<inputs.sagemaker.SpaceJupyterLabAppSettingsArgs>;
        /**
         * The Jupyter server's app settings.
         */
        jupyterServerAppSettings?: pulumi.Input<inputs.sagemaker.SpaceJupyterServerAppSettingsArgs>;
        /**
         * The kernel gateway app settings.
         */
        kernelGatewayAppSettings?: pulumi.Input<inputs.sagemaker.SpaceKernelGatewayAppSettingsArgs>;
        /**
         * Default storage settings for a space.
         */
        spaceStorageSettings?: pulumi.Input<inputs.sagemaker.SpaceStorageSettingsArgs>;
    }
    interface SpaceSharingSettingsArgs {
        /**
         * Specifies the sharing type of the space.
         */
        sharingType: pulumi.Input<enums.sagemaker.SpaceSharingSettingsSharingType>;
    }
    interface SpaceStorageSettingsArgs {
        /**
         * A collection of EBS storage settings for a space.
         */
        ebsStorageSettings?: pulumi.Input<inputs.sagemaker.SpaceEbsStorageSettingsArgs>;
    }
    interface UserProfileAppLifecycleManagementArgs {
        /**
         * Settings related to idle shutdown of Studio applications.
         */
        idleSettings?: pulumi.Input<inputs.sagemaker.UserProfileIdleSettingsArgs>;
    }
    /**
     * The CodeEditor app settings.
     */
    interface UserProfileCodeEditorAppSettingsArgs {
        /**
         * Settings that are used to configure and manage the lifecycle of CodeEditor applications.
         */
        appLifecycleManagement?: pulumi.Input<inputs.sagemaker.UserProfileAppLifecycleManagementArgs>;
        /**
         * A list of custom images for use for CodeEditor apps.
         */
        customImages?: pulumi.Input<pulumi.Input<inputs.sagemaker.UserProfileCustomImageArgs>[]>;
        /**
         * The default instance type and the Amazon Resource Name (ARN) of the default SageMaker image used by the CodeEditor app.
         */
        defaultResourceSpec?: pulumi.Input<inputs.sagemaker.UserProfileResourceSpecArgs>;
        /**
         * A list of LifecycleConfigArns available for use with CodeEditor apps.
         */
        lifecycleConfigArns?: pulumi.Input<pulumi.Input<string>[]>;
    }
    interface UserProfileCodeRepositoryArgs {
        /**
         * A CodeRepository (valid URL) to be used within Jupyter's Git extension.
         */
        repositoryUrl: pulumi.Input<string>;
    }
    interface UserProfileCustomFileSystemConfigArgs {
        /**
         * The settings for a custom Amazon EFS file system.
         */
        efsFileSystemConfig?: pulumi.Input<inputs.sagemaker.UserProfileEfsFileSystemConfigArgs>;
        /**
         * The settings for a custom Amazon FSx for Lustre file system.
         */
        fSxLustreFileSystemConfig?: pulumi.Input<inputs.sagemaker.UserProfileFSxLustreFileSystemConfigArgs>;
    }
    /**
     * A custom SageMaker image.
     */
    interface UserProfileCustomImageArgs {
        /**
         * The Name of the AppImageConfig.
         */
        appImageConfigName: pulumi.Input<string>;
        /**
         * The name of the CustomImage. Must be unique to your account.
         */
        imageName: pulumi.Input<string>;
        /**
         * The version number of the CustomImage.
         */
        imageVersionNumber?: pulumi.Input<number>;
    }
    interface UserProfileCustomPosixUserConfigArgs {
        /**
         * The POSIX group ID.
         */
        gid: pulumi.Input<number>;
        /**
         * The POSIX user ID.
         */
        uid: pulumi.Input<number>;
    }
    /**
     * Properties related to the Amazon Elastic Block Store volume.
     */
    interface UserProfileDefaultEbsStorageSettingsArgs {
        /**
         * Default size of the Amazon EBS volume in Gb
         */
        defaultEbsVolumeSizeInGb: pulumi.Input<number>;
        /**
         * Maximum size of the Amazon EBS volume in Gb. Must be greater than or equal to the DefaultEbsVolumeSizeInGb.
         */
        maximumEbsVolumeSizeInGb: pulumi.Input<number>;
    }
    /**
     * Default storage settings for a space.
     */
    interface UserProfileDefaultSpaceStorageSettingsArgs {
        /**
         * The default EBS storage settings for a space.
         */
        defaultEbsStorageSettings?: pulumi.Input<inputs.sagemaker.UserProfileDefaultEbsStorageSettingsArgs>;
    }
    interface UserProfileEfsFileSystemConfigArgs {
        /**
         * The ID of your Amazon EFS file system.
         */
        fileSystemId: pulumi.Input<string>;
        /**
         * The path to the file system directory that is accessible in Amazon SageMaker AI Studio. Permitted users can access only this directory and below.
         */
        fileSystemPath?: pulumi.Input<string>;
    }
    interface UserProfileFSxLustreFileSystemConfigArgs {
        /**
         * The globally unique, 17-digit, ID of the file system, assigned by Amazon FSx for Lustre.
         */
        fileSystemId: pulumi.Input<string>;
        /**
         * The path to the file system directory that is accessible in Amazon SageMaker Studio. Permitted users can access only this directory and below.
         */
        fileSystemPath?: pulumi.Input<string>;
    }
    interface UserProfileIdleSettingsArgs {
        /**
         * The time that SageMaker waits after the application becomes idle before shutting it down.
         */
        idleTimeoutInMinutes?: pulumi.Input<number>;
        /**
         * Indicates whether idle shutdown is activated for the application type.
         */
        lifecycleManagement?: pulumi.Input<enums.sagemaker.UserProfileLifecycleManagement>;
        /**
         * The maximum value in minutes that custom idle shutdown can be set to by the user.
         */
        maxIdleTimeoutInMinutes?: pulumi.Input<number>;
        /**
         * The minimum value in minutes that custom idle shutdown can be set to by the user.
         */
        minIdleTimeoutInMinutes?: pulumi.Input<number>;
    }
    /**
     * The JupyterLab app settings.
     */
    interface UserProfileJupyterLabAppSettingsArgs {
        /**
         * Indicates whether idle shutdown is activated for JupyterLab applications.
         */
        appLifecycleManagement?: pulumi.Input<inputs.sagemaker.UserProfileAppLifecycleManagementArgs>;
        /**
         * A list of CodeRepositories available for use with JupyterLab apps.
         */
        codeRepositories?: pulumi.Input<pulumi.Input<inputs.sagemaker.UserProfileCodeRepositoryArgs>[]>;
        /**
         * A list of custom images available for use for JupyterLab apps
         */
        customImages?: pulumi.Input<pulumi.Input<inputs.sagemaker.UserProfileCustomImageArgs>[]>;
        /**
         * The default instance type and the Amazon Resource Name (ARN) of the default SageMaker image used by the JupyterLab app.
         */
        defaultResourceSpec?: pulumi.Input<inputs.sagemaker.UserProfileResourceSpecArgs>;
        /**
         * A list of LifecycleConfigArns available for use with JupyterLab apps.
         */
        lifecycleConfigArns?: pulumi.Input<pulumi.Input<string>[]>;
    }
    /**
     * The JupyterServer app settings.
     */
    interface UserProfileJupyterServerAppSettingsArgs {
        /**
         * The default instance type and the Amazon Resource Name (ARN) of the default SageMaker image used by the JupyterServer app.
         */
        defaultResourceSpec?: pulumi.Input<inputs.sagemaker.UserProfileResourceSpecArgs>;
        /**
         * A list of LifecycleConfigArns available for use with JupyterServer apps.
         */
        lifecycleConfigArns?: pulumi.Input<pulumi.Input<string>[]>;
    }
    /**
     * The kernel gateway app settings.
     */
    interface UserProfileKernelGatewayAppSettingsArgs {
        /**
         * A list of custom SageMaker images that are configured to run as a KernelGateway app.
         */
        customImages?: pulumi.Input<pulumi.Input<inputs.sagemaker.UserProfileCustomImageArgs>[]>;
        /**
         * The default instance type and the Amazon Resource Name (ARN) of the default SageMaker image used by the KernelGateway app.
         */
        defaultResourceSpec?: pulumi.Input<inputs.sagemaker.UserProfileResourceSpecArgs>;
        /**
         * A list of LifecycleConfigArns available for use with KernelGateway apps.
         */
        lifecycleConfigArns?: pulumi.Input<pulumi.Input<string>[]>;
    }
    /**
     * A collection of settings that configure user interaction with the RStudioServerPro app.
     */
    interface UserProfileRStudioServerProAppSettingsArgs {
        /**
         * Indicates whether the current user has access to the RStudioServerPro app.
         */
        accessStatus?: pulumi.Input<enums.sagemaker.UserProfileRStudioServerProAppSettingsAccessStatus>;
        /**
         * The level of permissions that the user has within the RStudioServerPro app. This value defaults to User. The Admin value allows the user access to the RStudio Administrative Dashboard.
         */
        userGroup?: pulumi.Input<enums.sagemaker.UserProfileRStudioServerProAppSettingsUserGroup>;
    }
    interface UserProfileResourceSpecArgs {
        /**
         * The instance type that the image version runs on.
         */
        instanceType?: pulumi.Input<enums.sagemaker.UserProfileResourceSpecInstanceType>;
        /**
         * The Amazon Resource Name (ARN) of the Lifecycle Configuration to attach to the Resource.
         */
        lifecycleConfigArn?: pulumi.Input<string>;
        /**
         * The ARN of the SageMaker image that the image version belongs to.
         */
        sageMakerImageArn?: pulumi.Input<string>;
        /**
         * The ARN of the image version created on the instance.
         */
        sageMakerImageVersionArn?: pulumi.Input<string>;
    }
    /**
     * Specifies options when sharing an Amazon SageMaker Studio notebook. These settings are specified as part of DefaultUserSettings when the CreateDomain API is called, and as part of UserSettings when the CreateUserProfile API is called.
     */
    interface UserProfileSharingSettingsArgs {
        /**
         * Whether to include the notebook cell output when sharing the notebook. The default is Disabled.
         */
        notebookOutputOption?: pulumi.Input<enums.sagemaker.UserProfileSharingSettingsNotebookOutputOption>;
        /**
         * When NotebookOutputOption is Allowed, the AWS Key Management Service (KMS) encryption key ID used to encrypt the notebook cell output in the Amazon S3 bucket.
         */
        s3KmsKeyId?: pulumi.Input<string>;
        /**
         * When NotebookOutputOption is Allowed, the Amazon S3 bucket used to store the shared notebook snapshots.
         */
        s3OutputPath?: pulumi.Input<string>;
    }
    /**
     * Studio settings. If these settings are applied on a user level, they take priority over the settings applied on a domain level.
     */
    interface UserProfileStudioWebPortalSettingsArgs {
        /**
         * Applications supported in Studio that are hidden from the Studio left navigation pane.
         */
        hiddenAppTypes?: pulumi.Input<pulumi.Input<enums.sagemaker.UserProfileAppType>[]>;
        /**
         * The machine learning tools that are hidden from the Studio left navigation pane.
         */
        hiddenMlTools?: pulumi.Input<pulumi.Input<enums.sagemaker.UserProfileMlTools>[]>;
    }
    /**
     * A collection of settings that apply to users of Amazon SageMaker Studio. These settings are specified when the CreateUserProfile API is called, and as DefaultUserSettings when the CreateDomain API is called.
     */
    interface UserProfileUserSettingsArgs {
        /**
         * The Code Editor application settings.
         *
         * SageMaker applies these settings only to private spaces that the user creates in the domain. SageMaker doesn't apply these settings to shared spaces.
         */
        codeEditorAppSettings?: pulumi.Input<inputs.sagemaker.UserProfileCodeEditorAppSettingsArgs>;
        /**
         * The settings for assigning a custom file system to a user profile. Permitted users can access this file system in Amazon SageMaker AI Studio.
         *
         * SageMaker applies these settings only to private spaces that the user creates in the domain. SageMaker doesn't apply these settings to shared spaces.
         */
        customFileSystemConfigs?: pulumi.Input<pulumi.Input<inputs.sagemaker.UserProfileCustomFileSystemConfigArgs>[]>;
        /**
         * Details about the POSIX identity that is used for file system operations.
         *
         * SageMaker applies these settings only to private spaces that the user creates in the domain. SageMaker doesn't apply these settings to shared spaces.
         */
        customPosixUserConfig?: pulumi.Input<inputs.sagemaker.UserProfileCustomPosixUserConfigArgs>;
        /**
         * Defines which Amazon SageMaker application users are directed to by default.
         */
        defaultLandingUri?: pulumi.Input<string>;
        /**
         * The user profile Amazon Resource Name (ARN).
         */
        executionRole?: pulumi.Input<string>;
        /**
         * The settings for the JupyterLab application.
         *
         * SageMaker applies these settings only to private spaces that the user creates in the domain. SageMaker doesn't apply these settings to shared spaces.
         */
        jupyterLabAppSettings?: pulumi.Input<inputs.sagemaker.UserProfileJupyterLabAppSettingsArgs>;
        /**
         * The Jupyter server's app settings.
         */
        jupyterServerAppSettings?: pulumi.Input<inputs.sagemaker.UserProfileJupyterServerAppSettingsArgs>;
        /**
         * The kernel gateway app settings.
         */
        kernelGatewayAppSettings?: pulumi.Input<inputs.sagemaker.UserProfileKernelGatewayAppSettingsArgs>;
        /**
         * A collection of settings that configure user interaction with the `RStudioServerPro` app.
         */
        rStudioServerProAppSettings?: pulumi.Input<inputs.sagemaker.UserProfileRStudioServerProAppSettingsArgs>;
        /**
         * The security groups for the Amazon Virtual Private Cloud (VPC) that Studio uses for communication.
         */
        securityGroups?: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * The sharing settings.
         */
        sharingSettings?: pulumi.Input<inputs.sagemaker.UserProfileSharingSettingsArgs>;
        /**
         * The storage settings for a space.
         *
         * SageMaker applies these settings only to private spaces that the user creates in the domain. SageMaker doesn't apply these settings to shared spaces.
         */
        spaceStorageSettings?: pulumi.Input<inputs.sagemaker.UserProfileDefaultSpaceStorageSettingsArgs>;
        /**
         * Indicates whether the Studio experience is available to users. If not, users cannot access Studio.
         */
        studioWebPortal?: pulumi.Input<enums.sagemaker.UserProfileUserSettingsStudioWebPortal>;
        /**
         * Studio settings. If these settings are applied on a user level, they take priority over the settings applied on a domain level.
         */
        studioWebPortalSettings?: pulumi.Input<inputs.sagemaker.UserProfileStudioWebPortalSettingsArgs>;
    }
}
export declare namespace scheduler {
    /**
     * This structure specifies the VPC subnets and security groups for the task, and whether a public IP address is to be used. This structure is relevant only for ECS tasks that use the awsvpc network mode.
     */
    interface ScheduleAwsVpcConfigurationArgs {
        /**
         * Specifies whether the task's elastic network interface receives a public IP address. You can specify `ENABLED` only when `LaunchType` in `EcsParameters` is set to `FARGATE` .
         */
        assignPublicIp?: pulumi.Input<enums.scheduler.ScheduleAssignPublicIp>;
        /**
         * Specifies the security groups associated with the task. These security groups must all be in the same VPC. You can specify as many as five security groups. If you do not specify a security group, the default security group for the VPC is used.
         */
        securityGroups?: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * Specifies the subnets associated with the task. These subnets must all be in the same VPC. You can specify as many as 16 subnets.
         */
        subnets: pulumi.Input<pulumi.Input<string>[]>;
    }
    /**
     * The details of a capacity provider strategy.
     */
    interface ScheduleCapacityProviderStrategyItemArgs {
        /**
         * The base value designates how many tasks, at a minimum, to run on the specified capacity provider. Only one capacity provider in a capacity provider strategy can have a base defined. If no value is specified, the default value of 0 is used.
         */
        base?: pulumi.Input<number>;
        /**
         * The short name of the capacity provider.
         */
        capacityProvider: pulumi.Input<string>;
        /**
         * The weight value designates the relative percentage of the total number of tasks launched that should use the specified capacity provider. The weight value is taken into consideration after the base value, if defined, is satisfied.
         */
        weight?: pulumi.Input<number>;
    }
    /**
     * A DeadLetterConfig object that contains information about a dead-letter queue configuration.
     */
    interface ScheduleDeadLetterConfigArgs {
        /**
         * The ARN of the SQS queue specified as the target for the dead-letter queue.
         */
        arn?: pulumi.Input<string>;
    }
    /**
     * The custom parameters to be used when the target is an Amazon ECS task.
     */
    interface ScheduleEcsParametersArgs {
        /**
         * The capacity provider strategy to use for the task.
         */
        capacityProviderStrategy?: pulumi.Input<pulumi.Input<inputs.scheduler.ScheduleCapacityProviderStrategyItemArgs>[]>;
        /**
         * Specifies whether to enable Amazon ECS managed tags for the task. For more information, see Tagging Your Amazon ECS Resources in the Amazon Elastic Container Service Developer Guide.
         */
        enableEcsManagedTags?: pulumi.Input<boolean>;
        /**
         * Whether or not to enable the execute command functionality for the containers in this task. If true, this enables execute command functionality on all containers in the task.
         */
        enableExecuteCommand?: pulumi.Input<boolean>;
        /**
         * Specifies an ECS task group for the task. The maximum length is 255 characters.
         */
        group?: pulumi.Input<string>;
        /**
         * Specifies the launch type on which your task is running. The launch type that you specify here must match one of the launch type (compatibilities) of the target task. The `FARGATE` value is supported only in the Regions where Fargate with Amazon ECS is supported. For more information, see [AWS Fargate on Amazon ECS](https://docs.aws.amazon.com/AmazonECS/latest/developerguide/AWS_Fargate.html) in the *Amazon ECS Developer Guide* .
         */
        launchType?: pulumi.Input<enums.scheduler.ScheduleLaunchType>;
        /**
         * This structure specifies the network configuration for an ECS task.
         */
        networkConfiguration?: pulumi.Input<inputs.scheduler.ScheduleNetworkConfigurationArgs>;
        /**
         * An array of placement constraint objects to use for the task. You can specify up to 10 constraints per task (including constraints in the task definition and those specified at runtime).
         */
        placementConstraints?: pulumi.Input<pulumi.Input<inputs.scheduler.SchedulePlacementConstraintArgs>[]>;
        /**
         * The placement strategy objects to use for the task. You can specify a maximum of five strategy rules per task.
         */
        placementStrategy?: pulumi.Input<pulumi.Input<inputs.scheduler.SchedulePlacementStrategyArgs>[]>;
        /**
         * Specifies the platform version for the task. Specify only the numeric portion of the platform version, such as 1.1.0.
         */
        platformVersion?: pulumi.Input<string>;
        /**
         * Specifies whether to propagate the tags from the task definition to the task. If no value is specified, the tags are not propagated. Tags can only be propagated to the task during task creation. To add tags to a task after task creation, use the Amazon ECS [`TagResource`](https://docs.aws.amazon.com/AmazonECS/latest/APIReference/API_TagResource.html) API action.
         */
        propagateTags?: pulumi.Input<enums.scheduler.SchedulePropagateTags>;
        /**
         * The reference ID to use for the task.
         */
        referenceId?: pulumi.Input<string>;
        /**
         * The metadata that you apply to the task to help you categorize and organize them. Each tag consists of a key and an optional value, both of which you define. To learn more, see RunTask in the Amazon ECS API Reference.
         */
        tags?: pulumi.Input<pulumi.Input<{
            [key: string]: pulumi.Input<string>;
        }>[]>;
        /**
         * The number of tasks to create based on TaskDefinition. The default is 1.
         */
        taskCount?: pulumi.Input<number>;
        /**
         * The ARN of the task definition to use if the event target is an Amazon ECS task.
         */
        taskDefinitionArn: pulumi.Input<string>;
    }
    /**
     * EventBridge PutEvent predefined target type.
     */
    interface ScheduleEventBridgeParametersArgs {
        /**
         * Free-form string, with a maximum of 128 characters, used to decide what fields to expect in the event detail.
         */
        detailType: pulumi.Input<string>;
        /**
         * The source of the event.
         */
        source: pulumi.Input<string>;
    }
    /**
     * Flexible time window allows configuration of a window within which a schedule can be invoked
     */
    interface ScheduleFlexibleTimeWindowArgs {
        /**
         * The maximum time window during which a schedule can be invoked.
         */
        maximumWindowInMinutes?: pulumi.Input<number>;
        /**
         * Determines whether the schedule is invoked within a flexible time window. You must use quotation marks when you specify this value in your JSON or YAML template.
         *
         * *Allowed Values* : `"OFF"` | `"FLEXIBLE"`
         */
        mode: pulumi.Input<enums.scheduler.ScheduleFlexibleTimeWindowMode>;
    }
    /**
     * The custom parameter you can use to control the shard to which EventBridge Scheduler sends the event.
     */
    interface ScheduleKinesisParametersArgs {
        /**
         * The custom parameter used as the Kinesis partition key. For more information, see Amazon Kinesis Streams Key Concepts in the Amazon Kinesis Streams Developer Guide.
         */
        partitionKey: pulumi.Input<string>;
    }
    /**
     * This structure specifies the network configuration for an ECS task.
     */
    interface ScheduleNetworkConfigurationArgs {
        /**
         * Specifies the Amazon VPC subnets and security groups for the task, and whether a public IP address is to be used. This structure is relevant only for ECS tasks that use the awsvpc network mode.
         */
        awsvpcConfiguration?: pulumi.Input<inputs.scheduler.ScheduleAwsVpcConfigurationArgs>;
    }
    /**
     * An object representing a constraint on task placement.
     */
    interface SchedulePlacementConstraintArgs {
        /**
         * A cluster query language expression to apply to the constraint. You cannot specify an expression if the constraint type is distinctInstance. To learn more, see Cluster Query Language in the Amazon Elastic Container Service Developer Guide.
         */
        expression?: pulumi.Input<string>;
        /**
         * The type of constraint. Use `distinctInstance` to ensure that each task in a particular group is running on a different container instance. Use `memberOf` to restrict the selection to a group of valid candidates.
         */
        type?: pulumi.Input<enums.scheduler.SchedulePlacementConstraintType>;
    }
    /**
     * The task placement strategy for a task or service.
     */
    interface SchedulePlacementStrategyArgs {
        /**
         * The field to apply the placement strategy against. For the spread placement strategy, valid values are instanceId (or host, which has the same effect), or any platform or custom attribute that is applied to a container instance, such as attribute:ecs.availability-zone. For the binpack placement strategy, valid values are cpu and memory. For the random placement strategy, this field is not used.
         */
        field?: pulumi.Input<string>;
        /**
         * The type of placement strategy. The random placement strategy randomly places tasks on available candidates. The spread placement strategy spreads placement across available candidates evenly based on the field parameter. The binpack strategy places tasks on available candidates that have the least available amount of the resource that is specified with the field parameter. For example, if you binpack on memory, a task is placed on the instance with the least amount of remaining memory (but still enough to run the task).
         */
        type?: pulumi.Input<enums.scheduler.SchedulePlacementStrategyType>;
    }
    /**
     * A RetryPolicy object that includes information about the retry policy settings.
     */
    interface ScheduleRetryPolicyArgs {
        /**
         * The maximum amount of time, in seconds, to continue to make retry attempts.
         */
        maximumEventAgeInSeconds?: pulumi.Input<number>;
        /**
         * The maximum number of retry attempts to make before the request fails. Retry attempts with exponential backoff continue until either the maximum number of attempts is made or until the duration of the MaximumEventAgeInSeconds is reached.
         */
        maximumRetryAttempts?: pulumi.Input<number>;
    }
    /**
     * Name/Value pair of a parameter to start execution of a SageMaker Model Building Pipeline.
     */
    interface ScheduleSageMakerPipelineParameterArgs {
        /**
         * Name of parameter to start execution of a SageMaker Model Building Pipeline.
         */
        name: pulumi.Input<string>;
        /**
         * Value of parameter to start execution of a SageMaker Model Building Pipeline.
         */
        value: pulumi.Input<string>;
    }
    /**
     * These are custom parameters to use when the target is a SageMaker Model Building Pipeline that starts based on AWS EventBridge Scheduler schedules.
     */
    interface ScheduleSageMakerPipelineParametersArgs {
        /**
         * List of Parameter names and values for SageMaker Model Building Pipeline execution.
         */
        pipelineParameterList?: pulumi.Input<pulumi.Input<inputs.scheduler.ScheduleSageMakerPipelineParameterArgs>[]>;
    }
    /**
     * Contains the message group ID to use when the target is a FIFO queue. If you specify an SQS FIFO queue as a target, the queue must have content-based deduplication enabled.
     */
    interface ScheduleSqsParametersArgs {
        /**
         * The FIFO message group ID to use as the target.
         */
        messageGroupId?: pulumi.Input<string>;
    }
    /**
     * The schedule target.
     */
    interface ScheduleTargetArgs {
        /**
         * The Amazon Resource Name (ARN) of the target.
         */
        arn: pulumi.Input<string>;
        /**
         * An object that contains information about an Amazon SQS queue that EventBridge Scheduler uses as a dead-letter queue for your schedule. If specified, EventBridge Scheduler delivers failed events that could not be successfully delivered to a target to the queue.
         */
        deadLetterConfig?: pulumi.Input<inputs.scheduler.ScheduleDeadLetterConfigArgs>;
        /**
         * The templated target type for the Amazon ECS [`RunTask`](https://docs.aws.amazon.com/AmazonECS/latest/APIReference/API_RunTask.html) API operation.
         */
        ecsParameters?: pulumi.Input<inputs.scheduler.ScheduleEcsParametersArgs>;
        /**
         * The templated target type for the EventBridge [`PutEvents`](https://docs.aws.amazon.com/eventbridge/latest/APIReference/API_PutEvents.html) API operation.
         */
        eventBridgeParameters?: pulumi.Input<inputs.scheduler.ScheduleEventBridgeParametersArgs>;
        /**
         * The text, or well-formed JSON, passed to the target. If you are configuring a templated Lambda, AWS Step Functions, or Amazon EventBridge target, the input must be a well-formed JSON. For all other target types, a JSON is not required. If you do not specify anything for this field, EventBridge Scheduler delivers a default notification to the target.
         */
        input?: pulumi.Input<string>;
        /**
         * The templated target type for the Amazon Kinesis [`PutRecord`](https://docs.aws.amazon.com/kinesis/latest/APIReference/API_PutRecord.html) API operation.
         */
        kinesisParameters?: pulumi.Input<inputs.scheduler.ScheduleKinesisParametersArgs>;
        /**
         * A `RetryPolicy` object that includes information about the retry policy settings, including the maximum age of an event, and the maximum number of times EventBridge Scheduler will try to deliver the event to a target.
         */
        retryPolicy?: pulumi.Input<inputs.scheduler.ScheduleRetryPolicyArgs>;
        /**
         * The Amazon Resource Name (ARN) of the IAM role to be used for this target when the schedule is triggered.
         */
        roleArn: pulumi.Input<string>;
        /**
         * The templated target type for the Amazon SageMaker [`StartPipelineExecution`](https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_StartPipelineExecution.html) API operation.
         */
        sageMakerPipelineParameters?: pulumi.Input<inputs.scheduler.ScheduleSageMakerPipelineParametersArgs>;
        /**
         * The templated target type for the Amazon SQS [`SendMessage`](https://docs.aws.amazon.com/AWSSimpleQueueService/latest/APIReference/API_SendMessage.html) API operation. Contains the message group ID to use when the target is a FIFO queue. If you specify an Amazon SQS FIFO queue as a target, the queue must have content-based deduplication enabled. For more information, see [Using the Amazon SQS message deduplication ID](https://docs.aws.amazon.com/AWSSimpleQueueService/latest/SQSDeveloperGuide/using-messagededuplicationid-property.html) in the *Amazon SQS Developer Guide* .
         */
        sqsParameters?: pulumi.Input<inputs.scheduler.ScheduleSqsParametersArgs>;
    }
}
export declare namespace secretsmanager {
    interface RotationScheduleHostedRotationLambdaArgs {
        /**
         * A string of the characters that you don't want in the password.
         */
        excludeCharacters?: pulumi.Input<string>;
        /**
         * The ARN of the KMS key that Secrets Manager uses to encrypt the secret. If you don't specify this value, then Secrets Manager uses the key aws/secretsmanager. If aws/secretsmanager doesn't yet exist, then Secrets Manager creates it for you automatically the first time it encrypts the secret value.
         */
        kmsKeyArn?: pulumi.Input<string>;
        /**
         * The ARN of the secret that contains superuser credentials, if you use the alternating users rotation strategy. CloudFormation grants the execution role for the Lambda rotation function GetSecretValue permission to the secret in this property.
         */
        masterSecretArn?: pulumi.Input<string>;
        /**
         * The ARN of the KMS key that Secrets Manager used to encrypt the superuser secret, if you use the alternating users strategy and the superuser secret is encrypted with a customer managed key. You don't need to specify this property if the superuser secret is encrypted using the key aws/secretsmanager. CloudFormation grants the execution role for the Lambda rotation function Decrypt, DescribeKey, and GenerateDataKey permission to the key in this property.
         */
        masterSecretKmsKeyArn?: pulumi.Input<string>;
        /**
         * The name of the Lambda rotation function.
         */
        rotationLambdaName?: pulumi.Input<string>;
        /**
         * The type of rotation template to use
         */
        rotationType: pulumi.Input<string>;
        /**
         * The python runtime associated with the Lambda function
         */
        runtime?: pulumi.Input<string>;
        /**
         * The ARN of the secret that contains superuser credentials, if you use the alternating users rotation strategy. CloudFormation grants the execution role for the Lambda rotation function GetSecretValue permission to the secret in this property.
         */
        superuserSecretArn?: pulumi.Input<string>;
        /**
         * The ARN of the KMS key that Secrets Manager used to encrypt the superuser secret, if you use the alternating users strategy and the superuser secret is encrypted with a customer managed key. You don't need to specify this property if the superuser secret is encrypted using the key aws/secretsmanager. CloudFormation grants the execution role for the Lambda rotation function Decrypt, DescribeKey, and GenerateDataKey permission to the key in this property.
         */
        superuserSecretKmsKeyArn?: pulumi.Input<string>;
        /**
         * A comma-separated list of security group IDs applied to the target database.
         */
        vpcSecurityGroupIds?: pulumi.Input<string>;
        /**
         * A comma separated list of VPC subnet IDs of the target database network. The Lambda rotation function is in the same subnet group.
         */
        vpcSubnetIds?: pulumi.Input<string>;
    }
    interface RotationScheduleRotationRulesArgs {
        /**
         * The number of days between automatic scheduled rotations of the secret. You can use this value to check that your secret meets your compliance guidelines for how often secrets must be rotated.
         */
        automaticallyAfterDays?: pulumi.Input<number>;
        /**
         * The length of the rotation window in hours, for example 3h for a three hour window. Secrets Manager rotates your secret at any time during this window. The window must not extend into the next rotation window or the next UTC day. The window starts according to the ScheduleExpression. If you don't specify a Duration, for a ScheduleExpression in hours, the window automatically closes after one hour. For a ScheduleExpression in days, the window automatically closes at the end of the UTC day.
         */
        duration?: pulumi.Input<string>;
        /**
         * A cron() or rate() expression that defines the schedule for rotating your secret. Secrets Manager rotation schedules use UTC time zone.
         */
        scheduleExpression?: pulumi.Input<string>;
    }
    /**
     * Generates a random password. We recommend that you specify the maximum length and include every character type that the system you are generating a password for can support.
     *   *Required permissions:* ``secretsmanager:GetRandomPassword``. For more information, see [IAM policy actions for Secrets Manager](https://docs.aws.amazon.com/service-authorization/latest/reference/list_awssecretsmanager.html#awssecretsmanager-actions-as-permissions) and [Authentication and access control in Secrets Manager](https://docs.aws.amazon.com/secretsmanager/latest/userguide/auth-and-access.html).
     */
    interface SecretGenerateSecretStringArgs {
        /**
         * A string of the characters that you don't want in the password.
         */
        excludeCharacters?: pulumi.Input<string>;
        /**
         * Specifies whether to exclude lowercase letters from the password. If you don't include this switch, the password can contain lowercase letters.
         */
        excludeLowercase?: pulumi.Input<boolean>;
        /**
         * Specifies whether to exclude numbers from the password. If you don't include this switch, the password can contain numbers.
         */
        excludeNumbers?: pulumi.Input<boolean>;
        /**
         * Specifies whether to exclude the following punctuation characters from the password: ``! " # $ % & ' ( ) * + , - . / : ; < = > ? @ [ \ ] ^ _ ` { | } ~``. If you don't include this switch, the password can contain punctuation.
         */
        excludePunctuation?: pulumi.Input<boolean>;
        /**
         * Specifies whether to exclude uppercase letters from the password. If you don't include this switch, the password can contain uppercase letters.
         */
        excludeUppercase?: pulumi.Input<boolean>;
        /**
         * The JSON key name for the key/value pair, where the value is the generated password. This pair is added to the JSON structure specified by the ``SecretStringTemplate`` parameter. If you specify this parameter, then you must also specify ``SecretStringTemplate``.
         */
        generateStringKey?: pulumi.Input<string>;
        /**
         * Specifies whether to include the space character. If you include this switch, the password can contain space characters.
         */
        includeSpace?: pulumi.Input<boolean>;
        /**
         * The length of the password. If you don't include this parameter, the default length is 32 characters.
         */
        passwordLength?: pulumi.Input<number>;
        /**
         * Specifies whether to include at least one upper and lowercase letter, one number, and one punctuation. If you don't include this switch, the password contains at least one of every character type.
         */
        requireEachIncludedType?: pulumi.Input<boolean>;
        /**
         * A template that the generated string must match. When you make a change to this property, a new secret version is created.
         */
        secretStringTemplate?: pulumi.Input<string>;
    }
    /**
     * Specifies a ``Region`` and the ``KmsKeyId`` for a replica secret.
     */
    interface SecretReplicaRegionArgs {
        /**
         * The ARN, key ID, or alias of the KMS key to encrypt the secret. If you don't include this field, Secrets Manager uses ``aws/secretsmanager``.
         */
        kmsKeyId?: pulumi.Input<string>;
        /**
         * A string that represents a ``Region``, for example "us-east-1".
         */
        region: pulumi.Input<string>;
    }
}
export declare namespace securityhub {
    /**
     * A date filter for querying findings.
     */
    interface AutomationRuleDateFilterArgs {
        /**
         * A date range for the date filter.
         */
        dateRange?: pulumi.Input<inputs.securityhub.AutomationRuleDateRangeArgs>;
        /**
         * A timestamp that provides the end date for the date filter.
         *  For more information about the validation and formatting of timestamp fields in ASHlong, see [Timestamps](https://docs.aws.amazon.com/securityhub/1.0/APIReference/Welcome.html#timestamps).
         */
        end?: pulumi.Input<string>;
        /**
         * A timestamp that provides the start date for the date filter.
         *  For more information about the validation and formatting of timestamp fields in ASHlong, see [Timestamps](https://docs.aws.amazon.com/securityhub/1.0/APIReference/Welcome.html#timestamps).
         */
        start?: pulumi.Input<string>;
    }
    /**
     * A date range for the date filter.
     */
    interface AutomationRuleDateRangeArgs {
        /**
         * A date range unit for the date filter.
         */
        unit: pulumi.Input<enums.securityhub.AutomationRuleDateRangeUnit>;
        /**
         * A date range value for the date filter.
         */
        value: pulumi.Input<number>;
    }
    /**
     * A map filter for filtering ASHlong findings. Each map filter provides the field to check for, the value to check for, and the comparison operator.
     */
    interface AutomationRuleMapFilterArgs {
        /**
         * The condition to apply to the key value when filtering Security Hub findings with a map filter.
         *  To search for values that have the filter value, use one of the following comparison operators:
         *   +  To search for values that include the filter value, use ``CONTAINS``. For example, for the ``ResourceTags`` field, the filter ``Department CONTAINS Security`` matches findings that include the value ``Security`` for the ``Department`` tag. In the same example, a finding with a value of ``Security team`` for the ``Department`` tag is a match.
         *   +  To search for values that exactly match the filter value, use ``EQUALS``. For example, for the ``ResourceTags`` field, the filter ``Department EQUALS Security`` matches findings that have the value ``Security`` for the ``Department`` tag.
         *
         *   ``CONTAINS`` and ``EQUALS`` filters on the same field are joined by ``OR``. A finding matches if it matches any one of those filters. For example, the filters ``Department CONTAINS Security OR Department CONTAINS Finance`` match a finding that includes either ``Security``, ``Finance``, or both values.
         *  To search for values that don't have the filter value, use one of the following comparison operators:
         *   +  To search for values that exclude the filter value, use ``NOT_CONTAINS``. For example, for the ``ResourceTags`` field, the filter ``Department NOT_CONTAINS Finance`` matches findings that exclude the value ``Finance`` for the ``Department`` tag.
         *   +  To search for values other than the filter value, use ``NOT_EQUALS``. For example, for the ``ResourceTags`` field, the filter ``Department NOT_EQUALS Finance`` matches findings that don’t have the value ``Finance`` for the ``Department`` tag.
         *
         *   ``NOT_CONTAINS`` and ``NOT_EQUALS`` filters on the same field are joined by ``AND``. A finding matches only if it matches all of those filters. For example, the filters ``Department NOT_CONTAINS Security AND Department NOT_CONTAINS Finance`` match a finding that excludes both the ``Security`` and ``Finance`` values.
         *   ``CONTAINS`` filters can only be used with other ``CONTAINS`` filters. ``NOT_CONTAINS`` filters can only be used with other ``NOT_CONTAINS`` filters.
         *  You can’t have both a ``CONTAINS`` filter and a ``NOT_CONTAINS`` filter on the same field. Similarly, you can’t have both an ``EQUALS`` filter and a ``NOT_EQUALS`` filter on the same field. Combining filters in this way returns an error.
         *   ``CONTAINS`` and ``NOT_CONTAINS`` operators can be used only with automation rules. For more information, see [Automation rules](https://docs.aws.amazon.com/securityhub/latest/userguide/automation-rules.html) in the *User Guide*.
         */
        comparison: pulumi.Input<enums.securityhub.AutomationRuleMapFilterComparison>;
        /**
         * The key of the map filter. For example, for ``ResourceTags``, ``Key`` identifies the name of the tag. For ``UserDefinedFields``, ``Key`` is the name of the field.
         */
        key: pulumi.Input<string>;
        /**
         * The value for the key in the map filter. Filter values are case sensitive. For example, one of the values for a tag called ``Department`` might be ``Security``. If you provide ``security`` as the filter value, then there's no match.
         */
        value: pulumi.Input<string>;
    }
    /**
     * The updated note.
     */
    interface AutomationRuleNoteUpdateArgs {
        /**
         * The updated note text.
         */
        text: pulumi.Input<string>;
        /**
         * The principal that updated the note.
         */
        updatedBy: pulumi.Input<string>;
    }
    /**
     * A number filter for querying findings.
     */
    interface AutomationRuleNumberFilterArgs {
        /**
         * The equal-to condition to be applied to a single field when querying for findings.
         */
        eq?: pulumi.Input<number>;
        /**
         * The greater-than-equal condition to be applied to a single field when querying for findings.
         */
        gte?: pulumi.Input<number>;
        /**
         * The less-than-equal condition to be applied to a single field when querying for findings.
         */
        lte?: pulumi.Input<number>;
    }
    /**
     * Provides details about a list of findings that the current finding relates to.
     */
    interface AutomationRuleRelatedFindingArgs {
        /**
         * The product-generated identifier for a related finding.
         *   Array Members: Minimum number of 1 item. Maximum number of 20 items.
         */
        id: pulumi.Input<string>;
        /**
         * The Amazon Resource Name (ARN) for the product that generated a related finding.
         */
        productArn: pulumi.Input<string>;
    }
    /**
     * Updates to the severity information for a finding.
     */
    interface AutomationRuleSeverityUpdateArgs {
        /**
         * The severity value of the finding. The allowed values are the following.
         *   +   ``INFORMATIONAL`` - No issue was found.
         *   +   ``LOW`` - The issue does not require action on its own.
         *   +   ``MEDIUM`` - The issue must be addressed but not urgently.
         *   +   ``HIGH`` - The issue must be addressed as a priority.
         *   +   ``CRITICAL`` - The issue must be remediated immediately to avoid it escalating.
         */
        label?: pulumi.Input<enums.securityhub.AutomationRuleSeverityUpdateLabel>;
        /**
         * The normalized severity for the finding. This attribute is to be deprecated in favor of ``Label``.
         *  If you provide ``Normalized`` and don't provide ``Label``, ``Label`` is set automatically as follows.
         *   +  0 - ``INFORMATIONAL``
         *   +  1–39 - ``LOW``
         *   +  40–69 - ``MEDIUM``
         *   +  70–89 - ``HIGH``
         *   +  90–100 - ``CRITICAL``
         */
        normalized?: pulumi.Input<number>;
        /**
         * The native severity as defined by the AWS service or integrated partner product that generated the finding.
         */
        product?: pulumi.Input<number>;
    }
    /**
     * A string filter for filtering ASHlong findings.
     */
    interface AutomationRuleStringFilterArgs {
        /**
         * The condition to apply to a string value when filtering Security Hub findings.
         *  To search for values that have the filter value, use one of the following comparison operators:
         *   +  To search for values that include the filter value, use ``CONTAINS``. For example, the filter ``Title CONTAINS CloudFront`` matches findings that have a ``Title`` that includes the string CloudFront.
         *   +  To search for values that exactly match the filter value, use ``EQUALS``. For example, the filter ``AwsAccountId EQUALS 123456789012`` only matches findings that have an account ID of ``123456789012``.
         *   +  To search for values that start with the filter value, use ``PREFIX``. For example, the filter ``ResourceRegion PREFIX us`` matches findings that have a ``ResourceRegion`` that starts with ``us``. A ``ResourceRegion`` that starts with a different value, such as ``af``, ``ap``, or ``ca``, doesn't match.
         *
         *   ``CONTAINS``, ``EQUALS``, and ``PREFIX`` filters on the same field are joined by ``OR``. A finding matches if it matches any one of those filters. For example, the filters ``Title CONTAINS CloudFront OR Title CONTAINS CloudWatch`` match a finding that includes either ``CloudFront``, ``CloudWatch``, or both strings in the title.
         *  To search for values that don’t have the filter value, use one of the following comparison operators:
         *   +  To search for values that exclude the filter value, use ``NOT_CONTAINS``. For example, the filter ``Title NOT_CONTAINS CloudFront`` matches findings that have a ``Title`` that excludes the string CloudFront.
         *   +  To search for values other than the filter value, use ``NOT_EQUALS``. For example, the filter ``AwsAccountId NOT_EQUALS 123456789012`` only matches findings that have an account ID other than ``123456789012``.
         *   +  To search for values that don't start with the filter value, use ``PREFIX_NOT_EQUALS``. For example, the filter ``ResourceRegion PREFIX_NOT_EQUALS us`` matches findings with a ``ResourceRegion`` that starts with a value other than ``us``.
         *
         *   ``NOT_CONTAINS``, ``NOT_EQUALS``, and ``PREFIX_NOT_EQUALS`` filters on the same field are joined by ``AND``. A finding matches only if it matches all of those filters. For example, the filters ``Title NOT_CONTAINS CloudFront AND Title NOT_CONTAINS CloudWatch`` match a finding that excludes both ``CloudFront`` and ``CloudWatch`` in the title.
         *  You can’t have both a ``CONTAINS`` filter and a ``NOT_CONTAINS`` filter on the same field. Similarly, you can't provide both an ``EQUALS`` filter and a ``NOT_EQUALS`` or ``PREFIX_NOT_EQUALS`` filter on the same field. Combining filters in this way returns an error. ``CONTAINS`` filters can only be used with other ``CONTAINS`` filters. ``NOT_CONTAINS`` filters can only be used with other ``NOT_CONTAINS`` filters.
         *  You can combine ``PREFIX`` filters with ``NOT_EQUALS`` or ``PREFIX_NOT_EQUALS`` filters for the same field. Security Hub first processes the ``PREFIX`` filters, and then the ``NOT_EQUALS`` or ``PREFIX_NOT_EQUALS`` filters.
         *  For example, for the following filters, Security Hub first identifies findings that have resource types that start with either ``AwsIam`` or ``AwsEc2``. It then excludes findings that have a resource type of ``AwsIamPolicy`` and findings that have a resource type of ``AwsEc2NetworkInterface``.
         *   +   ``ResourceType PREFIX AwsIam``
         *   +   ``ResourceType PREFIX AwsEc2``
         *   +   ``ResourceType NOT_EQUALS AwsIamPolicy``
         *   +   ``ResourceType NOT_EQUALS AwsEc2NetworkInterface``
         *
         *   ``CONTAINS`` and ``NOT_CONTAINS`` operators can be used only with automation rules. For more information, see [Automation rules](https://docs.aws.amazon.com/securityhub/latest/userguide/automation-rules.html) in the *User Guide*.
         */
        comparison: pulumi.Input<enums.securityhub.AutomationRuleStringFilterComparison>;
        /**
         * The string filter value. Filter values are case sensitive. For example, the product name for control-based findings is ``Security Hub``. If you provide ``security hub`` as the filter value, there's no match.
         */
        value: pulumi.Input<string>;
    }
    /**
     * Used to update information about the investigation into the finding.
     */
    interface AutomationRuleWorkflowUpdateArgs {
        /**
         * The status of the investigation into the finding. The workflow status is specific to an individual finding. It does not affect the generation of new findings. For example, setting the workflow status to ``SUPPRESSED`` or ``RESOLVED`` does not prevent a new finding for the same issue.
         *  The allowed values are the following.
         *   +   ``NEW`` - The initial state of a finding, before it is reviewed.
         *  Security Hub also resets ``WorkFlowStatus`` from ``NOTIFIED`` or ``RESOLVED`` to ``NEW`` in the following cases:
         *   +  The record state changes from ``ARCHIVED`` to ``ACTIVE``.
         *   +  The compliance status changes from ``PASSED`` to either ``WARNING``, ``FAILED``, or ``NOT_AVAILABLE``.
         *
         *   +   ``NOTIFIED`` - Indicates that you notified the resource owner about the security issue. Used when the initial reviewer is not the resource owner, and needs intervention from the resource owner.
         *   +   ``RESOLVED`` - The finding was reviewed and remediated and is now considered resolved.
         *   +   ``SUPPRESSED`` - Indicates that you reviewed the finding and don't believe that any action is needed. The finding is no longer updated.
         */
        status: pulumi.Input<enums.securityhub.AutomationRuleWorkflowUpdateStatus>;
    }
    /**
     * One or more actions that ASHlong takes when a finding matches the defined criteria of a rule.
     */
    interface AutomationRulesActionArgs {
        /**
         * Specifies that the automation rule action is an update to a finding field.
         */
        findingFieldsUpdate: pulumi.Input<inputs.securityhub.AutomationRulesFindingFieldsUpdateArgs>;
        /**
         * Specifies the type of action that Security Hub takes when a finding matches the defined criteria of a rule.
         */
        type: pulumi.Input<enums.securityhub.AutomationRulesActionType>;
    }
    /**
     * Identifies the finding fields that the automation rule action updates when a finding matches the defined criteria.
     */
    interface AutomationRulesFindingFieldsUpdateArgs {
        /**
         * The rule action updates the ``Confidence`` field of a finding.
         */
        confidence?: pulumi.Input<number>;
        /**
         * The rule action updates the ``Criticality`` field of a finding.
         */
        criticality?: pulumi.Input<number>;
        /**
         * The rule action will update the ``Note`` field of a finding.
         */
        note?: pulumi.Input<inputs.securityhub.AutomationRuleNoteUpdateArgs>;
        /**
         * The rule action will update the ``RelatedFindings`` field of a finding.
         */
        relatedFindings?: pulumi.Input<pulumi.Input<inputs.securityhub.AutomationRuleRelatedFindingArgs>[]>;
        /**
         * The rule action will update the ``Severity`` field of a finding.
         */
        severity?: pulumi.Input<inputs.securityhub.AutomationRuleSeverityUpdateArgs>;
        /**
         * The rule action updates the ``Types`` field of a finding.
         */
        types?: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * The rule action updates the ``UserDefinedFields`` field of a finding.
         */
        userDefinedFields?: pulumi.Input<{
            [key: string]: pulumi.Input<string>;
        }>;
        /**
         * The rule action updates the ``VerificationState`` field of a finding.
         */
        verificationState?: pulumi.Input<enums.securityhub.AutomationRulesFindingFieldsUpdateVerificationState>;
        /**
         * The rule action will update the ``Workflow`` field of a finding.
         */
        workflow?: pulumi.Input<inputs.securityhub.AutomationRuleWorkflowUpdateArgs>;
    }
    /**
     * The criteria that determine which findings a rule applies to.
     */
    interface AutomationRulesFindingFiltersArgs {
        /**
         * The AWS-account ID in which a finding was generated.
         *   Array Members: Minimum number of 1 item. Maximum number of 100 items.
         */
        awsAccountId?: pulumi.Input<pulumi.Input<inputs.securityhub.AutomationRuleStringFilterArgs>[]>;
        /**
         * The name of the company for the product that generated the finding. For control-based findings, the company is AWS.
         *   Array Members: Minimum number of 1 item. Maximum number of 20 items.
         */
        companyName?: pulumi.Input<pulumi.Input<inputs.securityhub.AutomationRuleStringFilterArgs>[]>;
        /**
         * The unique identifier of a standard in which a control is enabled. This field consists of the resource portion of the Amazon Resource Name (ARN) returned for a standard in the [DescribeStandards](https://docs.aws.amazon.com/securityhub/1.0/APIReference/API_DescribeStandards.html) API response.
         *   Array Members: Minimum number of 1 item. Maximum number of 20 items.
         */
        complianceAssociatedStandardsId?: pulumi.Input<pulumi.Input<inputs.securityhub.AutomationRuleStringFilterArgs>[]>;
        /**
         * The security control ID for which a finding was generated. Security control IDs are the same across standards.
         *   Array Members: Minimum number of 1 item. Maximum number of 20 items.
         */
        complianceSecurityControlId?: pulumi.Input<pulumi.Input<inputs.securityhub.AutomationRuleStringFilterArgs>[]>;
        /**
         * The result of a security check. This field is only used for findings generated from controls.
         *   Array Members: Minimum number of 1 item. Maximum number of 20 items.
         */
        complianceStatus?: pulumi.Input<pulumi.Input<inputs.securityhub.AutomationRuleStringFilterArgs>[]>;
        /**
         * The likelihood that a finding accurately identifies the behavior or issue that it was intended to identify. ``Confidence`` is scored on a 0–100 basis using a ratio scale. A value of ``0`` means 0 percent confidence, and a value of ``100`` means 100 percent confidence. For example, a data exfiltration detection based on a statistical deviation of network traffic has low confidence because an actual exfiltration hasn't been verified. For more information, see [Confidence](https://docs.aws.amazon.com/securityhub/latest/userguide/asff-top-level-attributes.html#asff-confidence) in the *User Guide*.
         *   Array Members: Minimum number of 1 item. Maximum number of 20 items.
         */
        confidence?: pulumi.Input<pulumi.Input<inputs.securityhub.AutomationRuleNumberFilterArgs>[]>;
        /**
         * A timestamp that indicates when this finding record was created.
         *  For more information about the validation and formatting of timestamp fields in ASHlong, see [Timestamps](https://docs.aws.amazon.com/securityhub/1.0/APIReference/Welcome.html#timestamps).
         *   Array Members: Minimum number of 1 item. Maximum number of 20 items.
         */
        createdAt?: pulumi.Input<pulumi.Input<inputs.securityhub.AutomationRuleDateFilterArgs>[]>;
        /**
         * The level of importance that is assigned to the resources that are associated with a finding. ``Criticality`` is scored on a 0–100 basis, using a ratio scale that supports only full integers. A score of ``0`` means that the underlying resources have no criticality, and a score of ``100`` is reserved for the most critical resources. For more information, see [Criticality](https://docs.aws.amazon.com/securityhub/latest/userguide/asff-top-level-attributes.html#asff-criticality) in the *User Guide*.
         *   Array Members: Minimum number of 1 item. Maximum number of 20 items.
         */
        criticality?: pulumi.Input<pulumi.Input<inputs.securityhub.AutomationRuleNumberFilterArgs>[]>;
        /**
         * A finding's description.
         *   Array Members: Minimum number of 1 item. Maximum number of 20 items.
         */
        description?: pulumi.Input<pulumi.Input<inputs.securityhub.AutomationRuleStringFilterArgs>[]>;
        /**
         * A timestamp that indicates when the potential security issue captured by a finding was first observed by the security findings product.
         *  For more information about the validation and formatting of timestamp fields in ASHlong, see [Timestamps](https://docs.aws.amazon.com/securityhub/1.0/APIReference/Welcome.html#timestamps).
         *   Array Members: Minimum number of 1 item. Maximum number of 20 items.
         */
        firstObservedAt?: pulumi.Input<pulumi.Input<inputs.securityhub.AutomationRuleDateFilterArgs>[]>;
        /**
         * The identifier for the solution-specific component that generated a finding.
         *   Array Members: Minimum number of 1 item. Maximum number of 100 items.
         */
        generatorId?: pulumi.Input<pulumi.Input<inputs.securityhub.AutomationRuleStringFilterArgs>[]>;
        /**
         * The product-specific identifier for a finding.
         *   Array Members: Minimum number of 1 item. Maximum number of 20 items.
         */
        id?: pulumi.Input<pulumi.Input<inputs.securityhub.AutomationRuleStringFilterArgs>[]>;
        /**
         * A timestamp that indicates when the security findings provider most recently observed a change in the resource that is involved in the finding.
         *  For more information about the validation and formatting of timestamp fields in ASHlong, see [Timestamps](https://docs.aws.amazon.com/securityhub/1.0/APIReference/Welcome.html#timestamps).
         *   Array Members: Minimum number of 1 item. Maximum number of 20 items.
         */
        lastObservedAt?: pulumi.Input<pulumi.Input<inputs.securityhub.AutomationRuleDateFilterArgs>[]>;
        /**
         * The text of a user-defined note that's added to a finding.
         *   Array Members: Minimum number of 1 item. Maximum number of 20 items.
         */
        noteText?: pulumi.Input<pulumi.Input<inputs.securityhub.AutomationRuleStringFilterArgs>[]>;
        /**
         * The timestamp of when the note was updated.
         *  For more information about the validation and formatting of timestamp fields in ASHlong, see [Timestamps](https://docs.aws.amazon.com/securityhub/1.0/APIReference/Welcome.html#timestamps).
         *   Array Members: Minimum number of 1 item. Maximum number of 20 items.
         */
        noteUpdatedAt?: pulumi.Input<pulumi.Input<inputs.securityhub.AutomationRuleDateFilterArgs>[]>;
        /**
         * The principal that created a note.
         *   Array Members: Minimum number of 1 item. Maximum number of 20 items.
         */
        noteUpdatedBy?: pulumi.Input<pulumi.Input<inputs.securityhub.AutomationRuleStringFilterArgs>[]>;
        /**
         * The Amazon Resource Name (ARN) for a third-party product that generated a finding in Security Hub.
         *   Array Members: Minimum number of 1 item. Maximum number of 20 items.
         */
        productArn?: pulumi.Input<pulumi.Input<inputs.securityhub.AutomationRuleStringFilterArgs>[]>;
        /**
         * Provides the name of the product that generated the finding. For control-based findings, the product name is Security Hub.
         *   Array Members: Minimum number of 1 item. Maximum number of 20 items.
         */
        productName?: pulumi.Input<pulumi.Input<inputs.securityhub.AutomationRuleStringFilterArgs>[]>;
        /**
         * Provides the current state of a finding.
         *   Array Members: Minimum number of 1 item. Maximum number of 20 items.
         */
        recordState?: pulumi.Input<pulumi.Input<inputs.securityhub.AutomationRuleStringFilterArgs>[]>;
        /**
         * The product-generated identifier for a related finding.
         *   Array Members: Minimum number of 1 item. Maximum number of 20 items.
         */
        relatedFindingsId?: pulumi.Input<pulumi.Input<inputs.securityhub.AutomationRuleStringFilterArgs>[]>;
        /**
         * The ARN for the product that generated a related finding.
         *   Array Members: Minimum number of 1 item. Maximum number of 20 items.
         */
        relatedFindingsProductArn?: pulumi.Input<pulumi.Input<inputs.securityhub.AutomationRuleStringFilterArgs>[]>;
        /**
         * Custom fields and values about the resource that a finding pertains to.
         *   Array Members: Minimum number of 1 item. Maximum number of 20 items.
         */
        resourceDetailsOther?: pulumi.Input<pulumi.Input<inputs.securityhub.AutomationRuleMapFilterArgs>[]>;
        /**
         * The identifier for the given resource type. For AWS resources that are identified by Amazon Resource Names (ARNs), this is the ARN. For AWS resources that lack ARNs, this is the identifier as defined by the AWS-service that created the resource. For non-AWS resources, this is a unique identifier that is associated with the resource.
         *   Array Members: Minimum number of 1 item. Maximum number of 100 items.
         */
        resourceId?: pulumi.Input<pulumi.Input<inputs.securityhub.AutomationRuleStringFilterArgs>[]>;
        /**
         * The partition in which the resource that the finding pertains to is located. A partition is a group of AWS-Regions. Each AWS-account is scoped to one partition.
         *   Array Members: Minimum number of 1 item. Maximum number of 20 items.
         */
        resourcePartition?: pulumi.Input<pulumi.Input<inputs.securityhub.AutomationRuleStringFilterArgs>[]>;
        /**
         * The AWS-Region where the resource that a finding pertains to is located.
         *   Array Members: Minimum number of 1 item. Maximum number of 20 items.
         */
        resourceRegion?: pulumi.Input<pulumi.Input<inputs.securityhub.AutomationRuleStringFilterArgs>[]>;
        /**
         * A list of AWS tags associated with a resource at the time the finding was processed.
         *   Array Members: Minimum number of 1 item. Maximum number of 20 items.
         */
        resourceTags?: pulumi.Input<pulumi.Input<inputs.securityhub.AutomationRuleMapFilterArgs>[]>;
        /**
         * A finding's title.
         *   Array Members: Minimum number of 1 item. Maximum number of 100 items.
         */
        resourceType?: pulumi.Input<pulumi.Input<inputs.securityhub.AutomationRuleStringFilterArgs>[]>;
        /**
         * The severity value of the finding.
         *   Array Members: Minimum number of 1 item. Maximum number of 20 items.
         */
        severityLabel?: pulumi.Input<pulumi.Input<inputs.securityhub.AutomationRuleStringFilterArgs>[]>;
        /**
         * Provides a URL that links to a page about the current finding in the finding product.
         *   Array Members: Minimum number of 1 item. Maximum number of 20 items.
         */
        sourceUrl?: pulumi.Input<pulumi.Input<inputs.securityhub.AutomationRuleStringFilterArgs>[]>;
        /**
         * A finding's title.
         *   Array Members: Minimum number of 1 item. Maximum number of 100 items.
         */
        title?: pulumi.Input<pulumi.Input<inputs.securityhub.AutomationRuleStringFilterArgs>[]>;
        /**
         * One or more finding types in the format of namespace/category/classifier that classify a finding. For a list of namespaces, classifiers, and categories, see [Types taxonomy for ASFF](https://docs.aws.amazon.com/securityhub/latest/userguide/securityhub-findings-format-type-taxonomy.html) in the *User Guide*.
         *   Array Members: Minimum number of 1 item. Maximum number of 20 items.
         */
        type?: pulumi.Input<pulumi.Input<inputs.securityhub.AutomationRuleStringFilterArgs>[]>;
        /**
         * A timestamp that indicates when the finding record was most recently updated.
         *  For more information about the validation and formatting of timestamp fields in ASHlong, see [Timestamps](https://docs.aws.amazon.com/securityhub/1.0/APIReference/Welcome.html#timestamps).
         *   Array Members: Minimum number of 1 item. Maximum number of 20 items.
         */
        updatedAt?: pulumi.Input<pulumi.Input<inputs.securityhub.AutomationRuleDateFilterArgs>[]>;
        /**
         * A list of user-defined name and value string pairs added to a finding.
         *   Array Members: Minimum number of 1 item. Maximum number of 20 items.
         */
        userDefinedFields?: pulumi.Input<pulumi.Input<inputs.securityhub.AutomationRuleMapFilterArgs>[]>;
        /**
         * Provides the veracity of a finding.
         *   Array Members: Minimum number of 1 item. Maximum number of 20 items.
         */
        verificationState?: pulumi.Input<pulumi.Input<inputs.securityhub.AutomationRuleStringFilterArgs>[]>;
        /**
         * Provides information about the status of the investigation into a finding.
         *   Array Members: Minimum number of 1 item. Maximum number of 20 items.
         */
        workflowStatus?: pulumi.Input<pulumi.Input<inputs.securityhub.AutomationRuleStringFilterArgs>[]>;
    }
    /**
     * An object that provides the current value of a security control parameter and identifies whether it has been customized.
     */
    interface ConfigurationPolicyParameterConfigurationArgs {
        value?: pulumi.Input<inputs.securityhub.ConfigurationPolicyParameterValueArgs>;
        /**
         * Identifies whether a control parameter uses a custom user-defined value or subscribes to the default AWS Security Hub behavior.
         */
        valueType: pulumi.Input<enums.securityhub.ConfigurationPolicyParameterConfigurationValueType>;
    }
    /**
     * An object that includes the data type of a security control parameter and its current value.
     */
    interface ConfigurationPolicyParameterValueArgs {
        /**
         * A control parameter that is a boolean.
         */
        boolean?: pulumi.Input<boolean>;
        /**
         * A control parameter that is a double.
         */
        double?: pulumi.Input<number>;
        /**
         * A control parameter that is an enum.
         */
        enum?: pulumi.Input<string>;
        /**
         * A control parameter that is a list of enums.
         */
        enumList?: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * A control parameter that is an integer.
         */
        integer?: pulumi.Input<number>;
        /**
         * A control parameter that is a list of integers.
         */
        integerList?: pulumi.Input<pulumi.Input<number>[]>;
        /**
         * A control parameter that is a string.
         */
        string?: pulumi.Input<string>;
        /**
         * A control parameter that is a list of strings.
         */
        stringList?: pulumi.Input<pulumi.Input<string>[]>;
    }
    /**
     * An object that defines how Security Hub is configured.
     */
    interface ConfigurationPolicyPolicyArgs {
        /**
         * The AWS service that the configuration policy applies to.
         */
        securityHub?: pulumi.Input<inputs.securityhub.ConfigurationPolicySecurityHubPolicyArgs>;
    }
    /**
     * An object of security control and control parameter value that are included in a configuration policy.
     */
    interface ConfigurationPolicySecurityControlCustomParameterArgs {
        /**
         * An object that specifies parameter values for a control in a configuration policy.
         */
        parameters?: pulumi.Input<{
            [key: string]: pulumi.Input<inputs.securityhub.ConfigurationPolicyParameterConfigurationArgs>;
        }>;
        /**
         * The ID of the security control.
         */
        securityControlId?: pulumi.Input<string>;
    }
    /**
     * An object that defines which security controls are enabled in an AWS Security Hub configuration policy.
     */
    interface ConfigurationPolicySecurityControlsConfigurationArgs {
        /**
         * A list of security controls that are disabled in the configuration policy
         */
        disabledSecurityControlIdentifiers?: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * A list of security controls that are enabled in the configuration policy.
         */
        enabledSecurityControlIdentifiers?: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * A list of security controls and control parameter values that are included in a configuration policy.
         */
        securityControlCustomParameters?: pulumi.Input<pulumi.Input<inputs.securityhub.ConfigurationPolicySecurityControlCustomParameterArgs>[]>;
    }
    /**
     * An object that defines how AWS Security Hub is configured.
     */
    interface ConfigurationPolicySecurityHubPolicyArgs {
        /**
         * A list that defines which security standards are enabled in the configuration policy.
         */
        enabledStandardIdentifiers?: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * An object that defines which security controls are enabled in the configuration policy. The enablement status of a control is aligned across all of the enabled standards in an account.
         *
         * This property is required only if `ServiceEnabled` is set to true in your configuration policy.
         */
        securityControlsConfiguration?: pulumi.Input<inputs.securityhub.ConfigurationPolicySecurityControlsConfigurationArgs>;
        /**
         * Indicates whether Security Hub is enabled in the policy.
         */
        serviceEnabled?: pulumi.Input<boolean>;
    }
    /**
     * A collection of filters that are applied to all active findings aggregated by AWS Security Hub.
     */
    interface InsightAwsSecurityFindingFiltersArgs {
        /**
         * The AWS account ID in which a finding is generated.
         */
        awsAccountId?: pulumi.Input<pulumi.Input<inputs.securityhub.InsightStringFilterArgs>[]>;
        /**
         * The name of the AWS account in which a finding is generated.
         */
        awsAccountName?: pulumi.Input<pulumi.Input<inputs.securityhub.InsightStringFilterArgs>[]>;
        /**
         * The name of the findings provider (company) that owns the solution (product) that generates findings.
         */
        companyName?: pulumi.Input<pulumi.Input<inputs.securityhub.InsightStringFilterArgs>[]>;
        /**
         * The unique identifier of a standard in which a control is enabled.
         */
        complianceAssociatedStandardsId?: pulumi.Input<pulumi.Input<inputs.securityhub.InsightStringFilterArgs>[]>;
        /**
         * The unique identifier of a control across standards.
         */
        complianceSecurityControlId?: pulumi.Input<pulumi.Input<inputs.securityhub.InsightStringFilterArgs>[]>;
        /**
         * The name of a security control parameter.
         */
        complianceSecurityControlParametersName?: pulumi.Input<pulumi.Input<inputs.securityhub.InsightStringFilterArgs>[]>;
        /**
         * The current value of a security control parameter.
         */
        complianceSecurityControlParametersValue?: pulumi.Input<pulumi.Input<inputs.securityhub.InsightStringFilterArgs>[]>;
        /**
         * Exclusive to findings that are generated as the result of a check run against a specific rule in a supported standard.
         */
        complianceStatus?: pulumi.Input<pulumi.Input<inputs.securityhub.InsightStringFilterArgs>[]>;
        /**
         * A finding's confidence.
         */
        confidence?: pulumi.Input<pulumi.Input<inputs.securityhub.InsightNumberFilterArgs>[]>;
        /**
         * An ISO8601-formatted timestamp that indicates when the security findings provider captured the potential security issue that a finding captured.
         */
        createdAt?: pulumi.Input<pulumi.Input<inputs.securityhub.InsightDateFilterArgs>[]>;
        /**
         * The level of importance assigned to the resources associated with the finding.
         */
        criticality?: pulumi.Input<pulumi.Input<inputs.securityhub.InsightNumberFilterArgs>[]>;
        /**
         * A finding's description.
         */
        description?: pulumi.Input<pulumi.Input<inputs.securityhub.InsightStringFilterArgs>[]>;
        /**
         * The finding provider value for the finding confidence.
         */
        findingProviderFieldsConfidence?: pulumi.Input<pulumi.Input<inputs.securityhub.InsightNumberFilterArgs>[]>;
        /**
         * The finding provider value for the level of importance assigned to the resources associated with the findings.
         */
        findingProviderFieldsCriticality?: pulumi.Input<pulumi.Input<inputs.securityhub.InsightNumberFilterArgs>[]>;
        /**
         * The finding identifier of a related finding that is identified by the finding provider.
         */
        findingProviderFieldsRelatedFindingsId?: pulumi.Input<pulumi.Input<inputs.securityhub.InsightStringFilterArgs>[]>;
        /**
         * The ARN of the solution that generated a related finding that is identified by the finding provider.
         */
        findingProviderFieldsRelatedFindingsProductArn?: pulumi.Input<pulumi.Input<inputs.securityhub.InsightStringFilterArgs>[]>;
        /**
         * The finding provider value for the severity label.
         */
        findingProviderFieldsSeverityLabel?: pulumi.Input<pulumi.Input<inputs.securityhub.InsightStringFilterArgs>[]>;
        /**
         * The finding provider's original value for the severity.
         */
        findingProviderFieldsSeverityOriginal?: pulumi.Input<pulumi.Input<inputs.securityhub.InsightStringFilterArgs>[]>;
        /**
         * One or more finding types that the finding provider assigned to the finding.
         */
        findingProviderFieldsTypes?: pulumi.Input<pulumi.Input<inputs.securityhub.InsightStringFilterArgs>[]>;
        /**
         * An ISO8601-formatted timestamp that indicates when the security findings provider first observed the potential security issue that a finding captured.
         */
        firstObservedAt?: pulumi.Input<pulumi.Input<inputs.securityhub.InsightDateFilterArgs>[]>;
        /**
         * The identifier for the solution-specific component (a discrete unit of logic) that generated a finding.
         */
        generatorId?: pulumi.Input<pulumi.Input<inputs.securityhub.InsightStringFilterArgs>[]>;
        /**
         * The security findings provider-specific identifier for a finding.
         */
        id?: pulumi.Input<pulumi.Input<inputs.securityhub.InsightStringFilterArgs>[]>;
        /**
         * A keyword for a finding.
         */
        keyword?: pulumi.Input<pulumi.Input<inputs.securityhub.InsightKeywordFilterArgs>[]>;
        /**
         * An ISO8601-formatted timestamp that indicates when the security findings provider most recently observed the potential security issue that a finding captured.
         */
        lastObservedAt?: pulumi.Input<pulumi.Input<inputs.securityhub.InsightDateFilterArgs>[]>;
        /**
         * The name of the malware that was observed.
         */
        malwareName?: pulumi.Input<pulumi.Input<inputs.securityhub.InsightStringFilterArgs>[]>;
        /**
         * The filesystem path of the malware that was observed.
         */
        malwarePath?: pulumi.Input<pulumi.Input<inputs.securityhub.InsightStringFilterArgs>[]>;
        /**
         * The state of the malware that was observed.
         */
        malwareState?: pulumi.Input<pulumi.Input<inputs.securityhub.InsightStringFilterArgs>[]>;
        /**
         * The type of the malware that was observed.
         */
        malwareType?: pulumi.Input<pulumi.Input<inputs.securityhub.InsightStringFilterArgs>[]>;
        /**
         * The destination domain of network-related information about a finding.
         */
        networkDestinationDomain?: pulumi.Input<pulumi.Input<inputs.securityhub.InsightStringFilterArgs>[]>;
        /**
         * The destination IPv4 address of network-related information about a finding.
         */
        networkDestinationIpV4?: pulumi.Input<pulumi.Input<inputs.securityhub.InsightIpFilterArgs>[]>;
        /**
         * The destination IPv6 address of network-related information about a finding.
         */
        networkDestinationIpV6?: pulumi.Input<pulumi.Input<inputs.securityhub.InsightIpFilterArgs>[]>;
        /**
         * The destination port of network-related information about a finding.
         */
        networkDestinationPort?: pulumi.Input<pulumi.Input<inputs.securityhub.InsightNumberFilterArgs>[]>;
        /**
         * Indicates the direction of network traffic associated with a finding.
         */
        networkDirection?: pulumi.Input<pulumi.Input<inputs.securityhub.InsightStringFilterArgs>[]>;
        /**
         * The protocol of network-related information about a finding.
         */
        networkProtocol?: pulumi.Input<pulumi.Input<inputs.securityhub.InsightStringFilterArgs>[]>;
        /**
         * The source domain of network-related information about a finding.
         */
        networkSourceDomain?: pulumi.Input<pulumi.Input<inputs.securityhub.InsightStringFilterArgs>[]>;
        /**
         * The source IPv4 address of network-related information about a finding.
         */
        networkSourceIpV4?: pulumi.Input<pulumi.Input<inputs.securityhub.InsightIpFilterArgs>[]>;
        /**
         * The source IPv6 address of network-related information about a finding.
         */
        networkSourceIpV6?: pulumi.Input<pulumi.Input<inputs.securityhub.InsightIpFilterArgs>[]>;
        /**
         * The source media access control (MAC) address of network-related information about a finding.
         */
        networkSourceMac?: pulumi.Input<pulumi.Input<inputs.securityhub.InsightStringFilterArgs>[]>;
        /**
         * The source port of network-related information about a finding.
         */
        networkSourcePort?: pulumi.Input<pulumi.Input<inputs.securityhub.InsightNumberFilterArgs>[]>;
        /**
         * The text of a note.
         */
        noteText?: pulumi.Input<pulumi.Input<inputs.securityhub.InsightStringFilterArgs>[]>;
        /**
         * The timestamp of when the note was updated.
         */
        noteUpdatedAt?: pulumi.Input<pulumi.Input<inputs.securityhub.InsightDateFilterArgs>[]>;
        /**
         * The principal that created a note.
         */
        noteUpdatedBy?: pulumi.Input<pulumi.Input<inputs.securityhub.InsightStringFilterArgs>[]>;
        /**
         * A timestamp that identifies when the process was launched.
         */
        processLaunchedAt?: pulumi.Input<pulumi.Input<inputs.securityhub.InsightDateFilterArgs>[]>;
        /**
         * The name of the process.
         */
        processName?: pulumi.Input<pulumi.Input<inputs.securityhub.InsightStringFilterArgs>[]>;
        /**
         * The parent process ID.
         */
        processParentPid?: pulumi.Input<pulumi.Input<inputs.securityhub.InsightNumberFilterArgs>[]>;
        /**
         * The path to the process executable.
         */
        processPath?: pulumi.Input<pulumi.Input<inputs.securityhub.InsightStringFilterArgs>[]>;
        /**
         * The process ID.
         */
        processPid?: pulumi.Input<pulumi.Input<inputs.securityhub.InsightNumberFilterArgs>[]>;
        /**
         * A timestamp that identifies when the process was terminated.
         */
        processTerminatedAt?: pulumi.Input<pulumi.Input<inputs.securityhub.InsightDateFilterArgs>[]>;
        /**
         * The ARN generated by Security Hub that uniquely identifies a third-party company (security findings provider) after this provider's product (solution that generates findings) is registered with Security Hub.
         */
        productArn?: pulumi.Input<pulumi.Input<inputs.securityhub.InsightStringFilterArgs>[]>;
        /**
         * A data type where security findings providers can include additional solution-specific details that aren't part of the defined AwsSecurityFinding format.
         */
        productFields?: pulumi.Input<pulumi.Input<inputs.securityhub.InsightMapFilterArgs>[]>;
        /**
         * The name of the solution (product) that generates findings.
         */
        productName?: pulumi.Input<pulumi.Input<inputs.securityhub.InsightStringFilterArgs>[]>;
        /**
         * The recommendation of what to do about the issue described in a finding.
         */
        recommendationText?: pulumi.Input<pulumi.Input<inputs.securityhub.InsightStringFilterArgs>[]>;
        /**
         * The updated record state for the finding.
         */
        recordState?: pulumi.Input<pulumi.Input<inputs.securityhub.InsightStringFilterArgs>[]>;
        /**
         * The Region from which the finding was generated.
         */
        region?: pulumi.Input<pulumi.Input<inputs.securityhub.InsightStringFilterArgs>[]>;
        /**
         * The solution-generated identifier for a related finding.
         */
        relatedFindingsId?: pulumi.Input<pulumi.Input<inputs.securityhub.InsightStringFilterArgs>[]>;
        /**
         * The ARN of the solution that generated a related finding.
         */
        relatedFindingsProductArn?: pulumi.Input<pulumi.Input<inputs.securityhub.InsightStringFilterArgs>[]>;
        /**
         * The ARN of the application that is related to a finding.
         */
        resourceApplicationArn?: pulumi.Input<pulumi.Input<inputs.securityhub.InsightStringFilterArgs>[]>;
        /**
         * The name of the application that is related to a finding.
         */
        resourceApplicationName?: pulumi.Input<pulumi.Input<inputs.securityhub.InsightStringFilterArgs>[]>;
        /**
         * The IAM profile ARN of the instance.
         */
        resourceAwsEc2InstanceIamInstanceProfileArn?: pulumi.Input<pulumi.Input<inputs.securityhub.InsightStringFilterArgs>[]>;
        /**
         * The Amazon Machine Image (AMI) ID of the instance.
         */
        resourceAwsEc2InstanceImageId?: pulumi.Input<pulumi.Input<inputs.securityhub.InsightStringFilterArgs>[]>;
        /**
         * The IPv4 addresses associated with the instance.
         */
        resourceAwsEc2InstanceIpV4Addresses?: pulumi.Input<pulumi.Input<inputs.securityhub.InsightIpFilterArgs>[]>;
        /**
         * The IPv6 addresses associated with the instance.
         */
        resourceAwsEc2InstanceIpV6Addresses?: pulumi.Input<pulumi.Input<inputs.securityhub.InsightIpFilterArgs>[]>;
        /**
         * The key name associated with the instance.
         */
        resourceAwsEc2InstanceKeyName?: pulumi.Input<pulumi.Input<inputs.securityhub.InsightStringFilterArgs>[]>;
        /**
         * The date and time the instance was launched.
         */
        resourceAwsEc2InstanceLaunchedAt?: pulumi.Input<pulumi.Input<inputs.securityhub.InsightDateFilterArgs>[]>;
        /**
         * The identifier of the subnet that the instance was launched in.
         */
        resourceAwsEc2InstanceSubnetId?: pulumi.Input<pulumi.Input<inputs.securityhub.InsightStringFilterArgs>[]>;
        /**
         * The instance type of the instance.
         */
        resourceAwsEc2InstanceType?: pulumi.Input<pulumi.Input<inputs.securityhub.InsightStringFilterArgs>[]>;
        /**
         * The identifier of the VPC that the instance was launched in.
         */
        resourceAwsEc2InstanceVpcId?: pulumi.Input<pulumi.Input<inputs.securityhub.InsightStringFilterArgs>[]>;
        /**
         * The creation date/time of the IAM access key related to a finding.
         */
        resourceAwsIamAccessKeyCreatedAt?: pulumi.Input<pulumi.Input<inputs.securityhub.InsightDateFilterArgs>[]>;
        /**
         * The name of the principal that is associated with an IAM access key.
         */
        resourceAwsIamAccessKeyPrincipalName?: pulumi.Input<pulumi.Input<inputs.securityhub.InsightStringFilterArgs>[]>;
        /**
         * The status of the IAM access key related to a finding.
         */
        resourceAwsIamAccessKeyStatus?: pulumi.Input<pulumi.Input<inputs.securityhub.InsightStringFilterArgs>[]>;
        /**
         * The user associated with the IAM access key related to a finding.
         */
        resourceAwsIamAccessKeyUserName?: pulumi.Input<pulumi.Input<inputs.securityhub.InsightStringFilterArgs>[]>;
        /**
         * The name of an IAM user.
         */
        resourceAwsIamUserUserName?: pulumi.Input<pulumi.Input<inputs.securityhub.InsightStringFilterArgs>[]>;
        /**
         * The canonical user ID of the owner of the S3 bucket.
         */
        resourceAwsS3BucketOwnerId?: pulumi.Input<pulumi.Input<inputs.securityhub.InsightStringFilterArgs>[]>;
        /**
         * The display name of the owner of the S3 bucket.
         */
        resourceAwsS3BucketOwnerName?: pulumi.Input<pulumi.Input<inputs.securityhub.InsightStringFilterArgs>[]>;
        /**
         * The identifier of the image related to a finding.
         */
        resourceContainerImageId?: pulumi.Input<pulumi.Input<inputs.securityhub.InsightStringFilterArgs>[]>;
        /**
         * The name of the image related to a finding.
         */
        resourceContainerImageName?: pulumi.Input<pulumi.Input<inputs.securityhub.InsightStringFilterArgs>[]>;
        /**
         * A timestamp that identifies when the container was started.
         */
        resourceContainerLaunchedAt?: pulumi.Input<pulumi.Input<inputs.securityhub.InsightDateFilterArgs>[]>;
        /**
         * The name of the container related to a finding.
         */
        resourceContainerName?: pulumi.Input<pulumi.Input<inputs.securityhub.InsightStringFilterArgs>[]>;
        /**
         * The details of a resource that doesn't have a specific subfield for the resource type defined.
         */
        resourceDetailsOther?: pulumi.Input<pulumi.Input<inputs.securityhub.InsightMapFilterArgs>[]>;
        /**
         * The canonical identifier for the given resource type.
         */
        resourceId?: pulumi.Input<pulumi.Input<inputs.securityhub.InsightStringFilterArgs>[]>;
        /**
         * The canonical AWS partition name that the Region is assigned to.
         */
        resourcePartition?: pulumi.Input<pulumi.Input<inputs.securityhub.InsightStringFilterArgs>[]>;
        /**
         * The canonical AWS external Region name where this resource is located.
         */
        resourceRegion?: pulumi.Input<pulumi.Input<inputs.securityhub.InsightStringFilterArgs>[]>;
        /**
         * A list of AWS tags associated with a resource at the time the finding was processed.
         */
        resourceTags?: pulumi.Input<pulumi.Input<inputs.securityhub.InsightMapFilterArgs>[]>;
        /**
         * Specifies the type of the resource that details are provided for.
         */
        resourceType?: pulumi.Input<pulumi.Input<inputs.securityhub.InsightStringFilterArgs>[]>;
        /**
         * Indicates whether or not sample findings are included in the filter results.
         */
        sample?: pulumi.Input<pulumi.Input<inputs.securityhub.InsightBooleanFilterArgs>[]>;
        /**
         * The label of a finding's severity.
         */
        severityLabel?: pulumi.Input<pulumi.Input<inputs.securityhub.InsightStringFilterArgs>[]>;
        /**
         * The normalized severity of a finding.
         */
        severityNormalized?: pulumi.Input<pulumi.Input<inputs.securityhub.InsightNumberFilterArgs>[]>;
        /**
         * The native severity as defined by the security findings provider's solution that generated the finding.
         */
        severityProduct?: pulumi.Input<pulumi.Input<inputs.securityhub.InsightNumberFilterArgs>[]>;
        /**
         * A URL that links to a page about the current finding in the security findings provider's solution.
         */
        sourceUrl?: pulumi.Input<pulumi.Input<inputs.securityhub.InsightStringFilterArgs>[]>;
        /**
         * The category of a threat intelligence indicator.
         */
        threatIntelIndicatorCategory?: pulumi.Input<pulumi.Input<inputs.securityhub.InsightStringFilterArgs>[]>;
        /**
         * A timestamp that identifies the last observation of a threat intelligence indicator.
         */
        threatIntelIndicatorLastObservedAt?: pulumi.Input<pulumi.Input<inputs.securityhub.InsightDateFilterArgs>[]>;
        /**
         * The source of the threat intelligence.
         */
        threatIntelIndicatorSource?: pulumi.Input<pulumi.Input<inputs.securityhub.InsightStringFilterArgs>[]>;
        /**
         * The URL for more details from the source of the threat intelligence.
         */
        threatIntelIndicatorSourceUrl?: pulumi.Input<pulumi.Input<inputs.securityhub.InsightStringFilterArgs>[]>;
        /**
         * The type of a threat intelligence indicator.
         */
        threatIntelIndicatorType?: pulumi.Input<pulumi.Input<inputs.securityhub.InsightStringFilterArgs>[]>;
        /**
         * The value of a threat intelligence indicator.
         */
        threatIntelIndicatorValue?: pulumi.Input<pulumi.Input<inputs.securityhub.InsightStringFilterArgs>[]>;
        /**
         * A finding's title.
         */
        title?: pulumi.Input<pulumi.Input<inputs.securityhub.InsightStringFilterArgs>[]>;
        /**
         * A finding type in the format of namespace/category/classifier that classifies a finding.
         */
        type?: pulumi.Input<pulumi.Input<inputs.securityhub.InsightStringFilterArgs>[]>;
        /**
         * An ISO8601-formatted timestamp that indicates when the security findings provider last updated the finding record.
         */
        updatedAt?: pulumi.Input<pulumi.Input<inputs.securityhub.InsightDateFilterArgs>[]>;
        /**
         * A list of name/value string pairs associated with the finding.
         */
        userDefinedFields?: pulumi.Input<pulumi.Input<inputs.securityhub.InsightMapFilterArgs>[]>;
        /**
         * The veracity of a finding.
         */
        verificationState?: pulumi.Input<pulumi.Input<inputs.securityhub.InsightStringFilterArgs>[]>;
        /**
         * Indicates whether a software vulnerability in your environment has a known exploit.
         */
        vulnerabilitiesExploitAvailable?: pulumi.Input<pulumi.Input<inputs.securityhub.InsightStringFilterArgs>[]>;
        /**
         * Indicates whether a vulnerability is fixed in a newer version of the affected software packages.
         */
        vulnerabilitiesFixAvailable?: pulumi.Input<pulumi.Input<inputs.securityhub.InsightStringFilterArgs>[]>;
        /**
         * The workflow state of a finding.
         */
        workflowState?: pulumi.Input<pulumi.Input<inputs.securityhub.InsightStringFilterArgs>[]>;
        /**
         * The status of the investigation into a finding.
         */
        workflowStatus?: pulumi.Input<pulumi.Input<inputs.securityhub.InsightStringFilterArgs>[]>;
    }
    /**
     * Boolean filter for querying findings.
     */
    interface InsightBooleanFilterArgs {
        /**
         * The value of the boolean.
         */
        value: pulumi.Input<boolean>;
    }
    /**
     * A date filter for querying findings.
     */
    interface InsightDateFilterArgs {
        /**
         * A date range for the date filter.
         */
        dateRange?: pulumi.Input<inputs.securityhub.InsightDateRangeArgs>;
        /**
         * A timestamp that provides the end date for the date filter.
         *
         * For more information about the validation and formatting of timestamp fields in AWS Security Hub , see [Timestamps](https://docs.aws.amazon.com/securityhub/1.0/APIReference/Welcome.html#timestamps) .
         */
        end?: pulumi.Input<string>;
        /**
         * A timestamp that provides the start date for the date filter.
         *
         * For more information about the validation and formatting of timestamp fields in AWS Security Hub , see [Timestamps](https://docs.aws.amazon.com/securityhub/1.0/APIReference/Welcome.html#timestamps) .
         */
        start?: pulumi.Input<string>;
    }
    /**
     * A date range for the date filter.
     */
    interface InsightDateRangeArgs {
        /**
         * A date range unit for the date filter.
         */
        unit: pulumi.Input<enums.securityhub.InsightDateRangeUnit>;
        /**
         * A date range value for the date filter.
         */
        value: pulumi.Input<number>;
    }
    /**
     * The IP filter for querying findings.
     */
    interface InsightIpFilterArgs {
        /**
         * A finding's CIDR value.
         */
        cidr: pulumi.Input<string>;
    }
    /**
     * A keyword filter for querying findings.
     */
    interface InsightKeywordFilterArgs {
        /**
         * A value for the keyword.
         */
        value: pulumi.Input<string>;
    }
    /**
     * A map filter for filtering AWS Security Hub findings.
     */
    interface InsightMapFilterArgs {
        /**
         * The condition to apply to the key value when filtering Security Hub findings with a map filter.
         */
        comparison: pulumi.Input<enums.securityhub.InsightMapFilterComparison>;
        /**
         * The key of the map filter. For example, for `ResourceTags` , `Key` identifies the name of the tag. For `UserDefinedFields` , `Key` is the name of the field.
         */
        key: pulumi.Input<string>;
        /**
         * The value for the key in the map filter. Filter values are case sensitive. For example, one of the values for a tag called `Department` might be `Security` . If you provide `security` as the filter value, then there's no match.
         */
        value: pulumi.Input<string>;
    }
    /**
     * A number filter for querying findings.
     */
    interface InsightNumberFilterArgs {
        /**
         * The equal-to condition to be applied to a single field when querying for findings.
         */
        eq?: pulumi.Input<number>;
        /**
         * The greater-than-equal condition to be applied to a single field when querying for findings.
         */
        gte?: pulumi.Input<number>;
        /**
         * The less-than-equal condition to be applied to a single field when querying for findings.
         */
        lte?: pulumi.Input<number>;
    }
    /**
     * A string filter for filtering AWS Security Hub findings.
     */
    interface InsightStringFilterArgs {
        /**
         * The condition to apply to a string value when filtering Security Hub findings.
         *
         * To search for values that have the filter value, use one of the following comparison operators:
         *
         * - To search for values that include the filter value, use `CONTAINS` . For example, the filter `Title CONTAINS CloudFront` matches findings that have a `Title` that includes the string CloudFront.
         * - To search for values that exactly match the filter value, use `EQUALS` . For example, the filter `AwsAccountId EQUALS 123456789012` only matches findings that have an account ID of `123456789012` .
         * - To search for values that start with the filter value, use `PREFIX` . For example, the filter `ResourceRegion PREFIX us` matches findings that have a `ResourceRegion` that starts with `us` . A `ResourceRegion` that starts with a different value, such as `af` , `ap` , or `ca` , doesn't match.
         *
         * `CONTAINS` , `EQUALS` , and `PREFIX` filters on the same field are joined by `OR` . A finding matches if it matches any one of those filters. For example, the filters `Title CONTAINS CloudFront OR Title CONTAINS CloudWatch` match a finding that includes either `CloudFront` , `CloudWatch` , or both strings in the title.
         *
         * To search for values that don’t have the filter value, use one of the following comparison operators:
         *
         * - To search for values that exclude the filter value, use `NOT_CONTAINS` . For example, the filter `Title NOT_CONTAINS CloudFront` matches findings that have a `Title` that excludes the string CloudFront.
         * - To search for values other than the filter value, use `NOT_EQUALS` . For example, the filter `AwsAccountId NOT_EQUALS 123456789012` only matches findings that have an account ID other than `123456789012` .
         * - To search for values that don't start with the filter value, use `PREFIX_NOT_EQUALS` . For example, the filter `ResourceRegion PREFIX_NOT_EQUALS us` matches findings with a `ResourceRegion` that starts with a value other than `us` .
         *
         * `NOT_CONTAINS` , `NOT_EQUALS` , and `PREFIX_NOT_EQUALS` filters on the same field are joined by `AND` . A finding matches only if it matches all of those filters. For example, the filters `Title NOT_CONTAINS CloudFront AND Title NOT_CONTAINS CloudWatch` match a finding that excludes both `CloudFront` and `CloudWatch` in the title.
         *
         * You can’t have both a `CONTAINS` filter and a `NOT_CONTAINS` filter on the same field. Similarly, you can't provide both an `EQUALS` filter and a `NOT_EQUALS` or `PREFIX_NOT_EQUALS` filter on the same field. Combining filters in this way returns an error. `CONTAINS` filters can only be used with other `CONTAINS` filters. `NOT_CONTAINS` filters can only be used with other `NOT_CONTAINS` filters.
         *
         * You can combine `PREFIX` filters with `NOT_EQUALS` or `PREFIX_NOT_EQUALS` filters for the same field. Security Hub first processes the `PREFIX` filters, and then the `NOT_EQUALS` or `PREFIX_NOT_EQUALS` filters.
         *
         * For example, for the following filters, Security Hub first identifies findings that have resource types that start with either `AwsIam` or `AwsEc2` . It then excludes findings that have a resource type of `AwsIamPolicy` and findings that have a resource type of `AwsEc2NetworkInterface` .
         *
         * - `ResourceType PREFIX AwsIam`
         * - `ResourceType PREFIX AwsEc2`
         * - `ResourceType NOT_EQUALS AwsIamPolicy`
         * - `ResourceType NOT_EQUALS AwsEc2NetworkInterface`
         *
         * `CONTAINS` and `NOT_CONTAINS` operators can be used only with automation rules. For more information, see [Automation rules](https://docs.aws.amazon.com/securityhub/latest/userguide/automation-rules.html) in the *AWS Security Hub User Guide* .
         */
        comparison: pulumi.Input<enums.securityhub.InsightStringFilterComparison>;
        /**
         * The string filter value. Filter values are case sensitive. For example, the product name for control-based findings is `Security Hub` . If you provide `security hub` as the filter value, there's no match.
         */
        value: pulumi.Input<string>;
    }
    interface SecurityControlParameterConfigurationArgs {
        /**
         * The current value of a control parameter.
         */
        value?: pulumi.Input<inputs.securityhub.SecurityControlParameterValueArgs>;
        /**
         * Identifies whether a control parameter uses a custom user-defined value or subscribes to the default AWS Security Hub behavior.
         *
         * When `ValueType` is set equal to `DEFAULT` , the default behavior can be a specific Security Hub default value, or the default behavior can be to ignore a specific parameter. When `ValueType` is set equal to `DEFAULT` , Security Hub ignores user-provided input for the `Value` field.
         *
         * When `ValueType` is set equal to `CUSTOM` , the `Value` field can't be empty.
         */
        valueType: pulumi.Input<enums.securityhub.SecurityControlParameterConfigurationValueType>;
    }
    interface SecurityControlParameterValueArgs {
        /**
         * A control parameter that is a boolean.
         */
        boolean?: pulumi.Input<boolean>;
        /**
         * A control parameter that is a double.
         */
        double?: pulumi.Input<number>;
        /**
         * A control parameter that is a enum.
         */
        enum?: pulumi.Input<string>;
        /**
         * A control parameter that is a list of enums.
         */
        enumList?: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * A control parameter that is a integer.
         */
        integer?: pulumi.Input<number>;
        /**
         * A control parameter that is a list of integers.
         */
        integerList?: pulumi.Input<pulumi.Input<number>[]>;
        /**
         * A control parameter that is a string.
         */
        string?: pulumi.Input<string>;
        /**
         * A control parameter that is a list of strings.
         */
        stringList?: pulumi.Input<pulumi.Input<string>[]>;
    }
    /**
     * Provides details about an individual security control. For a list of ASH controls, see [controls reference](https://docs.aws.amazon.com/securityhub/latest/userguide/securityhub-controls-reference.html) in the *User Guide*.
     */
    interface StandardsControlArgs {
        /**
         * A user-defined reason for changing a control's enablement status in a specified standard. If you are disabling a control, then this property is required.
         */
        reason?: pulumi.Input<string>;
        /**
         * The Amazon Resource Name (ARN) of the control.
         */
        standardsControlArn: pulumi.Input<string>;
    }
}
export declare namespace securitylake {
    /**
     * Provides encryption details of Amazon Security Lake object.
     */
    interface DataLakeEncryptionConfigurationArgs {
        /**
         * The id of KMS encryption key used by Amazon Security Lake to encrypt the Security Lake object.
         */
        kmsKeyId?: pulumi.Input<string>;
    }
    /**
     * Provides data expiration details of Amazon Security Lake object.
     */
    interface DataLakeExpirationArgs {
        /**
         * The number of days before data expires in the Amazon Security Lake object.
         */
        days?: pulumi.Input<number>;
    }
    /**
     * Provides lifecycle details of Amazon Security Lake object.
     */
    interface DataLakeLifecycleConfigurationArgs {
        /**
         * Provides data expiration details of the Amazon Security Lake object.
         */
        expiration?: pulumi.Input<inputs.securitylake.DataLakeExpirationArgs>;
        /**
         * Provides data storage transition details of Amazon Security Lake object.
         */
        transitions?: pulumi.Input<pulumi.Input<inputs.securitylake.DataLakeTransitionsArgs>[]>;
    }
    /**
     * Provides replication details of Amazon Security Lake object.
     */
    interface DataLakeReplicationConfigurationArgs {
        /**
         * Specifies one or more centralized rollup Regions. The AWS Region specified in the region parameter of the `CreateDataLake` or `UpdateDataLake` operations contributes data to the rollup Region or Regions specified in this parameter.
         *
         * Replication enables automatic, asynchronous copying of objects across Amazon S3 buckets. S3 buckets that are configured for object replication can be owned by the same AWS account or by different accounts. You can replicate objects to a single destination bucket or to multiple destination buckets. The destination buckets can be in different Regions or within the same Region as the source bucket.
         */
        regions?: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * Replication settings for the Amazon S3 buckets. This parameter uses the AWS Identity and Access Management (IAM) role you created that is managed by Security Lake, to ensure the replication setting is correct.
         */
        roleArn?: pulumi.Input<string>;
    }
    interface DataLakeTransitionsArgs {
        /**
         * Number of days before data transitions to a different S3 Storage Class in the Amazon Security Lake object.
         */
        days?: pulumi.Input<number>;
        /**
         * The range of storage classes that you can choose from based on the data access, resiliency, and cost requirements of your workloads.
         */
        storageClass?: pulumi.Input<string>;
    }
    /**
     * Amazon Security Lake supports log and event collection for natively supported AWS services.
     */
    interface SubscriberAwsLogSourceArgs {
        /**
         * The name for a AWS source. This must be a Regionally unique value.
         */
        sourceName?: pulumi.Input<string>;
        /**
         * The version for a AWS source. This must be a Regionally unique value.
         */
        sourceVersion?: pulumi.Input<string>;
    }
    interface SubscriberCustomLogSourceArgs {
        /**
         * The name for a third-party custom source. This must be a Regionally unique value.
         */
        sourceName?: pulumi.Input<string>;
        /**
         * The version for a third-party custom source. This must be a Regionally unique value.
         */
        sourceVersion?: pulumi.Input<string>;
    }
    /**
     * The AWS identity used to access your data.
     */
    interface SubscriberIdentityPropertiesArgs {
        /**
         * The external ID used to establish trust relationship with the AWS identity.
         */
        externalId: pulumi.Input<string>;
        /**
         * The AWS identity principal.
         */
        principal: pulumi.Input<string>;
    }
    /**
     * The configuration for HTTPS subscriber notification.
     */
    interface SubscriberNotificationHttpsNotificationConfigurationArgs {
        /**
         * The key name for the notification subscription.
         */
        authorizationApiKeyName?: pulumi.Input<string>;
        /**
         * The key value for the notification subscription.
         */
        authorizationApiKeyValue?: pulumi.Input<string>;
        /**
         * The subscription endpoint in Security Lake.
         */
        endpoint: pulumi.Input<string>;
        /**
         * The HTTPS method used for the notification subscription.
         */
        httpMethod?: pulumi.Input<enums.securitylake.SubscriberNotificationHttpsNotificationConfigurationHttpMethod>;
        /**
         * The Amazon Resource Name (ARN) of the EventBridge API destinations IAM role that you created.
         */
        targetRoleArn: pulumi.Input<string>;
    }
    interface SubscriberNotificationNotificationConfigurationArgs {
        /**
         * The configurations used for HTTPS subscriber notification.
         */
        httpsNotificationConfiguration?: pulumi.Input<inputs.securitylake.SubscriberNotificationHttpsNotificationConfigurationArgs>;
        /**
         * The configurations for SQS subscriber notification. The members of this structure are context-dependent.
         */
        sqsNotificationConfiguration?: pulumi.Input<inputs.securitylake.SubscriberNotificationSqsNotificationConfigurationArgs>;
    }
    /**
     * The configurations for SQS subscriber notification. The members of this structure are context-dependent.
     */
    interface SubscriberNotificationSqsNotificationConfigurationArgs {
    }
    interface SubscriberSourceArgs {
        awsLogSource?: pulumi.Input<inputs.securitylake.SubscriberAwsLogSourceArgs>;
        customLogSource?: pulumi.Input<inputs.securitylake.SubscriberCustomLogSourceArgs>;
    }
}
export declare namespace servicecatalog {
    interface CloudFormationProvisionedProductProvisioningParameterArgs {
        /**
         * The parameter key.
         */
        key: pulumi.Input<string>;
        /**
         * The parameter value.
         */
        value: pulumi.Input<string>;
    }
    interface CloudFormationProvisionedProductProvisioningPreferencesArgs {
        /**
         * One or more AWS accounts where the provisioned product will be available.
         *
         * Applicable only to a `CFN_STACKSET` provisioned product type.
         *
         * The specified accounts should be within the list of accounts from the `STACKSET` constraint. To get the list of accounts in the `STACKSET` constraint, use the `DescribeProvisioningParameters` operation.
         *
         * If no values are specified, the default value is all acounts from the `STACKSET` constraint.
         */
        stackSetAccounts?: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * The number of accounts, per Region, for which this operation can fail before AWS Service Catalog stops the operation in that Region. If the operation is stopped in a Region, AWS Service Catalog doesn't attempt the operation in any subsequent Regions.
         *
         * Applicable only to a `CFN_STACKSET` provisioned product type.
         *
         * Conditional: You must specify either `StackSetFailureToleranceCount` or `StackSetFailureTolerancePercentage` , but not both.
         *
         * The default value is `0` if no value is specified.
         */
        stackSetFailureToleranceCount?: pulumi.Input<number>;
        /**
         * The percentage of accounts, per Region, for which this stack operation can fail before AWS Service Catalog stops the operation in that Region. If the operation is stopped in a Region, AWS Service Catalog doesn't attempt the operation in any subsequent Regions.
         *
         * When calculating the number of accounts based on the specified percentage, AWS Service Catalog rounds down to the next whole number.
         *
         * Applicable only to a `CFN_STACKSET` provisioned product type.
         *
         * Conditional: You must specify either `StackSetFailureToleranceCount` or `StackSetFailureTolerancePercentage` , but not both.
         */
        stackSetFailureTolerancePercentage?: pulumi.Input<number>;
        /**
         * The maximum number of accounts in which to perform this operation at one time. This is dependent on the value of `StackSetFailureToleranceCount` . `StackSetMaxConcurrentCount` is at most one more than the `StackSetFailureToleranceCount` .
         *
         * Note that this setting lets you specify the maximum for operations. For large deployments, under certain circumstances the actual number of accounts acted upon concurrently may be lower due to service throttling.
         *
         * Applicable only to a `CFN_STACKSET` provisioned product type.
         *
         * Conditional: You must specify either `StackSetMaxConcurrentCount` or `StackSetMaxConcurrentPercentage` , but not both.
         */
        stackSetMaxConcurrencyCount?: pulumi.Input<number>;
        /**
         * The maximum percentage of accounts in which to perform this operation at one time.
         *
         * When calculating the number of accounts based on the specified percentage, AWS Service Catalog rounds down to the next whole number. This is true except in cases where rounding down would result is zero. In this case, AWS Service Catalog sets the number as `1` instead.
         *
         * Note that this setting lets you specify the maximum for operations. For large deployments, under certain circumstances the actual number of accounts acted upon concurrently may be lower due to service throttling.
         *
         * Applicable only to a `CFN_STACKSET` provisioned product type.
         *
         * Conditional: You must specify either `StackSetMaxConcurrentCount` or `StackSetMaxConcurrentPercentage` , but not both.
         */
        stackSetMaxConcurrencyPercentage?: pulumi.Input<number>;
        /**
         * Determines what action AWS Service Catalog performs to a stack set or a stack instance represented by the provisioned product. The default value is `UPDATE` if nothing is specified.
         *
         * Applicable only to a `CFN_STACKSET` provisioned product type.
         *
         * - **CREATE** - Creates a new stack instance in the stack set represented by the provisioned product. In this case, only new stack instances are created based on accounts and Regions; if new ProductId or ProvisioningArtifactID are passed, they will be ignored.
         * - **UPDATE** - Updates the stack set represented by the provisioned product and also its stack instances.
         * - **DELETE** - Deletes a stack instance in the stack set represented by the provisioned product.
         */
        stackSetOperationType?: pulumi.Input<enums.servicecatalog.CloudFormationProvisionedProductProvisioningPreferencesStackSetOperationType>;
        /**
         * One or more AWS Regions where the provisioned product will be available.
         *
         * Applicable only to a `CFN_STACKSET` provisioned product type.
         *
         * The specified Regions should be within the list of Regions from the `STACKSET` constraint. To get the list of Regions in the `STACKSET` constraint, use the `DescribeProvisioningParameters` operation.
         *
         * If no values are specified, the default value is all Regions from the `STACKSET` constraint.
         */
        stackSetRegions?: pulumi.Input<pulumi.Input<string>[]>;
    }
    interface ServiceActionDefinitionParameterArgs {
        /**
         * The parameter key.
         */
        key: pulumi.Input<string>;
        /**
         * The value of the parameter.
         */
        value: pulumi.Input<string>;
    }
}
export declare namespace ses {
    /**
     * Preferences regarding the Dashboard feature.
     */
    interface ConfigurationSetDashboardOptionsArgs {
        /**
         * Whether emails sent with this configuration set have engagement tracking enabled.
         */
        engagementMetrics: pulumi.Input<string>;
    }
    /**
     * An object that defines the dedicated IP pool that is used to send emails that you send using the configuration set.
     */
    interface ConfigurationSetDeliveryOptionsArgs {
        /**
         * Specifies the maximum time until which SES will retry sending emails
         */
        maxDeliverySeconds?: pulumi.Input<number>;
        /**
         * The name of the dedicated IP pool to associate with the configuration set.
         */
        sendingPoolName?: pulumi.Input<string>;
        /**
         * Specifies whether messages that use the configuration set are required to use Transport Layer Security (TLS). If the value is Require , messages are only delivered if a TLS connection can be established. If the value is Optional , messages can be delivered in plain text if a TLS connection can't be established.
         */
        tlsPolicy?: pulumi.Input<string>;
    }
    /**
     * An object that contains the names, default values, and sources of the dimensions associated with an Amazon CloudWatch event destination.
     */
    interface ConfigurationSetEventDestinationCloudWatchDestinationArgs {
        /**
         * A list of dimensions upon which to categorize your emails when you publish email sending events to Amazon CloudWatch.
         */
        dimensionConfigurations?: pulumi.Input<pulumi.Input<inputs.ses.ConfigurationSetEventDestinationDimensionConfigurationArgs>[]>;
    }
    /**
     * A list of dimensions upon which to categorize your emails when you publish email sending events to Amazon CloudWatch.
     */
    interface ConfigurationSetEventDestinationDimensionConfigurationArgs {
        /**
         * The default value of the dimension that is published to Amazon CloudWatch if you do not provide the value of the dimension when you send an email.
         */
        defaultDimensionValue: pulumi.Input<string>;
        /**
         * The name of an Amazon CloudWatch dimension associated with an email sending metric.
         */
        dimensionName: pulumi.Input<string>;
        /**
         * The place where Amazon SES finds the value of a dimension to publish to Amazon CloudWatch. To use the message tags that you specify using an X-SES-MESSAGE-TAGS header or a parameter to the SendEmail/SendRawEmail API, specify messageTag. To use your own email headers, specify emailHeader. To put a custom tag on any link included in your email, specify linkTag.
         */
        dimensionValueSource: pulumi.Input<string>;
    }
    /**
     * An object that contains Event bus ARN associated with the event bridge destination.
     */
    interface ConfigurationSetEventDestinationEventBridgeDestinationArgs {
        /**
         * The Amazon Resource Name (ARN) of the Amazon EventBridge bus to publish email events to. Only the default bus is supported.
         */
        eventBusArn: pulumi.Input<string>;
    }
    interface ConfigurationSetEventDestinationEventDestinationArgs {
        /**
         * An object that contains the names, default values, and sources of the dimensions associated with an Amazon CloudWatch event destination.
         */
        cloudWatchDestination?: pulumi.Input<inputs.ses.ConfigurationSetEventDestinationCloudWatchDestinationArgs>;
        /**
         * Sets whether Amazon SES publishes events to this destination when you send an email with the associated configuration set. Set to true to enable publishing to this destination; set to false to prevent publishing to this destination. The default value is false.
         */
        enabled?: pulumi.Input<boolean>;
        /**
         * An object that contains Event bus ARN associated with the event bridge destination.
         */
        eventBridgeDestination?: pulumi.Input<inputs.ses.ConfigurationSetEventDestinationEventBridgeDestinationArgs>;
        /**
         * An object that contains the delivery stream ARN and the IAM role ARN associated with an Amazon Kinesis Firehose event destination.
         */
        kinesisFirehoseDestination?: pulumi.Input<inputs.ses.ConfigurationSetEventDestinationKinesisFirehoseDestinationArgs>;
        /**
         * The type of email sending events, send, reject, bounce, complaint, delivery, open, click, renderingFailure, deliveryDelay, and subscription.
         */
        matchingEventTypes: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * The name of the event destination set.
         */
        name?: pulumi.Input<string>;
        /**
         * An object that contains SNS topic ARN associated event destination.
         */
        snsDestination?: pulumi.Input<inputs.ses.ConfigurationSetEventDestinationSnsDestinationArgs>;
    }
    /**
     * An object that contains the delivery stream ARN and the IAM role ARN associated with an Amazon Kinesis Firehose event destination.
     */
    interface ConfigurationSetEventDestinationKinesisFirehoseDestinationArgs {
        /**
         * The ARN of the Amazon Kinesis Firehose stream that email sending events should be published to.
         */
        deliveryStreamArn: pulumi.Input<string>;
        /**
         * The ARN of the IAM role under which Amazon SES publishes email sending events to the Amazon Kinesis Firehose stream.
         */
        iamRoleArn: pulumi.Input<string>;
    }
    /**
     * An object that contains SNS topic ARN associated event destination.
     */
    interface ConfigurationSetEventDestinationSnsDestinationArgs {
        /**
         * The ARN of the Amazon SNS topic for email sending events. You can find the ARN of a topic by using the [ListTopics](https://docs.aws.amazon.com/sns/latest/api/API_ListTopics.html) Amazon SNS operation.
         *
         * For more information about Amazon SNS topics, see the [Amazon SNS Developer Guide](https://docs.aws.amazon.com/sns/latest/dg/CreateTopic.html) .
         */
        topicArn: pulumi.Input<string>;
    }
    /**
     * Preferences regarding the Guardian feature.
     */
    interface ConfigurationSetGuardianOptionsArgs {
        /**
         * Whether emails sent with this configuration set have optimized delivery algorithm enabled.
         */
        optimizedSharedDelivery: pulumi.Input<string>;
    }
    /**
     * An object that defines whether or not Amazon SES collects reputation metrics for the emails that you send that use the configuration set.
     */
    interface ConfigurationSetReputationOptionsArgs {
        /**
         * If true , tracking of reputation metrics is enabled for the configuration set. If false , tracking of reputation metrics is disabled for the configuration set.
         */
        reputationMetricsEnabled?: pulumi.Input<boolean>;
    }
    /**
     * An object that defines whether or not Amazon SES can send email that you send using the configuration set.
     */
    interface ConfigurationSetSendingOptionsArgs {
        /**
         * If `true` , email sending is enabled for the configuration set. If `false` , email sending is disabled for the configuration set.
         */
        sendingEnabled?: pulumi.Input<boolean>;
    }
    /**
     * An object that contains information about the suppression list preferences for your account.
     */
    interface ConfigurationSetSuppressionOptionsArgs {
        /**
         * A list that contains the reasons that email addresses are automatically added to the suppression list for your account.
         */
        suppressedReasons?: pulumi.Input<pulumi.Input<string>[]>;
    }
    /**
     * An object that defines the open and click tracking options for emails that you send using the configuration set.
     */
    interface ConfigurationSetTrackingOptionsArgs {
        /**
         * The domain to use for tracking open and click events.
         */
        customRedirectDomain?: pulumi.Input<string>;
        /**
         * The https policy to use for tracking open and click events.
         */
        httpsPolicy?: pulumi.Input<string>;
    }
    /**
     * An object that contains Virtual Deliverability Manager (VDM) settings for this configuration set.
     */
    interface ConfigurationSetVdmOptionsArgs {
        /**
         * Specifies additional settings for your VDM configuration as applicable to the Dashboard.
         */
        dashboardOptions?: pulumi.Input<inputs.ses.ConfigurationSetDashboardOptionsArgs>;
        /**
         * Specifies additional settings for your VDM configuration as applicable to the Guardian.
         */
        guardianOptions?: pulumi.Input<inputs.ses.ConfigurationSetGuardianOptionsArgs>;
    }
    interface ContactListTopicArgs {
        /**
         * The default subscription status to be applied to a contact if the contact has not noted their preference for subscribing to a topic.
         */
        defaultSubscriptionStatus: pulumi.Input<string>;
        /**
         * The description of the topic.
         */
        description?: pulumi.Input<string>;
        /**
         * The display name of the topic.
         */
        displayName: pulumi.Input<string>;
        /**
         * The name of the topic.
         */
        topicName: pulumi.Input<string>;
    }
    /**
     * Used to associate a configuration set with an email identity.
     */
    interface EmailIdentityConfigurationSetAttributesArgs {
        /**
         * The configuration set to use by default when sending from this identity. Note that any configuration set defined in the email sending request takes precedence.
         */
        configurationSetName?: pulumi.Input<string>;
    }
    /**
     * Used to enable or disable DKIM authentication for an email identity.
     */
    interface EmailIdentityDkimAttributesArgs {
        /**
         * Sets the DKIM signing configuration for the identity. When you set this value true, then the messages that are sent from the identity are signed using DKIM. If you set this value to false, your messages are sent without DKIM signing.
         */
        signingEnabled?: pulumi.Input<boolean>;
    }
    /**
     * If your request includes this object, Amazon SES configures the identity to use Bring Your Own DKIM (BYODKIM) for DKIM authentication purposes, or, configures the key length to be used for Easy DKIM.
     */
    interface EmailIdentityDkimSigningAttributesArgs {
        /**
         * [Bring Your Own DKIM] A private key that's used to generate a DKIM signature. The private key must use 1024 or 2048-bit RSA encryption, and must be encoded using base64 encoding.
         */
        domainSigningPrivateKey?: pulumi.Input<string>;
        /**
         * [Bring Your Own DKIM] A string that's used to identify a public key in the DNS configuration for a domain.
         */
        domainSigningSelector?: pulumi.Input<string>;
        /**
         * [Easy DKIM] The key length of the future DKIM key pair to be generated. This can be changed at most once per day.
         */
        nextSigningKeyLength?: pulumi.Input<string>;
    }
    /**
     * Used to enable or disable feedback forwarding for an identity.
     */
    interface EmailIdentityFeedbackAttributesArgs {
        /**
         * If the value is true, you receive email notifications when bounce or complaint events occur
         */
        emailForwardingEnabled?: pulumi.Input<boolean>;
    }
    /**
     * Used to enable or disable the custom Mail-From domain configuration for an email identity.
     */
    interface EmailIdentityMailFromAttributesArgs {
        /**
         * The action to take if the required MX record isn't found when you send an email. When you set this value to UseDefaultValue , the mail is sent using amazonses.com as the MAIL FROM domain. When you set this value to RejectMessage , the Amazon SES API v2 returns a MailFromDomainNotVerified error, and doesn't attempt to deliver the email.
         */
        behaviorOnMxFailure?: pulumi.Input<string>;
        /**
         * The custom MAIL FROM domain that you want the verified identity to use
         */
        mailFromDomain?: pulumi.Input<string>;
    }
    interface MailManagerArchiveArchiveRetentionPropertiesArgs {
        retentionPeriod: pulumi.Input<enums.ses.MailManagerArchiveRetentionPeriod>;
    }
    interface MailManagerIngressPointIngressPointConfiguration0PropertiesArgs {
        smtpPassword: pulumi.Input<string>;
    }
    interface MailManagerIngressPointIngressPointConfiguration1PropertiesArgs {
        secretArn: pulumi.Input<string>;
    }
    interface MailManagerIngressPointNetworkConfiguration0PropertiesArgs {
        publicNetworkConfiguration: pulumi.Input<inputs.ses.MailManagerIngressPointPublicNetworkConfigurationArgs>;
    }
    interface MailManagerIngressPointNetworkConfiguration1PropertiesArgs {
        privateNetworkConfiguration: pulumi.Input<inputs.ses.MailManagerIngressPointPrivateNetworkConfigurationArgs>;
    }
    interface MailManagerIngressPointPrivateNetworkConfigurationArgs {
        vpcEndpointId: pulumi.Input<string>;
    }
    interface MailManagerIngressPointPublicNetworkConfigurationArgs {
        ipType: any;
    }
    interface MailManagerRelayNoAuthenticationArgs {
    }
    interface MailManagerRelayRelayAuthentication0PropertiesArgs {
        secretArn: pulumi.Input<string>;
    }
    interface MailManagerRelayRelayAuthentication1PropertiesArgs {
        noAuthentication: pulumi.Input<inputs.ses.MailManagerRelayNoAuthenticationArgs>;
    }
    interface MailManagerRuleSetAddHeaderActionArgs {
        headerName: pulumi.Input<string>;
        headerValue: pulumi.Input<string>;
    }
    interface MailManagerRuleSetAnalysisArgs {
        analyzer: pulumi.Input<string>;
        resultField: pulumi.Input<string>;
    }
    interface MailManagerRuleSetArchiveActionArgs {
        actionFailurePolicy?: pulumi.Input<enums.ses.MailManagerRuleSetActionFailurePolicy>;
        targetArchive: pulumi.Input<string>;
    }
    interface MailManagerRuleSetDeliverToMailboxActionArgs {
        actionFailurePolicy?: pulumi.Input<enums.ses.MailManagerRuleSetActionFailurePolicy>;
        mailboxArn: pulumi.Input<string>;
        roleArn: pulumi.Input<string>;
    }
    interface MailManagerRuleSetDeliverToQBusinessActionArgs {
        actionFailurePolicy?: pulumi.Input<enums.ses.MailManagerRuleSetActionFailurePolicy>;
        applicationId: pulumi.Input<string>;
        indexId: pulumi.Input<string>;
        roleArn: pulumi.Input<string>;
    }
    interface MailManagerRuleSetDropActionArgs {
    }
    interface MailManagerRuleSetRelayActionArgs {
        actionFailurePolicy?: pulumi.Input<enums.ses.MailManagerRuleSetActionFailurePolicy>;
        mailFrom?: pulumi.Input<enums.ses.MailManagerRuleSetMailFrom>;
        relay: pulumi.Input<string>;
    }
    interface MailManagerRuleSetReplaceRecipientActionArgs {
        replaceWith?: pulumi.Input<pulumi.Input<string>[]>;
    }
    interface MailManagerRuleSetRuleArgs {
        /**
         * The list of actions to execute when the conditions match the incoming email, and none of the "unless conditions" match.
         */
        actions: pulumi.Input<pulumi.Input<inputs.ses.MailManagerRuleSetRuleAction0PropertiesArgs | inputs.ses.MailManagerRuleSetRuleAction1PropertiesArgs | inputs.ses.MailManagerRuleSetRuleAction2PropertiesArgs | inputs.ses.MailManagerRuleSetRuleAction3PropertiesArgs | inputs.ses.MailManagerRuleSetRuleAction4PropertiesArgs | inputs.ses.MailManagerRuleSetRuleAction5PropertiesArgs | inputs.ses.MailManagerRuleSetRuleAction6PropertiesArgs | inputs.ses.MailManagerRuleSetRuleAction7PropertiesArgs | inputs.ses.MailManagerRuleSetRuleAction8PropertiesArgs>[]>;
        /**
         * The conditions of this rule. All conditions must match the email for the actions to be executed. An empty list of conditions means that all emails match, but are still subject to any "unless conditions"
         */
        conditions?: pulumi.Input<pulumi.Input<inputs.ses.MailManagerRuleSetRuleCondition0PropertiesArgs | inputs.ses.MailManagerRuleSetRuleCondition1PropertiesArgs | inputs.ses.MailManagerRuleSetRuleCondition2PropertiesArgs | inputs.ses.MailManagerRuleSetRuleCondition3PropertiesArgs | inputs.ses.MailManagerRuleSetRuleCondition4PropertiesArgs | inputs.ses.MailManagerRuleSetRuleCondition5PropertiesArgs>[]>;
        /**
         * The user-friendly name of the rule.
         */
        name?: pulumi.Input<string>;
        /**
         * The "unless conditions" of this rule. None of the conditions can match the email for the actions to be executed. If any of these conditions do match the email, then the actions are not executed.
         */
        unless?: pulumi.Input<pulumi.Input<inputs.ses.MailManagerRuleSetRuleCondition0PropertiesArgs | inputs.ses.MailManagerRuleSetRuleCondition1PropertiesArgs | inputs.ses.MailManagerRuleSetRuleCondition2PropertiesArgs | inputs.ses.MailManagerRuleSetRuleCondition3PropertiesArgs | inputs.ses.MailManagerRuleSetRuleCondition4PropertiesArgs | inputs.ses.MailManagerRuleSetRuleCondition5PropertiesArgs>[]>;
    }
    interface MailManagerRuleSetRuleAction0PropertiesArgs {
        drop: pulumi.Input<inputs.ses.MailManagerRuleSetDropActionArgs>;
    }
    interface MailManagerRuleSetRuleAction1PropertiesArgs {
        relay: pulumi.Input<inputs.ses.MailManagerRuleSetRelayActionArgs>;
    }
    interface MailManagerRuleSetRuleAction2PropertiesArgs {
        archive: pulumi.Input<inputs.ses.MailManagerRuleSetArchiveActionArgs>;
    }
    interface MailManagerRuleSetRuleAction3PropertiesArgs {
        writeToS3: pulumi.Input<inputs.ses.MailManagerRuleSetS3ActionArgs>;
    }
    interface MailManagerRuleSetRuleAction4PropertiesArgs {
        send: pulumi.Input<inputs.ses.MailManagerRuleSetSendActionArgs>;
    }
    interface MailManagerRuleSetRuleAction5PropertiesArgs {
        addHeader: pulumi.Input<inputs.ses.MailManagerRuleSetAddHeaderActionArgs>;
    }
    interface MailManagerRuleSetRuleAction6PropertiesArgs {
        replaceRecipient: pulumi.Input<inputs.ses.MailManagerRuleSetReplaceRecipientActionArgs>;
    }
    interface MailManagerRuleSetRuleAction7PropertiesArgs {
        deliverToMailbox: pulumi.Input<inputs.ses.MailManagerRuleSetDeliverToMailboxActionArgs>;
    }
    interface MailManagerRuleSetRuleAction8PropertiesArgs {
        deliverToQBusiness: pulumi.Input<inputs.ses.MailManagerRuleSetDeliverToQBusinessActionArgs>;
    }
    interface MailManagerRuleSetRuleBooleanExpressionArgs {
        evaluate: pulumi.Input<inputs.ses.MailManagerRuleSetRuleBooleanToEvaluate0PropertiesArgs | inputs.ses.MailManagerRuleSetRuleBooleanToEvaluate1PropertiesArgs>;
        operator: pulumi.Input<enums.ses.MailManagerRuleSetRuleBooleanOperator>;
    }
    interface MailManagerRuleSetRuleBooleanToEvaluate0PropertiesArgs {
        attribute: pulumi.Input<enums.ses.MailManagerRuleSetRuleBooleanEmailAttribute>;
    }
    interface MailManagerRuleSetRuleBooleanToEvaluate1PropertiesArgs {
        analysis: pulumi.Input<inputs.ses.MailManagerRuleSetAnalysisArgs>;
    }
    interface MailManagerRuleSetRuleCondition0PropertiesArgs {
        booleanExpression: pulumi.Input<inputs.ses.MailManagerRuleSetRuleBooleanExpressionArgs>;
    }
    interface MailManagerRuleSetRuleCondition1PropertiesArgs {
        stringExpression: pulumi.Input<inputs.ses.MailManagerRuleSetRuleStringExpressionArgs>;
    }
    interface MailManagerRuleSetRuleCondition2PropertiesArgs {
        numberExpression: pulumi.Input<inputs.ses.MailManagerRuleSetRuleNumberExpressionArgs>;
    }
    interface MailManagerRuleSetRuleCondition3PropertiesArgs {
        ipExpression: pulumi.Input<inputs.ses.MailManagerRuleSetRuleIpExpressionArgs>;
    }
    interface MailManagerRuleSetRuleCondition4PropertiesArgs {
        verdictExpression: pulumi.Input<inputs.ses.MailManagerRuleSetRuleVerdictExpressionArgs>;
    }
    interface MailManagerRuleSetRuleCondition5PropertiesArgs {
        dmarcExpression: pulumi.Input<inputs.ses.MailManagerRuleSetRuleDmarcExpressionArgs>;
    }
    interface MailManagerRuleSetRuleDmarcExpressionArgs {
        operator: pulumi.Input<enums.ses.MailManagerRuleSetRuleDmarcOperator>;
        values: pulumi.Input<pulumi.Input<enums.ses.MailManagerRuleSetRuleDmarcPolicy>[]>;
    }
    interface MailManagerRuleSetRuleIpExpressionArgs {
        evaluate: pulumi.Input<inputs.ses.MailManagerRuleSetRuleIpToEvaluatePropertiesArgs>;
        operator: pulumi.Input<enums.ses.MailManagerRuleSetRuleIpOperator>;
        values: pulumi.Input<pulumi.Input<string>[]>;
    }
    interface MailManagerRuleSetRuleIpToEvaluatePropertiesArgs {
        attribute: pulumi.Input<enums.ses.MailManagerRuleSetRuleIpEmailAttribute>;
    }
    interface MailManagerRuleSetRuleNumberExpressionArgs {
        evaluate: pulumi.Input<inputs.ses.MailManagerRuleSetRuleNumberToEvaluatePropertiesArgs>;
        operator: pulumi.Input<enums.ses.MailManagerRuleSetRuleNumberOperator>;
        value: pulumi.Input<number>;
    }
    interface MailManagerRuleSetRuleNumberToEvaluatePropertiesArgs {
        attribute: pulumi.Input<enums.ses.MailManagerRuleSetRuleNumberEmailAttribute>;
    }
    interface MailManagerRuleSetRuleStringExpressionArgs {
        evaluate: pulumi.Input<inputs.ses.MailManagerRuleSetRuleStringToEvaluate0PropertiesArgs | inputs.ses.MailManagerRuleSetRuleStringToEvaluate1PropertiesArgs | inputs.ses.MailManagerRuleSetRuleStringToEvaluate2PropertiesArgs>;
        operator: pulumi.Input<enums.ses.MailManagerRuleSetRuleStringOperator>;
        values: pulumi.Input<pulumi.Input<string>[]>;
    }
    interface MailManagerRuleSetRuleStringToEvaluate0PropertiesArgs {
        attribute: pulumi.Input<enums.ses.MailManagerRuleSetRuleStringEmailAttribute>;
    }
    interface MailManagerRuleSetRuleStringToEvaluate1PropertiesArgs {
        mimeHeaderAttribute: pulumi.Input<string>;
    }
    interface MailManagerRuleSetRuleStringToEvaluate2PropertiesArgs {
        analysis: pulumi.Input<inputs.ses.MailManagerRuleSetAnalysisArgs>;
    }
    interface MailManagerRuleSetRuleVerdictExpressionArgs {
        evaluate: pulumi.Input<inputs.ses.MailManagerRuleSetRuleVerdictToEvaluate0PropertiesArgs | inputs.ses.MailManagerRuleSetRuleVerdictToEvaluate1PropertiesArgs>;
        operator: pulumi.Input<enums.ses.MailManagerRuleSetRuleVerdictOperator>;
        values: pulumi.Input<pulumi.Input<enums.ses.MailManagerRuleSetRuleVerdict>[]>;
    }
    interface MailManagerRuleSetRuleVerdictToEvaluate0PropertiesArgs {
        attribute: pulumi.Input<enums.ses.MailManagerRuleSetRuleVerdictAttribute>;
    }
    interface MailManagerRuleSetRuleVerdictToEvaluate1PropertiesArgs {
        analysis: pulumi.Input<inputs.ses.MailManagerRuleSetAnalysisArgs>;
    }
    interface MailManagerRuleSetS3ActionArgs {
        actionFailurePolicy?: pulumi.Input<enums.ses.MailManagerRuleSetActionFailurePolicy>;
        roleArn: pulumi.Input<string>;
        s3Bucket: pulumi.Input<string>;
        s3Prefix?: pulumi.Input<string>;
        s3SseKmsKeyId?: pulumi.Input<string>;
    }
    interface MailManagerRuleSetSendActionArgs {
        actionFailurePolicy?: pulumi.Input<enums.ses.MailManagerRuleSetActionFailurePolicy>;
        roleArn: pulumi.Input<string>;
    }
    interface MailManagerTrafficPolicyIngressAnalysisArgs {
        analyzer: pulumi.Input<string>;
        resultField: pulumi.Input<string>;
    }
    interface MailManagerTrafficPolicyIngressBooleanExpressionArgs {
        evaluate: pulumi.Input<inputs.ses.MailManagerTrafficPolicyIngressBooleanToEvaluatePropertiesArgs>;
        operator: pulumi.Input<enums.ses.MailManagerTrafficPolicyIngressBooleanOperator>;
    }
    interface MailManagerTrafficPolicyIngressBooleanToEvaluatePropertiesArgs {
        analysis: pulumi.Input<inputs.ses.MailManagerTrafficPolicyIngressAnalysisArgs>;
    }
    interface MailManagerTrafficPolicyIngressIpToEvaluatePropertiesArgs {
        attribute: pulumi.Input<enums.ses.MailManagerTrafficPolicyIngressIpv4Attribute>;
    }
    interface MailManagerTrafficPolicyIngressIpv4ExpressionArgs {
        evaluate: pulumi.Input<inputs.ses.MailManagerTrafficPolicyIngressIpToEvaluatePropertiesArgs>;
        operator: pulumi.Input<enums.ses.MailManagerTrafficPolicyIngressIpOperator>;
        values: pulumi.Input<pulumi.Input<string>[]>;
    }
    interface MailManagerTrafficPolicyIngressIpv6ExpressionArgs {
        evaluate: pulumi.Input<inputs.ses.MailManagerTrafficPolicyIngressIpv6ToEvaluatePropertiesArgs>;
        operator: pulumi.Input<enums.ses.MailManagerTrafficPolicyIngressIpOperator>;
        values: pulumi.Input<pulumi.Input<string>[]>;
    }
    interface MailManagerTrafficPolicyIngressIpv6ToEvaluatePropertiesArgs {
        attribute: pulumi.Input<enums.ses.MailManagerTrafficPolicyIngressIpv6Attribute>;
    }
    interface MailManagerTrafficPolicyIngressStringExpressionArgs {
        evaluate: pulumi.Input<inputs.ses.MailManagerTrafficPolicyIngressStringToEvaluate0PropertiesArgs | inputs.ses.MailManagerTrafficPolicyIngressStringToEvaluate1PropertiesArgs>;
        operator: pulumi.Input<enums.ses.MailManagerTrafficPolicyIngressStringOperator>;
        values: pulumi.Input<pulumi.Input<string>[]>;
    }
    interface MailManagerTrafficPolicyIngressStringToEvaluate0PropertiesArgs {
        attribute: pulumi.Input<enums.ses.MailManagerTrafficPolicyIngressStringEmailAttribute>;
    }
    interface MailManagerTrafficPolicyIngressStringToEvaluate1PropertiesArgs {
        analysis: pulumi.Input<inputs.ses.MailManagerTrafficPolicyIngressAnalysisArgs>;
    }
    interface MailManagerTrafficPolicyIngressTlsProtocolExpressionArgs {
        evaluate: pulumi.Input<inputs.ses.MailManagerTrafficPolicyIngressTlsProtocolToEvaluatePropertiesArgs>;
        operator: pulumi.Input<enums.ses.MailManagerTrafficPolicyIngressTlsProtocolOperator>;
        value: pulumi.Input<enums.ses.MailManagerTrafficPolicyIngressTlsProtocolAttribute>;
    }
    interface MailManagerTrafficPolicyIngressTlsProtocolToEvaluatePropertiesArgs {
        attribute: pulumi.Input<enums.ses.MailManagerTrafficPolicyIngressTlsAttribute>;
    }
    interface MailManagerTrafficPolicyPolicyCondition0PropertiesArgs {
        stringExpression: pulumi.Input<inputs.ses.MailManagerTrafficPolicyIngressStringExpressionArgs>;
    }
    interface MailManagerTrafficPolicyPolicyCondition1PropertiesArgs {
        ipExpression: pulumi.Input<inputs.ses.MailManagerTrafficPolicyIngressIpv4ExpressionArgs>;
    }
    interface MailManagerTrafficPolicyPolicyCondition2PropertiesArgs {
        ipv6Expression: pulumi.Input<inputs.ses.MailManagerTrafficPolicyIngressIpv6ExpressionArgs>;
    }
    interface MailManagerTrafficPolicyPolicyCondition3PropertiesArgs {
        tlsExpression: pulumi.Input<inputs.ses.MailManagerTrafficPolicyIngressTlsProtocolExpressionArgs>;
    }
    interface MailManagerTrafficPolicyPolicyCondition4PropertiesArgs {
        booleanExpression: pulumi.Input<inputs.ses.MailManagerTrafficPolicyIngressBooleanExpressionArgs>;
    }
    interface MailManagerTrafficPolicyPolicyStatementArgs {
        /**
         * The action that informs a traffic policy resource to either allow or block the email if it matches a condition in the policy statement.
         */
        action: pulumi.Input<enums.ses.MailManagerTrafficPolicyAcceptAction>;
        /**
         * The list of conditions to apply to incoming messages for filtering email traffic.
         */
        conditions: pulumi.Input<pulumi.Input<inputs.ses.MailManagerTrafficPolicyPolicyCondition0PropertiesArgs | inputs.ses.MailManagerTrafficPolicyPolicyCondition1PropertiesArgs | inputs.ses.MailManagerTrafficPolicyPolicyCondition2PropertiesArgs | inputs.ses.MailManagerTrafficPolicyPolicyCondition3PropertiesArgs | inputs.ses.MailManagerTrafficPolicyPolicyCondition4PropertiesArgs>[]>;
    }
    /**
     * The content of the email, composed of a subject line, an HTML part, and a text-only part
     */
    interface TemplateArgs {
        /**
         * The HTML body of the email.
         */
        htmlPart?: pulumi.Input<string>;
        /**
         * The subject line of the email.
         */
        subjectPart: pulumi.Input<string>;
        /**
         * The name of the template.
         */
        templateName?: pulumi.Input<string>;
        /**
         * The email body that is visible to recipients whose email clients do not display HTML content.
         */
        textPart?: pulumi.Input<string>;
    }
    /**
     * Preferences regarding the Dashboard feature.
     */
    interface VdmAttributesDashboardAttributesArgs {
        /**
         * Whether emails sent from this account have engagement tracking enabled.
         */
        engagementMetrics?: pulumi.Input<string>;
    }
    /**
     * Preferences regarding the Guardian feature.
     */
    interface VdmAttributesGuardianAttributesArgs {
        /**
         * Whether emails sent from this account have optimized delivery algorithm enabled.
         */
        optimizedSharedDelivery?: pulumi.Input<string>;
    }
}
export declare namespace shield {
    /**
     * An emergency contact is used by Shield Response Team (SRT) to contact you for escalations to the SRT and to initiate proactive customer support. An emergency contact requires an email address.
     */
    interface ProactiveEngagementEmergencyContactArgs {
        /**
         * Additional notes regarding the contact.
         */
        contactNotes?: pulumi.Input<string>;
        /**
         * The email address for the contact.
         */
        emailAddress: pulumi.Input<string>;
        /**
         * The phone number for the contact
         */
        phoneNumber?: pulumi.Input<string>;
    }
    /**
     * The automatic application layer DDoS mitigation settings for a Protection. This configuration determines whether Shield Advanced automatically manages rules in the web ACL in order to respond to application layer events that Shield Advanced determines to be DDoS attacks.
     */
    interface ProtectionApplicationLayerAutomaticResponseConfigurationArgs {
        /**
         * Specifies the action setting that Shield Advanced should use in the AWS WAF rules that it creates on behalf of the protected resource in response to DDoS attacks. You specify this as part of the configuration for the automatic application layer DDoS mitigation feature, when you enable or update automatic mitigation. Shield Advanced creates the AWS WAF rules in a Shield Advanced-managed rule group, inside the web ACL that you have associated with the resource.
         */
        action: pulumi.Input<inputs.shield.ProtectionApplicationLayerAutomaticResponseConfigurationAction0PropertiesArgs | inputs.shield.ProtectionApplicationLayerAutomaticResponseConfigurationAction1PropertiesArgs>;
        /**
         * Indicates whether automatic application layer DDoS mitigation is enabled for the protection.
         */
        status: pulumi.Input<enums.shield.ProtectionApplicationLayerAutomaticResponseConfigurationStatus>;
    }
    /**
     * Specifies the action setting that Shield Advanced should use in the AWS WAF rules that it creates on behalf of the protected resource in response to DDoS attacks. You specify this as part of the configuration for the automatic application layer DDoS mitigation feature, when you enable or update automatic mitigation. Shield Advanced creates the AWS WAF rules in a Shield Advanced-managed rule group, inside the web ACL that you have associated with the resource.
     */
    interface ProtectionApplicationLayerAutomaticResponseConfigurationAction0PropertiesArgs {
        /**
         * Specifies that Shield Advanced should configure its AWS WAF rules with the AWS WAF `Count` action.
         * You must specify exactly one action, either `Block` or `Count`.
         */
        count?: any;
    }
    /**
     * Specifies the action setting that Shield Advanced should use in the AWS WAF rules that it creates on behalf of the protected resource in response to DDoS attacks. You specify this as part of the configuration for the automatic application layer DDoS mitigation feature, when you enable or update automatic mitigation. Shield Advanced creates the AWS WAF rules in a Shield Advanced-managed rule group, inside the web ACL that you have associated with the resource.
     */
    interface ProtectionApplicationLayerAutomaticResponseConfigurationAction1PropertiesArgs {
        /**
         * Specifies that Shield Advanced should configure its AWS WAF rules with the AWS WAF `Block` action.
         * You must specify exactly one action, either `Block` or `Count`.
         */
        block?: any;
    }
}
export declare namespace signer {
    interface SigningProfileSignatureValidityPeriodArgs {
        /**
         * The time unit for signature validity: DAYS | MONTHS | YEARS.
         */
        type?: pulumi.Input<enums.signer.SigningProfileSignatureValidityPeriodType>;
        /**
         * The numerical value of the time unit for signature validity.
         */
        value?: pulumi.Input<number>;
    }
}
export declare namespace simspaceweaver {
    interface SimulationS3LocationArgs {
        /**
         * The Schema S3 bucket name.
         */
        bucketName: pulumi.Input<string>;
        /**
         * This is the schema S3 object key, which includes the full path of "folders" from the bucket root to the schema.
         */
        objectKey: pulumi.Input<string>;
    }
}
export declare namespace sns {
    /**
     * The ``LoggingConfig`` property type specifies the ``Delivery`` status logging configuration for an [AWS::SNS::Topic](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-sns-topic.html).
     */
    interface TopicLoggingConfigArgs {
        /**
         * The IAM role ARN to be used when logging failed message deliveries in Amazon CloudWatch.
         */
        failureFeedbackRoleArn?: pulumi.Input<string>;
        /**
         * Indicates one of the supported protocols for the Amazon SNS topic.
         *   At least one of the other three ``LoggingConfig`` properties is recommend along with ``Protocol``.
         */
        protocol: pulumi.Input<enums.sns.TopicLoggingConfigProtocol>;
        /**
         * The IAM role ARN to be used when logging successful message deliveries in Amazon CloudWatch.
         */
        successFeedbackRoleArn?: pulumi.Input<string>;
        /**
         * The percentage of successful message deliveries to be logged in Amazon CloudWatch. Valid percentage values range from 0 to 100.
         */
        successFeedbackSampleRate?: pulumi.Input<string>;
    }
    /**
     * ``Subscription`` is an embedded property that describes the subscription endpoints of an SNS topic.
     *   For full control over subscription behavior (for example, delivery policy, filtering, raw message delivery, and cross-region subscriptions), use the [AWS::SNS::Subscription](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-sns-subscription.html) resource.
     */
    interface TopicSubscriptionArgs {
        /**
         * The endpoint that receives notifications from the SNS topic. The endpoint value depends on the protocol that you specify. For more information, see the ``Endpoint`` parameter of the ``Subscribe`` action in the *API Reference*.
         */
        endpoint: pulumi.Input<string>;
        /**
         * The subscription's protocol. For more information, see the ``Protocol`` parameter of the ``Subscribe`` action in the *API Reference*.
         */
        protocol: pulumi.Input<string>;
    }
}
export declare namespace sqs {
}
export declare namespace ssm {
    interface AssociationInstanceAssociationOutputLocationArgs {
        /**
         * `S3OutputLocation` is a property of the [InstanceAssociationOutputLocation](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-ssm-association-instanceassociationoutputlocation.html) property that specifies an Amazon S3 bucket where you want to store the results of this request.
         */
        s3Location?: pulumi.Input<inputs.ssm.AssociationS3OutputLocationArgs>;
    }
    interface AssociationS3OutputLocationArgs {
        /**
         * The name of the S3 bucket.
         */
        outputS3BucketName?: pulumi.Input<string>;
        /**
         * The S3 bucket subfolder.
         */
        outputS3KeyPrefix?: pulumi.Input<string>;
        /**
         * The AWS Region of the S3 bucket.
         */
        outputS3Region?: pulumi.Input<string>;
    }
    interface AssociationTargetArgs {
        /**
         * User-defined criteria for sending commands that target managed nodes that meet the criteria.
         */
        key: pulumi.Input<string>;
        /**
         * User-defined criteria that maps to `Key` . For example, if you specified `tag:ServerRole` , you could specify `value:WebServer` to run a command on instances that include EC2 tags of `ServerRole,WebServer` .
         *
         * Depending on the type of target, the maximum number of values for a key might be lower than the global maximum of 50.
         */
        values: pulumi.Input<pulumi.Input<string>[]>;
    }
    interface DocumentAttachmentsSourceArgs {
        /**
         * The key of a key-value pair that identifies the location of an attachment to a document.
         */
        key?: pulumi.Input<enums.ssm.DocumentAttachmentsSourceKey>;
        /**
         * The name of the document attachment file.
         */
        name?: pulumi.Input<string>;
        /**
         * The value of a key-value pair that identifies the location of an attachment to a document. The format for Value depends on the type of key you specify.
         */
        values?: pulumi.Input<pulumi.Input<string>[]>;
    }
    interface DocumentRequiresArgs {
        /**
         * The name of the required SSM document. The name can be an Amazon Resource Name (ARN).
         */
        name?: pulumi.Input<string>;
        /**
         * The document version required by the current document.
         */
        version?: pulumi.Input<string>;
    }
    /**
     * Defines which patches should be included in a patch baseline.
     */
    interface PatchBaselinePatchFilterArgs {
        /**
         * The key for the filter.
         *
         * For information about valid keys, see [PatchFilter](https://docs.aws.amazon.com/systems-manager/latest/APIReference/API_PatchFilter.html) in the *AWS Systems Manager API Reference* .
         */
        key?: pulumi.Input<enums.ssm.PatchBaselinePatchFilterKey>;
        /**
         * The value for the filter key.
         *
         * For information about valid values for each key based on operating system type, see [PatchFilter](https://docs.aws.amazon.com/systems-manager/latest/APIReference/API_PatchFilter.html) in the *AWS Systems Manager API Reference* .
         */
        values?: pulumi.Input<pulumi.Input<string>[]>;
    }
    /**
     * The patch filter group that defines the criteria for the rule.
     */
    interface PatchBaselinePatchFilterGroupArgs {
        /**
         * The set of patch filters that make up the group.
         */
        patchFilters?: pulumi.Input<pulumi.Input<inputs.ssm.PatchBaselinePatchFilterArgs>[]>;
    }
    /**
     * Information about the patches to use to update the instances, including target operating systems and source repository. Applies to Linux instances only.
     */
    interface PatchBaselinePatchSourceArgs {
        /**
         * The value of the yum repo configuration. For example:
         *
         * `[main]`
         *
         * `name=MyCustomRepository`
         *
         * `baseurl=https://my-custom-repository`
         *
         * `enabled=1`
         *
         * > For information about other options available for your yum repository configuration, see [dnf.conf(5)](https://docs.aws.amazon.com/https://man7.org/linux/man-pages/man5/dnf.conf.5.html) .
         */
        configuration?: pulumi.Input<string>;
        /**
         * The name specified to identify the patch source.
         */
        name?: pulumi.Input<string>;
        /**
         * The specific operating system versions a patch repository applies to, such as "Ubuntu16.04", "RedhatEnterpriseLinux7.2" or "Suse12.7". For lists of supported product values, see [PatchFilter](https://docs.aws.amazon.com/systems-manager/latest/APIReference/API_PatchFilter.html) in the *AWS Systems Manager API Reference* .
         */
        products?: pulumi.Input<pulumi.Input<string>[]>;
    }
    /**
     * Defines an approval rule for a patch baseline.
     */
    interface PatchBaselineRuleArgs {
        /**
         * The number of days after the release date of each patch matched by the rule that the patch is marked as approved in the patch baseline. For example, a value of `7` means that patches are approved seven days after they are released.
         *
         * This parameter is marked as `Required: No` , but your request must include a value for either `ApproveAfterDays` or `ApproveUntilDate` .
         *
         * Not supported for Debian Server or Ubuntu Server.
         *
         * > Use caution when setting this value for Windows Server patch baselines. Because patch updates that are replaced by later updates are removed, setting too broad a value for this parameter can result in crucial patches not being installed. For more information, see the *Windows Server* tab in the topic [How security patches are selected](https://docs.aws.amazon.com/systems-manager/latest/userguide/patch-manager-selecting-patches.html) in the *AWS Systems Manager User Guide* .
         */
        approveAfterDays?: pulumi.Input<number>;
        /**
         * The cutoff date for auto approval of released patches. Any patches released on or before this date are installed automatically.
         *
         * Enter dates in the format `YYYY-MM-DD` . For example, `2024-12-31` .
         *
         * This parameter is marked as `Required: No` , but your request must include a value for either `ApproveUntilDate` or `ApproveAfterDays` .
         *
         * Not supported for Debian Server or Ubuntu Server.
         *
         * > Use caution when setting this value for Windows Server patch baselines. Because patch updates that are replaced by later updates are removed, setting too broad a value for this parameter can result in crucial patches not being installed. For more information, see the *Windows Server* tab in the topic [How security patches are selected](https://docs.aws.amazon.com/systems-manager/latest/userguide/patch-manager-selecting-patches.html) in the *AWS Systems Manager User Guide* .
         */
        approveUntilDate?: pulumi.Input<string>;
        /**
         * A compliance severity level for all approved patches in a patch baseline. Valid compliance severity levels include the following: `UNSPECIFIED` , `CRITICAL` , `HIGH` , `MEDIUM` , `LOW` , and `INFORMATIONAL` .
         */
        complianceLevel?: pulumi.Input<enums.ssm.PatchBaselineRuleComplianceLevel>;
        /**
         * For managed nodes identified by the approval rule filters, enables a patch baseline to apply non-security updates available in the specified repository. The default value is `false` . Applies to Linux managed nodes only.
         */
        enableNonSecurity?: pulumi.Input<boolean>;
        /**
         * The patch filter group that defines the criteria for the rule.
         */
        patchFilterGroup?: pulumi.Input<inputs.ssm.PatchBaselinePatchFilterGroupArgs>;
    }
    /**
     * A set of rules defining the approval rules for a patch baseline.
     */
    interface PatchBaselineRuleGroupArgs {
        /**
         * The rules that make up the rule group.
         */
        patchRules?: pulumi.Input<pulumi.Input<inputs.ssm.PatchBaselineRuleArgs>[]>;
    }
    interface ResourceDataSyncAwsOrganizationsSourceArgs {
        /**
         * If an AWS organization is present, this is either `OrganizationalUnits` or `EntireOrganization` . For `OrganizationalUnits` , the data is aggregated from a set of organization units. For `EntireOrganization` , the data is aggregated from the entire AWS organization.
         */
        organizationSourceType: pulumi.Input<string>;
        /**
         * The AWS Organizations organization units included in the sync.
         */
        organizationalUnits?: pulumi.Input<pulumi.Input<string>[]>;
    }
    interface ResourceDataSyncS3DestinationArgs {
        /**
         * The name of the S3 bucket where the aggregated data is stored.
         */
        bucketName: pulumi.Input<string>;
        /**
         * An Amazon S3 prefix for the bucket.
         */
        bucketPrefix?: pulumi.Input<string>;
        /**
         * The AWS Region with the S3 bucket targeted by the resource data sync.
         */
        bucketRegion: pulumi.Input<string>;
        /**
         * The ARN of an encryption key for a destination in Amazon S3. Must belong to the same Region as the destination S3 bucket.
         */
        kmsKeyArn?: pulumi.Input<string>;
        /**
         * A supported sync format. The following format is currently supported: JsonSerDe
         */
        syncFormat: pulumi.Input<string>;
    }
    interface ResourceDataSyncSyncSourceArgs {
        /**
         * Information about the AwsOrganizationsSource resource data sync source. A sync source of this type can synchronize data from AWS Organizations .
         */
        awsOrganizationsSource?: pulumi.Input<inputs.ssm.ResourceDataSyncAwsOrganizationsSourceArgs>;
        /**
         * Whether to automatically synchronize and aggregate data from new AWS Regions when those Regions come online.
         */
        includeFutureRegions?: pulumi.Input<boolean>;
        /**
         * The `SyncSource` AWS Regions included in the resource data sync.
         */
        sourceRegions: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * The type of data source for the resource data sync. `SourceType` is either `AwsOrganizations` (if an organization is present in AWS Organizations ) or `SingleAccountMultiRegions` .
         */
        sourceType: pulumi.Input<string>;
    }
}
export declare namespace ssmcontacts {
    /**
     * Information about the contact channel that SSM Incident Manager uses to engage the contact.
     */
    interface ContactChannelTargetInfoArgs {
        /**
         * The Amazon Resource Name (ARN) of the contact channel.
         */
        channelId: pulumi.Input<string>;
        /**
         * The number of minutes to wait to retry sending engagement in the case the engagement initially fails.
         */
        retryIntervalInMinutes: pulumi.Input<number>;
    }
    /**
     * A set amount of time that an escalation plan or engagement plan engages the specified contacts or contact methods.
     */
    interface ContactStageArgs {
        /**
         * The time to wait until beginning the next stage.
         */
        durationInMinutes?: pulumi.Input<number>;
        /**
         * List of Rotation Ids to associate with Contact
         */
        rotationIds?: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * The contacts or contact methods that the escalation plan or engagement plan is engaging.
         */
        targets?: pulumi.Input<pulumi.Input<inputs.ssmcontacts.ContactTargetsArgs>[]>;
    }
    /**
     * The contact that SSM Incident Manager is engaging during an incident.
     */
    interface ContactTargetInfoArgs {
        /**
         * The Amazon Resource Name (ARN) of the contact.
         */
        contactId: pulumi.Input<string>;
        /**
         * A Boolean value determining if the contact's acknowledgement stops the progress of stages in the plan.
         */
        isEssential: pulumi.Input<boolean>;
    }
    /**
     * The contacts or contact methods that the escalation plan or engagement plan is engaging.
     */
    interface ContactTargetsArgs {
        /**
         * Information about the contact channel that Incident Manager engages.
         */
        channelTargetInfo?: pulumi.Input<inputs.ssmcontacts.ContactChannelTargetInfoArgs>;
        /**
         * The contact that Incident Manager is engaging during an incident.
         */
        contactTargetInfo?: pulumi.Input<inputs.ssmcontacts.ContactTargetInfoArgs>;
    }
    /**
     * Information about the contact channel that SSM Incident Manager uses to engage the contact.
     */
    interface PlanChannelTargetInfoArgs {
        /**
         * The Amazon Resource Name (ARN) of the contact channel.
         */
        channelId: pulumi.Input<string>;
        /**
         * The number of minutes to wait to retry sending engagement in the case the engagement initially fails.
         */
        retryIntervalInMinutes: pulumi.Input<number>;
    }
    /**
     * The contact that SSM Incident Manager is engaging during an incident.
     */
    interface PlanContactTargetInfoArgs {
        /**
         * The Amazon Resource Name (ARN) of the contact.
         */
        contactId: pulumi.Input<string>;
        /**
         * A Boolean value determining if the contact's acknowledgement stops the progress of stages in the plan.
         */
        isEssential: pulumi.Input<boolean>;
    }
    /**
     * A set amount of time that an escalation plan or engagement plan engages the specified contacts or contact methods.
     */
    interface PlanStageArgs {
        /**
         * The time to wait until beginning the next stage.
         */
        durationInMinutes: pulumi.Input<number>;
        /**
         * The contacts or contact methods that the escalation plan or engagement plan is engaging.
         */
        targets?: pulumi.Input<pulumi.Input<inputs.ssmcontacts.PlanTargetsArgs>[]>;
    }
    /**
     * The contacts or contact methods that the escalation plan or engagement plan is engaging.
     */
    interface PlanTargetsArgs {
        /**
         * Information about the contact channel that Incident Manager engages.
         */
        channelTargetInfo?: pulumi.Input<inputs.ssmcontacts.PlanChannelTargetInfoArgs>;
        /**
         * Information about the contact that Incident Manager engages.
         */
        contactTargetInfo?: pulumi.Input<inputs.ssmcontacts.PlanContactTargetInfoArgs>;
    }
    /**
     * StartTime and EndTime for the Shift
     */
    interface RotationCoverageTimeArgs {
        /**
         * Information about when an on-call rotation shift ends.
         */
        endTime: pulumi.Input<string>;
        /**
         * Information about when an on-call rotation shift begins.
         */
        startTime: pulumi.Input<string>;
    }
    /**
     * DayOfWeek for Month and HandOff Time for Monthly Recurring Rotation.
     */
    interface RotationMonthlySettingArgs {
        /**
         * The day of the month when monthly recurring on-call rotations begin.
         */
        dayOfMonth: pulumi.Input<number>;
        /**
         * The time of day when a monthly recurring on-call shift rotation begins.
         */
        handOffTime: pulumi.Input<string>;
    }
    /**
     * Information about when an on-call rotation is in effect and how long the rotation period lasts.
     */
    interface RotationRecurrenceSettingsArgs {
        /**
         * Information about on-call rotations that recur daily.
         */
        dailySettings?: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * Information about on-call rotations that recur monthly.
         */
        monthlySettings?: pulumi.Input<pulumi.Input<inputs.ssmcontacts.RotationMonthlySettingArgs>[]>;
        /**
         * Number of Oncalls per shift.
         */
        numberOfOnCalls?: pulumi.Input<number>;
        /**
         * The number of days, weeks, or months a single rotation lasts.
         */
        recurrenceMultiplier?: pulumi.Input<number>;
        /**
         * Information about the days of the week included in on-call rotation coverage.
         */
        shiftCoverages?: pulumi.Input<pulumi.Input<inputs.ssmcontacts.RotationShiftCoverageArgs>[]>;
        /**
         * Information about on-call rotations that recur weekly.
         */
        weeklySettings?: pulumi.Input<pulumi.Input<inputs.ssmcontacts.RotationWeeklySettingArgs>[]>;
    }
    /**
     * Information about the days of the week included in on-call rotation coverage.
     */
    interface RotationShiftCoverageArgs {
        /**
         * Information about when an on-call shift begins and ends.
         */
        coverageTimes: pulumi.Input<pulumi.Input<inputs.ssmcontacts.RotationCoverageTimeArgs>[]>;
        /**
         * A list of days on which the schedule is active.
         */
        dayOfWeek: pulumi.Input<enums.ssmcontacts.RotationDayOfWeek>;
    }
    /**
     * DayOfWeek for Rotation and HandOff Time for Weekly Recurring Rotation.
     */
    interface RotationWeeklySettingArgs {
        /**
         * The day of the week when weekly recurring on-call shift rotations begins.
         */
        dayOfWeek: pulumi.Input<enums.ssmcontacts.RotationDayOfWeek>;
        /**
         * The time of day when a weekly recurring on-call shift rotation begins.
         */
        handOffTime: pulumi.Input<string>;
    }
}
export declare namespace ssmincidents {
    /**
     * The ReplicationSet regional configuration.
     */
    interface ReplicationSetRegionConfigurationArgs {
        /**
         * The AWS Key Management Service key ID or Key Alias to use to encrypt your replication set.
         */
        sseKmsKeyId: pulumi.Input<string>;
    }
    /**
     * The ReplicationSet regional configuration.
     */
    interface ReplicationSetReplicationRegionArgs {
        regionConfiguration?: pulumi.Input<inputs.ssmincidents.ReplicationSetRegionConfigurationArgs>;
        regionName?: pulumi.Input<string>;
    }
    /**
     * The automation configuration to launch.
     */
    interface ResponsePlanActionArgs {
        /**
         * Details about the Systems Manager automation document that will be used as a runbook during an incident.
         */
        ssmAutomation?: pulumi.Input<inputs.ssmincidents.ResponsePlanSsmAutomationArgs>;
    }
    /**
     * The chat channel configuration.
     */
    interface ResponsePlanChatChannelArgs {
        /**
         * The Amazon SNS targets that  uses to notify the chat channel of updates to an incident. You can also make updates to the incident through the chat channel by using the Amazon SNS topics
         */
        chatbotSns?: pulumi.Input<pulumi.Input<string>[]>;
    }
    /**
     * A parameter with a dynamic value to set when starting the SSM automation document.
     */
    interface ResponsePlanDynamicSsmParameterArgs {
        /**
         * The key parameter to use when running the Systems Manager Automation runbook.
         */
        key: pulumi.Input<string>;
        /**
         * The dynamic parameter value.
         */
        value: pulumi.Input<inputs.ssmincidents.ResponsePlanDynamicSsmParameterValueArgs>;
    }
    /**
     * Value of the dynamic parameter to set when starting the SSM automation document.
     */
    interface ResponsePlanDynamicSsmParameterValueArgs {
        /**
         * Variable dynamic parameters. A parameter value is determined when an incident is created.
         */
        variable?: pulumi.Input<enums.ssmincidents.ResponsePlanVariableType>;
    }
    /**
     * The incident template configuration.
     */
    interface ResponsePlanIncidentTemplateArgs {
        /**
         * The deduplication string.
         */
        dedupeString?: pulumi.Input<string>;
        /**
         * The impact value.
         */
        impact: pulumi.Input<number>;
        /**
         * Tags that get applied to incidents created by the StartIncident API action.
         */
        incidentTags?: pulumi.Input<pulumi.Input<inputs.ssmincidents.ResponsePlanTagArgs>[]>;
        /**
         * The list of notification targets.
         */
        notificationTargets?: pulumi.Input<pulumi.Input<inputs.ssmincidents.ResponsePlanNotificationTargetItemArgs>[]>;
        /**
         * The summary string.
         */
        summary?: pulumi.Input<string>;
        /**
         * The title string.
         */
        title: pulumi.Input<string>;
    }
    interface ResponsePlanIntegrationArgs {
        /**
         * Information about the PagerDuty service where the response plan creates an incident.
         */
        pagerDutyConfiguration?: pulumi.Input<inputs.ssmincidents.ResponsePlanPagerDutyConfigurationArgs>;
    }
    /**
     * A notification target.
     */
    interface ResponsePlanNotificationTargetItemArgs {
        /**
         * The Amazon Resource Name (ARN) of the Amazon SNS topic.
         */
        snsTopicArn?: pulumi.Input<string>;
    }
    /**
     * The pagerDuty configuration to use when starting the incident.
     */
    interface ResponsePlanPagerDutyConfigurationArgs {
        /**
         * The name of the pagerDuty configuration.
         */
        name: pulumi.Input<string>;
        /**
         * Details about the PagerDuty service associated with the configuration.
         */
        pagerDutyIncidentConfiguration: pulumi.Input<inputs.ssmincidents.ResponsePlanPagerDutyIncidentConfigurationArgs>;
        /**
         * The AWS secrets manager secretId storing the pagerDuty token.
         */
        secretId: pulumi.Input<string>;
    }
    /**
     * The pagerDuty incident configuration.
     */
    interface ResponsePlanPagerDutyIncidentConfigurationArgs {
        /**
         * The pagerDuty serviceId.
         */
        serviceId: pulumi.Input<string>;
    }
    /**
     * The configuration to use when starting the SSM automation document.
     */
    interface ResponsePlanSsmAutomationArgs {
        /**
         * The document name to use when starting the SSM automation document.
         */
        documentName: pulumi.Input<string>;
        /**
         * The version of the document to use when starting the SSM automation document.
         */
        documentVersion?: pulumi.Input<string>;
        /**
         * The parameters with dynamic values to set when starting the SSM automation document.
         */
        dynamicParameters?: pulumi.Input<pulumi.Input<inputs.ssmincidents.ResponsePlanDynamicSsmParameterArgs>[]>;
        /**
         * The parameters to set when starting the SSM automation document.
         */
        parameters?: pulumi.Input<pulumi.Input<inputs.ssmincidents.ResponsePlanSsmParameterArgs>[]>;
        /**
         * The role ARN to use when starting the SSM automation document.
         */
        roleArn: pulumi.Input<string>;
        /**
         * The account type to use when starting the SSM automation document.
         */
        targetAccount?: pulumi.Input<enums.ssmincidents.ResponsePlanSsmAutomationTargetAccount>;
    }
    /**
     * A parameter to set when starting the SSM automation document.
     */
    interface ResponsePlanSsmParameterArgs {
        /**
         * The key parameter to use when running the Automation runbook.
         */
        key: pulumi.Input<string>;
        /**
         * The value parameter to use when running the Automation runbook.
         */
        values: pulumi.Input<pulumi.Input<string>[]>;
    }
    /**
     * A key-value pair to tag a resource.
     */
    interface ResponsePlanTagArgs {
        /**
         * The tag key.
         */
        key: pulumi.Input<string>;
        /**
         * The tag value.
         */
        value: pulumi.Input<string>;
    }
}
export declare namespace ssmquicksetup {
    interface ConfigurationManagerConfigurationDefinitionArgs {
        /**
         * The ID of the configuration definition.
         */
        id?: pulumi.Input<string>;
        /**
         * The ARN of the IAM role used to administrate local configuration deployments.
         */
        localDeploymentAdministrationRoleArn?: pulumi.Input<string>;
        /**
         * The name of the IAM role used to deploy local configurations.
         */
        localDeploymentExecutionRoleName?: pulumi.Input<string>;
        /**
         * The parameters for the configuration definition type. Parameters for configuration definitions vary based the configuration type. The following lists outline the parameters for each configuration type.
         *
         * - **AWS Config Recording (Type: AWS QuickSetupType-CFGRecording)** - - `RecordAllResources`
         *
         * - Description: (Optional) A boolean value that determines whether all supported resources are recorded. The default value is " `true` ".
         * - `ResourceTypesToRecord`
         *
         * - Description: (Optional) A comma separated list of resource types you want to record.
         * - `RecordGlobalResourceTypes`
         *
         * - Description: (Optional) A boolean value that determines whether global resources are recorded with all resource configurations. The default value is " `false` ".
         * - `GlobalResourceTypesRegion`
         *
         * - Description: (Optional) Determines the AWS Region where global resources are recorded.
         * - `UseCustomBucket`
         *
         * - Description: (Optional) A boolean value that determines whether a custom Amazon S3 bucket is used for delivery. The default value is " `false` ".
         * - `DeliveryBucketName`
         *
         * - Description: (Optional) The name of the Amazon S3 bucket you want AWS Config to deliver configuration snapshots and configuration history files to.
         * - `DeliveryBucketPrefix`
         *
         * - Description: (Optional) The key prefix you want to use in the custom Amazon S3 bucket.
         * - `NotificationOptions`
         *
         * - Description: (Optional) Determines the notification configuration for the recorder. The valid values are `NoStreaming` , `UseExistingTopic` , and `CreateTopic` . The default value is `NoStreaming` .
         * - `CustomDeliveryTopicAccountId`
         *
         * - Description: (Optional) The ID of the AWS account where the Amazon SNS topic you want to use for notifications resides. You must specify a value for this parameter if you use the `UseExistingTopic` notification option.
         * - `CustomDeliveryTopicName`
         *
         * - Description: (Optional) The name of the Amazon SNS topic you want to use for notifications. You must specify a value for this parameter if you use the `UseExistingTopic` notification option.
         * - `RemediationSchedule`
         *
         * - Description: (Optional) A rate expression that defines the schedule for drift remediation. The valid values are `rate(30 days)` , `rate(7 days)` , `rate(1 days)` , and `none` . The default value is " `none` ".
         * - `TargetAccounts`
         *
         * - Description: (Optional) The ID of the AWS account initiating the configuration deployment. You only need to provide a value for this parameter if you want to deploy the configuration locally. A value must be provided for either `TargetAccounts` or `TargetOrganizationalUnits` .
         * - `TargetOrganizationalUnits`
         *
         * - Description: (Optional) The ID of the root of your Organization. This configuration type doesn't currently support choosing specific OUs. The configuration will be deployed to all the OUs in the Organization.
         * - `TargetRegions`
         *
         * - Description: (Required) A comma separated list of AWS Regions you want to deploy the configuration to.
         * - **Change Manager (Type: AWS QuickSetupType-SSMChangeMgr)** - - `DelegatedAccountId`
         *
         * - Description: (Required) The ID of the delegated administrator account.
         * - `JobFunction`
         *
         * - Description: (Required) The name for the Change Manager job function.
         * - `PermissionType`
         *
         * - Description: (Optional) Specifies whether you want to use default administrator permissions for the job function role, or provide a custom IAM policy. The valid values are `CustomPermissions` and `AdminPermissions` . The default value for the parameter is `CustomerPermissions` .
         * - `CustomPermissions`
         *
         * - Description: (Optional) A JSON string containing the IAM policy you want your job function to use. You must provide a value for this parameter if you specify `CustomPermissions` for the `PermissionType` parameter.
         * - `TargetOrganizationalUnits`
         *
         * - Description: (Required) A comma separated list of organizational units (OUs) you want to deploy the configuration to.
         * - `TargetRegions`
         *
         * - Description: (Required) A comma separated list of AWS Regions you want to deploy the configuration to.
         * - **Conformance Packs (Type: AWS QuickSetupType-CFGCPacks)** - - `DelegatedAccountId`
         *
         * - Description: (Optional) The ID of the delegated administrator account. This parameter is required for Organization deployments.
         * - `RemediationSchedule`
         *
         * - Description: (Optional) A rate expression that defines the schedule for drift remediation. The valid values are `rate(30 days)` , `rate(14 days)` , `rate(2 days)` , and `none` . The default value is " `none` ".
         * - `CPackNames`
         *
         * - Description: (Required) A comma separated list of AWS Config conformance packs.
         * - `TargetAccounts`
         *
         * - Description: (Optional) The ID of the AWS account initiating the configuration deployment. You only need to provide a value for this parameter if you want to deploy the configuration locally. A value must be provided for either `TargetAccounts` or `TargetOrganizationalUnits` .
         * - `TargetOrganizationalUnits`
         *
         * - Description: (Optional) The ID of the root of your Organization. This configuration type doesn't currently support choosing specific OUs. The configuration will be deployed to all the OUs in the Organization.
         * - `TargetRegions`
         *
         * - Description: (Required) A comma separated list of AWS Regions you want to deploy the configuration to.
         * - **Default Host Management Configuration (Type: AWS QuickSetupType-DHMC)** - - `UpdateSSMAgent`
         *
         * - Description: (Optional) A boolean value that determines whether the SSM Agent is updated on the target instances every 2 weeks. The default value is " `true` ".
         * - `TargetOrganizationalUnits`
         *
         * - Description: (Required) A comma separated list of organizational units (OUs) you want to deploy the configuration to.
         * - `TargetRegions`
         *
         * - Description: (Required) The AWS Regions to deploy the configuration to. For this type, the parameter only accepts a value of `AllRegions` .
         * - **DevOps Guru (Type: AWS QuickSetupType-DevOpsGuru)** - - `AnalyseAllResources`
         *
         * - Description: (Optional) A boolean value that determines whether DevOps Guru analyzes all AWS CloudFormation stacks in the account. The default value is " `false` ".
         * - `EnableSnsNotifications`
         *
         * - Description: (Optional) A boolean value that determines whether DevOps Guru sends notifications when an insight is created. The default value is " `true` ".
         * - `EnableSsmOpsItems`
         *
         * - Description: (Optional) A boolean value that determines whether DevOps Guru creates an OpsCenter OpsItem when an insight is created. The default value is " `true` ".
         * - `EnableDriftRemediation`
         *
         * - Description: (Optional) A boolean value that determines whether a drift remediation schedule is used. The default value is " `false` ".
         * - `RemediationSchedule`
         *
         * - Description: (Optional) A rate expression that defines the schedule for drift remediation. The valid values are `rate(30 days)` , `rate(14 days)` , `rate(1 days)` , and `none` . The default value is " `none` ".
         * - `TargetAccounts`
         *
         * - Description: (Optional) The ID of the AWS account initiating the configuration deployment. You only need to provide a value for this parameter if you want to deploy the configuration locally. A value must be provided for either `TargetAccounts` or `TargetOrganizationalUnits` .
         * - `TargetOrganizationalUnits`
         *
         * - Description: (Optional) A comma separated list of organizational units (OUs) you want to deploy the configuration to.
         * - `TargetRegions`
         *
         * - Description: (Required) A comma separated list of AWS Regions you want to deploy the configuration to.
         * - **Distributor (Type: AWS QuickSetupType-Distributor)** - - `PackagesToInstall`
         *
         * - Description: (Required) A comma separated list of packages you want to install on the target instances. The valid values are `AWSEFSTools` , `AWSCWAgent` , and `AWSEC2LaunchAgent` .
         * - `RemediationSchedule`
         *
         * - Description: (Optional) A rate expression that defines the schedule for drift remediation. The valid values are `rate(30 days)` , `rate(14 days)` , `rate(2 days)` , and `none` . The default value is " `rate(30 days)` ".
         * - `IsPolicyAttachAllowed`
         *
         * - Description: (Optional) A boolean value that determines whether Quick Setup attaches policies to instances profiles already associated with the target instances. The default value is " `false` ".
         * - `TargetType`
         *
         * - Description: (Optional) Determines how instances are targeted for local account deployments. Don't specify a value for this parameter if you're deploying to OUs. The valid values are `*` , `InstanceIds` , `ResourceGroups` , and `Tags` . Use `*` to target all instances in the account.
         * - `TargetInstances`
         *
         * - Description: (Optional) A comma separated list of instance IDs. You must provide a value for this parameter if you specify `InstanceIds` for the `TargetType` parameter.
         * - `TargetTagKey`
         *
         * - Description: (Required) The tag key assigned to the instances you want to target. You must provide a value for this parameter if you specify `Tags` for the `TargetType` parameter.
         * - `TargetTagValue`
         *
         * - Description: (Required) The value of the tag key assigned to the instances you want to target. You must provide a value for this parameter if you specify `Tags` for the `TargetType` parameter.
         * - `ResourceGroupName`
         *
         * - Description: (Required) The name of the resource group associated with the instances you want to target. You must provide a value for this parameter if you specify `ResourceGroups` for the `TargetType` parameter.
         * - `TargetAccounts`
         *
         * - Description: (Optional) The ID of the AWS account initiating the configuration deployment. You only need to provide a value for this parameter if you want to deploy the configuration locally. A value must be provided for either `TargetAccounts` or `TargetOrganizationalUnits` .
         * - `TargetOrganizationalUnits`
         *
         * - Description: (Optional) A comma separated list of organizational units (OUs) you want to deploy the configuration to.
         * - `TargetRegions`
         *
         * - Description: (Required) A comma separated list of AWS Regions you want to deploy the configuration to.
         * - **Host Management (Type: AWS QuickSetupType-SSMHostMgmt)** - - `UpdateSSMAgent`
         *
         * - Description: (Optional) A boolean value that determines whether the SSM Agent is updated on the target instances every 2 weeks. The default value is " `true` ".
         * - `UpdateEc2LaunchAgent`
         *
         * - Description: (Optional) A boolean value that determines whether the EC2 Launch agent is updated on the target instances every month. The default value is " `false` ".
         * - `CollectInventory`
         *
         * - Description: (Optional) A boolean value that determines whether instance metadata is collected on the target instances every 30 minutes. The default value is " `true` ".
         * - `ScanInstances`
         *
         * - Description: (Optional) A boolean value that determines whether the target instances are scanned daily for available patches. The default value is " `true` ".
         * - `InstallCloudWatchAgent`
         *
         * - Description: (Optional) A boolean value that determines whether the Amazon CloudWatch agent is installed on the target instances. The default value is " `false` ".
         * - `UpdateCloudWatchAgent`
         *
         * - Description: (Optional) A boolean value that determines whether the Amazon CloudWatch agent is updated on the target instances every month. The default value is " `false` ".
         * - `IsPolicyAttachAllowed`
         *
         * - Description: (Optional) A boolean value that determines whether Quick Setup attaches policies to instances profiles already associated with the target instances. The default value is " `false` ".
         * - `TargetType`
         *
         * - Description: (Optional) Determines how instances are targeted for local account deployments. Don't specify a value for this parameter if you're deploying to OUs. The valid values are `*` , `InstanceIds` , `ResourceGroups` , and `Tags` . Use `*` to target all instances in the account.
         * - `TargetInstances`
         *
         * - Description: (Optional) A comma separated list of instance IDs. You must provide a value for this parameter if you specify `InstanceIds` for the `TargetType` parameter.
         * - `TargetTagKey`
         *
         * - Description: (Optional) The tag key assigned to the instances you want to target. You must provide a value for this parameter if you specify `Tags` for the `TargetType` parameter.
         * - `TargetTagValue`
         *
         * - Description: (Optional) The value of the tag key assigned to the instances you want to target. You must provide a value for this parameter if you specify `Tags` for the `TargetType` parameter.
         * - `ResourceGroupName`
         *
         * - Description: (Optional) The name of the resource group associated with the instances you want to target. You must provide a value for this parameter if you specify `ResourceGroups` for the `TargetType` parameter.
         * - `TargetAccounts`
         *
         * - Description: (Optional) The ID of the AWS account initiating the configuration deployment. You only need to provide a value for this parameter if you want to deploy the configuration locally. A value must be provided for either `TargetAccounts` or `TargetOrganizationalUnits` .
         * - `TargetOrganizationalUnits`
         *
         * - Description: (Optional) A comma separated list of organizational units (OUs) you want to deploy the configuration to.
         * - `TargetRegions`
         *
         * - Description: (Required) A comma separated list of AWS Regions you want to deploy the configuration to.
         * - **OpsCenter (Type: AWS QuickSetupType-SSMOpsCenter)** - - `DelegatedAccountId`
         *
         * - Description: (Required) The ID of the delegated administrator account.
         * - `TargetOrganizationalUnits`
         *
         * - Description: (Required) A comma separated list of organizational units (OUs) you want to deploy the configuration to.
         * - `TargetRegions`
         *
         * - Description: (Required) A comma separated list of AWS Regions you want to deploy the configuration to.
         * - **Patch Policy (Type: AWS QuickSetupType-PatchPolicy)** - - `PatchPolicyName`
         *
         * - Description: (Required) A name for the patch policy. The value you provide is applied to target Amazon EC2 instances as a tag.
         * - `SelectedPatchBaselines`
         *
         * - Description: (Required) An array of JSON objects containing the information for the patch baselines to include in your patch policy.
         * - `PatchBaselineUseDefault`
         *
         * - Description: (Optional) A value that determines whether the selected patch baselines are all AWS provided. Supported values are `default` and `custom` .
         * - `PatchBaselineRegion`
         *
         * - Description: (Required) The AWS Region where the patch baseline exist.
         * - `ConfigurationOptionsPatchOperation`
         *
         * - Description: (Optional) Determines whether target instances scan for available patches, or scan and install available patches. The valid values are `Scan` and `ScanAndInstall` . The default value for the parameter is `Scan` .
         * - `ConfigurationOptionsScanValue`
         *
         * - Description: (Optional) A cron expression that is used as the schedule for when instances scan for available patches.
         * - `ConfigurationOptionsInstallValue`
         *
         * - Description: (Optional) A cron expression that is used as the schedule for when instances install available patches.
         * - `ConfigurationOptionsScanNextInterval`
         *
         * - Description: (Optional) A boolean value that determines whether instances should scan for available patches at the next cron interval. The default value is " `false` ".
         * - `ConfigurationOptionsInstallNextInterval`
         *
         * - Description: (Optional) A boolean value that determines whether instances should scan for available patches at the next cron interval. The default value is " `false` ".
         * - `RebootOption`
         *
         * - Description: (Optional) Determines whether instances are rebooted after patches are installed. Valid values are `RebootIfNeeded` and `NoReboot` .
         * - `IsPolicyAttachAllowed`
         *
         * - Description: (Optional) A boolean value that determines whether Quick Setup attaches policies to instances profiles already associated with the target instances. The default value is " `false` ".
         * - `OutputLogEnableS3`
         *
         * - Description: (Optional) A boolean value that determines whether command output logs are sent to Amazon S3.
         * - `OutputS3Location`
         *
         * - Description: (Optional) Information about the Amazon S3 bucket where you want to store the output details of the request.
         *
         * - `OutputBucketRegion`
         *
         * - Description: (Optional) The AWS Region where the Amazon S3 bucket you want to deliver command output to is located.
         * - `OutputS3BucketName`
         *
         * - Description: (Optional) The name of the Amazon S3 bucket you want to deliver command output to.
         * - `OutputS3KeyPrefix`
         *
         * - Description: (Optional) The key prefix you want to use in the custom Amazon S3 bucket.
         * - `TargetType`
         *
         * - Description: (Optional) Determines how instances are targeted for local account deployments. Don't specify a value for this parameter if you're deploying to OUs. The valid values are `*` , `InstanceIds` , `ResourceGroups` , and `Tags` . Use `*` to target all instances in the account.
         * - `TargetInstances`
         *
         * - Description: (Optional) A comma separated list of instance IDs. You must provide a value for this parameter if you specify `InstanceIds` for the `TargetType` parameter.
         * - `TargetTagKey`
         *
         * - Description: (Required) The tag key assigned to the instances you want to target. You must provide a value for this parameter if you specify `Tags` for the `TargetType` parameter.
         * - `TargetTagValue`
         *
         * - Description: (Required) The value of the tag key assigned to the instances you want to target. You must provide a value for this parameter if you specify `Tags` for the `TargetType` parameter.
         * - `ResourceGroupName`
         *
         * - Description: (Required) The name of the resource group associated with the instances you want to target. You must provide a value for this parameter if you specify `ResourceGroups` for the `TargetType` parameter.
         * - `TargetAccounts`
         *
         * - Description: (Optional) The ID of the AWS account initiating the configuration deployment. You only need to provide a value for this parameter if you want to deploy the configuration locally. A value must be provided for either `TargetAccounts` or `TargetOrganizationalUnits` .
         * - `TargetOrganizationalUnits`
         *
         * - Description: (Optional) A comma separated list of organizational units (OUs) you want to deploy the configuration to.
         * - `TargetRegions`
         *
         * - Description: (Required) A comma separated list of AWS Regions you want to deploy the configuration to.
         * - **Resource Explorer (Type: AWS QuickSetupType-ResourceExplorer)** - - `SelectedAggregatorRegion`
         *
         * - Description: (Required) The AWS Region where you want to create the aggregator index.
         * - `ReplaceExistingAggregator`
         *
         * - Description: (Required) A boolean value that determines whether to demote an existing aggregator if it is in a Region that differs from the value you specify for the `SelectedAggregatorRegion` .
         * - `TargetOrganizationalUnits`
         *
         * - Description: (Required) A comma separated list of organizational units (OUs) you want to deploy the configuration to.
         * - `TargetRegions`
         *
         * - Description: (Required) A comma separated list of AWS Regions you want to deploy the configuration to.
         * - **Resource Scheduler (Type: AWS QuickSetupType-Scheduler)** - - `TargetTagKey`
         *
         * - Description: (Required) The tag key assigned to the instances you want to target.
         * - `TargetTagValue`
         *
         * - Description: (Required) The value of the tag key assigned to the instances you want to target.
         * - `ICalendarString`
         *
         * - Description: (Required) An iCalendar formatted string containing the schedule you want Change Manager to use.
         * - `TargetAccounts`
         *
         * - Description: (Optional) The ID of the AWS account initiating the configuration deployment. You only need to provide a value for this parameter if you want to deploy the configuration locally. A value must be provided for either `TargetAccounts` or `TargetOrganizationalUnits` .
         * - `TargetOrganizationalUnits`
         *
         * - Description: (Optional) A comma separated list of organizational units (OUs) you want to deploy the configuration to.
         * - `TargetRegions`
         *
         * - Description: (Required) A comma separated list of AWS Regions you want to deploy the configuration to.
         */
        parameters: pulumi.Input<{
            [key: string]: pulumi.Input<string>;
        }>;
        /**
         * The type of the Quick Setup configuration.
         */
        type: pulumi.Input<string>;
        /**
         * The version of the Quick Setup type used.
         */
        typeVersion?: pulumi.Input<string>;
    }
}
export declare namespace sso {
    /**
     * A structure that describes the options for the access portal associated with an application
     */
    interface ApplicationPortalOptionsConfigurationArgs {
        /**
         * A structure that describes the sign-in options for the access portal
         */
        signInOptions?: pulumi.Input<inputs.sso.ApplicationSignInOptionsArgs>;
        /**
         * Indicates whether this application is visible in the access portal
         */
        visibility?: pulumi.Input<enums.sso.ApplicationPortalOptionsConfigurationVisibility>;
    }
    /**
     * A structure that describes the sign-in options for an application portal
     */
    interface ApplicationSignInOptionsArgs {
        /**
         * The URL that accepts authentication requests for an application, this is a required parameter if the Origin parameter is APPLICATION
         */
        applicationUrl?: pulumi.Input<string>;
        /**
         * This determines how IAM Identity Center navigates the user to the target application
         */
        origin: pulumi.Input<enums.sso.ApplicationSignInOptionsOrigin>;
    }
    interface InstanceAccessControlAttributeConfigurationAccessControlAttributeArgs {
        key: pulumi.Input<string>;
        value: pulumi.Input<inputs.sso.InstanceAccessControlAttributeConfigurationAccessControlAttributeValueArgs>;
    }
    interface InstanceAccessControlAttributeConfigurationAccessControlAttributeValueArgs {
        source: pulumi.Input<pulumi.Input<string>[]>;
    }
    /**
     * The InstanceAccessControlAttributeConfiguration property has been deprecated but is still supported for backwards compatibility purposes. We recomend that you use  AccessControlAttributes property instead.
     */
    interface InstanceAccessControlAttributeConfigurationPropertiesArgs {
        accessControlAttributes: pulumi.Input<pulumi.Input<inputs.sso.InstanceAccessControlAttributeConfigurationAccessControlAttributeArgs>[]>;
    }
    interface PermissionSetCustomerManagedPolicyReferenceArgs {
        /**
         * The name of the IAM policy that you have configured in each account where you want to deploy your permission set.
         */
        name: pulumi.Input<string>;
        /**
         * The path to the IAM policy that you have configured in each account where you want to deploy your permission set. The default is `/` . For more information, see [Friendly names and paths](https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_identifiers.html#identifiers-friendly-names) in the *IAM User Guide* .
         */
        path?: pulumi.Input<string>;
    }
    interface PermissionSetPermissionsBoundaryArgs {
        /**
         * Specifies the name and path of a customer managed policy. You must have an IAM policy that matches the name and path in each AWS account where you want to deploy your permission set.
         */
        customerManagedPolicyReference?: pulumi.Input<inputs.sso.PermissionSetCustomerManagedPolicyReferenceArgs>;
        /**
         * The AWS managed policy ARN that you want to attach to a permission set as a permissions boundary.
         */
        managedPolicyArn?: pulumi.Input<string>;
    }
}
export declare namespace stepfunctions {
    interface ActivityEncryptionConfigurationArgs {
        /**
         * Maximum duration that Step Functions will reuse data keys. When the period expires, Step Functions will call `GenerateDataKey` . Only applies to customer managed keys.
         */
        kmsDataKeyReusePeriodSeconds?: pulumi.Input<number>;
        /**
         * An alias, alias ARN, key ID, or key ARN of a symmetric encryption AWS KMS key to encrypt data. To specify a AWS KMS key in a different AWS account, you must use the key ARN or alias ARN.
         */
        kmsKeyId?: pulumi.Input<string>;
        /**
         * Encryption option for an activity.
         */
        type: pulumi.Input<enums.stepfunctions.ActivityEncryptionConfigurationType>;
    }
    /**
     * The settings to enable gradual state machine deployments.
     */
    interface StateMachineAliasDeploymentPreferenceArgs {
        /**
         * A list of CloudWatch alarm names that will be monitored during the deployment. The deployment will fail and rollback if any alarms go into ALARM state.
         */
        alarms?: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * The time in minutes between each traffic shifting increment.
         */
        interval?: pulumi.Input<number>;
        /**
         * The percentage of traffic to shift to the new version in each increment.
         */
        percentage?: pulumi.Input<number>;
        /**
         * The Amazon Resource Name (ARN) of the [`AWS::StepFunctions::StateMachineVersion`](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-stepfunctions-statemachineversion.html) resource that will be the final version to which the alias points to when the traffic shifting is complete.
         *
         * While performing gradual deployments, you can only provide a single state machine version ARN. To explicitly set version weights in a CloudFormation template, use `RoutingConfiguration` instead.
         */
        stateMachineVersionArn: pulumi.Input<string>;
        /**
         * The type of deployment to perform.
         */
        type: pulumi.Input<enums.stepfunctions.StateMachineAliasDeploymentPreferenceType>;
    }
    interface StateMachineAliasRoutingConfigurationVersionArgs {
        /**
         * The Amazon Resource Name (ARN) that identifies one or two state machine versions defined in the routing configuration.
         */
        stateMachineVersionArn: pulumi.Input<string>;
        /**
         * The percentage of traffic you want to route to the state machine version. The sum of the weights in the routing configuration must be equal to 100.
         */
        weight: pulumi.Input<number>;
    }
    interface StateMachineCloudWatchLogsLogGroupArgs {
        /**
         * The ARN of the the CloudWatch log group to which you want your logs emitted to. The ARN must end with `:*`
         */
        logGroupArn?: pulumi.Input<string>;
    }
    interface StateMachineDefinitionArgs {
    }
    interface StateMachineEncryptionConfigurationArgs {
        /**
         * Maximum duration that Step Functions will reuse data keys. When the period expires, Step Functions will call `GenerateDataKey` . Only applies to customer managed keys.
         */
        kmsDataKeyReusePeriodSeconds?: pulumi.Input<number>;
        /**
         * An alias, alias ARN, key ID, or key ARN of a symmetric encryption AWS KMS key to encrypt data. To specify a AWS KMS key in a different AWS account, you must use the key ARN or alias ARN.
         */
        kmsKeyId?: pulumi.Input<string>;
        /**
         * Encryption option for a state machine.
         */
        type: pulumi.Input<enums.stepfunctions.StateMachineEncryptionConfigurationType>;
    }
    interface StateMachineLogDestinationArgs {
        /**
         * An object describing a CloudWatch log group. For more information, see [AWS::Logs::LogGroup](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-logs-loggroup.html) in the AWS CloudFormation User Guide.
         */
        cloudWatchLogsLogGroup?: pulumi.Input<inputs.stepfunctions.StateMachineCloudWatchLogsLogGroupArgs>;
    }
    interface StateMachineLoggingConfigurationArgs {
        /**
         * An array of objects that describes where your execution history events will be logged. Limited to size 1. Required, if your log level is not set to `OFF` .
         */
        destinations?: pulumi.Input<pulumi.Input<inputs.stepfunctions.StateMachineLogDestinationArgs>[]>;
        /**
         * Determines whether execution data is included in your log. When set to `false` , data is excluded.
         */
        includeExecutionData?: pulumi.Input<boolean>;
        /**
         * Defines which category of execution history events are logged.
         */
        level?: pulumi.Input<enums.stepfunctions.StateMachineLoggingConfigurationLevel>;
    }
    interface StateMachineS3LocationArgs {
        /**
         * The name of the S3 bucket where the state machine definition JSON or YAML file is stored.
         */
        bucket: pulumi.Input<string>;
        /**
         * The name of the state machine definition file (Amazon S3 object name).
         */
        key: pulumi.Input<string>;
        /**
         * For versioning-enabled buckets, a specific version of the state machine definition.
         */
        version?: pulumi.Input<string>;
    }
    interface StateMachineTracingConfigurationArgs {
        /**
         * When set to `true` , X-Ray tracing is enabled.
         */
        enabled?: pulumi.Input<boolean>;
    }
}
export declare namespace synthetics {
    interface CanaryArtifactConfigArgs {
        /**
         * Encryption configuration for uploading artifacts to S3
         */
        s3Encryption?: pulumi.Input<inputs.synthetics.CanaryS3EncryptionArgs>;
    }
    interface CanaryBaseScreenshotArgs {
        /**
         * List of coordinates of rectangles to be ignored during visual testing
         */
        ignoreCoordinates?: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * Name of the screenshot to be used as base reference for visual testing
         */
        screenshotName: pulumi.Input<string>;
    }
    interface CanaryCodeArgs {
        /**
         * The entry point to use for the source code when running the canary. For canaries that use the `syn-python-selenium-1.0` runtime or a `syn-nodejs.puppeteer` runtime earlier than `syn-nodejs.puppeteer-3.4` , the handler must be specified as `*fileName* .handler` . For `syn-python-selenium-1.1` , `syn-nodejs.puppeteer-3.4` , and later runtimes, the handler can be specified as `*fileName* . *functionName*` , or you can specify a folder where canary scripts reside as `*folder* / *fileName* . *functionName*` .
         */
        handler: pulumi.Input<string>;
        /**
         * If your canary script is located in S3, specify the bucket name here. The bucket must already exist.
         */
        s3Bucket?: pulumi.Input<string>;
        /**
         * The S3 key of your script. For more information, see [Working with Amazon S3 Objects](https://docs.aws.amazon.com/AmazonS3/latest/dev/UsingObjects.html) .
         */
        s3Key?: pulumi.Input<string>;
        /**
         * The S3 version ID of your script.
         */
        s3ObjectVersion?: pulumi.Input<string>;
        /**
         * If you input your canary script directly into the canary instead of referring to an S3 location, the value of this parameter is the script in plain text. It can be up to 5 MB.
         */
        script?: pulumi.Input<string>;
        /**
         * The ARN of the Lambda layer where Synthetics stores the canary script code.
         */
        sourceLocationArn?: pulumi.Input<string>;
    }
    interface CanaryRunConfigArgs {
        /**
         * Enable active tracing if set to true
         */
        activeTracing?: pulumi.Input<boolean>;
        /**
         * Environment variable key-value pairs.
         */
        environmentVariables?: pulumi.Input<{
            [key: string]: pulumi.Input<string>;
        }>;
        /**
         * Provide maximum memory available for canary in MB
         */
        memoryInMb?: pulumi.Input<number>;
        /**
         * Provide maximum canary timeout per run in seconds
         */
        timeoutInSeconds?: pulumi.Input<number>;
    }
    interface CanaryS3EncryptionArgs {
        /**
         * Encryption mode for encrypting artifacts when uploading to S3. Valid values: SSE_S3 and SSE_KMS.
         */
        encryptionMode?: pulumi.Input<string>;
        /**
         * KMS key Arn for encrypting artifacts when uploading to S3. You must specify KMS key Arn for SSE_KMS encryption mode only.
         */
        kmsKeyArn?: pulumi.Input<string>;
    }
    interface CanaryScheduleArgs {
        /**
         * How long, in seconds, for the canary to continue making regular runs according to the schedule in the `Expression` value. If you specify 0, the canary continues making runs until you stop it. If you omit this field, the default of 0 is used.
         */
        durationInSeconds?: pulumi.Input<string>;
        /**
         * A `rate` expression or a `cron` expression that defines how often the canary is to run.
         *
         * For a rate expression, The syntax is `rate( *number unit* )` . *unit* can be `minute` , `minutes` , or `hour` .
         *
         * For example, `rate(1 minute)` runs the canary once a minute, `rate(10 minutes)` runs it once every 10 minutes, and `rate(1 hour)` runs it once every hour. You can specify a frequency between `rate(1 minute)` and `rate(1 hour)` .
         *
         * Specifying `rate(0 minute)` or `rate(0 hour)` is a special value that causes the canary to run only once when it is started.
         *
         * Use `cron( *expression* )` to specify a cron expression. You can't schedule a canary to wait for more than a year before running. For information about the syntax for cron expressions, see [Scheduling canary runs using cron](https://docs.aws.amazon.com/AmazonCloudWatch/latest/monitoring/CloudWatch_Synthetics_Canaries_cron.html) .
         */
        expression: pulumi.Input<string>;
    }
    interface CanaryVisualReferenceArgs {
        /**
         * Canary run id to be used as base reference for visual testing
         */
        baseCanaryRunId: pulumi.Input<string>;
        /**
         * List of screenshots used as base reference for visual testing
         */
        baseScreenshots?: pulumi.Input<pulumi.Input<inputs.synthetics.CanaryBaseScreenshotArgs>[]>;
    }
    interface CanaryVpcConfigArgs {
        /**
         * Allow outbound IPv6 traffic on VPC canaries that are connected to dual-stack subnets if set to true
         */
        ipv6AllowedForDualStack?: pulumi.Input<boolean>;
        /**
         * The IDs of the security groups for this canary.
         */
        securityGroupIds: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * The IDs of the subnets where this canary is to run.
         */
        subnetIds: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * The ID of the VPC where this canary is to run.
         */
        vpcId?: pulumi.Input<string>;
    }
}
export declare namespace systemsmanagersap {
    interface ApplicationComponentInfoArgs {
        /**
         * This string is the type of the component.
         *
         * Accepted value is `WD` .
         */
        componentType?: pulumi.Input<enums.systemsmanagersap.ApplicationComponentInfoComponentType>;
        /**
         * This is the Amazon EC2 instance on which your SAP component is running.
         *
         * Accepted values are alphanumeric.
         */
        ec2InstanceId?: pulumi.Input<string>;
        /**
         * This string is the SAP System ID of the component.
         *
         * Accepted values are alphanumeric.
         */
        sid?: pulumi.Input<string>;
    }
    interface ApplicationCredentialArgs {
        /**
         * The type of the application credentials.
         */
        credentialType?: pulumi.Input<enums.systemsmanagersap.ApplicationCredentialCredentialType>;
        /**
         * The name of the SAP HANA database.
         */
        databaseName?: pulumi.Input<string>;
        /**
         * The secret ID created in AWS Secrets Manager to store the credentials of the SAP application.
         */
        secretId?: pulumi.Input<string>;
    }
}
export declare namespace timestream {
    /**
     * Configuration for sending logs to customer account from the InfluxDB instance.
     */
    interface LogDeliveryConfigurationPropertiesArgs {
        /**
         * S3 configuration for sending logs to customer account from the InfluxDB instance.
         */
        s3Configuration: pulumi.Input<inputs.timestream.LogDeliveryConfigurationPropertiesS3ConfigurationPropertiesArgs>;
    }
    /**
     * S3 configuration for sending logs to customer account from the InfluxDB instance.
     */
    interface LogDeliveryConfigurationPropertiesS3ConfigurationPropertiesArgs {
        /**
         * The bucket name for logs to be sent from the InfluxDB instance
         */
        bucketName: pulumi.Input<string>;
        /**
         * Specifies whether logging to customer specified bucket is enabled.
         */
        enabled: pulumi.Input<boolean>;
    }
    /**
     * The properties that determine whether magnetic store writes are enabled.
     */
    interface MagneticStoreWritePropertiesPropertiesArgs {
        /**
         * Boolean flag indicating whether magnetic store writes are enabled.
         */
        enableMagneticStoreWrites: pulumi.Input<boolean>;
        /**
         * Location to store information about records that were asynchronously rejected during magnetic store writes.
         */
        magneticStoreRejectedDataLocation?: pulumi.Input<inputs.timestream.MagneticStoreWritePropertiesPropertiesMagneticStoreRejectedDataLocationPropertiesArgs>;
    }
    /**
     * Location to store information about records that were asynchronously rejected during magnetic store writes.
     */
    interface MagneticStoreWritePropertiesPropertiesMagneticStoreRejectedDataLocationPropertiesArgs {
        /**
         * S3 configuration for location to store rejections from magnetic store writes
         */
        s3Configuration?: pulumi.Input<inputs.timestream.MagneticStoreWritePropertiesPropertiesMagneticStoreRejectedDataLocationPropertiesS3ConfigurationPropertiesArgs>;
    }
    /**
     * S3 configuration for location to store rejections from magnetic store writes
     */
    interface MagneticStoreWritePropertiesPropertiesMagneticStoreRejectedDataLocationPropertiesS3ConfigurationPropertiesArgs {
        /**
         * The bucket name used to store the data.
         */
        bucketName: pulumi.Input<string>;
        /**
         * Either SSE_KMS or SSE_S3.
         */
        encryptionOption: pulumi.Input<string>;
        /**
         * Must be provided if SSE_KMS is specified as the encryption option
         */
        kmsKeyId?: pulumi.Input<string>;
        /**
         * String used to prefix all data in the bucket.
         */
        objectKeyPrefix?: pulumi.Input<string>;
    }
    /**
     * The retention duration of the memory store and the magnetic store.
     */
    interface RetentionPropertiesPropertiesArgs {
        /**
         * The duration for which data must be stored in the magnetic store.
         */
        magneticStoreRetentionPeriodInDays?: pulumi.Input<string>;
        /**
         * The duration for which data must be stored in the memory store.
         */
        memoryStoreRetentionPeriodInHours?: pulumi.Input<string>;
    }
    /**
     * This type is used to map column(s) from the query result to a dimension in the destination table.
     */
    interface ScheduledQueryDimensionMappingArgs {
        dimensionValueType: pulumi.Input<enums.timestream.ScheduledQueryDimensionValueType>;
        name: pulumi.Input<string>;
    }
    /**
     * Configuration for error reporting. Error reports will be generated when a problem is encountered when writing the query results.
     */
    interface ScheduledQueryErrorReportConfigurationArgs {
        /**
         * The S3 configuration for the error reports.
         */
        s3Configuration: pulumi.Input<inputs.timestream.ScheduledQueryS3ConfigurationArgs>;
    }
    /**
     * MixedMeasureMappings are mappings that can be used to ingest data into a mixture of narrow and multi measures in the derived table.
     */
    interface ScheduledQueryMixedMeasureMappingArgs {
        measureName?: pulumi.Input<string>;
        measureValueType: pulumi.Input<enums.timestream.ScheduledQueryMixedMeasureMappingMeasureValueType>;
        multiMeasureAttributeMappings?: pulumi.Input<pulumi.Input<inputs.timestream.ScheduledQueryMultiMeasureAttributeMappingArgs>[]>;
        sourceColumn?: pulumi.Input<string>;
        targetMeasureName?: pulumi.Input<string>;
    }
    /**
     * An attribute mapping to be used for mapping query results to ingest data for multi-measure attributes.
     */
    interface ScheduledQueryMultiMeasureAttributeMappingArgs {
        measureValueType: pulumi.Input<enums.timestream.ScheduledQueryMultiMeasureAttributeMappingMeasureValueType>;
        sourceColumn: pulumi.Input<string>;
        targetMultiMeasureAttributeName?: pulumi.Input<string>;
    }
    /**
     * Only one of MixedMeasureMappings or MultiMeasureMappings is to be provided. MultiMeasureMappings can be used to ingest data as multi measures in the derived table.
     */
    interface ScheduledQueryMultiMeasureMappingsArgs {
        /**
         * Required. Attribute mappings to be used for mapping query results to ingest data for multi-measure attributes.
         */
        multiMeasureAttributeMappings: pulumi.Input<pulumi.Input<inputs.timestream.ScheduledQueryMultiMeasureAttributeMappingArgs>[]>;
        /**
         * The name of the target multi-measure name in the derived table. This input is required when measureNameColumn is not provided. If MeasureNameColumn is provided, then value from that column will be used as multi-measure name.
         */
        targetMultiMeasureName?: pulumi.Input<string>;
    }
    /**
     * Notification configuration for the scheduled query. A notification is sent by Timestream when a query run finishes, when the state is updated or when you delete it.
     */
    interface ScheduledQueryNotificationConfigurationArgs {
        /**
         * Details on SNS configuration.
         */
        snsConfiguration: pulumi.Input<inputs.timestream.ScheduledQuerySnsConfigurationArgs>;
    }
    /**
     * Details on S3 location for error reports that result from running a query.
     */
    interface ScheduledQueryS3ConfigurationArgs {
        /**
         * Name of the S3 bucket under which error reports will be created.
         */
        bucketName: pulumi.Input<string>;
        /**
         * Encryption at rest options for the error reports. If no encryption option is specified, Timestream will choose SSE_S3 as default.
         */
        encryptionOption?: pulumi.Input<enums.timestream.ScheduledQueryEncryptionOption>;
        /**
         * Prefix for the error report key. Timestream by default adds the following prefix to the error report path.
         */
        objectKeyPrefix?: pulumi.Input<string>;
    }
    /**
     * Configuration for when the scheduled query is executed.
     */
    interface ScheduledQueryScheduleConfigurationArgs {
        /**
         * An expression that denotes when to trigger the scheduled query run. This can be a cron expression or a rate expression.
         */
        scheduleExpression: pulumi.Input<string>;
    }
    /**
     * SNS configuration for notification upon scheduled query execution.
     */
    interface ScheduledQuerySnsConfigurationArgs {
        /**
         * SNS topic ARN that the scheduled query status notifications will be sent to.
         */
        topicArn: pulumi.Input<string>;
    }
    /**
     * Configuration of target store where scheduled query results are written to.
     */
    interface ScheduledQueryTargetConfigurationArgs {
        /**
         * Configuration needed to write data into the Timestream database and table.
         */
        timestreamConfiguration: pulumi.Input<inputs.timestream.ScheduledQueryTimestreamConfigurationArgs>;
    }
    /**
     * Configuration needed to write data into the Timestream database and table.
     */
    interface ScheduledQueryTimestreamConfigurationArgs {
        /**
         * Name of Timestream database to which the query result will be written.
         */
        databaseName: pulumi.Input<string>;
        /**
         * This is to allow mapping column(s) from the query result to the dimension in the destination table.
         */
        dimensionMappings: pulumi.Input<pulumi.Input<inputs.timestream.ScheduledQueryDimensionMappingArgs>[]>;
        /**
         * Name of the measure column. Also see `MultiMeasureMappings` and `MixedMeasureMappings` for how measure name properties on those relate to `MeasureNameColumn` .
         */
        measureNameColumn?: pulumi.Input<string>;
        /**
         * Specifies how to map measures to multi-measure records.
         */
        mixedMeasureMappings?: pulumi.Input<pulumi.Input<inputs.timestream.ScheduledQueryMixedMeasureMappingArgs>[]>;
        /**
         * Multi-measure mappings.
         */
        multiMeasureMappings?: pulumi.Input<inputs.timestream.ScheduledQueryMultiMeasureMappingsArgs>;
        /**
         * Name of Timestream table that the query result will be written to. The table should be within the same database that is provided in Timestream configuration.
         */
        tableName: pulumi.Input<string>;
        /**
         * Column from query result that should be used as the time column in destination table. Column type for this should be TIMESTAMP.
         */
        timeColumn: pulumi.Input<string>;
    }
    /**
     * A Schema specifies the expected data model of the table.
     */
    interface SchemaPropertiesArgs {
        /**
         * A non-empty list of partition keys defining the attributes used to partition the table data. The order of the list determines the partition hierarchy. The name and type of each partition key as well as the partition key order cannot be changed after the table is created. However, the enforcement level of each partition key can be changed.
         */
        compositePartitionKey?: pulumi.Input<pulumi.Input<inputs.timestream.TablePartitionKeyArgs>[]>;
    }
    /**
     * An attribute used in partitioning data in a table. There are two types of partition keys: dimension keys and measure keys. A dimension key partitions data on a dimension name, while a measure key partitions data on the measure name.
     */
    interface TablePartitionKeyArgs {
        enforcementInRecord?: pulumi.Input<enums.timestream.TablePartitionKeyEnforcementLevel>;
        name?: pulumi.Input<string>;
        type: pulumi.Input<enums.timestream.TablePartitionKeyType>;
    }
}
export declare namespace transfer {
    /**
     * Configuration for an AS2 connector.
     */
    interface As2ConfigPropertiesArgs {
        /**
         * ARN or name of the secret in AWS Secrets Manager which contains the credentials for Basic authentication. If empty, Basic authentication is disabled for the AS2 connector
         */
        basicAuthSecretId?: pulumi.Input<string>;
        /**
         * Compression setting for this AS2 connector configuration.
         */
        compression?: pulumi.Input<enums.transfer.ConnectorAs2ConfigPropertiesCompression>;
        /**
         * Encryption algorithm for this AS2 connector configuration.
         */
        encryptionAlgorithm?: pulumi.Input<enums.transfer.ConnectorAs2ConfigPropertiesEncryptionAlgorithm>;
        /**
         * A unique identifier for the local profile.
         */
        localProfileId?: pulumi.Input<string>;
        /**
         * MDN Response setting for this AS2 connector configuration.
         */
        mdnResponse?: pulumi.Input<enums.transfer.ConnectorAs2ConfigPropertiesMdnResponse>;
        /**
         * MDN Signing algorithm for this AS2 connector configuration.
         */
        mdnSigningAlgorithm?: pulumi.Input<enums.transfer.ConnectorAs2ConfigPropertiesMdnSigningAlgorithm>;
        /**
         * The message subject for this AS2 connector configuration.
         */
        messageSubject?: pulumi.Input<string>;
        /**
         * A unique identifier for the partner profile.
         */
        partnerProfileId?: pulumi.Input<string>;
        /**
         * Specifies whether to use the AWS S3 object content-type as the content-type for the AS2 message.
         */
        preserveContentType?: pulumi.Input<enums.transfer.ConnectorAs2ConfigPropertiesPreserveContentType>;
        /**
         * Signing algorithm for this AS2 connector configuration.
         */
        signingAlgorithm?: pulumi.Input<enums.transfer.ConnectorAs2ConfigPropertiesSigningAlgorithm>;
    }
    /**
     * Specifies a separate directory for each type of file to store for an AS2 message.
     */
    interface CustomDirectoriesPropertiesArgs {
        /**
         * Specifies a location to store the failed files for an AS2 message.
         */
        failedFilesDirectory: pulumi.Input<string>;
        /**
         * Specifies a location to store the MDN file for an AS2 message.
         */
        mdnFilesDirectory: pulumi.Input<string>;
        /**
         * Specifies a location to store the payload file for an AS2 message.
         */
        payloadFilesDirectory: pulumi.Input<string>;
        /**
         * Specifies a location to store the status file for an AS2 message.
         */
        statusFilesDirectory: pulumi.Input<string>;
        /**
         * Specifies a location to store the temporary processing file for an AS2 message.
         */
        temporaryFilesDirectory: pulumi.Input<string>;
    }
    interface ServerEndpointDetailsArgs {
        /**
         * A list of address allocation IDs that are required to attach an Elastic IP address to your server's endpoint.
         *
         * An address allocation ID corresponds to the allocation ID of an Elastic IP address. This value can be retrieved from the `allocationId` field from the Amazon EC2 [Address](https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_Address.html) data type. One way to retrieve this value is by calling the EC2 [DescribeAddresses](https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_DescribeAddresses.html) API.
         *
         * This parameter is optional. Set this parameter if you want to make your VPC endpoint public-facing. For details, see [Create an internet-facing endpoint for your server](https://docs.aws.amazon.com/transfer/latest/userguide/create-server-in-vpc.html#create-internet-facing-endpoint) .
         *
         * > This property can only be set as follows:
         * >
         * > - `EndpointType` must be set to `VPC`
         * > - The Transfer Family server must be offline.
         * > - You cannot set this parameter for Transfer Family servers that use the FTP protocol.
         * > - The server must already have `SubnetIds` populated ( `SubnetIds` and `AddressAllocationIds` cannot be updated simultaneously).
         * > - `AddressAllocationIds` can't contain duplicates, and must be equal in length to `SubnetIds` . For example, if you have three subnet IDs, you must also specify three address allocation IDs.
         * > - Call the `UpdateServer` API to set or change this parameter.
         */
        addressAllocationIds?: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * A list of security groups IDs that are available to attach to your server's endpoint.
         *
         * > This property can only be set when `EndpointType` is set to `VPC` .
         * >
         * > You can edit the `SecurityGroupIds` property in the [UpdateServer](https://docs.aws.amazon.com/transfer/latest/userguide/API_UpdateServer.html) API only if you are changing the `EndpointType` from `PUBLIC` or `VPC_ENDPOINT` to `VPC` . To change security groups associated with your server's VPC endpoint after creation, use the Amazon EC2 [ModifyVpcEndpoint](https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_ModifyVpcEndpoint.html) API.
         */
        securityGroupIds?: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * A list of subnet IDs that are required to host your server endpoint in your VPC.
         *
         * > This property can only be set when `EndpointType` is set to `VPC` .
         */
        subnetIds?: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * The ID of the VPC endpoint.
         *
         * > This property can only be set when `EndpointType` is set to `VPC_ENDPOINT` .
         */
        vpcEndpointId?: pulumi.Input<string>;
        /**
         * The VPC ID of the virtual private cloud in which the server's endpoint will be hosted.
         *
         * > This property can only be set when `EndpointType` is set to `VPC` .
         */
        vpcId?: pulumi.Input<string>;
    }
    interface ServerIdentityProviderDetailsArgs {
        /**
         * The identifier of the AWS Directory Service directory that you want to use as your identity provider.
         */
        directoryId?: pulumi.Input<string>;
        /**
         * The ARN for a Lambda function to use for the Identity provider.
         */
        function?: pulumi.Input<string>;
        /**
         * This parameter is only applicable if your `IdentityProviderType` is `API_GATEWAY` . Provides the type of `InvocationRole` used to authenticate the user account.
         */
        invocationRole?: pulumi.Input<string>;
        /**
         * For SFTP-enabled servers, and for custom identity providers *only* , you can specify whether to authenticate using a password, SSH key pair, or both.
         *
         * - `PASSWORD` - users must provide their password to connect.
         * - `PUBLIC_KEY` - users must provide their private key to connect.
         * - `PUBLIC_KEY_OR_PASSWORD` - users can authenticate with either their password or their key. This is the default value.
         * - `PUBLIC_KEY_AND_PASSWORD` - users must provide both their private key and their password to connect. The server checks the key first, and then if the key is valid, the system prompts for a password. If the private key provided does not match the public key that is stored, authentication fails.
         */
        sftpAuthenticationMethods?: pulumi.Input<enums.transfer.ServerSftpAuthenticationMethods>;
        /**
         * Provides the location of the service endpoint used to authenticate users.
         */
        url?: pulumi.Input<string>;
    }
    interface ServerProtocolDetailsArgs {
        /**
         * List of `As2Transport` objects.
         */
        as2Transports?: pulumi.Input<pulumi.Input<enums.transfer.ServerAs2Transport>[]>;
        /**
         * Indicates passive mode, for FTP and FTPS protocols. Enter a single IPv4 address, such as the public IP address of a firewall, router, or load balancer. For example:
         *
         * `aws transfer update-server --protocol-details PassiveIp=0.0.0.0`
         *
         * Replace `0.0.0.0` in the example above with the actual IP address you want to use.
         *
         * > If you change the `PassiveIp` value, you must stop and then restart your Transfer Family server for the change to take effect. For details on using passive mode (PASV) in a NAT environment, see [Configuring your FTPS server behind a firewall or NAT with AWS Transfer Family](https://docs.aws.amazon.com/storage/configuring-your-ftps-server-behind-a-firewall-or-nat-with-aws-transfer-family/) .
         *
         * *Special values*
         *
         * The `AUTO` and `0.0.0.0` are special values for the `PassiveIp` parameter. The value `PassiveIp=AUTO` is assigned by default to FTP and FTPS type servers. In this case, the server automatically responds with one of the endpoint IPs within the PASV response. `PassiveIp=0.0.0.0` has a more unique application for its usage. For example, if you have a High Availability (HA) Network Load Balancer (NLB) environment, where you have 3 subnets, you can only specify a single IP address using the `PassiveIp` parameter. This reduces the effectiveness of having High Availability. In this case, you can specify `PassiveIp=0.0.0.0` . This tells the client to use the same IP address as the Control connection and utilize all AZs for their connections. Note, however, that not all FTP clients support the `PassiveIp=0.0.0.0` response. FileZilla and WinSCP do support it. If you are using other clients, check to see if your client supports the `PassiveIp=0.0.0.0` response.
         */
        passiveIp?: pulumi.Input<string>;
        /**
         * Use the `SetStatOption` to ignore the error that is generated when the client attempts to use `SETSTAT` on a file you are uploading to an S3 bucket.
         *
         * Some SFTP file transfer clients can attempt to change the attributes of remote files, including timestamp and permissions, using commands, such as `SETSTAT` when uploading the file. However, these commands are not compatible with object storage systems, such as Amazon S3. Due to this incompatibility, file uploads from these clients can result in errors even when the file is otherwise successfully uploaded.
         *
         * Set the value to `ENABLE_NO_OP` to have the Transfer Family server ignore the `SETSTAT` command, and upload files without needing to make any changes to your SFTP client. While the `SetStatOption` `ENABLE_NO_OP` setting ignores the error, it does generate a log entry in Amazon CloudWatch Logs, so you can determine when the client is making a `SETSTAT` call.
         *
         * > If you want to preserve the original timestamp for your file, and modify other file attributes using `SETSTAT` , you can use Amazon EFS as backend storage with Transfer Family.
         */
        setStatOption?: pulumi.Input<enums.transfer.ServerSetStatOption>;
        /**
         * A property used with Transfer Family servers that use the FTPS protocol. TLS Session Resumption provides a mechanism to resume or share a negotiated secret key between the control and data connection for an FTPS session. `TlsSessionResumptionMode` determines whether or not the server resumes recent, negotiated sessions through a unique session ID. This property is available during `CreateServer` and `UpdateServer` calls. If a `TlsSessionResumptionMode` value is not specified during `CreateServer` , it is set to `ENFORCED` by default.
         *
         * - `DISABLED` : the server does not process TLS session resumption client requests and creates a new TLS session for each request.
         * - `ENABLED` : the server processes and accepts clients that are performing TLS session resumption. The server doesn't reject client data connections that do not perform the TLS session resumption client processing.
         * - `ENFORCED` : the server processes and accepts clients that are performing TLS session resumption. The server rejects client data connections that do not perform the TLS session resumption client processing. Before you set the value to `ENFORCED` , test your clients.
         *
         * > Not all FTPS clients perform TLS session resumption. So, if you choose to enforce TLS session resumption, you prevent any connections from FTPS clients that don't perform the protocol negotiation. To determine whether or not you can use the `ENFORCED` value, you need to test your clients.
         */
        tlsSessionResumptionMode?: pulumi.Input<enums.transfer.ServerTlsSessionResumptionMode>;
    }
    interface ServerS3StorageOptionsArgs {
        /**
         * Specifies whether or not performance for your Amazon S3 directories is optimized. This is disabled by default.
         *
         * By default, home directory mappings have a `TYPE` of `DIRECTORY` . If you enable this option, you would then need to explicitly set the `HomeDirectoryMapEntry` `Type` to `FILE` if you want a mapping to have a file target.
         */
        directoryListingOptimization?: pulumi.Input<enums.transfer.ServerDirectoryListingOptimization>;
    }
    interface ServerWorkflowDetailArgs {
        /**
         * Includes the necessary permissions for S3, EFS, and Lambda operations that Transfer can assume, so that all workflow steps can operate on the required resources
         */
        executionRole: pulumi.Input<string>;
        /**
         * A unique identifier for the workflow.
         */
        workflowId: pulumi.Input<string>;
    }
    interface ServerWorkflowDetailsArgs {
        /**
         * A trigger that starts a workflow if a file is only partially uploaded. You can attach a workflow to a server that executes whenever there is a partial upload.
         *
         * A *partial upload* occurs when a file is open when the session disconnects.
         *
         * > `OnPartialUpload` can contain a maximum of one `WorkflowDetail` object.
         */
        onPartialUpload?: pulumi.Input<pulumi.Input<inputs.transfer.ServerWorkflowDetailArgs>[]>;
        /**
         * A trigger that starts a workflow: the workflow begins to execute after a file is uploaded.
         *
         * To remove an associated workflow from a server, you can provide an empty `OnUpload` object, as in the following example.
         *
         * `aws transfer update-server --server-id s-01234567890abcdef --workflow-details '{"OnUpload":[]}'`
         *
         * > `OnUpload` can contain a maximum of one `WorkflowDetail` object.
         */
        onUpload?: pulumi.Input<pulumi.Input<inputs.transfer.ServerWorkflowDetailArgs>[]>;
    }
    /**
     * Configuration for an SFTP connector.
     */
    interface SftpConfigPropertiesArgs {
        /**
         * List of public host keys, for the external server to which you are connecting.
         */
        trustedHostKeys?: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * ARN or name of the secret in AWS Secrets Manager which contains the SFTP user's private keys or passwords.
         */
        userSecretId?: pulumi.Input<string>;
    }
    interface UserHomeDirectoryMapEntryArgs {
        /**
         * Represents an entry for `HomeDirectoryMappings` .
         */
        entry: pulumi.Input<string>;
        /**
         * Represents the map target that is used in a `HomeDirectoryMapEntry` .
         */
        target: pulumi.Input<string>;
        /**
         * Specifies the type of mapping. Set the type to `FILE` if you want the mapping to point to a file, or `DIRECTORY` for the directory to point to a directory.
         *
         * > By default, home directory mappings have a `Type` of `DIRECTORY` when you create a Transfer Family server. You would need to explicitly set `Type` to `FILE` if you want a mapping to have a file target.
         */
        type?: pulumi.Input<enums.transfer.UserMapType>;
    }
    interface UserPosixProfileArgs {
        /**
         * The POSIX group ID used for all EFS operations by this user.
         */
        gid: pulumi.Input<number>;
        /**
         * The secondary POSIX group IDs used for all EFS operations by this user.
         */
        secondaryGids?: pulumi.Input<pulumi.Input<number>[]>;
        /**
         * The POSIX user ID used for all EFS operations by this user.
         */
        uid: pulumi.Input<number>;
    }
    interface WebAppCustomizationArgs {
        /**
         * Specifies a favicon to display in the browser tab.
         */
        faviconFile?: pulumi.Input<string>;
        /**
         * Specifies a logo to display on the web app.
         */
        logoFile?: pulumi.Input<string>;
        /**
         * Specifies a title to display on the web app.
         */
        title?: pulumi.Input<string>;
    }
    /**
     * You can provide a structure that contains the details for the identity provider to use with your web app.
     */
    interface WebAppIdentityProviderDetailsArgs {
        /**
         * The Amazon Resource Name (ARN) for the IAM Identity Center application: this value is set automatically when you create your web app.
         */
        applicationArn?: pulumi.Input<string>;
        /**
         * The Amazon Resource Name (ARN) for the IAM Identity Center used for the web app.
         */
        instanceArn?: pulumi.Input<string>;
        /**
         * The IAM role in IAM Identity Center used for the web app.
         */
        role?: pulumi.Input<string>;
    }
    /**
     * A union that contains the value for number of concurrent connections or the user sessions on your web app.
     */
    interface WebAppUnitsPropertiesArgs {
        provisioned: pulumi.Input<number>;
    }
    /**
     * Specifies the details for an EFS file.
     */
    interface WorkflowEfsInputFileLocationArgs {
        /**
         * Specifies the EFS filesystem that contains the file.
         */
        fileSystemId?: pulumi.Input<string>;
        /**
         * The name assigned to the file when it was created in EFS. You use the object path to retrieve the object.
         */
        path?: pulumi.Input<string>;
    }
    /**
     * Specifies the location for the file being decrypted. Only applicable for the Decrypt type of workflow steps.
     */
    interface WorkflowInputFileLocationArgs {
        efsFileLocation?: pulumi.Input<inputs.transfer.WorkflowEfsInputFileLocationArgs>;
        s3FileLocation?: pulumi.Input<inputs.transfer.WorkflowS3InputFileLocationArgs>;
    }
    /**
     * Specifies the location for the file being copied. Only applicable for the Copy type of workflow steps.
     */
    interface WorkflowS3FileLocationArgs {
        /**
         * Specifies the details for the file location for the file that's being used in the workflow. Only applicable if you are using Amazon S3 storage.
         */
        s3FileLocation?: pulumi.Input<inputs.transfer.WorkflowS3InputFileLocationArgs>;
    }
    /**
     * Specifies the details for a S3 file.
     */
    interface WorkflowS3InputFileLocationArgs {
        /**
         * Specifies the S3 bucket that contains the file.
         */
        bucket?: pulumi.Input<string>;
        /**
         * The name assigned to the file when it was created in S3. You use the object key to retrieve the object.
         */
        key?: pulumi.Input<string>;
    }
    /**
     * Specifies the key-value pair that are assigned to a file during the execution of a Tagging step.
     */
    interface WorkflowS3TagArgs {
        /**
         * The name assigned to the tag that you create.
         */
        key: pulumi.Input<string>;
        /**
         * The value that corresponds to the key.
         */
        value: pulumi.Input<string>;
    }
    /**
     * The basic building block of a workflow.
     */
    interface WorkflowStepArgs {
        /**
         * Details for a step that performs a file copy.
         */
        copyStepDetails?: pulumi.Input<inputs.transfer.WorkflowStepCopyStepDetailsPropertiesArgs>;
        /**
         * Details for a step that invokes a lambda function.
         */
        customStepDetails?: pulumi.Input<inputs.transfer.WorkflowStepCustomStepDetailsPropertiesArgs>;
        /**
         * Details for a step that performs a file decryption.
         */
        decryptStepDetails?: pulumi.Input<inputs.transfer.WorkflowStepDecryptStepDetailsPropertiesArgs>;
        /**
         * Details for a step that deletes the file.
         */
        deleteStepDetails?: pulumi.Input<inputs.transfer.WorkflowStepDeleteStepDetailsPropertiesArgs>;
        /**
         * Details for a step that creates one or more tags.
         */
        tagStepDetails?: pulumi.Input<inputs.transfer.WorkflowStepTagStepDetailsPropertiesArgs>;
        type?: pulumi.Input<enums.transfer.WorkflowStepType>;
    }
    /**
     * Details for a step that performs a file copy.
     */
    interface WorkflowStepCopyStepDetailsPropertiesArgs {
        destinationFileLocation?: pulumi.Input<inputs.transfer.WorkflowS3FileLocationArgs>;
        /**
         * The name of the step, used as an identifier.
         */
        name?: pulumi.Input<string>;
        /**
         * A flag that indicates whether or not to overwrite an existing file of the same name. The default is FALSE.
         */
        overwriteExisting?: pulumi.Input<enums.transfer.WorkflowStepCopyStepDetailsPropertiesOverwriteExisting>;
        /**
         * Specifies which file to use as input to the workflow step.
         */
        sourceFileLocation?: pulumi.Input<string>;
    }
    /**
     * Details for a step that invokes a lambda function.
     */
    interface WorkflowStepCustomStepDetailsPropertiesArgs {
        /**
         * The name of the step, used as an identifier.
         */
        name?: pulumi.Input<string>;
        /**
         * Specifies which file to use as input to the workflow step.
         */
        sourceFileLocation?: pulumi.Input<string>;
        /**
         * The ARN for the lambda function that is being called.
         */
        target?: pulumi.Input<string>;
        /**
         * Timeout, in seconds, for the step.
         */
        timeoutSeconds?: pulumi.Input<number>;
    }
    /**
     * Details for a step that performs a file decryption.
     */
    interface WorkflowStepDecryptStepDetailsPropertiesArgs {
        destinationFileLocation: pulumi.Input<inputs.transfer.WorkflowInputFileLocationArgs>;
        /**
         * The name of the step, used as an identifier.
         */
        name?: pulumi.Input<string>;
        /**
         * A flag that indicates whether or not to overwrite an existing file of the same name. The default is FALSE.
         */
        overwriteExisting?: pulumi.Input<enums.transfer.WorkflowStepDecryptStepDetailsPropertiesOverwriteExisting>;
        /**
         * Specifies which file to use as input to the workflow step.
         */
        sourceFileLocation?: pulumi.Input<string>;
        /**
         * Specifies which encryption method to use.
         */
        type: pulumi.Input<enums.transfer.WorkflowStepDecryptStepDetailsPropertiesType>;
    }
    /**
     * Details for a step that deletes the file.
     */
    interface WorkflowStepDeleteStepDetailsPropertiesArgs {
        /**
         * The name of the step, used as an identifier.
         */
        name?: pulumi.Input<string>;
        /**
         * Specifies which file to use as input to the workflow step.
         */
        sourceFileLocation?: pulumi.Input<string>;
    }
    /**
     * Details for a step that creates one or more tags.
     */
    interface WorkflowStepTagStepDetailsPropertiesArgs {
        /**
         * The name of the step, used as an identifier.
         */
        name?: pulumi.Input<string>;
        /**
         * Specifies which file to use as input to the workflow step.
         */
        sourceFileLocation?: pulumi.Input<string>;
        /**
         * Array that contains from 1 to 10 key/value pairs.
         */
        tags?: pulumi.Input<pulumi.Input<inputs.transfer.WorkflowS3TagArgs>[]>;
    }
}
export declare namespace verifiedpermissions {
    interface IdentitySourceCognitoGroupConfigurationArgs {
        groupEntityType: pulumi.Input<string>;
    }
    interface IdentitySourceCognitoUserPoolConfigurationArgs {
        clientIds?: pulumi.Input<pulumi.Input<string>[]>;
        groupConfiguration?: pulumi.Input<inputs.verifiedpermissions.IdentitySourceCognitoGroupConfigurationArgs>;
        userPoolArn: pulumi.Input<string>;
    }
    interface IdentitySourceConfiguration0PropertiesArgs {
        cognitoUserPoolConfiguration: pulumi.Input<inputs.verifiedpermissions.IdentitySourceCognitoUserPoolConfigurationArgs>;
    }
    interface IdentitySourceConfiguration1PropertiesArgs {
        openIdConnectConfiguration: pulumi.Input<inputs.verifiedpermissions.IdentitySourceOpenIdConnectConfigurationArgs>;
    }
    interface IdentitySourceOpenIdConnectAccessTokenConfigurationArgs {
        audiences?: pulumi.Input<pulumi.Input<string>[]>;
        principalIdClaim?: pulumi.Input<string>;
    }
    interface IdentitySourceOpenIdConnectConfigurationArgs {
        entityIdPrefix?: pulumi.Input<string>;
        groupConfiguration?: pulumi.Input<inputs.verifiedpermissions.IdentitySourceOpenIdConnectGroupConfigurationArgs>;
        issuer: pulumi.Input<string>;
        tokenSelection: pulumi.Input<inputs.verifiedpermissions.IdentitySourceOpenIdConnectTokenSelection0PropertiesArgs | inputs.verifiedpermissions.IdentitySourceOpenIdConnectTokenSelection1PropertiesArgs>;
    }
    interface IdentitySourceOpenIdConnectGroupConfigurationArgs {
        groupClaim: pulumi.Input<string>;
        groupEntityType: pulumi.Input<string>;
    }
    interface IdentitySourceOpenIdConnectIdentityTokenConfigurationArgs {
        clientIds?: pulumi.Input<pulumi.Input<string>[]>;
        principalIdClaim?: pulumi.Input<string>;
    }
    interface IdentitySourceOpenIdConnectTokenSelection0PropertiesArgs {
        accessTokenOnly: pulumi.Input<inputs.verifiedpermissions.IdentitySourceOpenIdConnectAccessTokenConfigurationArgs>;
    }
    interface IdentitySourceOpenIdConnectTokenSelection1PropertiesArgs {
        identityTokenOnly: pulumi.Input<inputs.verifiedpermissions.IdentitySourceOpenIdConnectIdentityTokenConfigurationArgs>;
    }
    interface PolicyDefinition0PropertiesArgs {
        static: pulumi.Input<inputs.verifiedpermissions.PolicyStaticPolicyDefinitionArgs>;
    }
    interface PolicyDefinition1PropertiesArgs {
        templateLinked: pulumi.Input<inputs.verifiedpermissions.PolicyTemplateLinkedPolicyDefinitionArgs>;
    }
    interface PolicyEntityIdentifierArgs {
        entityId: pulumi.Input<string>;
        entityType: pulumi.Input<string>;
    }
    interface PolicyStaticPolicyDefinitionArgs {
        description?: pulumi.Input<string>;
        statement: pulumi.Input<string>;
    }
    interface PolicyStoreSchemaDefinitionArgs {
        /**
         * A JSON string representation of the schema supported by applications that use this policy store. For more information, see [Policy store schema](https://docs.aws.amazon.com/verifiedpermissions/latest/userguide/schema.html) in the AVP User Guide.
         */
        cedarJson?: pulumi.Input<string>;
    }
    interface PolicyStoreValidationSettingsArgs {
        /**
         * The validation mode currently configured for this policy store. The valid values are:
         *
         * - *OFF* – Neither Verified Permissions nor Cedar perform any validation on policies. No validation errors are reported by either service.
         * - *STRICT* – Requires a schema to be present in the policy store. Cedar performs validation on all submitted new or updated static policies and policy templates. Any that fail validation are rejected and Cedar doesn't store them in the policy store.
         *
         * > If `Mode=STRICT` and the policy store doesn't contain a schema, Verified Permissions rejects all static policies and policy templates because there is no schema to validate against.
         * >
         * > To submit a static policy or policy template without a schema, you must turn off validation.
         */
        mode: pulumi.Input<enums.verifiedpermissions.PolicyStoreValidationMode>;
    }
    interface PolicyTemplateLinkedPolicyDefinitionArgs {
        policyTemplateId: pulumi.Input<string>;
        principal?: pulumi.Input<inputs.verifiedpermissions.PolicyEntityIdentifierArgs>;
        resource?: pulumi.Input<inputs.verifiedpermissions.PolicyEntityIdentifierArgs>;
    }
}
export declare namespace voiceid {
    interface DomainServerSideEncryptionConfigurationArgs {
        /**
         * The identifier of the KMS key to use to encrypt data stored by Voice ID. Voice ID doesn't support asymmetric customer managed keys.
         */
        kmsKeyId: pulumi.Input<string>;
    }
}
export declare namespace vpclattice {
    interface ListenerDefaultActionArgs {
        /**
         * Describes an action that returns a custom HTTP response.
         */
        fixedResponse?: pulumi.Input<inputs.vpclattice.ListenerFixedResponseArgs>;
        /**
         * Describes a forward action. You can use forward actions to route requests to one or more target groups.
         */
        forward?: pulumi.Input<inputs.vpclattice.ListenerForwardArgs>;
    }
    interface ListenerFixedResponseArgs {
        /**
         * The HTTP response code.
         */
        statusCode: pulumi.Input<number>;
    }
    interface ListenerForwardArgs {
        /**
         * The target groups. Traffic matching the rule is forwarded to the specified target groups. With forward actions, you can assign a weight that controls the prioritization and selection of each target group. This means that requests are distributed to individual target groups based on their weights. For example, if two target groups have the same weight, each target group receives half of the traffic.
         *
         * The default value is 1. This means that if only one target group is provided, there is no need to set the weight; 100% of the traffic goes to that target group.
         */
        targetGroups: pulumi.Input<pulumi.Input<inputs.vpclattice.ListenerWeightedTargetGroupArgs>[]>;
    }
    interface ListenerWeightedTargetGroupArgs {
        /**
         * The ID of the target group.
         */
        targetGroupIdentifier: pulumi.Input<string>;
        /**
         * Only required if you specify multiple target groups for a forward action. The weight determines how requests are distributed to the target group. For example, if you specify two target groups, each with a weight of 10, each target group receives half the requests. If you specify two target groups, one with a weight of 10 and the other with a weight of 20, the target group with a weight of 20 receives twice as many requests as the other target group. If there's only one target group specified, then the default value is 100.
         */
        weight?: pulumi.Input<number>;
    }
    /**
     * Identifies the resource configuration in one of the following ways:
     *
     * - *Amazon Resource Name (ARN)* - Supported resource-types that are provisioned by AWS services, such as RDS databases, can be identified by their ARN.
     * - *Domain name* - Any domain name that is publicly resolvable.
     * - *IP address* - For IPv4 and IPv6, only IP addresses in the VPC are supported.
     */
    interface ResourceConfigurationDefinition0PropertiesArgs {
        ipResource: pulumi.Input<string>;
    }
    /**
     * Identifies the resource configuration in one of the following ways:
     *
     * - *Amazon Resource Name (ARN)* - Supported resource-types that are provisioned by AWS services, such as RDS databases, can be identified by their ARN.
     * - *Domain name* - Any domain name that is publicly resolvable.
     * - *IP address* - For IPv4 and IPv6, only IP addresses in the VPC are supported.
     */
    interface ResourceConfigurationDefinition1PropertiesArgs {
        arnResource: pulumi.Input<string>;
    }
    /**
     * Identifies the resource configuration in one of the following ways:
     *
     * - *Amazon Resource Name (ARN)* - Supported resource-types that are provisioned by AWS services, such as RDS databases, can be identified by their ARN.
     * - *Domain name* - Any domain name that is publicly resolvable.
     * - *IP address* - For IPv4 and IPv6, only IP addresses in the VPC are supported.
     */
    interface ResourceConfigurationDefinition2PropertiesArgs {
        dnsResource: pulumi.Input<inputs.vpclattice.ResourceConfigurationDnsResourceArgs>;
    }
    interface ResourceConfigurationDnsResourceArgs {
        domainName: pulumi.Input<string>;
        ipAddressType: pulumi.Input<enums.vpclattice.ResourceConfigurationDnsResourceIpAddressType>;
    }
    interface RuleActionArgs {
        /**
         * The fixed response action. The rule returns a custom HTTP response.
         */
        fixedResponse?: pulumi.Input<inputs.vpclattice.RuleFixedResponseArgs>;
        /**
         * The forward action. Traffic that matches the rule is forwarded to the specified target groups.
         */
        forward?: pulumi.Input<inputs.vpclattice.RuleForwardArgs>;
    }
    interface RuleFixedResponseArgs {
        /**
         * The HTTP response code.
         */
        statusCode: pulumi.Input<number>;
    }
    interface RuleForwardArgs {
        /**
         * The target groups. Traffic matching the rule is forwarded to the specified target groups. With forward actions, you can assign a weight that controls the prioritization and selection of each target group. This means that requests are distributed to individual target groups based on their weights. For example, if two target groups have the same weight, each target group receives half of the traffic.
         *
         * The default value is 1. This means that if only one target group is provided, there is no need to set the weight; 100% of the traffic goes to that target group.
         */
        targetGroups: pulumi.Input<pulumi.Input<inputs.vpclattice.RuleWeightedTargetGroupArgs>[]>;
    }
    interface RuleHeaderMatchArgs {
        /**
         * Indicates whether the match is case sensitive.
         */
        caseSensitive?: pulumi.Input<boolean>;
        /**
         * The header match type.
         */
        match: pulumi.Input<inputs.vpclattice.RuleHeaderMatchTypeArgs>;
        /**
         * The name of the header.
         */
        name: pulumi.Input<string>;
    }
    interface RuleHeaderMatchTypeArgs {
        /**
         * A contains type match.
         */
        contains?: pulumi.Input<string>;
        /**
         * An exact type match.
         */
        exact?: pulumi.Input<string>;
        /**
         * A prefix type match. Matches the value with the prefix.
         */
        prefix?: pulumi.Input<string>;
    }
    interface RuleHttpMatchArgs {
        /**
         * The header matches. Matches incoming requests with rule based on request header value before applying rule action.
         */
        headerMatches?: pulumi.Input<pulumi.Input<inputs.vpclattice.RuleHeaderMatchArgs>[]>;
        /**
         * The HTTP method type.
         */
        method?: pulumi.Input<enums.vpclattice.RuleHttpMatchMethod>;
        /**
         * The path match.
         */
        pathMatch?: pulumi.Input<inputs.vpclattice.RulePathMatchArgs>;
    }
    interface RuleMatchArgs {
        /**
         * The HTTP criteria that a rule must match.
         */
        httpMatch: pulumi.Input<inputs.vpclattice.RuleHttpMatchArgs>;
    }
    interface RulePathMatchArgs {
        /**
         * Indicates whether the match is case sensitive.
         */
        caseSensitive?: pulumi.Input<boolean>;
        /**
         * The type of path match.
         */
        match: pulumi.Input<inputs.vpclattice.RulePathMatchTypeArgs>;
    }
    interface RulePathMatchTypeArgs {
        /**
         * An exact match of the path.
         */
        exact?: pulumi.Input<string>;
        /**
         * A prefix match of the path.
         */
        prefix?: pulumi.Input<string>;
    }
    interface RuleWeightedTargetGroupArgs {
        /**
         * The ID of the target group.
         */
        targetGroupIdentifier: pulumi.Input<string>;
        /**
         * Only required if you specify multiple target groups for a forward action. The weight determines how requests are distributed to the target group. For example, if you specify two target groups, each with a weight of 10, each target group receives half the requests. If you specify two target groups, one with a weight of 10 and the other with a weight of 20, the target group with a weight of 20 receives twice as many requests as the other target group. If there's only one target group specified, then the default value is 100.
         */
        weight?: pulumi.Input<number>;
    }
    interface ServiceDnsEntryArgs {
        /**
         * The domain name of the service.
         */
        domainName?: pulumi.Input<string>;
        /**
         * The ID of the hosted zone.
         */
        hostedZoneId?: pulumi.Input<string>;
    }
    interface ServiceNetworkServiceAssociationDnsEntryArgs {
        /**
         * The domain name of the service.
         */
        domainName?: pulumi.Input<string>;
        /**
         * The ID of the hosted zone.
         */
        hostedZoneId?: pulumi.Input<string>;
    }
    interface ServiceNetworkSharingConfigArgs {
        /**
         * Specify if the service network should be enabled for sharing.
         */
        enabled: pulumi.Input<boolean>;
    }
    interface TargetGroupConfigArgs {
        /**
         * The health check configuration. Not supported if the target group type is `LAMBDA` or `ALB` .
         */
        healthCheck?: pulumi.Input<inputs.vpclattice.TargetGroupHealthCheckConfigArgs>;
        /**
         * The type of IP address used for the target group. Supported only if the target group type is `IP` . The default is `IPV4` .
         */
        ipAddressType?: pulumi.Input<enums.vpclattice.TargetGroupConfigIpAddressType>;
        /**
         * The version of the event structure that your Lambda function receives. Supported only if the target group type is `LAMBDA` . The default is `V1` .
         */
        lambdaEventStructureVersion?: pulumi.Input<enums.vpclattice.TargetGroupConfigLambdaEventStructureVersion>;
        /**
         * The port on which the targets are listening. For HTTP, the default is 80. For HTTPS, the default is 443. Not supported if the target group type is `LAMBDA` .
         */
        port?: pulumi.Input<number>;
        /**
         * The protocol to use for routing traffic to the targets. The default is the protocol of the target group. Not supported if the target group type is `LAMBDA` .
         */
        protocol?: pulumi.Input<enums.vpclattice.TargetGroupConfigProtocol>;
        /**
         * The protocol version. The default is `HTTP1` . Not supported if the target group type is `LAMBDA` .
         */
        protocolVersion?: pulumi.Input<enums.vpclattice.TargetGroupConfigProtocolVersion>;
        /**
         * The ID of the VPC. Not supported if the target group type is `LAMBDA` .
         */
        vpcIdentifier?: pulumi.Input<string>;
    }
    interface TargetGroupHealthCheckConfigArgs {
        /**
         * Indicates whether health checking is enabled.
         */
        enabled?: pulumi.Input<boolean>;
        /**
         * The approximate amount of time, in seconds, between health checks of an individual target. The range is 5–300 seconds. The default is 30 seconds.
         */
        healthCheckIntervalSeconds?: pulumi.Input<number>;
        /**
         * The amount of time, in seconds, to wait before reporting a target as unhealthy. The range is 1–120 seconds. The default is 5 seconds.
         */
        healthCheckTimeoutSeconds?: pulumi.Input<number>;
        /**
         * The number of consecutive successful health checks required before considering an unhealthy target healthy. The range is 2–10. The default is 5.
         */
        healthyThresholdCount?: pulumi.Input<number>;
        /**
         * The codes to use when checking for a successful response from a target.
         */
        matcher?: pulumi.Input<inputs.vpclattice.TargetGroupMatcherArgs>;
        /**
         * The destination for health checks on the targets. If the protocol version is `HTTP/1.1` or `HTTP/2` , specify a valid URI (for example, `/path?query` ). The default path is `/` . Health checks are not supported if the protocol version is `gRPC` , however, you can choose `HTTP/1.1` or `HTTP/2` and specify a valid URI.
         */
        path?: pulumi.Input<string>;
        /**
         * The port used when performing health checks on targets. The default setting is the port that a target receives traffic on.
         */
        port?: pulumi.Input<number>;
        /**
         * The protocol used when performing health checks on targets. The possible protocols are `HTTP` and `HTTPS` . The default is `HTTP` .
         */
        protocol?: pulumi.Input<enums.vpclattice.TargetGroupHealthCheckConfigProtocol>;
        /**
         * The protocol version used when performing health checks on targets. The possible protocol versions are `HTTP1` and `HTTP2` .
         */
        protocolVersion?: pulumi.Input<enums.vpclattice.TargetGroupHealthCheckConfigProtocolVersion>;
        /**
         * The number of consecutive failed health checks required before considering a target unhealthy. The range is 2–10. The default is 2.
         */
        unhealthyThresholdCount?: pulumi.Input<number>;
    }
    interface TargetGroupMatcherArgs {
        /**
         * The HTTP code to use when checking for a successful response from a target.
         */
        httpCode: pulumi.Input<string>;
    }
    interface TargetGroupTargetArgs {
        /**
         * The ID of the target. If the target group type is `INSTANCE` , this is an instance ID. If the target group type is `IP` , this is an IP address. If the target group type is `LAMBDA` , this is the ARN of a Lambda function. If the target group type is `ALB` , this is the ARN of an Application Load Balancer.
         */
        id: pulumi.Input<string>;
        /**
         * The port on which the target is listening. For HTTP, the default is 80. For HTTPS, the default is 443.
         */
        port?: pulumi.Input<number>;
    }
}
export declare namespace wafv2 {
    interface LoggingConfigurationConditionArgs {
        /**
         * A single action condition.
         */
        actionCondition?: pulumi.Input<inputs.wafv2.LoggingConfigurationConditionActionConditionPropertiesArgs>;
        /**
         * A single label name condition.
         */
        labelNameCondition?: pulumi.Input<inputs.wafv2.LoggingConfigurationConditionLabelNameConditionPropertiesArgs>;
    }
    /**
     * A single action condition.
     */
    interface LoggingConfigurationConditionActionConditionPropertiesArgs {
        /**
         * Logic to apply to the filtering conditions. You can specify that, in order to satisfy the filter, a log must match all conditions or must match at least one condition.
         */
        action: pulumi.Input<enums.wafv2.LoggingConfigurationConditionActionConditionPropertiesAction>;
    }
    /**
     * A single label name condition.
     */
    interface LoggingConfigurationConditionLabelNameConditionPropertiesArgs {
        /**
         * The label name that a log record must contain in order to meet the condition. This must be a fully qualified label name. Fully qualified labels have a prefix, optional namespaces, and label name. The prefix identifies the rule group or web ACL context of the rule that added the label.
         */
        labelName: pulumi.Input<string>;
    }
    /**
     * A key-value pair to associate with a resource.
     */
    interface LoggingConfigurationFieldToMatchArgs {
        /**
         * Inspect the HTTP method. The method indicates the type of operation that the request is asking the origin to perform.
         */
        method?: any;
        /**
         * Inspect the query string. This is the part of a URL that appears after a ? character, if any.
         */
        queryString?: any;
        /**
         * Inspect a single header. Provide the name of the header to inspect, for example, User-Agent or Referer. This setting isn't case sensitive.
         */
        singleHeader?: pulumi.Input<inputs.wafv2.LoggingConfigurationFieldToMatchSingleHeaderPropertiesArgs>;
        /**
         * Inspect the request URI path. This is the part of a web request that identifies a resource, for example, /images/daily-ad.jpg.
         */
        uriPath?: any;
    }
    /**
     * Inspect a single header. Provide the name of the header to inspect, for example, User-Agent or Referer. This setting isn't case sensitive.
     */
    interface LoggingConfigurationFieldToMatchSingleHeaderPropertiesArgs {
        /**
         * The name of the query header to inspect.
         */
        name: pulumi.Input<string>;
    }
    interface LoggingConfigurationFilterArgs {
        /**
         * How to handle logs that satisfy the filter's conditions and requirement.
         */
        behavior: pulumi.Input<enums.wafv2.LoggingConfigurationFilterBehavior>;
        /**
         * Match conditions for the filter.
         */
        conditions: pulumi.Input<pulumi.Input<inputs.wafv2.LoggingConfigurationConditionArgs>[]>;
        /**
         * Logic to apply to the filtering conditions. You can specify that, in order to satisfy the filter, a log must match all conditions or must match at least one condition.
         */
        requirement: pulumi.Input<enums.wafv2.LoggingConfigurationFilterRequirement>;
    }
    /**
     * Filtering that specifies which web requests are kept in the logs and which are dropped. You can filter on the rule action and on the web request labels that were applied by matching rules during web ACL evaluation.
     */
    interface LoggingFilterPropertiesArgs {
        /**
         * Default handling for logs that don't match any of the specified filtering conditions.
         */
        defaultBehavior: pulumi.Input<enums.wafv2.LoggingConfigurationLoggingFilterPropertiesDefaultBehavior>;
        /**
         * The filters that you want to apply to the logs.
         */
        filters: pulumi.Input<pulumi.Input<inputs.wafv2.LoggingConfigurationFilterArgs>[]>;
    }
    /**
     * Allow traffic towards application.
     */
    interface RuleGroupAllowActionArgs {
        /**
         * Defines custom handling for the web request.
         *
         * For information about customizing web requests and responses, see [Customizing web requests and responses in AWS WAF](https://docs.aws.amazon.com/waf/latest/developerguide/waf-custom-request-response.html) in the *AWS WAF Developer Guide* .
         */
        customRequestHandling?: pulumi.Input<inputs.wafv2.RuleGroupCustomRequestHandlingArgs>;
    }
    interface RuleGroupAndStatementArgs {
        /**
         * The statements to combine with AND logic. You can use any statements that can be nested.
         */
        statements: pulumi.Input<pulumi.Input<inputs.wafv2.RuleGroupStatementArgs>[]>;
    }
    /**
     * Block traffic towards application.
     */
    interface RuleGroupBlockActionArgs {
        /**
         * Defines a custom response for the web request.
         *
         * For information about customizing web requests and responses, see [Customizing web requests and responses in AWS WAF](https://docs.aws.amazon.com/waf/latest/developerguide/waf-custom-request-response.html) in the *AWS WAF Developer Guide* .
         */
        customResponse?: pulumi.Input<inputs.wafv2.RuleGroupCustomResponseArgs>;
    }
    /**
     * The body of a web request. This immediately follows the request headers.
     */
    interface RuleGroupBodyArgs {
        /**
         * What AWS WAF should do if the body is larger than AWS WAF can inspect.
         *
         * AWS WAF does not support inspecting the entire contents of the web request body if the body exceeds the limit for the resource type. When a web request body is larger than the limit, the underlying host service only forwards the contents that are within the limit to AWS WAF for inspection.
         *
         * - For Application Load Balancer and AWS AppSync , the limit is fixed at 8 KB (8,192 bytes).
         * - For CloudFront, API Gateway, Amazon Cognito, App Runner, and Verified Access, the default limit is 16 KB (16,384 bytes), and you can increase the limit for each resource type in the web ACL `AssociationConfig` , for additional processing fees.
         * - For AWS Amplify , use the CloudFront limit.
         *
         * The options for oversize handling are the following:
         *
         * - `CONTINUE` - Inspect the available body contents normally, according to the rule inspection criteria.
         * - `MATCH` - Treat the web request as matching the rule statement. AWS WAF applies the rule action to the request.
         * - `NO_MATCH` - Treat the web request as not matching the rule statement.
         *
         * You can combine the `MATCH` or `NO_MATCH` settings for oversize handling with your rule and web ACL action settings, so that you block any request whose body is over the limit.
         *
         * Default: `CONTINUE`
         */
        oversizeHandling?: pulumi.Input<enums.wafv2.RuleGroupOversizeHandling>;
    }
    /**
     * Byte Match statement.
     */
    interface RuleGroupByteMatchStatementArgs {
        /**
         * The part of the web request that you want AWS WAF to inspect.
         */
        fieldToMatch: pulumi.Input<inputs.wafv2.RuleGroupFieldToMatchArgs>;
        /**
         * The area within the portion of the web request that you want AWS WAF to search for `SearchString` . Valid values include the following:
         *
         * *CONTAINS*
         *
         * The specified part of the web request must include the value of `SearchString` , but the location doesn't matter.
         *
         * *CONTAINS_WORD*
         *
         * The specified part of the web request must include the value of `SearchString` , and `SearchString` must contain only alphanumeric characters or underscore (A-Z, a-z, 0-9, or _). In addition, `SearchString` must be a word, which means that both of the following are true:
         *
         * - `SearchString` is at the beginning of the specified part of the web request or is preceded by a character other than an alphanumeric character or underscore (_). Examples include the value of a header and `;BadBot` .
         * - `SearchString` is at the end of the specified part of the web request or is followed by a character other than an alphanumeric character or underscore (_), for example, `BadBot;` and `-BadBot;` .
         *
         * *EXACTLY*
         *
         * The value of the specified part of the web request must exactly match the value of `SearchString` .
         *
         * *STARTS_WITH*
         *
         * The value of `SearchString` must appear at the beginning of the specified part of the web request.
         *
         * *ENDS_WITH*
         *
         * The value of `SearchString` must appear at the end of the specified part of the web request.
         */
        positionalConstraint: pulumi.Input<enums.wafv2.RuleGroupPositionalConstraint>;
        /**
         * A string value that you want AWS WAF to search for. AWS WAF searches only in the part of web requests that you designate for inspection in `FieldToMatch` . The maximum length of the value is 200 bytes. For alphabetic characters A-Z and a-z, the value is case sensitive.
         *
         * Don't encode this string. Provide the value that you want AWS WAF to search for. AWS CloudFormation automatically base64 encodes the value for you.
         *
         * For example, suppose the value of `Type` is `HEADER` and the value of `Data` is `User-Agent` . If you want to search the `User-Agent` header for the value `BadBot` , you provide the string `BadBot` in the value of `SearchString` .
         *
         * You must specify either `SearchString` or `SearchStringBase64` in a `ByteMatchStatement` .
         */
        searchString?: pulumi.Input<string>;
        /**
         * String to search for in a web request component, base64-encoded. If you don't want to encode the string, specify the unencoded value in `SearchString` instead.
         *
         * You must specify either `SearchString` or `SearchStringBase64` in a `ByteMatchStatement` .
         */
        searchStringBase64?: pulumi.Input<string>;
        /**
         * Text transformations eliminate some of the unusual formatting that attackers use in web requests in an effort to bypass detection. If you specify one or more transformations in a rule statement, AWS WAF performs all transformations on the content of the request component identified by `FieldToMatch` , starting from the lowest priority setting, before inspecting the content for a match.
         */
        textTransformations: pulumi.Input<pulumi.Input<inputs.wafv2.RuleGroupTextTransformationArgs>[]>;
    }
    /**
     * Checks valid token exists with request.
     */
    interface RuleGroupCaptchaActionArgs {
        /**
         * Defines custom handling for the web request, used when the `CAPTCHA` inspection determines that the request's token is valid and unexpired.
         *
         * For information about customizing web requests and responses, see [Customizing web requests and responses in AWS WAF](https://docs.aws.amazon.com/waf/latest/developerguide/waf-custom-request-response.html) in the *AWS WAF Developer Guide* .
         */
        customRequestHandling?: pulumi.Input<inputs.wafv2.RuleGroupCustomRequestHandlingArgs>;
    }
    interface RuleGroupCaptchaConfigArgs {
        /**
         * Determines how long a `CAPTCHA` timestamp in the token remains valid after the client successfully solves a `CAPTCHA` puzzle.
         */
        immunityTimeProperty?: pulumi.Input<inputs.wafv2.RuleGroupImmunityTimePropertyArgs>;
    }
    /**
     * Checks that the request has a valid token with an unexpired challenge timestamp and, if not, returns a browser challenge to the client.
     */
    interface RuleGroupChallengeActionArgs {
        /**
         * Defines custom handling for the web request, used when the challenge inspection determines that the request's token is valid and unexpired.
         *
         * For information about customizing web requests and responses, see [Customizing web requests and responses in AWS WAF](https://docs.aws.amazon.com/waf/latest/developerguide/waf-custom-request-response.html) in the *AWS WAF Developer Guide* .
         */
        customRequestHandling?: pulumi.Input<inputs.wafv2.RuleGroupCustomRequestHandlingArgs>;
    }
    interface RuleGroupChallengeConfigArgs {
        /**
         * Determines how long a challenge timestamp in the token remains valid after the client successfully responds to a challenge.
         */
        immunityTimeProperty?: pulumi.Input<inputs.wafv2.RuleGroupImmunityTimePropertyArgs>;
    }
    /**
     * The pattern to look for in the request cookies.
     */
    interface RuleGroupCookieMatchPatternArgs {
        /**
         * Inspect all parts of the web request cookies.
         */
        all?: any;
        /**
         * Inspect only the cookies whose keys don't match any of the strings specified here.
         */
        excludedCookies?: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * Inspect only the cookies that have a key that matches one of the strings specified here.
         */
        includedCookies?: pulumi.Input<pulumi.Input<string>[]>;
    }
    /**
     * Includes cookies of a web request.
     */
    interface RuleGroupCookiesArgs {
        /**
         * The filter to use to identify the subset of cookies to inspect in a web request.
         *
         * You must specify exactly one setting: either `All` , `IncludedCookies` , or `ExcludedCookies` .
         *
         * Example JSON: `"MatchPattern": { "IncludedCookies": [ "session-id-time", "session-id" ] }`
         */
        matchPattern: pulumi.Input<inputs.wafv2.RuleGroupCookieMatchPatternArgs>;
        /**
         * The parts of the cookies to inspect with the rule inspection criteria. If you specify `ALL` , AWS WAF inspects both keys and values.
         *
         * `All` does not require a match to be found in the keys and a match to be found in the values. It requires a match to be found in the keys or the values or both. To require a match in the keys and in the values, use a logical `AND` statement to combine two match rules, one that inspects the keys and another that inspects the values.
         */
        matchScope: pulumi.Input<enums.wafv2.RuleGroupMapMatchScope>;
        /**
         * What AWS WAF should do if the cookies of the request are more numerous or larger than AWS WAF can inspect. AWS WAF does not support inspecting the entire contents of request cookies when they exceed 8 KB (8192 bytes) or 200 total cookies. The underlying host service forwards a maximum of 200 cookies and at most 8 KB of cookie contents to AWS WAF .
         *
         * The options for oversize handling are the following:
         *
         * - `CONTINUE` - Inspect the available cookies normally, according to the rule inspection criteria.
         * - `MATCH` - Treat the web request as matching the rule statement. AWS WAF applies the rule action to the request.
         * - `NO_MATCH` - Treat the web request as not matching the rule statement.
         */
        oversizeHandling: pulumi.Input<enums.wafv2.RuleGroupOversizeHandling>;
    }
    /**
     * Count traffic towards application.
     */
    interface RuleGroupCountActionArgs {
        /**
         * Defines custom handling for the web request.
         *
         * For information about customizing web requests and responses, see [Customizing web requests and responses in AWS WAF](https://docs.aws.amazon.com/waf/latest/developerguide/waf-custom-request-response.html) in the *AWS WAF Developer Guide* .
         */
        customRequestHandling?: pulumi.Input<inputs.wafv2.RuleGroupCustomRequestHandlingArgs>;
    }
    /**
     * HTTP header.
     */
    interface RuleGroupCustomHttpHeaderArgs {
        /**
         * The name of the custom header.
         *
         * For custom request header insertion, when AWS WAF inserts the header into the request, it prefixes this name `x-amzn-waf-` , to avoid confusion with the headers that are already in the request. For example, for the header name `sample` , AWS WAF inserts the header `x-amzn-waf-sample` .
         */
        name: pulumi.Input<string>;
        /**
         * The value of the custom header.
         */
        value: pulumi.Input<string>;
    }
    /**
     * Custom request handling.
     */
    interface RuleGroupCustomRequestHandlingArgs {
        /**
         * Collection of HTTP headers.
         */
        insertHeaders: pulumi.Input<pulumi.Input<inputs.wafv2.RuleGroupCustomHttpHeaderArgs>[]>;
    }
    /**
     * Custom response.
     */
    interface RuleGroupCustomResponseArgs {
        /**
         * Custom response body key.
         */
        customResponseBodyKey?: pulumi.Input<string>;
        /**
         * The HTTP status code to return to the client.
         *
         * For a list of status codes that you can use in your custom responses, see [Supported status codes for custom response](https://docs.aws.amazon.com/waf/latest/developerguide/customizing-the-response-status-codes.html) in the *AWS WAF Developer Guide* .
         */
        responseCode: pulumi.Input<number>;
        /**
         * Collection of HTTP headers.
         */
        responseHeaders?: pulumi.Input<pulumi.Input<inputs.wafv2.RuleGroupCustomHttpHeaderArgs>[]>;
    }
    /**
     * Custom response body.
     */
    interface RuleGroupCustomResponseBodyArgs {
        /**
         * The payload of the custom response.
         *
         * You can use JSON escape strings in JSON content. To do this, you must specify JSON content in the `ContentType` setting.
         *
         * For information about the limits on count and size for custom request and response settings, see [AWS WAF quotas](https://docs.aws.amazon.com/waf/latest/developerguide/limits.html) in the *AWS WAF Developer Guide* .
         */
        content: pulumi.Input<string>;
        /**
         * The type of content in the payload that you are defining in the `Content` string.
         */
        contentType: pulumi.Input<enums.wafv2.RuleGroupResponseContentType>;
    }
    /**
     * Field of the request to match.
     */
    interface RuleGroupFieldToMatchArgs {
        /**
         * All query arguments of a web request.
         */
        allQueryArguments?: any;
        /**
         * Inspect the request body as plain text. The request body immediately follows the request headers. This is the part of a request that contains any additional data that you want to send to your web server as the HTTP request body, such as data from a form.
         *
         * AWS WAF does not support inspecting the entire contents of the web request body if the body exceeds the limit for the resource type. When a web request body is larger than the limit, the underlying host service only forwards the contents that are within the limit to AWS WAF for inspection.
         *
         * - For Application Load Balancer and AWS AppSync , the limit is fixed at 8 KB (8,192 bytes).
         * - For CloudFront, API Gateway, Amazon Cognito, App Runner, and Verified Access, the default limit is 16 KB (16,384 bytes), and you can increase the limit for each resource type in the web ACL `AssociationConfig` , for additional processing fees.
         * - For AWS Amplify , use the CloudFront limit.
         *
         * For information about how to handle oversized request bodies, see the `Body` object configuration.
         */
        body?: pulumi.Input<inputs.wafv2.RuleGroupBodyArgs>;
        /**
         * Inspect the request cookies. You must configure scope and pattern matching filters in the `Cookies` object, to define the set of cookies and the parts of the cookies that AWS WAF inspects.
         *
         * Only the first 8 KB (8192 bytes) of a request's cookies and only the first 200 cookies are forwarded to AWS WAF for inspection by the underlying host service. You must configure how to handle any oversize cookie content in the `Cookies` object. AWS WAF applies the pattern matching filters to the cookies that it receives from the underlying host service.
         */
        cookies?: pulumi.Input<inputs.wafv2.RuleGroupCookiesArgs>;
        /**
         * Inspect the request headers. You must configure scope and pattern matching filters in the `Headers` object, to define the set of headers to and the parts of the headers that AWS WAF inspects.
         *
         * Only the first 8 KB (8192 bytes) of a request's headers and only the first 200 headers are forwarded to AWS WAF for inspection by the underlying host service. You must configure how to handle any oversize header content in the `Headers` object. AWS WAF applies the pattern matching filters to the headers that it receives from the underlying host service.
         */
        headers?: pulumi.Input<inputs.wafv2.RuleGroupHeadersArgs>;
        /**
         * Available for use with Amazon CloudFront distributions and Application Load Balancers. Match against the request's JA3 fingerprint. The JA3 fingerprint is a 32-character hash derived from the TLS Client Hello of an incoming request. This fingerprint serves as a unique identifier for the client's TLS configuration. AWS WAF calculates and logs this fingerprint for each request that has enough TLS Client Hello information for the calculation. Almost all web requests include this information.
         *
         * > You can use this choice only with a string match `ByteMatchStatement` with the `PositionalConstraint` set to `EXACTLY` .
         *
         * You can obtain the JA3 fingerprint for client requests from the web ACL logs. If AWS WAF is able to calculate the fingerprint, it includes it in the logs. For information about the logging fields, see [Log fields](https://docs.aws.amazon.com/waf/latest/developerguide/logging-fields.html) in the *AWS WAF Developer Guide* .
         *
         * Provide the JA3 fingerprint string from the logs in your string match statement specification, to match with any future requests that have the same TLS configuration.
         */
        ja3Fingerprint?: pulumi.Input<inputs.wafv2.RuleGroupJa3FingerprintArgs>;
        /**
         * Available for use with Amazon CloudFront distributions and Application Load Balancers. Match against the request's JA4 fingerprint. The JA4 fingerprint is a 36-character hash derived from the TLS Client Hello of an incoming request. This fingerprint serves as a unique identifier for the client's TLS configuration. AWS WAF calculates and logs this fingerprint for each request that has enough TLS Client Hello information for the calculation. Almost all web requests include this information.
         *
         * > You can use this choice only with a string match `ByteMatchStatement` with the `PositionalConstraint` set to `EXACTLY` .
         *
         * You can obtain the JA4 fingerprint for client requests from the web ACL logs. If AWS WAF is able to calculate the fingerprint, it includes it in the logs. For information about the logging fields, see [Log fields](https://docs.aws.amazon.com/waf/latest/developerguide/logging-fields.html) in the *AWS WAF Developer Guide* .
         *
         * Provide the JA4 fingerprint string from the logs in your string match statement specification, to match with any future requests that have the same TLS configuration.
         */
        ja4Fingerprint?: pulumi.Input<inputs.wafv2.RuleGroupJa4FingerprintArgs>;
        /**
         * Inspect the request body as JSON. The request body immediately follows the request headers. This is the part of a request that contains any additional data that you want to send to your web server as the HTTP request body, such as data from a form.
         *
         * AWS WAF does not support inspecting the entire contents of the web request body if the body exceeds the limit for the resource type. When a web request body is larger than the limit, the underlying host service only forwards the contents that are within the limit to AWS WAF for inspection.
         *
         * - For Application Load Balancer and AWS AppSync , the limit is fixed at 8 KB (8,192 bytes).
         * - For CloudFront, API Gateway, Amazon Cognito, App Runner, and Verified Access, the default limit is 16 KB (16,384 bytes), and you can increase the limit for each resource type in the web ACL `AssociationConfig` , for additional processing fees.
         * - For AWS Amplify , use the CloudFront limit.
         *
         * For information about how to handle oversized request bodies, see the `JsonBody` object configuration.
         */
        jsonBody?: pulumi.Input<inputs.wafv2.RuleGroupJsonBodyArgs>;
        /**
         * The HTTP method of a web request. The method indicates the type of operation that the request is asking the origin to perform.
         */
        method?: any;
        /**
         * The query string of a web request. This is the part of a URL that appears after a ? character, if any.
         */
        queryString?: any;
        /**
         * Inspect a single header. Provide the name of the header to inspect, for example, `User-Agent` or `Referer` . This setting isn't case sensitive.
         *
         * Example JSON: `"SingleHeader": { "Name": "haystack" }`
         *
         * Alternately, you can filter and inspect all headers with the `Headers` `FieldToMatch` setting.
         */
        singleHeader?: pulumi.Input<inputs.wafv2.RuleGroupFieldToMatchSingleHeaderPropertiesArgs>;
        /**
         * One query argument in a web request, identified by name, for example UserName or SalesRegion. The name can be up to 30 characters long and isn't case sensitive.
         */
        singleQueryArgument?: pulumi.Input<inputs.wafv2.RuleGroupFieldToMatchSingleQueryArgumentPropertiesArgs>;
        /**
         * Inspect fragments of the request URI. You must configure scope and pattern matching filters in the `UriFragment` object, to define the fragment of a URI that AWS WAF inspects.
         *
         * Only the first 8 KB (8192 bytes) of a request's URI fragments and only the first 200 URI fragments are forwarded to AWS WAF for inspection by the underlying host service. You must configure how to handle any oversize URI fragment content in the `UriFragment` object. AWS WAF applies the pattern matching filters to the cookies that it receives from the underlying host service.
         */
        uriFragment?: pulumi.Input<inputs.wafv2.RuleGroupUriFragmentArgs>;
        /**
         * The path component of the URI of a web request. This is the part of a web request that identifies a resource, for example, /images/daily-ad.jpg.
         */
        uriPath?: any;
    }
    /**
     * Inspect a single header. Provide the name of the header to inspect, for example, `User-Agent` or `Referer` . This setting isn't case sensitive.
     *
     * Example JSON: `"SingleHeader": { "Name": "haystack" }`
     *
     * Alternately, you can filter and inspect all headers with the `Headers` `FieldToMatch` setting.
     */
    interface RuleGroupFieldToMatchSingleHeaderPropertiesArgs {
        name: pulumi.Input<string>;
    }
    /**
     * One query argument in a web request, identified by name, for example UserName or SalesRegion. The name can be up to 30 characters long and isn't case sensitive.
     */
    interface RuleGroupFieldToMatchSingleQueryArgumentPropertiesArgs {
        name: pulumi.Input<string>;
    }
    interface RuleGroupForwardedIpConfigurationArgs {
        /**
         * The match status to assign to the web request if the request doesn't have a valid IP address in the specified position.
         *
         * > If the specified header isn't present in the request, AWS WAF doesn't apply the rule to the web request at all.
         *
         * You can specify the following fallback behaviors:
         *
         * - `MATCH` - Treat the web request as matching the rule statement. AWS WAF applies the rule action to the request.
         * - `NO_MATCH` - Treat the web request as not matching the rule statement.
         */
        fallbackBehavior: pulumi.Input<enums.wafv2.RuleGroupForwardedIpConfigurationFallbackBehavior>;
        /**
         * The name of the HTTP header to use for the IP address. For example, to use the X-Forwarded-For (XFF) header, set this to `X-Forwarded-For` .
         *
         * > If the specified header isn't present in the request, AWS WAF doesn't apply the rule to the web request at all.
         */
        headerName: pulumi.Input<string>;
    }
    interface RuleGroupGeoMatchStatementArgs {
        /**
         * An array of two-character country codes that you want to match against, for example, `[ "US", "CN" ]` , from the alpha-2 country ISO codes of the ISO 3166 international standard.
         *
         * When you use a geo match statement just for the region and country labels that it adds to requests, you still have to supply a country code for the rule to evaluate. In this case, you configure the rule to only count matching requests, but it will still generate logging and count metrics for any matches. You can reduce the logging and metrics that the rule produces by specifying a country that's unlikely to be a source of traffic to your site.
         */
        countryCodes?: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * The configuration for inspecting IP addresses in an HTTP header that you specify, instead of using the IP address that's reported by the web request origin. Commonly, this is the X-Forwarded-For (XFF) header, but you can specify any header name.
         *
         * > If the specified header isn't present in the request, AWS WAF doesn't apply the rule to the web request at all.
         */
        forwardedIpConfig?: pulumi.Input<inputs.wafv2.RuleGroupForwardedIpConfigurationArgs>;
    }
    /**
     * The pattern to look for in the request headers.
     */
    interface RuleGroupHeaderMatchPatternArgs {
        /**
         * Inspect all parts of the web request headers.
         */
        all?: any;
        /**
         * Inspect only the headers whose keys don't match any of the strings specified here.
         */
        excludedHeaders?: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * Inspect only the headers that have a key that matches one of the strings specified here.
         */
        includedHeaders?: pulumi.Input<pulumi.Input<string>[]>;
    }
    /**
     * Includes headers of a web request.
     */
    interface RuleGroupHeadersArgs {
        /**
         * The filter to use to identify the subset of headers to inspect in a web request.
         *
         * You must specify exactly one setting: either `All` , `IncludedHeaders` , or `ExcludedHeaders` .
         *
         * Example JSON: `"MatchPattern": { "ExcludedHeaders": [ "KeyToExclude1", "KeyToExclude2" ] }`
         */
        matchPattern: pulumi.Input<inputs.wafv2.RuleGroupHeaderMatchPatternArgs>;
        /**
         * The parts of the headers to match with the rule inspection criteria. If you specify `ALL` , AWS WAF inspects both keys and values.
         *
         * `All` does not require a match to be found in the keys and a match to be found in the values. It requires a match to be found in the keys or the values or both. To require a match in the keys and in the values, use a logical `AND` statement to combine two match rules, one that inspects the keys and another that inspects the values.
         */
        matchScope: pulumi.Input<enums.wafv2.RuleGroupMapMatchScope>;
        /**
         * What AWS WAF should do if the headers of the request are more numerous or larger than AWS WAF can inspect. AWS WAF does not support inspecting the entire contents of request headers when they exceed 8 KB (8192 bytes) or 200 total headers. The underlying host service forwards a maximum of 200 headers and at most 8 KB of header contents to AWS WAF .
         *
         * The options for oversize handling are the following:
         *
         * - `CONTINUE` - Inspect the available headers normally, according to the rule inspection criteria.
         * - `MATCH` - Treat the web request as matching the rule statement. AWS WAF applies the rule action to the request.
         * - `NO_MATCH` - Treat the web request as not matching the rule statement.
         */
        oversizeHandling: pulumi.Input<enums.wafv2.RuleGroupOversizeHandling>;
    }
    interface RuleGroupImmunityTimePropertyArgs {
        /**
         * The amount of time, in seconds, that a `CAPTCHA` or challenge timestamp is considered valid by AWS WAF . The default setting is 300.
         *
         * For the Challenge action, the minimum setting is 300.
         */
        immunityTime: pulumi.Input<number>;
    }
    interface RuleGroupIpSetForwardedIpConfigurationArgs {
        /**
         * The match status to assign to the web request if the request doesn't have a valid IP address in the specified position.
         *
         * > If the specified header isn't present in the request, AWS WAF doesn't apply the rule to the web request at all.
         *
         * You can specify the following fallback behaviors:
         *
         * - `MATCH` - Treat the web request as matching the rule statement. AWS WAF applies the rule action to the request.
         * - `NO_MATCH` - Treat the web request as not matching the rule statement.
         */
        fallbackBehavior: pulumi.Input<enums.wafv2.RuleGroupIpSetForwardedIpConfigurationFallbackBehavior>;
        /**
         * The name of the HTTP header to use for the IP address. For example, to use the X-Forwarded-For (XFF) header, set this to `X-Forwarded-For` .
         *
         * > If the specified header isn't present in the request, AWS WAF doesn't apply the rule to the web request at all.
         */
        headerName: pulumi.Input<string>;
        /**
         * The position in the header to search for the IP address. The header can contain IP addresses of the original client and also of proxies. For example, the header value could be `10.1.1.1, 127.0.0.0, 10.10.10.10` where the first IP address identifies the original client and the rest identify proxies that the request went through.
         *
         * The options for this setting are the following:
         *
         * - FIRST - Inspect the first IP address in the list of IP addresses in the header. This is usually the client's original IP.
         * - LAST - Inspect the last IP address in the list of IP addresses in the header.
         * - ANY - Inspect all IP addresses in the header for a match. If the header contains more than 10 IP addresses, AWS WAF inspects the last 10.
         */
        position: pulumi.Input<enums.wafv2.RuleGroupIpSetForwardedIpConfigurationPosition>;
    }
    interface RuleGroupIpSetReferenceStatementArgs {
        /**
         * The Amazon Resource Name (ARN) of the `IPSet` that this statement references.
         */
        arn: pulumi.Input<string>;
        /**
         * The configuration for inspecting IP addresses in an HTTP header that you specify, instead of using the IP address that's reported by the web request origin. Commonly, this is the X-Forwarded-For (XFF) header, but you can specify any header name.
         *
         * > If the specified header isn't present in the request, AWS WAF doesn't apply the rule to the web request at all.
         */
        ipSetForwardedIpConfig?: pulumi.Input<inputs.wafv2.RuleGroupIpSetForwardedIpConfigurationArgs>;
    }
    /**
     * Includes the JA3 fingerprint of a web request.
     */
    interface RuleGroupJa3FingerprintArgs {
        /**
         * The match status to assign to the web request if the request doesn't have a JA3 fingerprint.
         *
         * You can specify the following fallback behaviors:
         *
         * - `MATCH` - Treat the web request as matching the rule statement. AWS WAF applies the rule action to the request.
         * - `NO_MATCH` - Treat the web request as not matching the rule statement.
         */
        fallbackBehavior: pulumi.Input<enums.wafv2.RuleGroupJa3FingerprintFallbackBehavior>;
    }
    /**
     * Includes the JA4 fingerprint of a web request.
     */
    interface RuleGroupJa4FingerprintArgs {
        /**
         * The match status to assign to the web request if the request doesn't have a JA4 fingerprint.
         *
         * You can specify the following fallback behaviors:
         *
         * - `MATCH` - Treat the web request as matching the rule statement. AWS WAF applies the rule action to the request.
         * - `NO_MATCH` - Treat the web request as not matching the rule statement.
         */
        fallbackBehavior: pulumi.Input<enums.wafv2.RuleGroupJa4FingerprintFallbackBehavior>;
    }
    /**
     * Inspect the request body as JSON. The request body immediately follows the request headers.
     */
    interface RuleGroupJsonBodyArgs {
        /**
         * What AWS WAF should do if it fails to completely parse the JSON body. The options are the following:
         *
         * - `EVALUATE_AS_STRING` - Inspect the body as plain text. AWS WAF applies the text transformations and inspection criteria that you defined for the JSON inspection to the body text string.
         * - `MATCH` - Treat the web request as matching the rule statement. AWS WAF applies the rule action to the request.
         * - `NO_MATCH` - Treat the web request as not matching the rule statement.
         *
         * If you don't provide this setting, AWS WAF parses and evaluates the content only up to the first parsing failure that it encounters.
         *
         * > AWS WAF parsing doesn't fully validate the input JSON string, so parsing can succeed even for invalid JSON. When parsing succeeds, AWS WAF doesn't apply the fallback behavior. For more information, see [JSON body](https://docs.aws.amazon.com/waf/latest/developerguide/waf-rule-statement-fields-list.html#waf-rule-statement-request-component-json-body) in the *AWS WAF Developer Guide* .
         */
        invalidFallbackBehavior?: pulumi.Input<enums.wafv2.RuleGroupBodyParsingFallbackBehavior>;
        /**
         * The patterns to look for in the JSON body. AWS WAF inspects the results of these pattern matches against the rule inspection criteria.
         */
        matchPattern: pulumi.Input<inputs.wafv2.RuleGroupJsonMatchPatternArgs>;
        /**
         * The parts of the JSON to match against using the `MatchPattern` . If you specify `ALL` , AWS WAF matches against keys and values.
         *
         * `All` does not require a match to be found in the keys and a match to be found in the values. It requires a match to be found in the keys or the values or both. To require a match in the keys and in the values, use a logical `AND` statement to combine two match rules, one that inspects the keys and another that inspects the values.
         */
        matchScope: pulumi.Input<enums.wafv2.RuleGroupJsonMatchScope>;
        /**
         * What AWS WAF should do if the body is larger than AWS WAF can inspect.
         *
         * AWS WAF does not support inspecting the entire contents of the web request body if the body exceeds the limit for the resource type. When a web request body is larger than the limit, the underlying host service only forwards the contents that are within the limit to AWS WAF for inspection.
         *
         * - For Application Load Balancer and AWS AppSync , the limit is fixed at 8 KB (8,192 bytes).
         * - For CloudFront, API Gateway, Amazon Cognito, App Runner, and Verified Access, the default limit is 16 KB (16,384 bytes), and you can increase the limit for each resource type in the web ACL `AssociationConfig` , for additional processing fees.
         * - For AWS Amplify , use the CloudFront limit.
         *
         * The options for oversize handling are the following:
         *
         * - `CONTINUE` - Inspect the available body contents normally, according to the rule inspection criteria.
         * - `MATCH` - Treat the web request as matching the rule statement. AWS WAF applies the rule action to the request.
         * - `NO_MATCH` - Treat the web request as not matching the rule statement.
         *
         * You can combine the `MATCH` or `NO_MATCH` settings for oversize handling with your rule and web ACL action settings, so that you block any request whose body is over the limit.
         *
         * Default: `CONTINUE`
         */
        oversizeHandling?: pulumi.Input<enums.wafv2.RuleGroupOversizeHandling>;
    }
    /**
     * The pattern to look for in the JSON body.
     */
    interface RuleGroupJsonMatchPatternArgs {
        /**
         * Inspect all parts of the web request's JSON body.
         */
        all?: any;
        /**
         * Match only the specified include paths. See also `MatchScope` in the `JsonBody` `FieldToMatch` specification.
         *
         * Provide the include paths using JSON Pointer syntax. For example, `"IncludedPaths": ["/dogs/0/name", "/dogs/1/name"]` . For information about this syntax, see the Internet Engineering Task Force (IETF) documentation [JavaScript Object Notation (JSON) Pointer](https://docs.aws.amazon.com/https://tools.ietf.org/html/rfc6901) .
         *
         * You must specify either this setting or the `All` setting, but not both.
         *
         * > Don't use this option to include all paths. Instead, use the `All` setting.
         */
        includedPaths?: pulumi.Input<pulumi.Input<string>[]>;
    }
    interface RuleGroupLabelArgs {
        /**
         * The label string.
         */
        name: pulumi.Input<string>;
    }
    interface RuleGroupLabelMatchStatementArgs {
        /**
         * The string to match against. The setting you provide for this depends on the match statement's `Scope` setting:
         *
         * - If the `Scope` indicates `LABEL` , then this specification must include the name and can include any number of preceding namespace specifications and prefix up to providing the fully qualified label name.
         * - If the `Scope` indicates `NAMESPACE` , then this specification can include any number of contiguous namespace strings, and can include the entire label namespace prefix from the rule group or web ACL where the label originates.
         *
         * Labels are case sensitive and components of a label must be separated by colon, for example `NS1:NS2:name` .
         */
        key: pulumi.Input<string>;
        /**
         * Specify whether you want to match using the label name or just the namespace.
         */
        scope: pulumi.Input<enums.wafv2.RuleGroupLabelMatchScope>;
    }
    interface RuleGroupLabelSummaryArgs {
        /**
         * An individual label specification.
         */
        name?: pulumi.Input<string>;
    }
    interface RuleGroupNotStatementArgs {
        /**
         * The statement to negate. You can use any statement that can be nested.
         */
        statement: pulumi.Input<inputs.wafv2.RuleGroupStatementArgs>;
    }
    interface RuleGroupOrStatementArgs {
        /**
         * The statements to combine with OR logic. You can use any statements that can be nested.
         */
        statements: pulumi.Input<pulumi.Input<inputs.wafv2.RuleGroupStatementArgs>[]>;
    }
    interface RuleGroupRateBasedStatementArgs {
        /**
         * Setting that indicates how to aggregate the request counts.
         *
         * > Web requests that are missing any of the components specified in the aggregation keys are omitted from the rate-based rule evaluation and handling.
         *
         * - `CONSTANT` - Count and limit the requests that match the rate-based rule's scope-down statement. With this option, the counted requests aren't further aggregated. The scope-down statement is the only specification used. When the count of all requests that satisfy the scope-down statement goes over the limit, AWS WAF applies the rule action to all requests that satisfy the scope-down statement.
         *
         * With this option, you must configure the `ScopeDownStatement` property.
         * - `CUSTOM_KEYS` - Aggregate the request counts using one or more web request components as the aggregate keys.
         *
         * With this option, you must specify the aggregate keys in the `CustomKeys` property.
         *
         * To aggregate on only the IP address or only the forwarded IP address, don't use custom keys. Instead, set the aggregate key type to `IP` or `FORWARDED_IP` .
         * - `FORWARDED_IP` - Aggregate the request counts on the first IP address in an HTTP header.
         *
         * With this option, you must specify the header to use in the `ForwardedIPConfig` property.
         *
         * To aggregate on a combination of the forwarded IP address with other aggregate keys, use `CUSTOM_KEYS` .
         * - `IP` - Aggregate the request counts on the IP address from the web request origin.
         *
         * To aggregate on a combination of the IP address with other aggregate keys, use `CUSTOM_KEYS` .
         */
        aggregateKeyType: pulumi.Input<enums.wafv2.RuleGroupRateBasedStatementAggregateKeyType>;
        /**
         * Specifies the aggregate keys to use in a rate-base rule.
         */
        customKeys?: pulumi.Input<pulumi.Input<inputs.wafv2.RuleGroupRateBasedStatementCustomKeyArgs>[]>;
        /**
         * The amount of time, in seconds, that AWS WAF should include in its request counts, looking back from the current time. For example, for a setting of 120, when AWS WAF checks the rate, it counts the requests for the 2 minutes immediately preceding the current time. Valid settings are 60, 120, 300, and 600.
         *
         * This setting doesn't determine how often AWS WAF checks the rate, but how far back it looks each time it checks. AWS WAF checks the rate about every 10 seconds.
         *
         * Default: `300` (5 minutes)
         */
        evaluationWindowSec?: pulumi.Input<number>;
        /**
         * The configuration for inspecting IP addresses in an HTTP header that you specify, instead of using the IP address that's reported by the web request origin. Commonly, this is the X-Forwarded-For (XFF) header, but you can specify any header name.
         *
         * > If the specified header isn't present in the request, AWS WAF doesn't apply the rule to the web request at all.
         *
         * This is required if you specify a forwarded IP in the rule's aggregate key settings.
         */
        forwardedIpConfig?: pulumi.Input<inputs.wafv2.RuleGroupForwardedIpConfigurationArgs>;
        /**
         * The limit on requests during the specified evaluation window for a single aggregation instance for the rate-based rule. If the rate-based statement includes a `ScopeDownStatement` , this limit is applied only to the requests that match the statement.
         *
         * Examples:
         *
         * - If you aggregate on just the IP address, this is the limit on requests from any single IP address.
         * - If you aggregate on the HTTP method and the query argument name "city", then this is the limit on requests for any single method, city pair.
         */
        limit: pulumi.Input<number>;
        /**
         * An optional nested statement that narrows the scope of the web requests that are evaluated and managed by the rate-based statement. When you use a scope-down statement, the rate-based rule only tracks and rate limits requests that match the scope-down statement. You can use any nestable `Statement` in the scope-down statement, and you can nest statements at any level, the same as you can for a rule statement.
         */
        scopeDownStatement?: pulumi.Input<inputs.wafv2.RuleGroupStatementArgs>;
    }
    /**
     * Specifies a single custom aggregate key for a rate-base rule.
     */
    interface RuleGroupRateBasedStatementCustomKeyArgs {
        /**
         * Use the value of a cookie in the request as an aggregate key. Each distinct value in the cookie contributes to the aggregation instance. If you use a single cookie as your custom key, then each value fully defines an aggregation instance.
         */
        cookie?: pulumi.Input<inputs.wafv2.RuleGroupRateLimitCookieArgs>;
        /**
         * Use the first IP address in an HTTP header as an aggregate key. Each distinct forwarded IP address contributes to the aggregation instance.
         *
         * When you specify an IP or forwarded IP in the custom key settings, you must also specify at least one other key to use. You can aggregate on only the forwarded IP address by specifying `FORWARDED_IP` in your rate-based statement's `AggregateKeyType` .
         *
         * With this option, you must specify the header to use in the rate-based rule's `ForwardedIPConfig` property.
         */
        forwardedIp?: pulumi.Input<inputs.wafv2.RuleGroupRateLimitForwardedIpArgs>;
        /**
         * Use the value of a header in the request as an aggregate key. Each distinct value in the header contributes to the aggregation instance. If you use a single header as your custom key, then each value fully defines an aggregation instance.
         */
        header?: pulumi.Input<inputs.wafv2.RuleGroupRateLimitHeaderArgs>;
        /**
         * Use the request's HTTP method as an aggregate key. Each distinct HTTP method contributes to the aggregation instance. If you use just the HTTP method as your custom key, then each method fully defines an aggregation instance.
         */
        httpMethod?: pulumi.Input<inputs.wafv2.RuleGroupRateLimitHttpMethodArgs>;
        /**
         * Use the request's originating IP address as an aggregate key. Each distinct IP address contributes to the aggregation instance.
         *
         * When you specify an IP or forwarded IP in the custom key settings, you must also specify at least one other key to use. You can aggregate on only the IP address by specifying `IP` in your rate-based statement's `AggregateKeyType` .
         */
        ip?: pulumi.Input<inputs.wafv2.RuleGroupRateLimitIpArgs>;
        /**
         * Use the request's JA3 fingerprint as an aggregate key. If you use a single JA3 fingerprint as your custom key, then each value fully defines an aggregation instance.
         */
        ja3Fingerprint?: pulumi.Input<inputs.wafv2.RuleGroupRateLimitJa3FingerprintArgs>;
        /**
         * Use the request's JA4 fingerprint as an aggregate key. If you use a single JA4 fingerprint as your custom key, then each value fully defines an aggregation instance.
         */
        ja4Fingerprint?: pulumi.Input<inputs.wafv2.RuleGroupRateLimitJa4FingerprintArgs>;
        /**
         * Use the specified label namespace as an aggregate key. Each distinct fully qualified label name that has the specified label namespace contributes to the aggregation instance. If you use just one label namespace as your custom key, then each label name fully defines an aggregation instance.
         *
         * This uses only labels that have been added to the request by rules that are evaluated before this rate-based rule in the web ACL.
         *
         * For information about label namespaces and names, see [Label syntax and naming requirements](https://docs.aws.amazon.com/waf/latest/developerguide/waf-rule-label-requirements.html) in the *AWS WAF Developer Guide* .
         */
        labelNamespace?: pulumi.Input<inputs.wafv2.RuleGroupRateLimitLabelNamespaceArgs>;
        /**
         * Use the specified query argument as an aggregate key. Each distinct value for the named query argument contributes to the aggregation instance. If you use a single query argument as your custom key, then each value fully defines an aggregation instance.
         */
        queryArgument?: pulumi.Input<inputs.wafv2.RuleGroupRateLimitQueryArgumentArgs>;
        /**
         * Use the request's query string as an aggregate key. Each distinct string contributes to the aggregation instance. If you use just the query string as your custom key, then each string fully defines an aggregation instance.
         */
        queryString?: pulumi.Input<inputs.wafv2.RuleGroupRateLimitQueryStringArgs>;
        /**
         * Use the request's URI path as an aggregate key. Each distinct URI path contributes to the aggregation instance. If you use just the URI path as your custom key, then each URI path fully defines an aggregation instance.
         */
        uriPath?: pulumi.Input<inputs.wafv2.RuleGroupRateLimitUriPathArgs>;
    }
    /**
     * Specifies a cookie as an aggregate key for a rate-based rule.
     */
    interface RuleGroupRateLimitCookieArgs {
        /**
         * The name of the cookie to use.
         */
        name: pulumi.Input<string>;
        /**
         * Text transformations eliminate some of the unusual formatting that attackers use in web requests in an effort to bypass detection. Text transformations are used in rule match statements, to transform the `FieldToMatch` request component before inspecting it, and they're used in rate-based rule statements, to transform request components before using them as custom aggregation keys. If you specify one or more transformations to apply, AWS WAF performs all transformations on the specified content, starting from the lowest priority setting, and then uses the transformed component contents.
         */
        textTransformations: pulumi.Input<pulumi.Input<inputs.wafv2.RuleGroupTextTransformationArgs>[]>;
    }
    /**
     * Specifies the first IP address in an HTTP header as an aggregate key for a rate-based rule.
     */
    interface RuleGroupRateLimitForwardedIpArgs {
    }
    /**
     * Specifies a header as an aggregate key for a rate-based rule.
     */
    interface RuleGroupRateLimitHeaderArgs {
        /**
         * The name of the header to use.
         */
        name: pulumi.Input<string>;
        /**
         * Text transformations eliminate some of the unusual formatting that attackers use in web requests in an effort to bypass detection. Text transformations are used in rule match statements, to transform the `FieldToMatch` request component before inspecting it, and they're used in rate-based rule statements, to transform request components before using them as custom aggregation keys. If you specify one or more transformations to apply, AWS WAF performs all transformations on the specified content, starting from the lowest priority setting, and then uses the transformed component contents.
         */
        textTransformations: pulumi.Input<pulumi.Input<inputs.wafv2.RuleGroupTextTransformationArgs>[]>;
    }
    /**
     * Specifies the request's HTTP method as an aggregate key for a rate-based rule.
     */
    interface RuleGroupRateLimitHttpMethodArgs {
    }
    /**
     * Specifies the IP address in the web request as an aggregate key for a rate-based rule.
     */
    interface RuleGroupRateLimitIpArgs {
    }
    /**
     * Specifies the request's JA3 fingerprint as an aggregate key for a rate-based rule.
     */
    interface RuleGroupRateLimitJa3FingerprintArgs {
        /**
         * The match status to assign to the web request if there is insufficient TSL Client Hello information to compute the JA3 fingerprint.
         *
         * You can specify the following fallback behaviors:
         *
         * - `MATCH` - Treat the web request as matching the rule statement. AWS WAF applies the rule action to the request.
         * - `NO_MATCH` - Treat the web request as not matching the rule statement.
         */
        fallbackBehavior: pulumi.Input<enums.wafv2.RuleGroupRateLimitJa3FingerprintFallbackBehavior>;
    }
    /**
     * Specifies the request's JA4 fingerprint as an aggregate key for a rate-based rule.
     */
    interface RuleGroupRateLimitJa4FingerprintArgs {
        /**
         * The match status to assign to the web request if there is insufficient TSL Client Hello information to compute the JA4 fingerprint.
         *
         * You can specify the following fallback behaviors:
         *
         * - `MATCH` - Treat the web request as matching the rule statement. AWS WAF applies the rule action to the request.
         * - `NO_MATCH` - Treat the web request as not matching the rule statement.
         */
        fallbackBehavior: pulumi.Input<enums.wafv2.RuleGroupRateLimitJa4FingerprintFallbackBehavior>;
    }
    /**
     * Specifies a label namespace to use as an aggregate key for a rate-based rule.
     */
    interface RuleGroupRateLimitLabelNamespaceArgs {
        /**
         * The namespace to use for aggregation.
         */
        namespace: pulumi.Input<string>;
    }
    /**
     * Specifies a query argument in the request as an aggregate key for a rate-based rule.
     */
    interface RuleGroupRateLimitQueryArgumentArgs {
        /**
         * The name of the query argument to use.
         */
        name: pulumi.Input<string>;
        /**
         * Text transformations eliminate some of the unusual formatting that attackers use in web requests in an effort to bypass detection. Text transformations are used in rule match statements, to transform the `FieldToMatch` request component before inspecting it, and they're used in rate-based rule statements, to transform request components before using them as custom aggregation keys. If you specify one or more transformations to apply, AWS WAF performs all transformations on the specified content, starting from the lowest priority setting, and then uses the transformed component contents.
         */
        textTransformations: pulumi.Input<pulumi.Input<inputs.wafv2.RuleGroupTextTransformationArgs>[]>;
    }
    /**
     * Specifies the request's query string as an aggregate key for a rate-based rule.
     */
    interface RuleGroupRateLimitQueryStringArgs {
        /**
         * Text transformations eliminate some of the unusual formatting that attackers use in web requests in an effort to bypass detection. Text transformations are used in rule match statements, to transform the `FieldToMatch` request component before inspecting it, and they're used in rate-based rule statements, to transform request components before using them as custom aggregation keys. If you specify one or more transformations to apply, AWS WAF performs all transformations on the specified content, starting from the lowest priority setting, and then uses the transformed component contents.
         */
        textTransformations: pulumi.Input<pulumi.Input<inputs.wafv2.RuleGroupTextTransformationArgs>[]>;
    }
    /**
     * Specifies the request's URI Path as an aggregate key for a rate-based rule.
     */
    interface RuleGroupRateLimitUriPathArgs {
        /**
         * Text transformations eliminate some of the unusual formatting that attackers use in web requests in an effort to bypass detection. Text transformations are used in rule match statements, to transform the `FieldToMatch` request component before inspecting it, and they're used in rate-based rule statements, to transform request components before using them as custom aggregation keys. If you specify one or more transformations to apply, AWS WAF performs all transformations on the specified content, starting from the lowest priority setting, and then uses the transformed component contents.
         */
        textTransformations: pulumi.Input<pulumi.Input<inputs.wafv2.RuleGroupTextTransformationArgs>[]>;
    }
    interface RuleGroupRegexMatchStatementArgs {
        /**
         * The part of the web request that you want AWS WAF to inspect.
         */
        fieldToMatch: pulumi.Input<inputs.wafv2.RuleGroupFieldToMatchArgs>;
        /**
         * The string representing the regular expression.
         */
        regexString: pulumi.Input<string>;
        /**
         * Text transformations eliminate some of the unusual formatting that attackers use in web requests in an effort to bypass detection. If you specify one or more transformations in a rule statement, AWS WAF performs all transformations on the content of the request component identified by `FieldToMatch` , starting from the lowest priority setting, before inspecting the content for a match.
         */
        textTransformations: pulumi.Input<pulumi.Input<inputs.wafv2.RuleGroupTextTransformationArgs>[]>;
    }
    interface RuleGroupRegexPatternSetReferenceStatementArgs {
        /**
         * The Amazon Resource Name (ARN) of the `RegexPatternSet` that this statement references.
         */
        arn: pulumi.Input<string>;
        /**
         * The part of the web request that you want AWS WAF to inspect.
         */
        fieldToMatch: pulumi.Input<inputs.wafv2.RuleGroupFieldToMatchArgs>;
        /**
         * Text transformations eliminate some of the unusual formatting that attackers use in web requests in an effort to bypass detection. If you specify one or more transformations in a rule statement, AWS WAF performs all transformations on the content of the request component identified by `FieldToMatch` , starting from the lowest priority setting, before inspecting the content for a match.
         */
        textTransformations: pulumi.Input<pulumi.Input<inputs.wafv2.RuleGroupTextTransformationArgs>[]>;
    }
    /**
     * Rule of RuleGroup that contains condition and action.
     */
    interface RuleGroupRuleArgs {
        /**
         * The action that AWS WAF should take on a web request when it matches the rule statement. Settings at the web ACL level can override the rule action setting.
         */
        action?: pulumi.Input<inputs.wafv2.RuleGroupRuleActionArgs>;
        /**
         * Specifies how AWS WAF should handle `CAPTCHA` evaluations. If you don't specify this, AWS WAF uses the `CAPTCHA` configuration that's defined for the web ACL.
         */
        captchaConfig?: pulumi.Input<inputs.wafv2.RuleGroupCaptchaConfigArgs>;
        /**
         * Specifies how AWS WAF should handle `Challenge` evaluations. If you don't specify this, AWS WAF uses the challenge configuration that's defined for the web ACL.
         */
        challengeConfig?: pulumi.Input<inputs.wafv2.RuleGroupChallengeConfigArgs>;
        /**
         * The name of the rule.
         *
         * If you change the name of a `Rule` after you create it and you want the rule's metric name to reflect the change, update the metric name in the rule's `VisibilityConfig` settings. AWS WAF doesn't automatically update the metric name when you update the rule name.
         */
        name: pulumi.Input<string>;
        /**
         * If you define more than one `Rule` in a `WebACL` , AWS WAF evaluates each request against the `Rules` in order based on the value of `Priority` . AWS WAF processes rules with lower priority first. The priorities don't need to be consecutive, but they must all be different.
         */
        priority: pulumi.Input<number>;
        /**
         * Collection of Rule Labels.
         */
        ruleLabels?: pulumi.Input<pulumi.Input<inputs.wafv2.RuleGroupLabelArgs>[]>;
        /**
         * The AWS WAF processing statement for the rule, for example `ByteMatchStatement` or `SizeConstraintStatement` .
         */
        statement: pulumi.Input<inputs.wafv2.RuleGroupStatementArgs>;
        /**
         * Defines and enables Amazon CloudWatch metrics and web request sample collection.
         *
         * If you change the name of a `Rule` after you create it and you want the rule's metric name to reflect the change, update the metric name as well. AWS WAF doesn't automatically update the metric name.
         */
        visibilityConfig: pulumi.Input<inputs.wafv2.RuleGroupVisibilityConfigArgs>;
    }
    /**
     * Action taken when Rule matches its condition.
     */
    interface RuleGroupRuleActionArgs {
        /**
         * Instructs AWS WAF to allow the web request.
         */
        allow?: pulumi.Input<inputs.wafv2.RuleGroupAllowActionArgs>;
        /**
         * Instructs AWS WAF to block the web request.
         */
        block?: pulumi.Input<inputs.wafv2.RuleGroupBlockActionArgs>;
        /**
         * Specifies that AWS WAF should run a `CAPTCHA` check against the request:
         *
         * - If the request includes a valid, unexpired `CAPTCHA` token, AWS WAF allows the web request inspection to proceed to the next rule, similar to a `CountAction` .
         * - If the request doesn't include a valid, unexpired `CAPTCHA` token, AWS WAF discontinues the web ACL evaluation of the request and blocks it from going to its intended destination.
         *
         * AWS WAF generates a response that it sends back to the client, which includes the following:
         *
         * - The header `x-amzn-waf-action` with a value of `captcha` .
         * - The HTTP status code `405 Method Not Allowed` .
         * - If the request contains an `Accept` header with a value of `text/html` , the response includes a `CAPTCHA` challenge.
         *
         * You can configure the expiration time in the `CaptchaConfig` `ImmunityTimeProperty` setting at the rule and web ACL level. The rule setting overrides the web ACL setting.
         *
         * This action option is available for rules. It isn't available for web ACL default actions.
         */
        captcha?: pulumi.Input<inputs.wafv2.RuleGroupCaptchaActionArgs>;
        /**
         * Instructs AWS WAF to run a `Challenge` check against the web request.
         */
        challenge?: pulumi.Input<inputs.wafv2.RuleGroupChallengeActionArgs>;
        /**
         * Instructs AWS WAF to count the web request and then continue evaluating the request using the remaining rules in the web ACL.
         */
        count?: pulumi.Input<inputs.wafv2.RuleGroupCountActionArgs>;
    }
    /**
     * Size Constraint statement.
     */
    interface RuleGroupSizeConstraintStatementArgs {
        /**
         * The operator to use to compare the request part to the size setting.
         */
        comparisonOperator: pulumi.Input<enums.wafv2.RuleGroupSizeConstraintStatementComparisonOperator>;
        /**
         * The part of the web request that you want AWS WAF to inspect.
         */
        fieldToMatch: pulumi.Input<inputs.wafv2.RuleGroupFieldToMatchArgs>;
        /**
         * The size, in byte, to compare to the request part, after any transformations.
         */
        size: pulumi.Input<number>;
        /**
         * Text transformations eliminate some of the unusual formatting that attackers use in web requests in an effort to bypass detection. If you specify one or more transformations in a rule statement, AWS WAF performs all transformations on the content of the request component identified by `FieldToMatch` , starting from the lowest priority setting, before inspecting the content for a match.
         */
        textTransformations: pulumi.Input<pulumi.Input<inputs.wafv2.RuleGroupTextTransformationArgs>[]>;
    }
    /**
     * Sqli Match Statement.
     */
    interface RuleGroupSqliMatchStatementArgs {
        /**
         * The part of the web request that you want AWS WAF to inspect.
         */
        fieldToMatch: pulumi.Input<inputs.wafv2.RuleGroupFieldToMatchArgs>;
        /**
         * The sensitivity that you want AWS WAF to use to inspect for SQL injection attacks.
         *
         * `HIGH` detects more attacks, but might generate more false positives, especially if your web requests frequently contain unusual strings. For information about identifying and mitigating false positives, see [Testing and tuning](https://docs.aws.amazon.com/waf/latest/developerguide/web-acl-testing.html) in the *AWS WAF Developer Guide* .
         *
         * `LOW` is generally a better choice for resources that already have other protections against SQL injection attacks or that have a low tolerance for false positives.
         *
         * Default: `LOW`
         */
        sensitivityLevel?: pulumi.Input<enums.wafv2.RuleGroupSensitivityLevel>;
        /**
         * Text transformations eliminate some of the unusual formatting that attackers use in web requests in an effort to bypass detection. If you specify one or more transformations in a rule statement, AWS WAF performs all transformations on the content of the request component identified by `FieldToMatch` , starting from the lowest priority setting, before inspecting the content for a match.
         */
        textTransformations: pulumi.Input<pulumi.Input<inputs.wafv2.RuleGroupTextTransformationArgs>[]>;
    }
    /**
     * First level statement that contains conditions, such as ByteMatch, SizeConstraint, etc
     */
    interface RuleGroupStatementArgs {
        /**
         * A logical rule statement used to combine other rule statements with AND logic. You provide more than one `Statement` within the `AndStatement` .
         */
        andStatement?: pulumi.Input<inputs.wafv2.RuleGroupAndStatementArgs>;
        /**
         * A rule statement that defines a string match search for AWS WAF to apply to web requests. The byte match statement provides the bytes to search for, the location in requests that you want AWS WAF to search, and other settings. The bytes to search for are typically a string that corresponds with ASCII characters. In the AWS WAF console and the developer guide, this is called a string match statement.
         */
        byteMatchStatement?: pulumi.Input<inputs.wafv2.RuleGroupByteMatchStatementArgs>;
        /**
         * A rule statement that labels web requests by country and region and that matches against web requests based on country code. A geo match rule labels every request that it inspects regardless of whether it finds a match.
         *
         * - To manage requests only by country, you can use this statement by itself and specify the countries that you want to match against in the `CountryCodes` array.
         * - Otherwise, configure your geo match rule with Count action so that it only labels requests. Then, add one or more label match rules to run after the geo match rule and configure them to match against the geographic labels and handle the requests as needed.
         *
         * AWS WAF labels requests using the alpha-2 country and region codes from the International Organization for Standardization (ISO) 3166 standard. AWS WAF determines the codes using either the IP address in the web request origin or, if you specify it, the address in the geo match `ForwardedIPConfig` .
         *
         * If you use the web request origin, the label formats are `awswaf:clientip:geo:region:<ISO country code>-<ISO region code>` and `awswaf:clientip:geo:country:<ISO country code>` .
         *
         * If you use a forwarded IP address, the label formats are `awswaf:forwardedip:geo:region:<ISO country code>-<ISO region code>` and `awswaf:forwardedip:geo:country:<ISO country code>` .
         *
         * For additional details, see [Geographic match rule statement](https://docs.aws.amazon.com/waf/latest/developerguide/waf-rule-statement-type-geo-match.html) in the [AWS WAF Developer Guide](https://docs.aws.amazon.com/waf/latest/developerguide/waf-chapter.html) .
         */
        geoMatchStatement?: pulumi.Input<inputs.wafv2.RuleGroupGeoMatchStatementArgs>;
        /**
         * A rule statement used to detect web requests coming from particular IP addresses or address ranges. To use this, create an `IPSet` that specifies the addresses you want to detect, then use the ARN of that set in this statement.
         *
         * Each IP set rule statement references an IP set. You create and maintain the set independent of your rules. This allows you to use the single set in multiple rules. When you update the referenced set, AWS WAF automatically updates all rules that reference it.
         */
        ipSetReferenceStatement?: pulumi.Input<inputs.wafv2.RuleGroupIpSetReferenceStatementArgs>;
        /**
         * A rule statement to match against labels that have been added to the web request by rules that have already run in the web ACL.
         *
         * The label match statement provides the label or namespace string to search for. The label string can represent a part or all of the fully qualified label name that had been added to the web request. Fully qualified labels have a prefix, optional namespaces, and label name. The prefix identifies the rule group or web ACL context of the rule that added the label. If you do not provide the fully qualified name in your label match string, AWS WAF performs the search for labels that were added in the same context as the label match statement.
         */
        labelMatchStatement?: pulumi.Input<inputs.wafv2.RuleGroupLabelMatchStatementArgs>;
        /**
         * A logical rule statement used to negate the results of another rule statement. You provide one `Statement` within the `NotStatement` .
         */
        notStatement?: pulumi.Input<inputs.wafv2.RuleGroupNotStatementArgs>;
        /**
         * A logical rule statement used to combine other rule statements with OR logic. You provide more than one `Statement` within the `OrStatement` .
         */
        orStatement?: pulumi.Input<inputs.wafv2.RuleGroupOrStatementArgs>;
        /**
         * A rate-based rule counts incoming requests and rate limits requests when they are coming at too fast a rate. The rule categorizes requests according to your aggregation criteria, collects them into aggregation instances, and counts and rate limits the requests for each instance.
         *
         * > If you change any of these settings in a rule that's currently in use, the change resets the rule's rate limiting counts. This can pause the rule's rate limiting activities for up to a minute.
         *
         * You can specify individual aggregation keys, like IP address or HTTP method. You can also specify aggregation key combinations, like IP address and HTTP method, or HTTP method, query argument, and cookie.
         *
         * Each unique set of values for the aggregation keys that you specify is a separate aggregation instance, with the value from each key contributing to the aggregation instance definition.
         *
         * For example, assume the rule evaluates web requests with the following IP address and HTTP method values:
         *
         * - IP address 10.1.1.1, HTTP method POST
         * - IP address 10.1.1.1, HTTP method GET
         * - IP address 127.0.0.0, HTTP method POST
         * - IP address 10.1.1.1, HTTP method GET
         *
         * The rule would create different aggregation instances according to your aggregation criteria, for example:
         *
         * - If the aggregation criteria is just the IP address, then each individual address is an aggregation instance, and AWS WAF counts requests separately for each. The aggregation instances and request counts for our example would be the following:
         *
         * - IP address 10.1.1.1: count 3
         * - IP address 127.0.0.0: count 1
         * - If the aggregation criteria is HTTP method, then each individual HTTP method is an aggregation instance. The aggregation instances and request counts for our example would be the following:
         *
         * - HTTP method POST: count 2
         * - HTTP method GET: count 2
         * - If the aggregation criteria is IP address and HTTP method, then each IP address and each HTTP method would contribute to the combined aggregation instance. The aggregation instances and request counts for our example would be the following:
         *
         * - IP address 10.1.1.1, HTTP method POST: count 1
         * - IP address 10.1.1.1, HTTP method GET: count 2
         * - IP address 127.0.0.0, HTTP method POST: count 1
         *
         * For any n-tuple of aggregation keys, each unique combination of values for the keys defines a separate aggregation instance, which AWS WAF counts and rate-limits individually.
         *
         * You can optionally nest another statement inside the rate-based statement, to narrow the scope of the rule so that it only counts and rate limits requests that match the nested statement. You can use this nested scope-down statement in conjunction with your aggregation key specifications or you can just count and rate limit all requests that match the scope-down statement, without additional aggregation. When you choose to just manage all requests that match a scope-down statement, the aggregation instance is singular for the rule.
         *
         * You cannot nest a `RateBasedStatement` inside another statement, for example inside a `NotStatement` or `OrStatement` . You can define a `RateBasedStatement` inside a web ACL and inside a rule group.
         *
         * For additional information about the options, see [Rate limiting web requests using rate-based rules](https://docs.aws.amazon.com/waf/latest/developerguide/waf-rate-based-rules.html) in the *AWS WAF Developer Guide* .
         *
         * If you only aggregate on the individual IP address or forwarded IP address, you can retrieve the list of IP addresses that AWS WAF is currently rate limiting for a rule through the API call `GetRateBasedStatementManagedKeys` . This option is not available for other aggregation configurations.
         *
         * AWS WAF tracks and manages web requests separately for each instance of a rate-based rule that you use. For example, if you provide the same rate-based rule settings in two web ACLs, each of the two rule statements represents a separate instance of the rate-based rule and gets its own tracking and management by AWS WAF . If you define a rate-based rule inside a rule group, and then use that rule group in multiple places, each use creates a separate instance of the rate-based rule that gets its own tracking and management by AWS WAF .
         */
        rateBasedStatement?: pulumi.Input<inputs.wafv2.RuleGroupRateBasedStatementArgs>;
        /**
         * A rule statement used to search web request components for a match against a single regular expression.
         */
        regexMatchStatement?: pulumi.Input<inputs.wafv2.RuleGroupRegexMatchStatementArgs>;
        /**
         * A rule statement used to search web request components for matches with regular expressions. To use this, create a `RegexPatternSet` that specifies the expressions that you want to detect, then use the ARN of that set in this statement. A web request matches the pattern set rule statement if the request component matches any of the patterns in the set.
         *
         * Each regex pattern set rule statement references a regex pattern set. You create and maintain the set independent of your rules. This allows you to use the single set in multiple rules. When you update the referenced set, AWS WAF automatically updates all rules that reference it.
         */
        regexPatternSetReferenceStatement?: pulumi.Input<inputs.wafv2.RuleGroupRegexPatternSetReferenceStatementArgs>;
        /**
         * A rule statement that compares a number of bytes against the size of a request component, using a comparison operator, such as greater than (>) or less than (<). For example, you can use a size constraint statement to look for query strings that are longer than 100 bytes.
         *
         * If you configure AWS WAF to inspect the request body, AWS WAF inspects only the number of bytes in the body up to the limit for the web ACL and protected resource type. If you know that the request body for your web requests should never exceed the inspection limit, you can use a size constraint statement to block requests that have a larger request body size. For more information about the inspection limits, see `Body` and `JsonBody` settings for the `FieldToMatch` data type.
         *
         * If you choose URI for the value of Part of the request to filter on, the slash (/) in the URI counts as one character. For example, the URI `/logo.jpg` is nine characters long.
         */
        sizeConstraintStatement?: pulumi.Input<inputs.wafv2.RuleGroupSizeConstraintStatementArgs>;
        /**
         * A rule statement that inspects for malicious SQL code. Attackers insert malicious SQL code into web requests to do things like modify your database or extract data from it.
         */
        sqliMatchStatement?: pulumi.Input<inputs.wafv2.RuleGroupSqliMatchStatementArgs>;
        /**
         * A rule statement that inspects for cross-site scripting (XSS) attacks. In XSS attacks, the attacker uses vulnerabilities in a benign website as a vehicle to inject malicious client-site scripts into other legitimate web browsers.
         */
        xssMatchStatement?: pulumi.Input<inputs.wafv2.RuleGroupXssMatchStatementArgs>;
    }
    /**
     * Text Transformation on the Search String before match.
     */
    interface RuleGroupTextTransformationArgs {
        /**
         * Sets the relative processing order for multiple transformations. AWS WAF processes all transformations, from lowest priority to highest, before inspecting the transformed content. The priorities don't need to be consecutive, but they must all be different.
         */
        priority: pulumi.Input<number>;
        /**
         * For detailed descriptions of each of the transformation types, see [Text transformations](https://docs.aws.amazon.com/waf/latest/developerguide/waf-rule-statement-transformation.html) in the *AWS WAF Developer Guide* .
         */
        type: pulumi.Input<enums.wafv2.RuleGroupTextTransformationType>;
    }
    /**
     * The path component of the URI Fragment. This is the part of a web request that identifies a fragment uri, for example, /abcd#introduction
     */
    interface RuleGroupUriFragmentArgs {
        /**
         * What AWS WAF should do if it fails to completely parse the JSON body. The options are the following:
         *
         * - `EVALUATE_AS_STRING` - Inspect the body as plain text. AWS WAF applies the text transformations and inspection criteria that you defined for the JSON inspection to the body text string.
         * - `MATCH` - Treat the web request as matching the rule statement. AWS WAF applies the rule action to the request.
         * - `NO_MATCH` - Treat the web request as not matching the rule statement.
         *
         * If you don't provide this setting, AWS WAF parses and evaluates the content only up to the first parsing failure that it encounters.
         *
         * Example JSON: `{ "UriFragment": { "FallbackBehavior": "MATCH"} }`
         *
         * > AWS WAF parsing doesn't fully validate the input JSON string, so parsing can succeed even for invalid JSON. When parsing succeeds, AWS WAF doesn't apply the fallback behavior. For more information, see [JSON body](https://docs.aws.amazon.com/waf/latest/developerguide/waf-rule-statement-fields-list.html#waf-rule-statement-request-component-json-body) in the *AWS WAF Developer Guide* .
         */
        fallbackBehavior?: pulumi.Input<enums.wafv2.RuleGroupUriFragmentFallbackBehavior>;
    }
    /**
     * Visibility Metric of the RuleGroup.
     */
    interface RuleGroupVisibilityConfigArgs {
        /**
         * Indicates whether the associated resource sends metrics to Amazon CloudWatch. For the list of available metrics, see [AWS WAF Metrics](https://docs.aws.amazon.com/waf/latest/developerguide/monitoring-cloudwatch.html#waf-metrics) in the *AWS WAF Developer Guide* .
         *
         * For web ACLs, the metrics are for web requests that have the web ACL default action applied. AWS WAF applies the default action to web requests that pass the inspection of all rules in the web ACL without being either allowed or blocked. For more information,
         * see [The web ACL default action](https://docs.aws.amazon.com/waf/latest/developerguide/web-acl-default-action.html) in the *AWS WAF Developer Guide* .
         */
        cloudWatchMetricsEnabled: pulumi.Input<boolean>;
        /**
         * A name of the Amazon CloudWatch metric dimension. The name can contain only the characters: A-Z, a-z, 0-9, - (hyphen), and _ (underscore). The name can be from one to 128 characters long. It can't contain whitespace or metric names that are reserved for AWS WAF , for example `All` and `Default_Action` .
         */
        metricName: pulumi.Input<string>;
        /**
         * Indicates whether AWS WAF should store a sampling of the web requests that match the rules. You can view the sampled requests through the AWS WAF console.
         *
         * If you configure data protection for the web ACL, the protection applies to the web ACL's sampled web request data.
         *
         * > Request sampling doesn't provide a field redaction option, and any field redaction that you specify in your logging configuration doesn't affect sampling. You can only exclude fields from request sampling by disabling sampling in the web ACL visibility configuration or by configuring data protection for the web ACL.
         */
        sampledRequestsEnabled: pulumi.Input<boolean>;
    }
    /**
     * Xss Match Statement.
     */
    interface RuleGroupXssMatchStatementArgs {
        /**
         * The part of the web request that you want AWS WAF to inspect.
         */
        fieldToMatch: pulumi.Input<inputs.wafv2.RuleGroupFieldToMatchArgs>;
        /**
         * Text transformations eliminate some of the unusual formatting that attackers use in web requests in an effort to bypass detection. If you specify one or more transformations in a rule statement, AWS WAF performs all transformations on the content of the request component identified by `FieldToMatch` , starting from the lowest priority setting, before inspecting the content for a match.
         */
        textTransformations: pulumi.Input<pulumi.Input<inputs.wafv2.RuleGroupTextTransformationArgs>[]>;
    }
    /**
     * Allow traffic towards application.
     */
    interface WebAclAllowActionArgs {
        /**
         * Defines custom handling for the web request.
         *
         * For information about customizing web requests and responses, see [Customizing web requests and responses in AWS WAF](https://docs.aws.amazon.com/waf/latest/developerguide/waf-custom-request-response.html) in the *AWS WAF Developer Guide* .
         */
        customRequestHandling?: pulumi.Input<inputs.wafv2.WebAclCustomRequestHandlingArgs>;
    }
    interface WebAclAndStatementArgs {
        /**
         * The statements to combine with AND logic. You can use any statements that can be nested.
         */
        statements: pulumi.Input<pulumi.Input<inputs.wafv2.WebAclStatementArgs>[]>;
    }
    /**
     * AssociationConfig for body inspection
     */
    interface WebAclAssociationConfigArgs {
        /**
         * Customizes the maximum size of the request body that your protected CloudFront, API Gateway, Amazon Cognito, App Runner, and Verified Access resources forward to AWS WAF for inspection. The default size is 16 KB (16,384 bytes). You can change the setting for any of the available resource types.
         *
         * > You are charged additional fees when your protected resources forward body sizes that are larger than the default. For more information, see [AWS WAF Pricing](https://docs.aws.amazon.com/waf/pricing/) .
         *
         * Example JSON: `{ "API_GATEWAY": "KB_48", "APP_RUNNER_SERVICE": "KB_32" }`
         *
         * For Application Load Balancer and AWS AppSync , the limit is fixed at 8 KB (8,192 bytes).
         */
        requestBody?: pulumi.Input<{
            [key: string]: pulumi.Input<inputs.wafv2.WebAclRequestBodyAssociatedResourceTypeConfigArgs>;
        }>;
    }
    /**
     * Configures how to use the Account creation fraud prevention managed rule group in the web ACL
     */
    interface WebAclAwsManagedRulesAcfpRuleSetArgs {
        /**
         * The path of the account creation endpoint for your application. This is the page on your website that accepts the completed registration form for a new user. This page must accept `POST` requests.
         *
         * For example, for the URL `https://example.com/web/newaccount` , you would provide the path `/web/newaccount` . Account creation page paths that start with the path that you provide are considered a match. For example `/web/newaccount` matches the account creation paths `/web/newaccount` , `/web/newaccount/` , `/web/newaccountPage` , and `/web/newaccount/thisPage` , but doesn't match the path `/home/web/newaccount` or `/website/newaccount` .
         */
        creationPath: pulumi.Input<string>;
        /**
         * Allow the use of regular expressions in the registration page path and the account creation path.
         */
        enableRegexInPath?: pulumi.Input<boolean>;
        /**
         * The path of the account registration endpoint for your application. This is the page on your website that presents the registration form to new users.
         *
         * > This page must accept `GET` text/html requests.
         *
         * For example, for the URL `https://example.com/web/registration` , you would provide the path `/web/registration` . Registration page paths that start with the path that you provide are considered a match. For example `/web/registration` matches the registration paths `/web/registration` , `/web/registration/` , `/web/registrationPage` , and `/web/registration/thisPage` , but doesn't match the path `/home/web/registration` or `/website/registration` .
         */
        registrationPagePath: pulumi.Input<string>;
        /**
         * The criteria for inspecting account creation requests, used by the ACFP rule group to validate and track account creation attempts.
         */
        requestInspection: pulumi.Input<inputs.wafv2.WebAclRequestInspectionAcfpArgs>;
        /**
         * The criteria for inspecting responses to account creation requests, used by the ACFP rule group to track account creation success rates.
         *
         * > Response inspection is available only in web ACLs that protect Amazon CloudFront distributions.
         *
         * The ACFP rule group evaluates the responses that your protected resources send back to client account creation attempts, keeping count of successful and failed attempts from each IP address and client session. Using this information, the rule group labels and mitigates requests from client sessions and IP addresses that have had too many successful account creation attempts in a short amount of time.
         */
        responseInspection?: pulumi.Input<inputs.wafv2.WebAclResponseInspectionArgs>;
    }
    /**
     * Configures how to use the Account Takeover Prevention managed rule group in the web ACL
     */
    interface WebAclAwsManagedRulesAtpRuleSetArgs {
        /**
         * Allow the use of regular expressions in the login page path.
         */
        enableRegexInPath?: pulumi.Input<boolean>;
        /**
         * The path of the login endpoint for your application. For example, for the URL `https://example.com/web/login` , you would provide the path `/web/login` . Login paths that start with the path that you provide are considered a match. For example `/web/login` matches the login paths `/web/login` , `/web/login/` , `/web/loginPage` , and `/web/login/thisPage` , but doesn't match the login path `/home/web/login` or `/website/login` .
         *
         * The rule group inspects only HTTP `POST` requests to your specified login endpoint.
         */
        loginPath: pulumi.Input<string>;
        /**
         * The criteria for inspecting login requests, used by the ATP rule group to validate credentials usage.
         */
        requestInspection?: pulumi.Input<inputs.wafv2.WebAclRequestInspectionArgs>;
        /**
         * The criteria for inspecting responses to login requests, used by the ATP rule group to track login failure rates.
         *
         * > Response inspection is available only in web ACLs that protect Amazon CloudFront distributions.
         *
         * The ATP rule group evaluates the responses that your protected resources send back to client login attempts, keeping count of successful and failed attempts for each IP address and client session. Using this information, the rule group labels and mitigates requests from client sessions and IP addresses that have had too many failed login attempts in a short amount of time.
         */
        responseInspection?: pulumi.Input<inputs.wafv2.WebAclResponseInspectionArgs>;
    }
    /**
     * Configures how to use the Bot Control managed rule group in the web ACL
     */
    interface WebAclAwsManagedRulesBotControlRuleSetArgs {
        /**
         * Applies only to the targeted inspection level.
         *
         * Determines whether to use machine learning (ML) to analyze your web traffic for bot-related activity. Machine learning is required for the Bot Control rules `TGT_ML_CoordinatedActivityLow` and `TGT_ML_CoordinatedActivityMedium` , which
         * inspect for anomalous behavior that might indicate distributed, coordinated bot activity.
         *
         * For more information about this choice, see the listing for these rules in the table at [Bot Control rules listing](https://docs.aws.amazon.com/waf/latest/developerguide/aws-managed-rule-groups-bot.html#aws-managed-rule-groups-bot-rules) in the *AWS WAF Developer Guide* .
         *
         * Default: `TRUE`
         */
        enableMachineLearning?: pulumi.Input<boolean>;
        /**
         * The inspection level to use for the Bot Control rule group. The common level is the least expensive. The targeted level includes all common level rules and adds rules with more advanced inspection criteria. For details, see [AWS WAF Bot Control rule group](https://docs.aws.amazon.com/waf/latest/developerguide/aws-managed-rule-groups-bot.html) in the *AWS WAF Developer Guide* .
         */
        inspectionLevel: pulumi.Input<enums.wafv2.WebAclAwsManagedRulesBotControlRuleSetInspectionLevel>;
    }
    /**
     * Block traffic towards application.
     */
    interface WebAclBlockActionArgs {
        /**
         * Defines a custom response for the web request.
         *
         * For information about customizing web requests and responses, see [Customizing web requests and responses in AWS WAF](https://docs.aws.amazon.com/waf/latest/developerguide/waf-custom-request-response.html) in the *AWS WAF Developer Guide* .
         */
        customResponse?: pulumi.Input<inputs.wafv2.WebAclCustomResponseArgs>;
    }
    /**
     * The body of a web request. This immediately follows the request headers.
     */
    interface WebAclBodyArgs {
        /**
         * What AWS WAF should do if the body is larger than AWS WAF can inspect.
         *
         * AWS WAF does not support inspecting the entire contents of the web request body if the body exceeds the limit for the resource type. When a web request body is larger than the limit, the underlying host service only forwards the contents that are within the limit to AWS WAF for inspection.
         *
         * - For Application Load Balancer and AWS AppSync , the limit is fixed at 8 KB (8,192 bytes).
         * - For CloudFront, API Gateway, Amazon Cognito, App Runner, and Verified Access, the default limit is 16 KB (16,384 bytes), and you can increase the limit for each resource type in the web ACL `AssociationConfig` , for additional processing fees.
         * - For AWS Amplify , use the CloudFront limit.
         *
         * The options for oversize handling are the following:
         *
         * - `CONTINUE` - Inspect the available body contents normally, according to the rule inspection criteria.
         * - `MATCH` - Treat the web request as matching the rule statement. AWS WAF applies the rule action to the request.
         * - `NO_MATCH` - Treat the web request as not matching the rule statement.
         *
         * You can combine the `MATCH` or `NO_MATCH` settings for oversize handling with your rule and web ACL action settings, so that you block any request whose body is over the limit.
         *
         * Default: `CONTINUE`
         */
        oversizeHandling?: pulumi.Input<enums.wafv2.WebAclOversizeHandling>;
    }
    /**
     * Byte Match statement.
     */
    interface WebAclByteMatchStatementArgs {
        /**
         * The part of the web request that you want AWS WAF to inspect.
         */
        fieldToMatch: pulumi.Input<inputs.wafv2.WebAclFieldToMatchArgs>;
        /**
         * The area within the portion of the web request that you want AWS WAF to search for `SearchString` . Valid values include the following:
         *
         * *CONTAINS*
         *
         * The specified part of the web request must include the value of `SearchString` , but the location doesn't matter.
         *
         * *CONTAINS_WORD*
         *
         * The specified part of the web request must include the value of `SearchString` , and `SearchString` must contain only alphanumeric characters or underscore (A-Z, a-z, 0-9, or _). In addition, `SearchString` must be a word, which means that both of the following are true:
         *
         * - `SearchString` is at the beginning of the specified part of the web request or is preceded by a character other than an alphanumeric character or underscore (_). Examples include the value of a header and `;BadBot` .
         * - `SearchString` is at the end of the specified part of the web request or is followed by a character other than an alphanumeric character or underscore (_), for example, `BadBot;` and `-BadBot;` .
         *
         * *EXACTLY*
         *
         * The value of the specified part of the web request must exactly match the value of `SearchString` .
         *
         * *STARTS_WITH*
         *
         * The value of `SearchString` must appear at the beginning of the specified part of the web request.
         *
         * *ENDS_WITH*
         *
         * The value of `SearchString` must appear at the end of the specified part of the web request.
         */
        positionalConstraint: pulumi.Input<enums.wafv2.WebAclPositionalConstraint>;
        /**
         * A string value that you want AWS WAF to search for. AWS WAF searches only in the part of web requests that you designate for inspection in `FieldToMatch` . The maximum length of the value is 200 bytes. For alphabetic characters A-Z and a-z, the value is case sensitive.
         *
         * Don't encode this string. Provide the value that you want AWS WAF to search for. AWS CloudFormation automatically base64 encodes the value for you.
         *
         * For example, suppose the value of `Type` is `HEADER` and the value of `Data` is `User-Agent` . If you want to search the `User-Agent` header for the value `BadBot` , you provide the string `BadBot` in the value of `SearchString` .
         *
         * You must specify either `SearchString` or `SearchStringBase64` in a `ByteMatchStatement` .
         */
        searchString?: pulumi.Input<string>;
        /**
         * String to search for in a web request component, base64-encoded. If you don't want to encode the string, specify the unencoded value in `SearchString` instead.
         *
         * You must specify either `SearchString` or `SearchStringBase64` in a `ByteMatchStatement` .
         */
        searchStringBase64?: pulumi.Input<string>;
        /**
         * Text transformations eliminate some of the unusual formatting that attackers use in web requests in an effort to bypass detection. If you specify one or more transformations in a rule statement, AWS WAF performs all transformations on the content of the request component identified by `FieldToMatch` , starting from the lowest priority setting, before inspecting the content for a match.
         */
        textTransformations: pulumi.Input<pulumi.Input<inputs.wafv2.WebAclTextTransformationArgs>[]>;
    }
    /**
     * Checks valid token exists with request.
     */
    interface WebAclCaptchaActionArgs {
        /**
         * Defines custom handling for the web request, used when the `CAPTCHA` inspection determines that the request's token is valid and unexpired.
         *
         * For information about customizing web requests and responses, see [Customizing web requests and responses in AWS WAF](https://docs.aws.amazon.com/waf/latest/developerguide/waf-custom-request-response.html) in the *AWS WAF Developer Guide* .
         */
        customRequestHandling?: pulumi.Input<inputs.wafv2.WebAclCustomRequestHandlingArgs>;
    }
    interface WebAclCaptchaConfigArgs {
        /**
         * Determines how long a `CAPTCHA` timestamp in the token remains valid after the client successfully solves a `CAPTCHA` puzzle.
         */
        immunityTimeProperty?: pulumi.Input<inputs.wafv2.WebAclImmunityTimePropertyArgs>;
    }
    /**
     * Checks that the request has a valid token with an unexpired challenge timestamp and, if not, returns a browser challenge to the client.
     */
    interface WebAclChallengeActionArgs {
        /**
         * Defines custom handling for the web request, used when the challenge inspection determines that the request's token is valid and unexpired.
         *
         * For information about customizing web requests and responses, see [Customizing web requests and responses in AWS WAF](https://docs.aws.amazon.com/waf/latest/developerguide/waf-custom-request-response.html) in the [AWS WAF developer guide](https://docs.aws.amazon.com/waf/latest/developerguide/waf-chapter.html) .
         */
        customRequestHandling?: pulumi.Input<inputs.wafv2.WebAclCustomRequestHandlingArgs>;
    }
    interface WebAclChallengeConfigArgs {
        /**
         * Determines how long a challenge timestamp in the token remains valid after the client successfully responds to a challenge.
         */
        immunityTimeProperty?: pulumi.Input<inputs.wafv2.WebAclImmunityTimePropertyArgs>;
    }
    /**
     * The pattern to look for in the request cookies.
     */
    interface WebAclCookieMatchPatternArgs {
        /**
         * Inspect all parts of the web request cookies.
         */
        all?: any;
        /**
         * Inspect only the cookies whose keys don't match any of the strings specified here.
         */
        excludedCookies?: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * Inspect only the cookies that have a key that matches one of the strings specified here.
         */
        includedCookies?: pulumi.Input<pulumi.Input<string>[]>;
    }
    /**
     * Includes cookies of a web request.
     */
    interface WebAclCookiesArgs {
        /**
         * The filter to use to identify the subset of cookies to inspect in a web request.
         *
         * You must specify exactly one setting: either `All` , `IncludedCookies` , or `ExcludedCookies` .
         *
         * Example JSON: `"MatchPattern": { "IncludedCookies": [ "session-id-time", "session-id" ] }`
         */
        matchPattern: pulumi.Input<inputs.wafv2.WebAclCookieMatchPatternArgs>;
        /**
         * The parts of the cookies to inspect with the rule inspection criteria. If you specify `ALL` , AWS WAF inspects both keys and values.
         *
         * `All` does not require a match to be found in the keys and a match to be found in the values. It requires a match to be found in the keys or the values or both. To require a match in the keys and in the values, use a logical `AND` statement to combine two match rules, one that inspects the keys and another that inspects the values.
         */
        matchScope: pulumi.Input<enums.wafv2.WebAclMapMatchScope>;
        /**
         * What AWS WAF should do if the cookies of the request are more numerous or larger than AWS WAF can inspect. AWS WAF does not support inspecting the entire contents of request cookies when they exceed 8 KB (8192 bytes) or 200 total cookies. The underlying host service forwards a maximum of 200 cookies and at most 8 KB of cookie contents to AWS WAF .
         *
         * The options for oversize handling are the following:
         *
         * - `CONTINUE` - Inspect the available cookies normally, according to the rule inspection criteria.
         * - `MATCH` - Treat the web request as matching the rule statement. AWS WAF applies the rule action to the request.
         * - `NO_MATCH` - Treat the web request as not matching the rule statement.
         */
        oversizeHandling: pulumi.Input<enums.wafv2.WebAclOversizeHandling>;
    }
    /**
     * Allow traffic towards application.
     */
    interface WebAclCountActionArgs {
        /**
         * Defines custom handling for the web request.
         *
         * For information about customizing web requests and responses, see [Customizing web requests and responses in AWS WAF](https://docs.aws.amazon.com/waf/latest/developerguide/waf-custom-request-response.html) in the *AWS WAF Developer Guide* .
         */
        customRequestHandling?: pulumi.Input<inputs.wafv2.WebAclCustomRequestHandlingArgs>;
    }
    /**
     * HTTP header.
     */
    interface WebAclCustomHttpHeaderArgs {
        /**
         * The name of the custom header.
         *
         * For custom request header insertion, when AWS WAF inserts the header into the request, it prefixes this name `x-amzn-waf-` , to avoid confusion with the headers that are already in the request. For example, for the header name `sample` , AWS WAF inserts the header `x-amzn-waf-sample` .
         */
        name: pulumi.Input<string>;
        /**
         * The value of the custom header.
         */
        value: pulumi.Input<string>;
    }
    /**
     * Custom request handling.
     */
    interface WebAclCustomRequestHandlingArgs {
        /**
         * Collection of HTTP headers.
         */
        insertHeaders: pulumi.Input<pulumi.Input<inputs.wafv2.WebAclCustomHttpHeaderArgs>[]>;
    }
    /**
     * Custom response.
     */
    interface WebAclCustomResponseArgs {
        /**
         * Custom response body key.
         */
        customResponseBodyKey?: pulumi.Input<string>;
        /**
         * The HTTP status code to return to the client.
         *
         * For a list of status codes that you can use in your custom responses, see [Supported status codes for custom response](https://docs.aws.amazon.com/waf/latest/developerguide/customizing-the-response-status-codes.html) in the *AWS WAF Developer Guide* .
         */
        responseCode: pulumi.Input<number>;
        /**
         * Collection of HTTP headers.
         */
        responseHeaders?: pulumi.Input<pulumi.Input<inputs.wafv2.WebAclCustomHttpHeaderArgs>[]>;
    }
    /**
     * Custom response body.
     */
    interface WebAclCustomResponseBodyArgs {
        /**
         * The payload of the custom response.
         *
         * You can use JSON escape strings in JSON content. To do this, you must specify JSON content in the `ContentType` setting.
         *
         * For information about the limits on count and size for custom request and response settings, see [AWS WAF quotas](https://docs.aws.amazon.com/waf/latest/developerguide/limits.html) in the *AWS WAF Developer Guide* .
         */
        content: pulumi.Input<string>;
        /**
         * The type of content in the payload that you are defining in the `Content` string.
         */
        contentType: pulumi.Input<enums.wafv2.WebAclResponseContentType>;
    }
    interface WebAclDataProtectArgs {
        action: pulumi.Input<enums.wafv2.WebAclDataProtectionAction>;
        excludeRateBasedDetails?: pulumi.Input<boolean>;
        excludeRuleMatchDetails?: pulumi.Input<boolean>;
        field: pulumi.Input<inputs.wafv2.WebAclFieldToProtectArgs>;
    }
    interface WebAclDataProtectionConfigArgs {
        /**
         * An array of data protection configurations for specific web request field types. This is defined for each web ACL. AWS WAF applies the specified protection to all web requests that the web ACL inspects.
         */
        dataProtections: pulumi.Input<pulumi.Input<inputs.wafv2.WebAclDataProtectArgs>[]>;
    }
    /**
     * Default Action WebACL will take against ingress traffic when there is no matching Rule.
     */
    interface WebAclDefaultActionArgs {
        /**
         * Specifies that AWS WAF should allow requests by default.
         */
        allow?: pulumi.Input<inputs.wafv2.WebAclAllowActionArgs>;
        /**
         * Specifies that AWS WAF should block requests by default.
         */
        block?: pulumi.Input<inputs.wafv2.WebAclBlockActionArgs>;
    }
    /**
     * Excluded Rule in the RuleGroup or ManagedRuleGroup will not be evaluated.
     */
    interface WebAclExcludedRuleArgs {
        /**
         * The name of the rule whose action you want to override to `Count` .
         */
        name: pulumi.Input<string>;
    }
    interface WebAclFieldIdentifierArgs {
        /**
         * The name of the field.
         *
         * When the `PayloadType` in the request inspection is `JSON` , this identifier must be in JSON pointer syntax. For example `/form/username` . For information about the JSON Pointer syntax, see the Internet Engineering Task Force (IETF) documentation [JavaScript Object Notation (JSON) Pointer](https://docs.aws.amazon.com/https://tools.ietf.org/html/rfc6901) .
         *
         * When the `PayloadType` is `FORM_ENCODED` , use the HTML form names. For example, `username` .
         *
         * For more information, see the descriptions for each field type in the request inspection properties.
         */
        identifier: pulumi.Input<string>;
    }
    /**
     * Field of the request to match.
     */
    interface WebAclFieldToMatchArgs {
        /**
         * All query arguments of a web request.
         */
        allQueryArguments?: any;
        /**
         * Inspect the request body as plain text. The request body immediately follows the request headers. This is the part of a request that contains any additional data that you want to send to your web server as the HTTP request body, such as data from a form.
         *
         * AWS WAF does not support inspecting the entire contents of the web request body if the body exceeds the limit for the resource type. When a web request body is larger than the limit, the underlying host service only forwards the contents that are within the limit to AWS WAF for inspection.
         *
         * - For Application Load Balancer and AWS AppSync , the limit is fixed at 8 KB (8,192 bytes).
         * - For CloudFront, API Gateway, Amazon Cognito, App Runner, and Verified Access, the default limit is 16 KB (16,384 bytes), and you can increase the limit for each resource type in the web ACL `AssociationConfig` , for additional processing fees.
         * - For AWS Amplify , use the CloudFront limit.
         *
         * For information about how to handle oversized request bodies, see the `Body` object configuration.
         */
        body?: pulumi.Input<inputs.wafv2.WebAclBodyArgs>;
        /**
         * Inspect the request cookies. You must configure scope and pattern matching filters in the `Cookies` object, to define the set of cookies and the parts of the cookies that AWS WAF inspects.
         *
         * Only the first 8 KB (8192 bytes) of a request's cookies and only the first 200 cookies are forwarded to AWS WAF for inspection by the underlying host service. You must configure how to handle any oversize cookie content in the `Cookies` object. AWS WAF applies the pattern matching filters to the cookies that it receives from the underlying host service.
         */
        cookies?: pulumi.Input<inputs.wafv2.WebAclCookiesArgs>;
        /**
         * Inspect the request headers. You must configure scope and pattern matching filters in the `Headers` object, to define the set of headers to and the parts of the headers that AWS WAF inspects.
         *
         * Only the first 8 KB (8192 bytes) of a request's headers and only the first 200 headers are forwarded to AWS WAF for inspection by the underlying host service. You must configure how to handle any oversize header content in the `Headers` object. AWS WAF applies the pattern matching filters to the headers that it receives from the underlying host service.
         */
        headers?: pulumi.Input<inputs.wafv2.WebAclHeadersArgs>;
        /**
         * Available for use with Amazon CloudFront distributions and Application Load Balancers. Match against the request's JA3 fingerprint. The JA3 fingerprint is a 32-character hash derived from the TLS Client Hello of an incoming request. This fingerprint serves as a unique identifier for the client's TLS configuration. AWS WAF calculates and logs this fingerprint for each request that has enough TLS Client Hello information for the calculation. Almost all web requests include this information.
         *
         * > You can use this choice only with a string match `ByteMatchStatement` with the `PositionalConstraint` set to `EXACTLY` .
         *
         * You can obtain the JA3 fingerprint for client requests from the web ACL logs. If AWS WAF is able to calculate the fingerprint, it includes it in the logs. For information about the logging fields, see [Log fields](https://docs.aws.amazon.com/waf/latest/developerguide/logging-fields.html) in the *AWS WAF Developer Guide* .
         *
         * Provide the JA3 fingerprint string from the logs in your string match statement specification, to match with any future requests that have the same TLS configuration.
         */
        ja3Fingerprint?: pulumi.Input<inputs.wafv2.WebAclJa3FingerprintArgs>;
        /**
         * Available for use with Amazon CloudFront distributions and Application Load Balancers. Match against the request's JA4 fingerprint. The JA4 fingerprint is a 36-character hash derived from the TLS Client Hello of an incoming request. This fingerprint serves as a unique identifier for the client's TLS configuration. AWS WAF calculates and logs this fingerprint for each request that has enough TLS Client Hello information for the calculation. Almost all web requests include this information.
         *
         * > You can use this choice only with a string match `ByteMatchStatement` with the `PositionalConstraint` set to `EXACTLY` .
         *
         * You can obtain the JA4 fingerprint for client requests from the web ACL logs. If AWS WAF is able to calculate the fingerprint, it includes it in the logs. For information about the logging fields, see [Log fields](https://docs.aws.amazon.com/waf/latest/developerguide/logging-fields.html) in the *AWS WAF Developer Guide* .
         *
         * Provide the JA4 fingerprint string from the logs in your string match statement specification, to match with any future requests that have the same TLS configuration.
         */
        ja4Fingerprint?: pulumi.Input<inputs.wafv2.WebAclJa4FingerprintArgs>;
        /**
         * Inspect the request body as JSON. The request body immediately follows the request headers. This is the part of a request that contains any additional data that you want to send to your web server as the HTTP request body, such as data from a form.
         *
         * AWS WAF does not support inspecting the entire contents of the web request body if the body exceeds the limit for the resource type. When a web request body is larger than the limit, the underlying host service only forwards the contents that are within the limit to AWS WAF for inspection.
         *
         * - For Application Load Balancer and AWS AppSync , the limit is fixed at 8 KB (8,192 bytes).
         * - For CloudFront, API Gateway, Amazon Cognito, App Runner, and Verified Access, the default limit is 16 KB (16,384 bytes), and you can increase the limit for each resource type in the web ACL `AssociationConfig` , for additional processing fees.
         * - For AWS Amplify , use the CloudFront limit.
         *
         * For information about how to handle oversized request bodies, see the `JsonBody` object configuration.
         */
        jsonBody?: pulumi.Input<inputs.wafv2.WebAclJsonBodyArgs>;
        /**
         * The HTTP method of a web request. The method indicates the type of operation that the request is asking the origin to perform.
         */
        method?: any;
        /**
         * The query string of a web request. This is the part of a URL that appears after a ? character, if any.
         */
        queryString?: any;
        /**
         * Inspect a single header. Provide the name of the header to inspect, for example, `User-Agent` or `Referer` . This setting isn't case sensitive.
         *
         * Example JSON: `"SingleHeader": { "Name": "haystack" }`
         *
         * Alternately, you can filter and inspect all headers with the `Headers` `FieldToMatch` setting.
         */
        singleHeader?: pulumi.Input<inputs.wafv2.WebAclFieldToMatchSingleHeaderPropertiesArgs>;
        /**
         * One query argument in a web request, identified by name, for example UserName or SalesRegion. The name can be up to 30 characters long and isn't case sensitive.
         */
        singleQueryArgument?: pulumi.Input<inputs.wafv2.WebAclFieldToMatchSingleQueryArgumentPropertiesArgs>;
        /**
         * Inspect fragments of the request URI. You must configure scope and pattern matching filters in the `UriFragment` object, to define the fragment of a URI that AWS WAF inspects.
         *
         * Only the first 8 KB (8192 bytes) of a request's URI fragments and only the first 200 URI fragments are forwarded to AWS WAF for inspection by the underlying host service. You must configure how to handle any oversize URI fragment content in the `UriFragment` object. AWS WAF applies the pattern matching filters to the cookies that it receives from the underlying host service.
         */
        uriFragment?: pulumi.Input<inputs.wafv2.WebAclUriFragmentArgs>;
        /**
         * The path component of the URI of a web request. This is the part of a web request that identifies a resource, for example, /images/daily-ad.jpg.
         */
        uriPath?: any;
    }
    /**
     * Inspect a single header. Provide the name of the header to inspect, for example, `User-Agent` or `Referer` . This setting isn't case sensitive.
     *
     * Example JSON: `"SingleHeader": { "Name": "haystack" }`
     *
     * Alternately, you can filter and inspect all headers with the `Headers` `FieldToMatch` setting.
     */
    interface WebAclFieldToMatchSingleHeaderPropertiesArgs {
        name: pulumi.Input<string>;
    }
    /**
     * One query argument in a web request, identified by name, for example UserName or SalesRegion. The name can be up to 30 characters long and isn't case sensitive.
     */
    interface WebAclFieldToMatchSingleQueryArgumentPropertiesArgs {
        name: pulumi.Input<string>;
    }
    /**
     * Field in log to protect.
     */
    interface WebAclFieldToProtectArgs {
        /**
         * List of field keys to protect
         */
        fieldKeys?: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * Field type to protect
         */
        fieldType: pulumi.Input<enums.wafv2.WebAclFieldToProtectFieldType>;
    }
    interface WebAclForwardedIpConfigurationArgs {
        /**
         * The match status to assign to the web request if the request doesn't have a valid IP address in the specified position.
         *
         * > If the specified header isn't present in the request, AWS WAF doesn't apply the rule to the web request at all.
         *
         * You can specify the following fallback behaviors:
         *
         * - `MATCH` - Treat the web request as matching the rule statement. AWS WAF applies the rule action to the request.
         * - `NO_MATCH` - Treat the web request as not matching the rule statement.
         */
        fallbackBehavior: pulumi.Input<enums.wafv2.WebAclForwardedIpConfigurationFallbackBehavior>;
        /**
         * The name of the HTTP header to use for the IP address. For example, to use the X-Forwarded-For (XFF) header, set this to `X-Forwarded-For` .
         *
         * > If the specified header isn't present in the request, AWS WAF doesn't apply the rule to the web request at all.
         */
        headerName: pulumi.Input<string>;
    }
    interface WebAclGeoMatchStatementArgs {
        /**
         * An array of two-character country codes that you want to match against, for example, `[ "US", "CN" ]` , from the alpha-2 country ISO codes of the ISO 3166 international standard.
         *
         * When you use a geo match statement just for the region and country labels that it adds to requests, you still have to supply a country code for the rule to evaluate. In this case, you configure the rule to only count matching requests, but it will still generate logging and count metrics for any matches. You can reduce the logging and metrics that the rule produces by specifying a country that's unlikely to be a source of traffic to your site.
         */
        countryCodes?: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * The configuration for inspecting IP addresses in an HTTP header that you specify, instead of using the IP address that's reported by the web request origin. Commonly, this is the X-Forwarded-For (XFF) header, but you can specify any header name.
         *
         * > If the specified header isn't present in the request, AWS WAF doesn't apply the rule to the web request at all.
         */
        forwardedIpConfig?: pulumi.Input<inputs.wafv2.WebAclForwardedIpConfigurationArgs>;
    }
    /**
     * The pattern to look for in the request headers.
     */
    interface WebAclHeaderMatchPatternArgs {
        /**
         * Inspect all parts of the web request headers.
         */
        all?: any;
        /**
         * Inspect only the headers whose keys don't match any of the strings specified here.
         */
        excludedHeaders?: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * Inspect only the headers that have a key that matches one of the strings specified here.
         */
        includedHeaders?: pulumi.Input<pulumi.Input<string>[]>;
    }
    /**
     * Includes headers of a web request.
     */
    interface WebAclHeadersArgs {
        /**
         * The filter to use to identify the subset of headers to inspect in a web request.
         *
         * You must specify exactly one setting: either `All` , `IncludedHeaders` , or `ExcludedHeaders` .
         *
         * Example JSON: `"MatchPattern": { "ExcludedHeaders": [ "KeyToExclude1", "KeyToExclude2" ] }`
         */
        matchPattern: pulumi.Input<inputs.wafv2.WebAclHeaderMatchPatternArgs>;
        /**
         * The parts of the headers to match with the rule inspection criteria. If you specify `ALL` , AWS WAF inspects both keys and values.
         *
         * `All` does not require a match to be found in the keys and a match to be found in the values. It requires a match to be found in the keys or the values or both. To require a match in the keys and in the values, use a logical `AND` statement to combine two match rules, one that inspects the keys and another that inspects the values.
         */
        matchScope: pulumi.Input<enums.wafv2.WebAclMapMatchScope>;
        /**
         * What AWS WAF should do if the headers of the request are more numerous or larger than AWS WAF can inspect. AWS WAF does not support inspecting the entire contents of request headers when they exceed 8 KB (8192 bytes) or 200 total headers. The underlying host service forwards a maximum of 200 headers and at most 8 KB of header contents to AWS WAF .
         *
         * The options for oversize handling are the following:
         *
         * - `CONTINUE` - Inspect the available headers normally, according to the rule inspection criteria.
         * - `MATCH` - Treat the web request as matching the rule statement. AWS WAF applies the rule action to the request.
         * - `NO_MATCH` - Treat the web request as not matching the rule statement.
         */
        oversizeHandling: pulumi.Input<enums.wafv2.WebAclOversizeHandling>;
    }
    interface WebAclImmunityTimePropertyArgs {
        /**
         * The amount of time, in seconds, that a `CAPTCHA` or challenge timestamp is considered valid by AWS WAF . The default setting is 300.
         *
         * For the Challenge action, the minimum setting is 300.
         */
        immunityTime: pulumi.Input<number>;
    }
    interface WebAclIpSetForwardedIpConfigurationArgs {
        /**
         * The match status to assign to the web request if the request doesn't have a valid IP address in the specified position.
         *
         * > If the specified header isn't present in the request, AWS WAF doesn't apply the rule to the web request at all.
         *
         * You can specify the following fallback behaviors:
         *
         * - `MATCH` - Treat the web request as matching the rule statement. AWS WAF applies the rule action to the request.
         * - `NO_MATCH` - Treat the web request as not matching the rule statement.
         */
        fallbackBehavior: pulumi.Input<enums.wafv2.WebAclIpSetForwardedIpConfigurationFallbackBehavior>;
        /**
         * The name of the HTTP header to use for the IP address. For example, to use the X-Forwarded-For (XFF) header, set this to `X-Forwarded-For` .
         *
         * > If the specified header isn't present in the request, AWS WAF doesn't apply the rule to the web request at all.
         */
        headerName: pulumi.Input<string>;
        /**
         * The position in the header to search for the IP address. The header can contain IP addresses of the original client and also of proxies. For example, the header value could be `10.1.1.1, 127.0.0.0, 10.10.10.10` where the first IP address identifies the original client and the rest identify proxies that the request went through.
         *
         * The options for this setting are the following:
         *
         * - FIRST - Inspect the first IP address in the list of IP addresses in the header. This is usually the client's original IP.
         * - LAST - Inspect the last IP address in the list of IP addresses in the header.
         * - ANY - Inspect all IP addresses in the header for a match. If the header contains more than 10 IP addresses, AWS WAF inspects the last 10.
         */
        position: pulumi.Input<enums.wafv2.WebAclIpSetForwardedIpConfigurationPosition>;
    }
    interface WebAclIpSetReferenceStatementArgs {
        /**
         * The Amazon Resource Name (ARN) of the `IPSet` that this statement references.
         */
        arn: pulumi.Input<string>;
        /**
         * The configuration for inspecting IP addresses in an HTTP header that you specify, instead of using the IP address that's reported by the web request origin. Commonly, this is the X-Forwarded-For (XFF) header, but you can specify any header name.
         *
         * > If the specified header isn't present in the request, AWS WAF doesn't apply the rule to the web request at all.
         */
        ipSetForwardedIpConfig?: pulumi.Input<inputs.wafv2.WebAclIpSetForwardedIpConfigurationArgs>;
    }
    /**
     * Includes the JA3 fingerprint of a web request.
     */
    interface WebAclJa3FingerprintArgs {
        /**
         * The match status to assign to the web request if the request doesn't have a JA3 fingerprint.
         *
         * You can specify the following fallback behaviors:
         *
         * - `MATCH` - Treat the web request as matching the rule statement. AWS WAF applies the rule action to the request.
         * - `NO_MATCH` - Treat the web request as not matching the rule statement.
         */
        fallbackBehavior: pulumi.Input<enums.wafv2.WebAclJa3FingerprintFallbackBehavior>;
    }
    /**
     * Includes the JA4 fingerprint of a web request.
     */
    interface WebAclJa4FingerprintArgs {
        /**
         * The match status to assign to the web request if the request doesn't have a JA4 fingerprint.
         *
         * You can specify the following fallback behaviors:
         *
         * - `MATCH` - Treat the web request as matching the rule statement. AWS WAF applies the rule action to the request.
         * - `NO_MATCH` - Treat the web request as not matching the rule statement.
         */
        fallbackBehavior: pulumi.Input<enums.wafv2.WebAclJa4FingerprintFallbackBehavior>;
    }
    /**
     * Inspect the request body as JSON. The request body immediately follows the request headers.
     */
    interface WebAclJsonBodyArgs {
        /**
         * What AWS WAF should do if it fails to completely parse the JSON body. The options are the following:
         *
         * - `EVALUATE_AS_STRING` - Inspect the body as plain text. AWS WAF applies the text transformations and inspection criteria that you defined for the JSON inspection to the body text string.
         * - `MATCH` - Treat the web request as matching the rule statement. AWS WAF applies the rule action to the request.
         * - `NO_MATCH` - Treat the web request as not matching the rule statement.
         *
         * If you don't provide this setting, AWS WAF parses and evaluates the content only up to the first parsing failure that it encounters.
         *
         * > AWS WAF parsing doesn't fully validate the input JSON string, so parsing can succeed even for invalid JSON. When parsing succeeds, AWS WAF doesn't apply the fallback behavior. For more information, see [JSON body](https://docs.aws.amazon.com/waf/latest/developerguide/waf-rule-statement-fields-list.html#waf-rule-statement-request-component-json-body) in the *AWS WAF Developer Guide* .
         */
        invalidFallbackBehavior?: pulumi.Input<enums.wafv2.WebAclBodyParsingFallbackBehavior>;
        /**
         * The patterns to look for in the JSON body. AWS WAF inspects the results of these pattern matches against the rule inspection criteria.
         */
        matchPattern: pulumi.Input<inputs.wafv2.WebAclJsonMatchPatternArgs>;
        /**
         * The parts of the JSON to match against using the `MatchPattern` . If you specify `ALL` , AWS WAF matches against keys and values.
         *
         * `All` does not require a match to be found in the keys and a match to be found in the values. It requires a match to be found in the keys or the values or both. To require a match in the keys and in the values, use a logical `AND` statement to combine two match rules, one that inspects the keys and another that inspects the values.
         */
        matchScope: pulumi.Input<enums.wafv2.WebAclJsonMatchScope>;
        /**
         * What AWS WAF should do if the body is larger than AWS WAF can inspect.
         *
         * AWS WAF does not support inspecting the entire contents of the web request body if the body exceeds the limit for the resource type. When a web request body is larger than the limit, the underlying host service only forwards the contents that are within the limit to AWS WAF for inspection.
         *
         * - For Application Load Balancer and AWS AppSync , the limit is fixed at 8 KB (8,192 bytes).
         * - For CloudFront, API Gateway, Amazon Cognito, App Runner, and Verified Access, the default limit is 16 KB (16,384 bytes), and you can increase the limit for each resource type in the web ACL `AssociationConfig` , for additional processing fees.
         * - For AWS Amplify , use the CloudFront limit.
         *
         * The options for oversize handling are the following:
         *
         * - `CONTINUE` - Inspect the available body contents normally, according to the rule inspection criteria.
         * - `MATCH` - Treat the web request as matching the rule statement. AWS WAF applies the rule action to the request.
         * - `NO_MATCH` - Treat the web request as not matching the rule statement.
         *
         * You can combine the `MATCH` or `NO_MATCH` settings for oversize handling with your rule and web ACL action settings, so that you block any request whose body is over the limit.
         *
         * Default: `CONTINUE`
         */
        oversizeHandling?: pulumi.Input<enums.wafv2.WebAclOversizeHandling>;
    }
    /**
     * The pattern to look for in the JSON body.
     */
    interface WebAclJsonMatchPatternArgs {
        /**
         * Inspect all parts of the web request's JSON body.
         */
        all?: any;
        /**
         * Match only the specified include paths. See also `MatchScope` in the `JsonBody` `FieldToMatch` specification.
         *
         * Provide the include paths using JSON Pointer syntax. For example, `"IncludedPaths": ["/dogs/0/name", "/dogs/1/name"]` . For information about this syntax, see the Internet Engineering Task Force (IETF) documentation [JavaScript Object Notation (JSON) Pointer](https://docs.aws.amazon.com/https://tools.ietf.org/html/rfc6901) .
         *
         * You must specify either this setting or the `All` setting, but not both.
         *
         * > Don't use this option to include all paths. Instead, use the `All` setting.
         */
        includedPaths?: pulumi.Input<pulumi.Input<string>[]>;
    }
    interface WebAclLabelArgs {
        /**
         * The label string.
         */
        name: pulumi.Input<string>;
    }
    interface WebAclLabelMatchStatementArgs {
        /**
         * The string to match against. The setting you provide for this depends on the match statement's `Scope` setting:
         *
         * - If the `Scope` indicates `LABEL` , then this specification must include the name and can include any number of preceding namespace specifications and prefix up to providing the fully qualified label name.
         * - If the `Scope` indicates `NAMESPACE` , then this specification can include any number of contiguous namespace strings, and can include the entire label namespace prefix from the rule group or web ACL where the label originates.
         *
         * Labels are case sensitive and components of a label must be separated by colon, for example `NS1:NS2:name` .
         */
        key: pulumi.Input<string>;
        /**
         * Specify whether you want to match using the label name or just the namespace.
         */
        scope: pulumi.Input<enums.wafv2.WebAclLabelMatchScope>;
    }
    /**
     * ManagedRuleGroupConfig.
     */
    interface WebAclManagedRuleGroupConfigArgs {
        /**
         * Additional configuration for using the account creation fraud prevention (ACFP) managed rule group, `AWSManagedRulesACFPRuleSet` . Use this to provide account creation request information to the rule group. For web ACLs that protect CloudFront distributions, use this to also provide the information about how your distribution responds to account creation requests.
         *
         * For information about using the ACFP managed rule group, see [AWS WAF Fraud Control account creation fraud prevention (ACFP) rule group](https://docs.aws.amazon.com/waf/latest/developerguide/aws-managed-rule-groups-acfp.html) and [AWS WAF Fraud Control account creation fraud prevention (ACFP)](https://docs.aws.amazon.com/waf/latest/developerguide/waf-acfp.html) in the *AWS WAF Developer Guide* .
         */
        awsManagedRulesAcfpRuleSet?: pulumi.Input<inputs.wafv2.WebAclAwsManagedRulesAcfpRuleSetArgs>;
        /**
         * Additional configuration for using the account takeover prevention (ATP) managed rule group, `AWSManagedRulesATPRuleSet` . Use this to provide login request information to the rule group. For web ACLs that protect CloudFront distributions, use this to also provide the information about how your distribution responds to login requests.
         *
         * This configuration replaces the individual configuration fields in `ManagedRuleGroupConfig` and provides additional feature configuration.
         *
         * For information about using the ATP managed rule group, see [AWS WAF Fraud Control account takeover prevention (ATP) rule group](https://docs.aws.amazon.com/waf/latest/developerguide/aws-managed-rule-groups-atp.html) and [AWS WAF Fraud Control account takeover prevention (ATP)](https://docs.aws.amazon.com/waf/latest/developerguide/waf-atp.html) in the *AWS WAF Developer Guide* .
         */
        awsManagedRulesAtpRuleSet?: pulumi.Input<inputs.wafv2.WebAclAwsManagedRulesAtpRuleSetArgs>;
        /**
         * Additional configuration for using the Bot Control managed rule group. Use this to specify the inspection level that you want to use. For information about using the Bot Control managed rule group, see [AWS WAF Bot Control rule group](https://docs.aws.amazon.com/waf/latest/developerguide/aws-managed-rule-groups-bot.html) and [AWS WAF Bot Control](https://docs.aws.amazon.com/waf/latest/developerguide/waf-bot-control.html) in the *AWS WAF Developer Guide* .
         */
        awsManagedRulesBotControlRuleSet?: pulumi.Input<inputs.wafv2.WebAclAwsManagedRulesBotControlRuleSetArgs>;
        /**
         * > Instead of this setting, provide your configuration under `AWSManagedRulesATPRuleSet` .
         */
        loginPath?: pulumi.Input<string>;
        /**
         * > Instead of this setting, provide your configuration under the request inspection configuration for `AWSManagedRulesATPRuleSet` or `AWSManagedRulesACFPRuleSet` .
         */
        passwordField?: pulumi.Input<inputs.wafv2.WebAclFieldIdentifierArgs>;
        /**
         * > Instead of this setting, provide your configuration under the request inspection configuration for `AWSManagedRulesATPRuleSet` or `AWSManagedRulesACFPRuleSet` .
         */
        payloadType?: pulumi.Input<enums.wafv2.WebAclManagedRuleGroupConfigPayloadType>;
        /**
         * > Instead of this setting, provide your configuration under the request inspection configuration for `AWSManagedRulesATPRuleSet` or `AWSManagedRulesACFPRuleSet` .
         */
        usernameField?: pulumi.Input<inputs.wafv2.WebAclFieldIdentifierArgs>;
    }
    interface WebAclManagedRuleGroupStatementArgs {
        /**
         * Rules in the referenced rule group whose actions are set to `Count` .
         *
         * > Instead of this option, use `RuleActionOverrides` . It accepts any valid action setting, including `Count` .
         */
        excludedRules?: pulumi.Input<pulumi.Input<inputs.wafv2.WebAclExcludedRuleArgs>[]>;
        /**
         * Collection of ManagedRuleGroupConfig.
         */
        managedRuleGroupConfigs?: pulumi.Input<pulumi.Input<inputs.wafv2.WebAclManagedRuleGroupConfigArgs>[]>;
        /**
         * The name of the managed rule group. You use this, along with the vendor name, to identify the rule group.
         */
        name: pulumi.Input<string>;
        /**
         * Action overrides for rules in the rule group.
         */
        ruleActionOverrides?: pulumi.Input<pulumi.Input<inputs.wafv2.WebAclRuleActionOverrideArgs>[]>;
        /**
         * An optional nested statement that narrows the scope of the web requests that are evaluated by the managed rule group. Requests are only evaluated by the rule group if they match the scope-down statement. You can use any nestable `Statement` in the scope-down statement, and you can nest statements at any level, the same as you can for a rule statement.
         */
        scopeDownStatement?: pulumi.Input<inputs.wafv2.WebAclStatementArgs>;
        /**
         * The name of the managed rule group vendor. You use this, along with the rule group name, to identify a rule group.
         */
        vendorName: pulumi.Input<string>;
        /**
         * The version of the managed rule group to use. If you specify this, the version setting is fixed until you change it. If you don't specify this, AWS WAF uses the vendor's default version, and then keeps the version at the vendor's default when the vendor updates the managed rule group settings.
         */
        version?: pulumi.Input<string>;
    }
    interface WebAclNotStatementArgs {
        /**
         * The statement to negate. You can use any statement that can be nested.
         */
        statement: pulumi.Input<inputs.wafv2.WebAclStatementArgs>;
    }
    interface WebAclOrStatementArgs {
        /**
         * The statements to combine with OR logic. You can use any statements that can be nested.
         */
        statements: pulumi.Input<pulumi.Input<inputs.wafv2.WebAclStatementArgs>[]>;
    }
    /**
     * Override a RuleGroup or ManagedRuleGroup behavior. This can only be applied to Rule that has RuleGroupReferenceStatement or ManagedRuleGroupReferenceStatement.
     */
    interface WebAclOverrideActionArgs {
        /**
         * Count traffic towards application.
         */
        count?: any;
        /**
         * Keep the RuleGroup or ManagedRuleGroup behavior as is.
         */
        none?: any;
    }
    interface WebAclRateBasedStatementArgs {
        /**
         * Setting that indicates how to aggregate the request counts.
         *
         * > Web requests that are missing any of the components specified in the aggregation keys are omitted from the rate-based rule evaluation and handling.
         *
         * - `CONSTANT` - Count and limit the requests that match the rate-based rule's scope-down statement. With this option, the counted requests aren't further aggregated. The scope-down statement is the only specification used. When the count of all requests that satisfy the scope-down statement goes over the limit, AWS WAF applies the rule action to all requests that satisfy the scope-down statement.
         *
         * With this option, you must configure the `ScopeDownStatement` property.
         * - `CUSTOM_KEYS` - Aggregate the request counts using one or more web request components as the aggregate keys.
         *
         * With this option, you must specify the aggregate keys in the `CustomKeys` property.
         *
         * To aggregate on only the IP address or only the forwarded IP address, don't use custom keys. Instead, set the aggregate key type to `IP` or `FORWARDED_IP` .
         * - `FORWARDED_IP` - Aggregate the request counts on the first IP address in an HTTP header.
         *
         * With this option, you must specify the header to use in the `ForwardedIPConfig` property.
         *
         * To aggregate on a combination of the forwarded IP address with other aggregate keys, use `CUSTOM_KEYS` .
         * - `IP` - Aggregate the request counts on the IP address from the web request origin.
         *
         * To aggregate on a combination of the IP address with other aggregate keys, use `CUSTOM_KEYS` .
         */
        aggregateKeyType: pulumi.Input<enums.wafv2.WebAclRateBasedStatementAggregateKeyType>;
        /**
         * Specifies the aggregate keys to use in a rate-base rule.
         */
        customKeys?: pulumi.Input<pulumi.Input<inputs.wafv2.WebAclRateBasedStatementCustomKeyArgs>[]>;
        /**
         * The amount of time, in seconds, that AWS WAF should include in its request counts, looking back from the current time. For example, for a setting of 120, when AWS WAF checks the rate, it counts the requests for the 2 minutes immediately preceding the current time. Valid settings are 60, 120, 300, and 600.
         *
         * This setting doesn't determine how often AWS WAF checks the rate, but how far back it looks each time it checks. AWS WAF checks the rate about every 10 seconds.
         *
         * Default: `300` (5 minutes)
         */
        evaluationWindowSec?: pulumi.Input<number>;
        /**
         * The configuration for inspecting IP addresses in an HTTP header that you specify, instead of using the IP address that's reported by the web request origin. Commonly, this is the X-Forwarded-For (XFF) header, but you can specify any header name.
         *
         * > If the specified header isn't present in the request, AWS WAF doesn't apply the rule to the web request at all.
         *
         * This is required if you specify a forwarded IP in the rule's aggregate key settings.
         */
        forwardedIpConfig?: pulumi.Input<inputs.wafv2.WebAclForwardedIpConfigurationArgs>;
        /**
         * The limit on requests during the specified evaluation window for a single aggregation instance for the rate-based rule. If the rate-based statement includes a `ScopeDownStatement` , this limit is applied only to the requests that match the statement.
         *
         * Examples:
         *
         * - If you aggregate on just the IP address, this is the limit on requests from any single IP address.
         * - If you aggregate on the HTTP method and the query argument name "city", then this is the limit on requests for any single method, city pair.
         */
        limit: pulumi.Input<number>;
        /**
         * An optional nested statement that narrows the scope of the web requests that are evaluated and managed by the rate-based statement. When you use a scope-down statement, the rate-based rule only tracks and rate limits requests that match the scope-down statement. You can use any nestable `Statement` in the scope-down statement, and you can nest statements at any level, the same as you can for a rule statement.
         */
        scopeDownStatement?: pulumi.Input<inputs.wafv2.WebAclStatementArgs>;
    }
    /**
     * Specifies a single custom aggregate key for a rate-base rule.
     */
    interface WebAclRateBasedStatementCustomKeyArgs {
        /**
         * Use the value of a cookie in the request as an aggregate key. Each distinct value in the cookie contributes to the aggregation instance. If you use a single cookie as your custom key, then each value fully defines an aggregation instance.
         */
        cookie?: pulumi.Input<inputs.wafv2.WebAclRateLimitCookieArgs>;
        /**
         * Use the first IP address in an HTTP header as an aggregate key. Each distinct forwarded IP address contributes to the aggregation instance.
         *
         * When you specify an IP or forwarded IP in the custom key settings, you must also specify at least one other key to use. You can aggregate on only the forwarded IP address by specifying `FORWARDED_IP` in your rate-based statement's `AggregateKeyType` .
         *
         * With this option, you must specify the header to use in the rate-based rule's `ForwardedIPConfig` property.
         */
        forwardedIp?: pulumi.Input<inputs.wafv2.WebAclRateLimitForwardedIpArgs>;
        /**
         * Use the value of a header in the request as an aggregate key. Each distinct value in the header contributes to the aggregation instance. If you use a single header as your custom key, then each value fully defines an aggregation instance.
         */
        header?: pulumi.Input<inputs.wafv2.WebAclRateLimitHeaderArgs>;
        /**
         * Use the request's HTTP method as an aggregate key. Each distinct HTTP method contributes to the aggregation instance. If you use just the HTTP method as your custom key, then each method fully defines an aggregation instance.
         */
        httpMethod?: pulumi.Input<inputs.wafv2.WebAclRateLimitHttpMethodArgs>;
        /**
         * Use the request's originating IP address as an aggregate key. Each distinct IP address contributes to the aggregation instance.
         *
         * When you specify an IP or forwarded IP in the custom key settings, you must also specify at least one other key to use. You can aggregate on only the IP address by specifying `IP` in your rate-based statement's `AggregateKeyType` .
         */
        ip?: pulumi.Input<inputs.wafv2.WebAclRateLimitIpArgs>;
        /**
         * Use the request's JA3 fingerprint as an aggregate key. If you use a single JA3 fingerprint as your custom key, then each value fully defines an aggregation instance.
         */
        ja3Fingerprint?: pulumi.Input<inputs.wafv2.WebAclRateLimitJa3FingerprintArgs>;
        /**
         * Use the request's JA4 fingerprint as an aggregate key. If you use a single JA4 fingerprint as your custom key, then each value fully defines an aggregation instance.
         */
        ja4Fingerprint?: pulumi.Input<inputs.wafv2.WebAclRateLimitJa4FingerprintArgs>;
        /**
         * Use the specified label namespace as an aggregate key. Each distinct fully qualified label name that has the specified label namespace contributes to the aggregation instance. If you use just one label namespace as your custom key, then each label name fully defines an aggregation instance.
         *
         * This uses only labels that have been added to the request by rules that are evaluated before this rate-based rule in the web ACL.
         *
         * For information about label namespaces and names, see [Label syntax and naming requirements](https://docs.aws.amazon.com/waf/latest/developerguide/waf-rule-label-requirements.html) in the *AWS WAF Developer Guide* .
         */
        labelNamespace?: pulumi.Input<inputs.wafv2.WebAclRateLimitLabelNamespaceArgs>;
        /**
         * Use the specified query argument as an aggregate key. Each distinct value for the named query argument contributes to the aggregation instance. If you use a single query argument as your custom key, then each value fully defines an aggregation instance.
         */
        queryArgument?: pulumi.Input<inputs.wafv2.WebAclRateLimitQueryArgumentArgs>;
        /**
         * Use the request's query string as an aggregate key. Each distinct string contributes to the aggregation instance. If you use just the query string as your custom key, then each string fully defines an aggregation instance.
         */
        queryString?: pulumi.Input<inputs.wafv2.WebAclRateLimitQueryStringArgs>;
        /**
         * Use the request's URI path as an aggregate key. Each distinct URI path contributes to the aggregation instance. If you use just the URI path as your custom key, then each URI path fully defines an aggregation instance.
         */
        uriPath?: pulumi.Input<inputs.wafv2.WebAclRateLimitUriPathArgs>;
    }
    /**
     * Specifies a cookie as an aggregate key for a rate-based rule.
     */
    interface WebAclRateLimitCookieArgs {
        /**
         * The name of the cookie to use.
         */
        name: pulumi.Input<string>;
        /**
         * Text transformations eliminate some of the unusual formatting that attackers use in web requests in an effort to bypass detection. Text transformations are used in rule match statements, to transform the `FieldToMatch` request component before inspecting it, and they're used in rate-based rule statements, to transform request components before using them as custom aggregation keys. If you specify one or more transformations to apply, AWS WAF performs all transformations on the specified content, starting from the lowest priority setting, and then uses the transformed component contents.
         */
        textTransformations: pulumi.Input<pulumi.Input<inputs.wafv2.WebAclTextTransformationArgs>[]>;
    }
    /**
     * Specifies the first IP address in an HTTP header as an aggregate key for a rate-based rule.
     */
    interface WebAclRateLimitForwardedIpArgs {
    }
    /**
     * Specifies a header as an aggregate key for a rate-based rule.
     */
    interface WebAclRateLimitHeaderArgs {
        /**
         * The name of the header to use.
         */
        name: pulumi.Input<string>;
        /**
         * Text transformations eliminate some of the unusual formatting that attackers use in web requests in an effort to bypass detection. Text transformations are used in rule match statements, to transform the `FieldToMatch` request component before inspecting it, and they're used in rate-based rule statements, to transform request components before using them as custom aggregation keys. If you specify one or more transformations to apply, AWS WAF performs all transformations on the specified content, starting from the lowest priority setting, and then uses the transformed component contents.
         */
        textTransformations: pulumi.Input<pulumi.Input<inputs.wafv2.WebAclTextTransformationArgs>[]>;
    }
    /**
     * Specifies the request's HTTP method as an aggregate key for a rate-based rule.
     */
    interface WebAclRateLimitHttpMethodArgs {
    }
    /**
     * Specifies the IP address in the web request as an aggregate key for a rate-based rule.
     */
    interface WebAclRateLimitIpArgs {
    }
    /**
     * Specifies the request's JA3 fingerprint as an aggregate key for a rate-based rule.
     */
    interface WebAclRateLimitJa3FingerprintArgs {
        /**
         * The match status to assign to the web request if there is insufficient TSL Client Hello information to compute the JA3 fingerprint.
         *
         * You can specify the following fallback behaviors:
         *
         * - `MATCH` - Treat the web request as matching the rule statement. AWS WAF applies the rule action to the request.
         * - `NO_MATCH` - Treat the web request as not matching the rule statement.
         */
        fallbackBehavior: pulumi.Input<enums.wafv2.WebAclRateLimitJa3FingerprintFallbackBehavior>;
    }
    /**
     * Specifies the request's JA4 fingerprint as an aggregate key for a rate-based rule.
     */
    interface WebAclRateLimitJa4FingerprintArgs {
        /**
         * The match status to assign to the web request if there is insufficient TSL Client Hello information to compute the JA4 fingerprint.
         *
         * You can specify the following fallback behaviors:
         *
         * - `MATCH` - Treat the web request as matching the rule statement. AWS WAF applies the rule action to the request.
         * - `NO_MATCH` - Treat the web request as not matching the rule statement.
         */
        fallbackBehavior: pulumi.Input<enums.wafv2.WebAclRateLimitJa4FingerprintFallbackBehavior>;
    }
    /**
     * Specifies a label namespace to use as an aggregate key for a rate-based rule.
     */
    interface WebAclRateLimitLabelNamespaceArgs {
        /**
         * The namespace to use for aggregation.
         */
        namespace: pulumi.Input<string>;
    }
    /**
     * Specifies a query argument in the request as an aggregate key for a rate-based rule.
     */
    interface WebAclRateLimitQueryArgumentArgs {
        /**
         * The name of the query argument to use.
         */
        name: pulumi.Input<string>;
        /**
         * Text transformations eliminate some of the unusual formatting that attackers use in web requests in an effort to bypass detection. Text transformations are used in rule match statements, to transform the `FieldToMatch` request component before inspecting it, and they're used in rate-based rule statements, to transform request components before using them as custom aggregation keys. If you specify one or more transformations to apply, AWS WAF performs all transformations on the specified content, starting from the lowest priority setting, and then uses the transformed component contents.
         */
        textTransformations: pulumi.Input<pulumi.Input<inputs.wafv2.WebAclTextTransformationArgs>[]>;
    }
    /**
     * Specifies the request's query string as an aggregate key for a rate-based rule.
     */
    interface WebAclRateLimitQueryStringArgs {
        /**
         * Text transformations eliminate some of the unusual formatting that attackers use in web requests in an effort to bypass detection. Text transformations are used in rule match statements, to transform the `FieldToMatch` request component before inspecting it, and they're used in rate-based rule statements, to transform request components before using them as custom aggregation keys. If you specify one or more transformations to apply, AWS WAF performs all transformations on the specified content, starting from the lowest priority setting, and then uses the transformed component contents.
         */
        textTransformations: pulumi.Input<pulumi.Input<inputs.wafv2.WebAclTextTransformationArgs>[]>;
    }
    /**
     * Specifies the request's URI Path as an aggregate key for a rate-based rule.
     */
    interface WebAclRateLimitUriPathArgs {
        /**
         * Text transformations eliminate some of the unusual formatting that attackers use in web requests in an effort to bypass detection. Text transformations are used in rule match statements, to transform the `FieldToMatch` request component before inspecting it, and they're used in rate-based rule statements, to transform request components before using them as custom aggregation keys. If you specify one or more transformations to apply, AWS WAF performs all transformations on the specified content, starting from the lowest priority setting, and then uses the transformed component contents.
         */
        textTransformations: pulumi.Input<pulumi.Input<inputs.wafv2.WebAclTextTransformationArgs>[]>;
    }
    interface WebAclRegexMatchStatementArgs {
        /**
         * The part of the web request that you want AWS WAF to inspect.
         */
        fieldToMatch: pulumi.Input<inputs.wafv2.WebAclFieldToMatchArgs>;
        /**
         * The string representing the regular expression.
         */
        regexString: pulumi.Input<string>;
        /**
         * Text transformations eliminate some of the unusual formatting that attackers use in web requests in an effort to bypass detection. If you specify one or more transformations in a rule statement, AWS WAF performs all transformations on the content of the request component identified by `FieldToMatch` , starting from the lowest priority setting, before inspecting the content for a match.
         */
        textTransformations: pulumi.Input<pulumi.Input<inputs.wafv2.WebAclTextTransformationArgs>[]>;
    }
    interface WebAclRegexPatternSetReferenceStatementArgs {
        /**
         * The Amazon Resource Name (ARN) of the `RegexPatternSet` that this statement references.
         */
        arn: pulumi.Input<string>;
        /**
         * The part of the web request that you want AWS WAF to inspect.
         */
        fieldToMatch: pulumi.Input<inputs.wafv2.WebAclFieldToMatchArgs>;
        /**
         * Text transformations eliminate some of the unusual formatting that attackers use in web requests in an effort to bypass detection. If you specify one or more transformations in a rule statement, AWS WAF performs all transformations on the content of the request component identified by `FieldToMatch` , starting from the lowest priority setting, before inspecting the content for a match.
         */
        textTransformations: pulumi.Input<pulumi.Input<inputs.wafv2.WebAclTextTransformationArgs>[]>;
    }
    /**
     * Configures the inspection size in the request body.
     */
    interface WebAclRequestBodyAssociatedResourceTypeConfigArgs {
        /**
         * Specifies the maximum size of the web request body component that an associated CloudFront, API Gateway, Amazon Cognito, App Runner, or Verified Access resource should send to AWS WAF for inspection. This applies to statements in the web ACL that inspect the body or JSON body.
         *
         * Default: `16 KB (16,384 bytes)`
         */
        defaultSizeInspectionLimit: pulumi.Input<enums.wafv2.WebAclSizeInspectionLimit>;
    }
    /**
     * Configures the inspection of login requests
     */
    interface WebAclRequestInspectionArgs {
        /**
         * The name of the field in the request payload that contains your customer's password.
         *
         * How you specify this depends on the request inspection payload type.
         *
         * - For JSON payloads, specify the field name in JSON pointer syntax. For information about the JSON Pointer syntax, see the Internet Engineering Task Force (IETF) documentation [JavaScript Object Notation (JSON) Pointer](https://docs.aws.amazon.com/https://tools.ietf.org/html/rfc6901) .
         *
         * For example, for the JSON payload `{ "form": { "password": "THE_PASSWORD" } }` , the password field specification is `/form/password` .
         * - For form encoded payload types, use the HTML form names.
         *
         * For example, for an HTML form with the input element named `password1` , the password field specification is `password1` .
         */
        passwordField: pulumi.Input<inputs.wafv2.WebAclFieldIdentifierArgs>;
        /**
         * The payload type for your login endpoint, either JSON or form encoded.
         */
        payloadType: pulumi.Input<enums.wafv2.WebAclRequestInspectionPayloadType>;
        /**
         * The name of the field in the request payload that contains your customer's username.
         *
         * How you specify this depends on the request inspection payload type.
         *
         * - For JSON payloads, specify the field name in JSON pointer syntax. For information about the JSON Pointer syntax, see the Internet Engineering Task Force (IETF) documentation [JavaScript Object Notation (JSON) Pointer](https://docs.aws.amazon.com/https://tools.ietf.org/html/rfc6901) .
         *
         * For example, for the JSON payload `{ "form": { "username": "THE_USERNAME" } }` , the username field specification is `/form/username` .
         * - For form encoded payload types, use the HTML form names.
         *
         * For example, for an HTML form with the input element named `username1` , the username field specification is `username1`
         */
        usernameField: pulumi.Input<inputs.wafv2.WebAclFieldIdentifierArgs>;
    }
    /**
     * Configures the inspection of sign-up requests
     */
    interface WebAclRequestInspectionAcfpArgs {
        /**
         * The names of the fields in the request payload that contain your customer's primary physical address.
         *
         * Order the address fields in the array exactly as they are ordered in the request payload.
         *
         * How you specify the address fields depends on the request inspection payload type.
         *
         * - For JSON payloads, specify the field identifiers in JSON pointer syntax. For information about the JSON Pointer syntax, see the Internet Engineering Task Force (IETF) documentation [JavaScript Object Notation (JSON) Pointer](https://docs.aws.amazon.com/https://tools.ietf.org/html/rfc6901) .
         *
         * For example, for the JSON payload `{ "form": { "primaryaddressline1": "THE_ADDRESS1", "primaryaddressline2": "THE_ADDRESS2", "primaryaddressline3": "THE_ADDRESS3" } }` , the address field idenfiers are `/form/primaryaddressline1` , `/form/primaryaddressline2` , and `/form/primaryaddressline3` .
         * - For form encoded payload types, use the HTML form names.
         *
         * For example, for an HTML form with input elements named `primaryaddressline1` , `primaryaddressline2` , and `primaryaddressline3` , the address fields identifiers are `primaryaddressline1` , `primaryaddressline2` , and `primaryaddressline3` .
         */
        addressFields?: pulumi.Input<pulumi.Input<inputs.wafv2.WebAclFieldIdentifierArgs>[]>;
        /**
         * The name of the field in the request payload that contains your customer's email.
         *
         * How you specify this depends on the request inspection payload type.
         *
         * - For JSON payloads, specify the field name in JSON pointer syntax. For information about the JSON Pointer syntax, see the Internet Engineering Task Force (IETF) documentation [JavaScript Object Notation (JSON) Pointer](https://docs.aws.amazon.com/https://tools.ietf.org/html/rfc6901) .
         *
         * For example, for the JSON payload `{ "form": { "email": "THE_EMAIL" } }` , the email field specification is `/form/email` .
         * - For form encoded payload types, use the HTML form names.
         *
         * For example, for an HTML form with the input element named `email1` , the email field specification is `email1` .
         */
        emailField?: pulumi.Input<inputs.wafv2.WebAclFieldIdentifierArgs>;
        /**
         * The name of the field in the request payload that contains your customer's password.
         *
         * How you specify this depends on the request inspection payload type.
         *
         * - For JSON payloads, specify the field name in JSON pointer syntax. For information about the JSON Pointer syntax, see the Internet Engineering Task Force (IETF) documentation [JavaScript Object Notation (JSON) Pointer](https://docs.aws.amazon.com/https://tools.ietf.org/html/rfc6901) .
         *
         * For example, for the JSON payload `{ "form": { "password": "THE_PASSWORD" } }` , the password field specification is `/form/password` .
         * - For form encoded payload types, use the HTML form names.
         *
         * For example, for an HTML form with the input element named `password1` , the password field specification is `password1` .
         */
        passwordField?: pulumi.Input<inputs.wafv2.WebAclFieldIdentifierArgs>;
        /**
         * The payload type for your account creation endpoint, either JSON or form encoded.
         */
        payloadType: pulumi.Input<enums.wafv2.WebAclRequestInspectionAcfpPayloadType>;
        /**
         * The names of the fields in the request payload that contain your customer's primary phone number.
         *
         * Order the phone number fields in the array exactly as they are ordered in the request payload.
         *
         * How you specify the phone number fields depends on the request inspection payload type.
         *
         * - For JSON payloads, specify the field identifiers in JSON pointer syntax. For information about the JSON Pointer syntax, see the Internet Engineering Task Force (IETF) documentation [JavaScript Object Notation (JSON) Pointer](https://docs.aws.amazon.com/https://tools.ietf.org/html/rfc6901) .
         *
         * For example, for the JSON payload `{ "form": { "primaryphoneline1": "THE_PHONE1", "primaryphoneline2": "THE_PHONE2", "primaryphoneline3": "THE_PHONE3" } }` , the phone number field identifiers are `/form/primaryphoneline1` , `/form/primaryphoneline2` , and `/form/primaryphoneline3` .
         * - For form encoded payload types, use the HTML form names.
         *
         * For example, for an HTML form with input elements named `primaryphoneline1` , `primaryphoneline2` , and `primaryphoneline3` , the phone number field identifiers are `primaryphoneline1` , `primaryphoneline2` , and `primaryphoneline3` .
         */
        phoneNumberFields?: pulumi.Input<pulumi.Input<inputs.wafv2.WebAclFieldIdentifierArgs>[]>;
        /**
         * The name of the field in the request payload that contains your customer's username.
         *
         * How you specify this depends on the request inspection payload type.
         *
         * - For JSON payloads, specify the field name in JSON pointer syntax. For information about the JSON Pointer syntax, see the Internet Engineering Task Force (IETF) documentation [JavaScript Object Notation (JSON) Pointer](https://docs.aws.amazon.com/https://tools.ietf.org/html/rfc6901) .
         *
         * For example, for the JSON payload `{ "form": { "username": "THE_USERNAME" } }` , the username field specification is `/form/username` .
         * - For form encoded payload types, use the HTML form names.
         *
         * For example, for an HTML form with the input element named `username1` , the username field specification is `username1`
         */
        usernameField?: pulumi.Input<inputs.wafv2.WebAclFieldIdentifierArgs>;
    }
    /**
     * Configures the inspection of login responses
     */
    interface WebAclResponseInspectionArgs {
        /**
         * Configures inspection of the response body for success and failure indicators. AWS WAF can inspect the first 65,536 bytes (64 KB) of the response body.
         */
        bodyContains?: pulumi.Input<inputs.wafv2.WebAclResponseInspectionBodyContainsArgs>;
        /**
         * Configures inspection of the response header for success and failure indicators.
         */
        header?: pulumi.Input<inputs.wafv2.WebAclResponseInspectionHeaderArgs>;
        /**
         * Configures inspection of the response JSON for success and failure indicators. AWS WAF can inspect the first 65,536 bytes (64 KB) of the response JSON.
         */
        json?: pulumi.Input<inputs.wafv2.WebAclResponseInspectionJsonArgs>;
        /**
         * Configures inspection of the response status code for success and failure indicators.
         */
        statusCode?: pulumi.Input<inputs.wafv2.WebAclResponseInspectionStatusCodeArgs>;
    }
    /**
     * Response body contents that indicate success or failure of a login request
     */
    interface WebAclResponseInspectionBodyContainsArgs {
        /**
         * Strings in the body of the response that indicate a failed login or account creation attempt. To be counted as a failure, the string can be anywhere in the body and must be an exact match, including case. Each string must be unique among the success and failure strings.
         *
         * JSON example: `"FailureStrings": [ "Request failed" ]`
         */
        failureStrings: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * Strings in the body of the response that indicate a successful login or account creation attempt. To be counted as a success, the string can be anywhere in the body and must be an exact match, including case. Each string must be unique among the success and failure strings.
         *
         * JSON examples: `"SuccessStrings": [ "Login successful" ]` and `"SuccessStrings": [ "Account creation successful", "Welcome to our site!" ]`
         */
        successStrings: pulumi.Input<pulumi.Input<string>[]>;
    }
    /**
     * Response headers that indicate success or failure of a login request
     */
    interface WebAclResponseInspectionHeaderArgs {
        /**
         * Values in the response header with the specified name that indicate a failed login or account creation attempt. To be counted as a failure, the value must be an exact match, including case. Each value must be unique among the success and failure values.
         *
         * JSON examples: `"FailureValues": [ "LoginFailed", "Failed login" ]` and `"FailureValues": [ "AccountCreationFailed" ]`
         */
        failureValues: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * The name of the header to match against. The name must be an exact match, including case.
         *
         * JSON example: `"Name": [ "RequestResult" ]`
         */
        name: pulumi.Input<string>;
        /**
         * Values in the response header with the specified name that indicate a successful login or account creation attempt. To be counted as a success, the value must be an exact match, including case. Each value must be unique among the success and failure values.
         *
         * JSON examples: `"SuccessValues": [ "LoginPassed", "Successful login" ]` and `"SuccessValues": [ "AccountCreated", "Successful account creation" ]`
         */
        successValues: pulumi.Input<pulumi.Input<string>[]>;
    }
    /**
     * Response JSON that indicate success or failure of a login request
     */
    interface WebAclResponseInspectionJsonArgs {
        /**
         * Values for the specified identifier in the response JSON that indicate a failed login or account creation attempt. To be counted as a failure, the value must be an exact match, including case. Each value must be unique among the success and failure values.
         *
         * JSON example: `"FailureValues": [ "False", "Failed" ]`
         */
        failureValues: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * The identifier for the value to match against in the JSON. The identifier must be an exact match, including case.
         *
         * JSON examples: `"Identifier": [ "/login/success" ]` and `"Identifier": [ "/sign-up/success" ]`
         */
        identifier: pulumi.Input<string>;
        /**
         * Values for the specified identifier in the response JSON that indicate a successful login or account creation attempt. To be counted as a success, the value must be an exact match, including case. Each value must be unique among the success and failure values.
         *
         * JSON example: `"SuccessValues": [ "True", "Succeeded" ]`
         */
        successValues: pulumi.Input<pulumi.Input<string>[]>;
    }
    /**
     * Response status codes that indicate success or failure of a login request
     */
    interface WebAclResponseInspectionStatusCodeArgs {
        /**
         * Status codes in the response that indicate a failed login or account creation attempt. To be counted as a failure, the response status code must match one of these. Each code must be unique among the success and failure status codes.
         *
         * JSON example: `"FailureCodes": [ 400, 404 ]`
         */
        failureCodes: pulumi.Input<pulumi.Input<number>[]>;
        /**
         * Status codes in the response that indicate a successful login or account creation attempt. To be counted as a success, the response status code must match one of these. Each code must be unique among the success and failure status codes.
         *
         * JSON example: `"SuccessCodes": [ 200, 201 ]`
         */
        successCodes: pulumi.Input<pulumi.Input<number>[]>;
    }
    /**
     * Rule of WebACL that contains condition and action.
     */
    interface WebAclRuleArgs {
        /**
         * The action that AWS WAF should take on a web request when it matches the rule's statement. Settings at the web ACL level can override the rule action setting.
         *
         * This is used only for rules whose statements don't reference a rule group. Rule statements that reference a rule group are `RuleGroupReferenceStatement` and `ManagedRuleGroupStatement` .
         *
         * You must set either this `Action` setting or the rule's `OverrideAction` , but not both:
         *
         * - If the rule statement doesn't reference a rule group, you must set this rule action setting and you must not set the rule's override action setting.
         * - If the rule statement references a rule group, you must not set this action setting, because the actions are already set on the rules inside the rule group. You must set the rule's override action setting to indicate specifically whether to override the actions that are set on the rules in the rule group.
         */
        action?: pulumi.Input<inputs.wafv2.WebAclRuleActionArgs>;
        /**
         * Specifies how AWS WAF should handle `CAPTCHA` evaluations. If you don't specify this, AWS WAF uses the `CAPTCHA` configuration that's defined for the web ACL.
         */
        captchaConfig?: pulumi.Input<inputs.wafv2.WebAclCaptchaConfigArgs>;
        /**
         * Specifies how AWS WAF should handle `Challenge` evaluations. If you don't specify this, AWS WAF uses the challenge configuration that's defined for the web ACL.
         */
        challengeConfig?: pulumi.Input<inputs.wafv2.WebAclChallengeConfigArgs>;
        /**
         * The name of the rule.
         *
         * If you change the name of a `Rule` after you create it and you want the rule's metric name to reflect the change, update the metric name in the rule's `VisibilityConfig` settings. AWS WAF doesn't automatically update the metric name when you update the rule name.
         */
        name: pulumi.Input<string>;
        /**
         * The override action to apply to the rules in a rule group, instead of the individual rule action settings. This is used only for rules whose statements reference a rule group. Rule statements that reference a rule group are `RuleGroupReferenceStatement` and `ManagedRuleGroupStatement` .
         *
         * Set the override action to none to leave the rule group rule actions in effect. Set it to count to only count matches, regardless of the rule action settings.
         *
         * You must set either this `OverrideAction` setting or the `Action` setting, but not both:
         *
         * - If the rule statement references a rule group, you must set this override action setting and you must not set the rule's action setting.
         * - If the rule statement doesn't reference a rule group, you must set the rule action setting and you must not set the rule's override action setting.
         */
        overrideAction?: pulumi.Input<inputs.wafv2.WebAclOverrideActionArgs>;
        /**
         * If you define more than one `Rule` in a `WebACL` , AWS WAF evaluates each request against the `Rules` in order based on the value of `Priority` . AWS WAF processes rules with lower priority first. The priorities don't need to be consecutive, but they must all be different.
         */
        priority: pulumi.Input<number>;
        /**
         * Collection of Rule Labels.
         */
        ruleLabels?: pulumi.Input<pulumi.Input<inputs.wafv2.WebAclLabelArgs>[]>;
        /**
         * The AWS WAF processing statement for the rule, for example `ByteMatchStatement` or `SizeConstraintStatement` .
         */
        statement: pulumi.Input<inputs.wafv2.WebAclStatementArgs>;
        /**
         * Defines and enables Amazon CloudWatch metrics and web request sample collection.
         *
         * If you change the name of a `Rule` after you create it and you want the rule's metric name to reflect the change, update the metric name as well. AWS WAF doesn't automatically update the metric name.
         */
        visibilityConfig: pulumi.Input<inputs.wafv2.WebAclVisibilityConfigArgs>;
    }
    /**
     * Action taken when Rule matches its condition.
     */
    interface WebAclRuleActionArgs {
        /**
         * Instructs AWS WAF to allow the web request.
         */
        allow?: pulumi.Input<inputs.wafv2.WebAclAllowActionArgs>;
        /**
         * Instructs AWS WAF to block the web request.
         */
        block?: pulumi.Input<inputs.wafv2.WebAclBlockActionArgs>;
        /**
         * Specifies that AWS WAF should run a `CAPTCHA` check against the request:
         *
         * - If the request includes a valid, unexpired `CAPTCHA` token, AWS WAF allows the web request inspection to proceed to the next rule, similar to a `CountAction` .
         * - If the request doesn't include a valid, unexpired `CAPTCHA` token, AWS WAF discontinues the web ACL evaluation of the request and blocks it from going to its intended destination.
         *
         * AWS WAF generates a response that it sends back to the client, which includes the following:
         *
         * - The header `x-amzn-waf-action` with a value of `captcha` .
         * - The HTTP status code `405 Method Not Allowed` .
         * - If the request contains an `Accept` header with a value of `text/html` , the response includes a `CAPTCHA` challenge.
         *
         * You can configure the expiration time in the `CaptchaConfig` `ImmunityTimeProperty` setting at the rule and web ACL level. The rule setting overrides the web ACL setting.
         *
         * This action option is available for rules. It isn't available for web ACL default actions.
         */
        captcha?: pulumi.Input<inputs.wafv2.WebAclCaptchaActionArgs>;
        /**
         * Instructs AWS WAF to run a `Challenge` check against the web request.
         */
        challenge?: pulumi.Input<inputs.wafv2.WebAclChallengeActionArgs>;
        /**
         * Instructs AWS WAF to count the web request and then continue evaluating the request using the remaining rules in the web ACL.
         */
        count?: pulumi.Input<inputs.wafv2.WebAclCountActionArgs>;
    }
    /**
     * Action override for rules in the rule group.
     */
    interface WebAclRuleActionOverrideArgs {
        /**
         * The override action to use, in place of the configured action of the rule in the rule group.
         */
        actionToUse: pulumi.Input<inputs.wafv2.WebAclRuleActionArgs>;
        /**
         * The name of the rule to override.
         */
        name: pulumi.Input<string>;
    }
    interface WebAclRuleGroupReferenceStatementArgs {
        /**
         * The Amazon Resource Name (ARN) of the entity.
         */
        arn: pulumi.Input<string>;
        /**
         * Rules in the referenced rule group whose actions are set to `Count` .
         *
         * > Instead of this option, use `RuleActionOverrides` . It accepts any valid action setting, including `Count` .
         */
        excludedRules?: pulumi.Input<pulumi.Input<inputs.wafv2.WebAclExcludedRuleArgs>[]>;
        /**
         * Action overrides for rules in the rule group.
         */
        ruleActionOverrides?: pulumi.Input<pulumi.Input<inputs.wafv2.WebAclRuleActionOverrideArgs>[]>;
    }
    /**
     * Size Constraint statement.
     */
    interface WebAclSizeConstraintStatementArgs {
        /**
         * The operator to use to compare the request part to the size setting.
         */
        comparisonOperator: pulumi.Input<enums.wafv2.WebAclSizeConstraintStatementComparisonOperator>;
        /**
         * The part of the web request that you want AWS WAF to inspect.
         */
        fieldToMatch: pulumi.Input<inputs.wafv2.WebAclFieldToMatchArgs>;
        /**
         * The size, in byte, to compare to the request part, after any transformations.
         */
        size: pulumi.Input<number>;
        /**
         * Text transformations eliminate some of the unusual formatting that attackers use in web requests in an effort to bypass detection. If you specify one or more transformations in a rule statement, AWS WAF performs all transformations on the content of the request component identified by `FieldToMatch` , starting from the lowest priority setting, before inspecting the content for a match.
         */
        textTransformations: pulumi.Input<pulumi.Input<inputs.wafv2.WebAclTextTransformationArgs>[]>;
    }
    /**
     * Sqli Match Statement.
     */
    interface WebAclSqliMatchStatementArgs {
        /**
         * The part of the web request that you want AWS WAF to inspect.
         */
        fieldToMatch: pulumi.Input<inputs.wafv2.WebAclFieldToMatchArgs>;
        /**
         * The sensitivity that you want AWS WAF to use to inspect for SQL injection attacks.
         *
         * `HIGH` detects more attacks, but might generate more false positives, especially if your web requests frequently contain unusual strings. For information about identifying and mitigating false positives, see [Testing and tuning](https://docs.aws.amazon.com/waf/latest/developerguide/web-acl-testing.html) in the *AWS WAF Developer Guide* .
         *
         * `LOW` is generally a better choice for resources that already have other protections against SQL injection attacks or that have a low tolerance for false positives.
         *
         * Default: `LOW`
         */
        sensitivityLevel?: pulumi.Input<enums.wafv2.WebAclSensitivityLevel>;
        /**
         * Text transformations eliminate some of the unusual formatting that attackers use in web requests in an effort to bypass detection. If you specify one or more transformations in a rule statement, AWS WAF performs all transformations on the content of the request component identified by `FieldToMatch` , starting from the lowest priority setting, before inspecting the content for a match.
         */
        textTransformations: pulumi.Input<pulumi.Input<inputs.wafv2.WebAclTextTransformationArgs>[]>;
    }
    /**
     * First level statement that contains conditions, such as ByteMatch, SizeConstraint, etc
     */
    interface WebAclStatementArgs {
        /**
         * A logical rule statement used to combine other rule statements with AND logic. You provide more than one `Statement` within the `AndStatement` .
         */
        andStatement?: pulumi.Input<inputs.wafv2.WebAclAndStatementArgs>;
        /**
         * A rule statement that defines a string match search for AWS WAF to apply to web requests. The byte match statement provides the bytes to search for, the location in requests that you want AWS WAF to search, and other settings. The bytes to search for are typically a string that corresponds with ASCII characters. In the AWS WAF console and the developer guide, this is called a string match statement.
         */
        byteMatchStatement?: pulumi.Input<inputs.wafv2.WebAclByteMatchStatementArgs>;
        /**
         * A rule statement that labels web requests by country and region and that matches against web requests based on country code. A geo match rule labels every request that it inspects regardless of whether it finds a match.
         *
         * - To manage requests only by country, you can use this statement by itself and specify the countries that you want to match against in the `CountryCodes` array.
         * - Otherwise, configure your geo match rule with Count action so that it only labels requests. Then, add one or more label match rules to run after the geo match rule and configure them to match against the geographic labels and handle the requests as needed.
         *
         * AWS WAF labels requests using the alpha-2 country and region codes from the International Organization for Standardization (ISO) 3166 standard. AWS WAF determines the codes using either the IP address in the web request origin or, if you specify it, the address in the geo match `ForwardedIPConfig` .
         *
         * If you use the web request origin, the label formats are `awswaf:clientip:geo:region:<ISO country code>-<ISO region code>` and `awswaf:clientip:geo:country:<ISO country code>` .
         *
         * If you use a forwarded IP address, the label formats are `awswaf:forwardedip:geo:region:<ISO country code>-<ISO region code>` and `awswaf:forwardedip:geo:country:<ISO country code>` .
         *
         * For additional details, see [Geographic match rule statement](https://docs.aws.amazon.com/waf/latest/developerguide/waf-rule-statement-type-geo-match.html) in the [AWS WAF Developer Guide](https://docs.aws.amazon.com/waf/latest/developerguide/waf-chapter.html) .
         */
        geoMatchStatement?: pulumi.Input<inputs.wafv2.WebAclGeoMatchStatementArgs>;
        /**
         * A rule statement used to detect web requests coming from particular IP addresses or address ranges. To use this, create an `IPSet` that specifies the addresses you want to detect, then use the ARN of that set in this statement.
         *
         * Each IP set rule statement references an IP set. You create and maintain the set independent of your rules. This allows you to use the single set in multiple rules. When you update the referenced set, AWS WAF automatically updates all rules that reference it.
         */
        ipSetReferenceStatement?: pulumi.Input<inputs.wafv2.WebAclIpSetReferenceStatementArgs>;
        /**
         * A rule statement to match against labels that have been added to the web request by rules that have already run in the web ACL.
         *
         * The label match statement provides the label or namespace string to search for. The label string can represent a part or all of the fully qualified label name that had been added to the web request. Fully qualified labels have a prefix, optional namespaces, and label name. The prefix identifies the rule group or web ACL context of the rule that added the label. If you do not provide the fully qualified name in your label match string, AWS WAF performs the search for labels that were added in the same context as the label match statement.
         */
        labelMatchStatement?: pulumi.Input<inputs.wafv2.WebAclLabelMatchStatementArgs>;
        /**
         * A rule statement used to run the rules that are defined in a managed rule group. To use this, provide the vendor name and the name of the rule group in this statement. You can retrieve the required names through the API call `ListAvailableManagedRuleGroups` .
         *
         * You cannot nest a `ManagedRuleGroupStatement` , for example for use inside a `NotStatement` or `OrStatement` . It can only be referenced as a top-level statement within a rule.
         *
         * > You are charged additional fees when you use the AWS WAF Bot Control managed rule group `AWSManagedRulesBotControlRuleSet` , the AWS WAF Fraud Control account takeover prevention (ATP) managed rule group `AWSManagedRulesATPRuleSet` , or the AWS WAF Fraud Control account creation fraud prevention (ACFP) managed rule group `AWSManagedRulesACFPRuleSet` . For more information, see [AWS WAF Pricing](https://docs.aws.amazon.com/waf/pricing/) .
         */
        managedRuleGroupStatement?: pulumi.Input<inputs.wafv2.WebAclManagedRuleGroupStatementArgs>;
        /**
         * A logical rule statement used to negate the results of another rule statement. You provide one `Statement` within the `NotStatement` .
         */
        notStatement?: pulumi.Input<inputs.wafv2.WebAclNotStatementArgs>;
        /**
         * A logical rule statement used to combine other rule statements with OR logic. You provide more than one `Statement` within the `OrStatement` .
         */
        orStatement?: pulumi.Input<inputs.wafv2.WebAclOrStatementArgs>;
        /**
         * A rate-based rule counts incoming requests and rate limits requests when they are coming at too fast a rate. The rule categorizes requests according to your aggregation criteria, collects them into aggregation instances, and counts and rate limits the requests for each instance.
         *
         * > If you change any of these settings in a rule that's currently in use, the change resets the rule's rate limiting counts. This can pause the rule's rate limiting activities for up to a minute.
         *
         * You can specify individual aggregation keys, like IP address or HTTP method. You can also specify aggregation key combinations, like IP address and HTTP method, or HTTP method, query argument, and cookie.
         *
         * Each unique set of values for the aggregation keys that you specify is a separate aggregation instance, with the value from each key contributing to the aggregation instance definition.
         *
         * For example, assume the rule evaluates web requests with the following IP address and HTTP method values:
         *
         * - IP address 10.1.1.1, HTTP method POST
         * - IP address 10.1.1.1, HTTP method GET
         * - IP address 127.0.0.0, HTTP method POST
         * - IP address 10.1.1.1, HTTP method GET
         *
         * The rule would create different aggregation instances according to your aggregation criteria, for example:
         *
         * - If the aggregation criteria is just the IP address, then each individual address is an aggregation instance, and AWS WAF counts requests separately for each. The aggregation instances and request counts for our example would be the following:
         *
         * - IP address 10.1.1.1: count 3
         * - IP address 127.0.0.0: count 1
         * - If the aggregation criteria is HTTP method, then each individual HTTP method is an aggregation instance. The aggregation instances and request counts for our example would be the following:
         *
         * - HTTP method POST: count 2
         * - HTTP method GET: count 2
         * - If the aggregation criteria is IP address and HTTP method, then each IP address and each HTTP method would contribute to the combined aggregation instance. The aggregation instances and request counts for our example would be the following:
         *
         * - IP address 10.1.1.1, HTTP method POST: count 1
         * - IP address 10.1.1.1, HTTP method GET: count 2
         * - IP address 127.0.0.0, HTTP method POST: count 1
         *
         * For any n-tuple of aggregation keys, each unique combination of values for the keys defines a separate aggregation instance, which AWS WAF counts and rate-limits individually.
         *
         * You can optionally nest another statement inside the rate-based statement, to narrow the scope of the rule so that it only counts and rate limits requests that match the nested statement. You can use this nested scope-down statement in conjunction with your aggregation key specifications or you can just count and rate limit all requests that match the scope-down statement, without additional aggregation. When you choose to just manage all requests that match a scope-down statement, the aggregation instance is singular for the rule.
         *
         * You cannot nest a `RateBasedStatement` inside another statement, for example inside a `NotStatement` or `OrStatement` . You can define a `RateBasedStatement` inside a web ACL and inside a rule group.
         *
         * For additional information about the options, see [Rate limiting web requests using rate-based rules](https://docs.aws.amazon.com/waf/latest/developerguide/waf-rate-based-rules.html) in the *AWS WAF Developer Guide* .
         *
         * If you only aggregate on the individual IP address or forwarded IP address, you can retrieve the list of IP addresses that AWS WAF is currently rate limiting for a rule through the API call `GetRateBasedStatementManagedKeys` . This option is not available for other aggregation configurations.
         *
         * AWS WAF tracks and manages web requests separately for each instance of a rate-based rule that you use. For example, if you provide the same rate-based rule settings in two web ACLs, each of the two rule statements represents a separate instance of the rate-based rule and gets its own tracking and management by AWS WAF . If you define a rate-based rule inside a rule group, and then use that rule group in multiple places, each use creates a separate instance of the rate-based rule that gets its own tracking and management by AWS WAF .
         */
        rateBasedStatement?: pulumi.Input<inputs.wafv2.WebAclRateBasedStatementArgs>;
        /**
         * A rule statement used to search web request components for a match against a single regular expression.
         */
        regexMatchStatement?: pulumi.Input<inputs.wafv2.WebAclRegexMatchStatementArgs>;
        /**
         * A rule statement used to search web request components for matches with regular expressions. To use this, create a `RegexPatternSet` that specifies the expressions that you want to detect, then use the ARN of that set in this statement. A web request matches the pattern set rule statement if the request component matches any of the patterns in the set.
         *
         * Each regex pattern set rule statement references a regex pattern set. You create and maintain the set independent of your rules. This allows you to use the single set in multiple rules. When you update the referenced set, AWS WAF automatically updates all rules that reference it.
         */
        regexPatternSetReferenceStatement?: pulumi.Input<inputs.wafv2.WebAclRegexPatternSetReferenceStatementArgs>;
        /**
         * A rule statement used to run the rules that are defined in a `RuleGroup` . To use this, create a rule group with your rules, then provide the ARN of the rule group in this statement.
         *
         * You cannot nest a `RuleGroupReferenceStatement` , for example for use inside a `NotStatement` or `OrStatement` . You cannot use a rule group reference statement inside another rule group. You can only reference a rule group as a top-level statement within a rule that you define in a web ACL.
         */
        ruleGroupReferenceStatement?: pulumi.Input<inputs.wafv2.WebAclRuleGroupReferenceStatementArgs>;
        /**
         * A rule statement that compares a number of bytes against the size of a request component, using a comparison operator, such as greater than (>) or less than (<). For example, you can use a size constraint statement to look for query strings that are longer than 100 bytes.
         *
         * If you configure AWS WAF to inspect the request body, AWS WAF inspects only the number of bytes in the body up to the limit for the web ACL and protected resource type. If you know that the request body for your web requests should never exceed the inspection limit, you can use a size constraint statement to block requests that have a larger request body size. For more information about the inspection limits, see `Body` and `JsonBody` settings for the `FieldToMatch` data type.
         *
         * If you choose URI for the value of Part of the request to filter on, the slash (/) in the URI counts as one character. For example, the URI `/logo.jpg` is nine characters long.
         */
        sizeConstraintStatement?: pulumi.Input<inputs.wafv2.WebAclSizeConstraintStatementArgs>;
        /**
         * A rule statement that inspects for malicious SQL code. Attackers insert malicious SQL code into web requests to do things like modify your database or extract data from it.
         */
        sqliMatchStatement?: pulumi.Input<inputs.wafv2.WebAclSqliMatchStatementArgs>;
        /**
         * A rule statement that inspects for cross-site scripting (XSS) attacks. In XSS attacks, the attacker uses vulnerabilities in a benign website as a vehicle to inject malicious client-site scripts into other legitimate web browsers.
         */
        xssMatchStatement?: pulumi.Input<inputs.wafv2.WebAclXssMatchStatementArgs>;
    }
    /**
     * Text Transformation on the Search String before match.
     */
    interface WebAclTextTransformationArgs {
        /**
         * Sets the relative processing order for multiple transformations. AWS WAF processes all transformations, from lowest priority to highest, before inspecting the transformed content. The priorities don't need to be consecutive, but they must all be different.
         */
        priority: pulumi.Input<number>;
        /**
         * For detailed descriptions of each of the transformation types, see [Text transformations](https://docs.aws.amazon.com/waf/latest/developerguide/waf-rule-statement-transformation.html) in the *AWS WAF Developer Guide* .
         */
        type: pulumi.Input<enums.wafv2.WebAclTextTransformationType>;
    }
    /**
     * The path component of the URI Fragment. This is the part of a web request that identifies a fragment uri, for example, /abcd#introduction
     */
    interface WebAclUriFragmentArgs {
        /**
         * What AWS WAF should do if it fails to completely parse the JSON body. The options are the following:
         *
         * - `EVALUATE_AS_STRING` - Inspect the body as plain text. AWS WAF applies the text transformations and inspection criteria that you defined for the JSON inspection to the body text string.
         * - `MATCH` - Treat the web request as matching the rule statement. AWS WAF applies the rule action to the request.
         * - `NO_MATCH` - Treat the web request as not matching the rule statement.
         *
         * If you don't provide this setting, AWS WAF parses and evaluates the content only up to the first parsing failure that it encounters.
         *
         * Example JSON: `{ "UriFragment": { "FallbackBehavior": "MATCH"} }`
         *
         * > AWS WAF parsing doesn't fully validate the input JSON string, so parsing can succeed even for invalid JSON. When parsing succeeds, AWS WAF doesn't apply the fallback behavior. For more information, see [JSON body](https://docs.aws.amazon.com/waf/latest/developerguide/waf-rule-statement-fields-list.html#waf-rule-statement-request-component-json-body) in the *AWS WAF Developer Guide* .
         */
        fallbackBehavior?: pulumi.Input<enums.wafv2.WebAclUriFragmentFallbackBehavior>;
    }
    /**
     * Visibility Metric of the WebACL.
     */
    interface WebAclVisibilityConfigArgs {
        /**
         * Indicates whether the associated resource sends metrics to Amazon CloudWatch. For the list of available metrics, see [AWS WAF Metrics](https://docs.aws.amazon.com/waf/latest/developerguide/monitoring-cloudwatch.html#waf-metrics) in the *AWS WAF Developer Guide* .
         *
         * For web ACLs, the metrics are for web requests that have the web ACL default action applied. AWS WAF applies the default action to web requests that pass the inspection of all rules in the web ACL without being either allowed or blocked. For more information,
         * see [The web ACL default action](https://docs.aws.amazon.com/waf/latest/developerguide/web-acl-default-action.html) in the *AWS WAF Developer Guide* .
         */
        cloudWatchMetricsEnabled: pulumi.Input<boolean>;
        /**
         * A name of the Amazon CloudWatch metric dimension. The name can contain only the characters: A-Z, a-z, 0-9, - (hyphen), and _ (underscore). The name can be from one to 128 characters long. It can't contain whitespace or metric names that are reserved for AWS WAF , for example `All` and `Default_Action` .
         */
        metricName: pulumi.Input<string>;
        /**
         * Indicates whether AWS WAF should store a sampling of the web requests that match the rules. You can view the sampled requests through the AWS WAF console.
         *
         * If you configure data protection for the web ACL, the protection applies to the web ACL's sampled web request data.
         *
         * > Request sampling doesn't provide a field redaction option, and any field redaction that you specify in your logging configuration doesn't affect sampling. You can only exclude fields from request sampling by disabling sampling in the web ACL visibility configuration or by configuring data protection for the web ACL.
         */
        sampledRequestsEnabled: pulumi.Input<boolean>;
    }
    /**
     * Xss Match Statement.
     */
    interface WebAclXssMatchStatementArgs {
        /**
         * The part of the web request that you want AWS WAF to inspect.
         */
        fieldToMatch: pulumi.Input<inputs.wafv2.WebAclFieldToMatchArgs>;
        /**
         * Text transformations eliminate some of the unusual formatting that attackers use in web requests in an effort to bypass detection. If you specify one or more transformations in a rule statement, AWS WAF performs all transformations on the content of the request component identified by `FieldToMatch` , starting from the lowest priority setting, before inspecting the content for a match.
         */
        textTransformations: pulumi.Input<pulumi.Input<inputs.wafv2.WebAclTextTransformationArgs>[]>;
    }
}
export declare namespace wisdom {
    interface AiAgentAiAgentConfiguration0PropertiesArgs {
        manualSearchAiAgentConfiguration: pulumi.Input<inputs.wisdom.AiAgentManualSearchAiAgentConfigurationArgs>;
    }
    interface AiAgentAiAgentConfiguration1PropertiesArgs {
        answerRecommendationAiAgentConfiguration: pulumi.Input<inputs.wisdom.AiAgentAnswerRecommendationAiAgentConfigurationArgs>;
    }
    interface AiAgentAiAgentConfiguration2PropertiesArgs {
        selfServiceAiAgentConfiguration: pulumi.Input<inputs.wisdom.AiAgentSelfServiceAiAgentConfigurationArgs>;
    }
    interface AiAgentAnswerRecommendationAiAgentConfigurationArgs {
        answerGenerationAiGuardrailId?: pulumi.Input<string>;
        answerGenerationAiPromptId?: pulumi.Input<string>;
        associationConfigurations?: pulumi.Input<pulumi.Input<inputs.wisdom.AiAgentAssociationConfigurationArgs>[]>;
        intentLabelingGenerationAiPromptId?: pulumi.Input<string>;
        locale?: pulumi.Input<string>;
        queryReformulationAiPromptId?: pulumi.Input<string>;
    }
    interface AiAgentAssociationConfigurationArgs {
        associationConfigurationData?: pulumi.Input<inputs.wisdom.AiAgentAssociationConfigurationDataPropertiesArgs>;
        associationId?: pulumi.Input<string>;
        associationType?: pulumi.Input<enums.wisdom.AiAgentAiAgentAssociationConfigurationType>;
    }
    interface AiAgentAssociationConfigurationDataPropertiesArgs {
        knowledgeBaseAssociationConfigurationData: pulumi.Input<inputs.wisdom.AiAgentKnowledgeBaseAssociationConfigurationDataArgs>;
    }
    interface AiAgentKnowledgeBaseAssociationConfigurationDataArgs {
        contentTagFilter?: pulumi.Input<inputs.wisdom.AiAgentTagFilter0PropertiesArgs | inputs.wisdom.AiAgentTagFilter1PropertiesArgs | inputs.wisdom.AiAgentTagFilter2PropertiesArgs>;
        maxResults?: pulumi.Input<number>;
        overrideKnowledgeBaseSearchType?: pulumi.Input<enums.wisdom.AiAgentKnowledgeBaseSearchType>;
    }
    interface AiAgentManualSearchAiAgentConfigurationArgs {
        answerGenerationAiGuardrailId?: pulumi.Input<string>;
        answerGenerationAiPromptId?: pulumi.Input<string>;
        associationConfigurations?: pulumi.Input<pulumi.Input<inputs.wisdom.AiAgentAssociationConfigurationArgs>[]>;
        locale?: pulumi.Input<string>;
    }
    interface AiAgentOrCondition0PropertiesArgs {
        andConditions: pulumi.Input<pulumi.Input<inputs.wisdom.AiAgentTagConditionArgs>[]>;
    }
    interface AiAgentOrCondition1PropertiesArgs {
        tagCondition: pulumi.Input<inputs.wisdom.AiAgentTagConditionArgs>;
    }
    interface AiAgentSelfServiceAiAgentConfigurationArgs {
        associationConfigurations?: pulumi.Input<pulumi.Input<inputs.wisdom.AiAgentAssociationConfigurationArgs>[]>;
        selfServiceAiGuardrailId?: pulumi.Input<string>;
        selfServiceAnswerGenerationAiPromptId?: pulumi.Input<string>;
        selfServicePreProcessingAiPromptId?: pulumi.Input<string>;
    }
    interface AiAgentTagConditionArgs {
        key: pulumi.Input<string>;
        value?: pulumi.Input<string>;
    }
    interface AiAgentTagFilter0PropertiesArgs {
        tagCondition: pulumi.Input<inputs.wisdom.AiAgentTagConditionArgs>;
    }
    interface AiAgentTagFilter1PropertiesArgs {
        andConditions: pulumi.Input<pulumi.Input<inputs.wisdom.AiAgentTagConditionArgs>[]>;
    }
    interface AiAgentTagFilter2PropertiesArgs {
        orConditions: pulumi.Input<pulumi.Input<inputs.wisdom.AiAgentOrCondition0PropertiesArgs | inputs.wisdom.AiAgentOrCondition1PropertiesArgs>[]>;
    }
    /**
     * Content policy config for a guardrail.
     */
    interface AiGuardrailAiGuardrailContentPolicyConfigArgs {
        /**
         * List of content filter configs in content policy.
         */
        filtersConfig: pulumi.Input<pulumi.Input<inputs.wisdom.AiGuardrailGuardrailContentFilterConfigArgs>[]>;
    }
    /**
     * Contextual grounding policy config for a guardrail.
     */
    interface AiGuardrailAiGuardrailContextualGroundingPolicyConfigArgs {
        /**
         * List of contextual grounding filter configs.
         */
        filtersConfig: pulumi.Input<pulumi.Input<inputs.wisdom.AiGuardrailGuardrailContextualGroundingFilterConfigArgs>[]>;
    }
    /**
     * Sensitive information policy config for a guardrail.
     */
    interface AiGuardrailAiGuardrailSensitiveInformationPolicyConfigArgs {
        /**
         * List of entities.
         */
        piiEntitiesConfig?: pulumi.Input<pulumi.Input<inputs.wisdom.AiGuardrailGuardrailPiiEntityConfigArgs>[]>;
        /**
         * List of regex.
         */
        regexesConfig?: pulumi.Input<pulumi.Input<inputs.wisdom.AiGuardrailGuardrailRegexConfigArgs>[]>;
    }
    /**
     * Topic policy config for a guardrail.
     */
    interface AiGuardrailAiGuardrailTopicPolicyConfigArgs {
        /**
         * List of topic configs in topic policy.
         */
        topicsConfig: pulumi.Input<pulumi.Input<inputs.wisdom.AiGuardrailGuardrailTopicConfigArgs>[]>;
    }
    /**
     * Word policy config for a guardrail.
     */
    interface AiGuardrailAiGuardrailWordPolicyConfigArgs {
        /**
         * A config for the list of managed words.
         */
        managedWordListsConfig?: pulumi.Input<pulumi.Input<inputs.wisdom.AiGuardrailGuardrailManagedWordsConfigArgs>[]>;
        /**
         * List of custom word configs.
         */
        wordsConfig?: pulumi.Input<pulumi.Input<inputs.wisdom.AiGuardrailGuardrailWordConfigArgs>[]>;
    }
    /**
     * Content filter config in content policy.
     */
    interface AiGuardrailGuardrailContentFilterConfigArgs {
        /**
         * The strength of the input for the guardrail content filter.
         */
        inputStrength: pulumi.Input<enums.wisdom.AiGuardrailGuardrailFilterStrength>;
        /**
         * The output strength of the guardrail content filter.
         */
        outputStrength: pulumi.Input<enums.wisdom.AiGuardrailGuardrailFilterStrength>;
        /**
         * The type of the guardrail content filter.
         */
        type: pulumi.Input<enums.wisdom.AiGuardrailGuardrailContentFilterType>;
    }
    /**
     * A config for grounding filter.
     */
    interface AiGuardrailGuardrailContextualGroundingFilterConfigArgs {
        /**
         * The threshold for this filter.
         */
        threshold: pulumi.Input<number>;
        /**
         * The type of this filter.
         */
        type: pulumi.Input<enums.wisdom.AiGuardrailGuardrailContextualGroundingFilterType>;
    }
    /**
     * A managed words config.
     */
    interface AiGuardrailGuardrailManagedWordsConfigArgs {
        /**
         * The type of guardrail managed words.
         */
        type: pulumi.Input<enums.wisdom.AiGuardrailGuardrailManagedWordsType>;
    }
    /**
     * Pii entity configuration.
     */
    interface AiGuardrailGuardrailPiiEntityConfigArgs {
        /**
         * The action of guardrail PII entity configuration.
         */
        action: pulumi.Input<enums.wisdom.AiGuardrailGuardrailSensitiveInformationAction>;
        type: pulumi.Input<enums.wisdom.AiGuardrailGuardrailPiiEntityType>;
    }
    /**
     * A regex configuration.
     */
    interface AiGuardrailGuardrailRegexConfigArgs {
        /**
         * The action of the guardrail regex configuration.
         */
        action: pulumi.Input<enums.wisdom.AiGuardrailGuardrailSensitiveInformationAction>;
        /**
         * The regex description.
         */
        description?: pulumi.Input<string>;
        /**
         * The regex name.
         */
        name: pulumi.Input<string>;
        /**
         * The regex pattern.
         */
        pattern: pulumi.Input<string>;
    }
    /**
     * Topic config in topic policy.
     */
    interface AiGuardrailGuardrailTopicConfigArgs {
        /**
         * Definition of topic in topic policy
         */
        definition: pulumi.Input<string>;
        /**
         * List of text examples
         */
        examples?: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * Name of topic in topic policy
         */
        name: pulumi.Input<string>;
        /**
         * Type of topic in a policy.
         */
        type: pulumi.Input<enums.wisdom.AiGuardrailGuardrailTopicType>;
    }
    /**
     * A custom word config.
     */
    interface AiGuardrailGuardrailWordConfigArgs {
        /**
         * The custom word text.
         */
        text: pulumi.Input<string>;
    }
    interface AiPromptAiPromptTemplateConfigurationArgs {
    }
    interface AssistantAssociationAssociationDataArgs {
        /**
         * The identifier of the knowledge base.
         */
        knowledgeBaseId: pulumi.Input<string>;
    }
    interface AssistantServerSideEncryptionConfigurationArgs {
        /**
         * The customer managed key used for encryption. The customer managed key must have a policy that allows `kms:CreateGrant` and `kms:DescribeKey` permissions to the IAM identity using the key to invoke Wisdom. To use Wisdom with chat, the key policy must also allow `kms:Decrypt` , `kms:GenerateDataKey*` , and `kms:DescribeKey` permissions to the `connect.amazonaws.com` service principal. For more information about setting up a customer managed key for Wisdom, see [Enable Amazon Connect Wisdom for your instance](https://docs.aws.amazon.com/connect/latest/adminguide/enable-wisdom.html) . For information about valid ID values, see [Key identifiers (KeyId)](https://docs.aws.amazon.com/kms/latest/developerguide/concepts.html#key-id) in the *AWS Key Management Service Developer Guide* .
         */
        kmsKeyId?: pulumi.Input<string>;
    }
    interface KnowledgeBaseAppIntegrationsConfigurationArgs {
        appIntegrationArn: pulumi.Input<string>;
        objectFields?: pulumi.Input<pulumi.Input<string>[]>;
    }
    interface KnowledgeBaseBedrockFoundationModelConfigurationArgs {
        /**
         * The model ARN of the Bedrock foundation model.
         */
        modelArn: pulumi.Input<string>;
        /**
         * The parsing prompt of the Bedrock foundation model configuration.
         */
        parsingPrompt?: pulumi.Input<inputs.wisdom.KnowledgeBaseBedrockFoundationModelConfigurationParsingPromptPropertiesArgs>;
    }
    /**
     * The parsing prompt of the Bedrock foundation model configuration.
     */
    interface KnowledgeBaseBedrockFoundationModelConfigurationParsingPromptPropertiesArgs {
        parsingPromptText: pulumi.Input<string>;
    }
    interface KnowledgeBaseFixedSizeChunkingConfigurationArgs {
        /**
         * The maximum number of tokens to include in a chunk.
         */
        maxTokens: pulumi.Input<number>;
        /**
         * The percentage of overlap between adjacent chunks of a data source.
         */
        overlapPercentage: pulumi.Input<number>;
    }
    interface KnowledgeBaseHierarchicalChunkingConfigurationArgs {
        /**
         * Token settings for each layer.
         */
        levelConfigurations: pulumi.Input<pulumi.Input<inputs.wisdom.KnowledgeBaseHierarchicalChunkingLevelConfigurationArgs>[]>;
        /**
         * The number of tokens to repeat across chunks in the same layer.
         */
        overlapTokens: pulumi.Input<number>;
    }
    interface KnowledgeBaseHierarchicalChunkingLevelConfigurationArgs {
        /**
         * The maximum number of tokens that a chunk can contain in this layer.
         */
        maxTokens: pulumi.Input<number>;
    }
    interface KnowledgeBaseManagedSourceConfigurationPropertiesArgs {
        webCrawlerConfiguration: pulumi.Input<inputs.wisdom.KnowledgeBaseWebCrawlerConfigurationArgs>;
    }
    interface KnowledgeBaseRenderingConfigurationArgs {
        /**
         * A URI template containing exactly one variable in `${variableName}` format. This can only be set for `EXTERNAL` knowledge bases. For Salesforce, ServiceNow, and Zendesk, the variable must be one of the following:
         *
         * - Salesforce: `Id` , `ArticleNumber` , `VersionNumber` , `Title` , `PublishStatus` , or `IsDeleted`
         * - ServiceNow: `number` , `short_description` , `sys_mod_count` , `workflow_state` , or `active`
         * - Zendesk: `id` , `title` , `updated_at` , or `draft`
         *
         * The variable is replaced with the actual value for a piece of content when calling [GetContent](https://docs.aws.amazon.com/amazon-q-connect/latest/APIReference/API_GetContent.html) .
         */
        templateUri?: pulumi.Input<string>;
    }
    interface KnowledgeBaseSeedUrlArgs {
        url?: pulumi.Input<string>;
    }
    interface KnowledgeBaseSemanticChunkingConfigurationArgs {
        /**
         * The dissimilarity threshold for splitting chunks.
         */
        breakpointPercentileThreshold: pulumi.Input<number>;
        /**
         * The buffer size.
         */
        bufferSize: pulumi.Input<number>;
        /**
         * The maximum number of tokens that a chunk can contain.
         */
        maxTokens: pulumi.Input<number>;
    }
    interface KnowledgeBaseServerSideEncryptionConfigurationArgs {
        /**
         * The customer managed key used for encryption.
         *
         * This customer managed key must have a policy that allows `kms:CreateGrant` and `kms:DescribeKey` permissions to the IAM identity using the key to invoke Wisdom.
         *
         * For more information about setting up a customer managed key for Wisdom, see [Enable Amazon Connect Wisdom for your instance](https://docs.aws.amazon.com/connect/latest/adminguide/enable-wisdom.html) . For information about valid ID values, see [Key identifiers (KeyId)](https://docs.aws.amazon.com/kms/latest/developerguide/concepts.html#key-id) .
         */
        kmsKeyId?: pulumi.Input<string>;
    }
    interface KnowledgeBaseSourceConfiguration0PropertiesArgs {
        appIntegrations: pulumi.Input<inputs.wisdom.KnowledgeBaseAppIntegrationsConfigurationArgs>;
    }
    interface KnowledgeBaseSourceConfiguration1PropertiesArgs {
        managedSourceConfiguration: pulumi.Input<inputs.wisdom.KnowledgeBaseManagedSourceConfigurationPropertiesArgs>;
    }
    interface KnowledgeBaseVectorIngestionConfigurationArgs {
        /**
         * Details about how to chunk the documents in the data source. A chunk refers to an excerpt from a data source that is returned when the knowledge base that it belongs to is queried.
         */
        chunkingConfiguration?: pulumi.Input<inputs.wisdom.KnowledgeBaseVectorIngestionConfigurationChunkingConfigurationPropertiesArgs>;
        /**
         * A custom parser for data source documents.
         */
        parsingConfiguration?: pulumi.Input<inputs.wisdom.KnowledgeBaseVectorIngestionConfigurationParsingConfigurationPropertiesArgs>;
    }
    /**
     * Details about how to chunk the documents in the data source. A chunk refers to an excerpt from a data source that is returned when the knowledge base that it belongs to is queried.
     */
    interface KnowledgeBaseVectorIngestionConfigurationChunkingConfigurationPropertiesArgs {
        chunkingStrategy: pulumi.Input<enums.wisdom.KnowledgeBaseVectorIngestionConfigurationChunkingConfigurationPropertiesChunkingStrategy>;
        fixedSizeChunkingConfiguration?: pulumi.Input<inputs.wisdom.KnowledgeBaseFixedSizeChunkingConfigurationArgs>;
        hierarchicalChunkingConfiguration?: pulumi.Input<inputs.wisdom.KnowledgeBaseHierarchicalChunkingConfigurationArgs>;
        semanticChunkingConfiguration?: pulumi.Input<inputs.wisdom.KnowledgeBaseSemanticChunkingConfigurationArgs>;
    }
    /**
     * A custom parser for data source documents.
     */
    interface KnowledgeBaseVectorIngestionConfigurationParsingConfigurationPropertiesArgs {
        bedrockFoundationModelConfiguration?: pulumi.Input<inputs.wisdom.KnowledgeBaseBedrockFoundationModelConfigurationArgs>;
        parsingStrategy: pulumi.Input<enums.wisdom.KnowledgeBaseVectorIngestionConfigurationParsingConfigurationPropertiesParsingStrategy>;
    }
    interface KnowledgeBaseWebCrawlerConfigurationArgs {
        crawlerLimits?: pulumi.Input<inputs.wisdom.KnowledgeBaseWebCrawlerConfigurationCrawlerLimitsPropertiesArgs>;
        exclusionFilters?: pulumi.Input<pulumi.Input<string>[]>;
        inclusionFilters?: pulumi.Input<pulumi.Input<string>[]>;
        scope?: pulumi.Input<enums.wisdom.KnowledgeBaseWebCrawlerConfigurationScope>;
        urlConfiguration: pulumi.Input<inputs.wisdom.KnowledgeBaseWebCrawlerConfigurationUrlConfigurationPropertiesArgs>;
    }
    interface KnowledgeBaseWebCrawlerConfigurationCrawlerLimitsPropertiesArgs {
        rateLimit?: pulumi.Input<number>;
    }
    interface KnowledgeBaseWebCrawlerConfigurationUrlConfigurationPropertiesArgs {
        seedUrls?: pulumi.Input<pulumi.Input<inputs.wisdom.KnowledgeBaseSeedUrlArgs>[]>;
    }
    /**
     * The agent attributes that are used with the message template.
     */
    interface MessageTemplateAgentAttributesArgs {
        /**
         * The agent’s first name as entered in their Amazon Connect user account.
         */
        firstName?: pulumi.Input<string>;
        /**
         * The agent’s last name as entered in their Amazon Connect user account.
         */
        lastName?: pulumi.Input<string>;
    }
    /**
     * An object that specifies the default values to use for variables in the message template. This object contains different categories of key-value pairs. Each key defines a variable or placeholder in the message template. The corresponding value defines the default value for that variable.
     */
    interface MessageTemplateAttributesArgs {
        /**
         * The agent attributes that are used with the message template.
         */
        agentAttributes?: pulumi.Input<inputs.wisdom.MessageTemplateAgentAttributesArgs>;
        /**
         * The custom attributes that are used with the message template.
         */
        customAttributes?: pulumi.Input<{
            [key: string]: pulumi.Input<string>;
        }>;
        /**
         * The customer profile attributes that are used with the message template.
         */
        customerProfileAttributes?: pulumi.Input<inputs.wisdom.MessageTemplateCustomerProfileAttributesArgs>;
        /**
         * The system attributes that are used with the message template.
         */
        systemAttributes?: pulumi.Input<inputs.wisdom.MessageTemplateSystemAttributesArgs>;
    }
    /**
     * The container of message template body.
     */
    interface MessageTemplateBodyContentProviderArgs {
        /**
         * The content of the message template.
         */
        content?: pulumi.Input<string>;
    }
    /**
     * The content of the message template.
     */
    interface MessageTemplateContentArgs {
        /**
         * The content of the message template that applies to the email channel subtype.
         */
        emailMessageTemplateContent?: pulumi.Input<inputs.wisdom.MessageTemplateEmailMessageTemplateContentArgs>;
        /**
         * The content of message template that applies to SMS channel subtype.
         */
        smsMessageTemplateContent?: pulumi.Input<inputs.wisdom.MessageTemplateSmsMessageTemplateContentArgs>;
    }
    /**
     * The customer profile attributes that are used with the message template.
     */
    interface MessageTemplateCustomerProfileAttributesArgs {
        /**
         * A unique account number that you have given to the customer.
         */
        accountNumber?: pulumi.Input<string>;
        /**
         * Any additional information relevant to the customer's profile.
         */
        additionalInformation?: pulumi.Input<string>;
        /**
         * The first line of a customer address.
         */
        address1?: pulumi.Input<string>;
        /**
         * The second line of a customer address.
         */
        address2?: pulumi.Input<string>;
        /**
         * The third line of a customer address.
         */
        address3?: pulumi.Input<string>;
        /**
         * The fourth line of a customer address.
         */
        address4?: pulumi.Input<string>;
        /**
         * The first line of a customer’s billing address.
         */
        billingAddress1?: pulumi.Input<string>;
        /**
         * The second line of a customer’s billing address.
         */
        billingAddress2?: pulumi.Input<string>;
        /**
         * The third line of a customer’s billing address.
         */
        billingAddress3?: pulumi.Input<string>;
        /**
         * The fourth line of a customer’s billing address.
         */
        billingAddress4?: pulumi.Input<string>;
        /**
         * The city of a customer’s billing address.
         */
        billingCity?: pulumi.Input<string>;
        /**
         * The country of a customer’s billing address.
         */
        billingCountry?: pulumi.Input<string>;
        /**
         * The county of a customer’s billing address.
         */
        billingCounty?: pulumi.Input<string>;
        /**
         * The postal code of a customer’s billing address.
         */
        billingPostalCode?: pulumi.Input<string>;
        /**
         * The province of a customer’s billing address.
         */
        billingProvince?: pulumi.Input<string>;
        /**
         * The state of a customer’s billing address.
         */
        billingState?: pulumi.Input<string>;
        /**
         * The customer's birth date.
         */
        birthDate?: pulumi.Input<string>;
        /**
         * The customer's business email address.
         */
        businessEmailAddress?: pulumi.Input<string>;
        /**
         * The name of the customer's business.
         */
        businessName?: pulumi.Input<string>;
        /**
         * The customer's business phone number.
         */
        businessPhoneNumber?: pulumi.Input<string>;
        /**
         * The city in which a customer lives.
         */
        city?: pulumi.Input<string>;
        /**
         * The country in which a customer lives.
         */
        country?: pulumi.Input<string>;
        /**
         * The county in which a customer lives.
         */
        county?: pulumi.Input<string>;
        /**
         * The custom attributes in customer profile attributes.
         */
        custom?: pulumi.Input<{
            [key: string]: pulumi.Input<string>;
        }>;
        /**
         * The customer's email address, which has not been specified as a personal or business address.
         */
        emailAddress?: pulumi.Input<string>;
        /**
         * The customer's first name.
         */
        firstName?: pulumi.Input<string>;
        /**
         * The customer's gender.
         */
        gender?: pulumi.Input<string>;
        /**
         * The customer's home phone number.
         */
        homePhoneNumber?: pulumi.Input<string>;
        /**
         * The customer's last name.
         */
        lastName?: pulumi.Input<string>;
        /**
         * The first line of a customer’s mailing address.
         */
        mailingAddress1?: pulumi.Input<string>;
        /**
         * The second line of a customer’s mailing address.
         */
        mailingAddress2?: pulumi.Input<string>;
        /**
         * The third line of a customer’s mailing address.
         */
        mailingAddress3?: pulumi.Input<string>;
        /**
         * The fourth line of a customer’s mailing address.
         */
        mailingAddress4?: pulumi.Input<string>;
        /**
         * The city of a customer’s mailing address.
         */
        mailingCity?: pulumi.Input<string>;
        /**
         * The country of a customer’s mailing address.
         */
        mailingCountry?: pulumi.Input<string>;
        /**
         * The county of a customer’s mailing address.
         */
        mailingCounty?: pulumi.Input<string>;
        /**
         * The postal code of a customer’s mailing address
         */
        mailingPostalCode?: pulumi.Input<string>;
        /**
         * The province of a customer’s mailing address.
         */
        mailingProvince?: pulumi.Input<string>;
        /**
         * The state of a customer’s mailing address.
         */
        mailingState?: pulumi.Input<string>;
        /**
         * The customer's middle name.
         */
        middleName?: pulumi.Input<string>;
        /**
         * The customer's mobile phone number.
         */
        mobilePhoneNumber?: pulumi.Input<string>;
        /**
         * The customer's party type.
         */
        partyType?: pulumi.Input<string>;
        /**
         * The customer's phone number, which has not been specified as a mobile, home, or business number.
         */
        phoneNumber?: pulumi.Input<string>;
        /**
         * The postal code of a customer address.
         */
        postalCode?: pulumi.Input<string>;
        /**
         * The ARN of a customer profile.
         */
        profileArn?: pulumi.Input<string>;
        /**
         * The unique identifier of a customer profile.
         */
        profileId?: pulumi.Input<string>;
        /**
         * The province in which a customer lives.
         */
        province?: pulumi.Input<string>;
        /**
         * The first line of a customer’s shipping address.
         */
        shippingAddress1?: pulumi.Input<string>;
        /**
         * The second line of a customer’s shipping address.
         */
        shippingAddress2?: pulumi.Input<string>;
        /**
         * The third line of a customer’s shipping address.
         */
        shippingAddress3?: pulumi.Input<string>;
        /**
         * The fourth line of a customer’s shipping address
         */
        shippingAddress4?: pulumi.Input<string>;
        /**
         * The city of a customer’s shipping address.
         */
        shippingCity?: pulumi.Input<string>;
        /**
         * The country of a customer’s shipping address.
         */
        shippingCountry?: pulumi.Input<string>;
        /**
         * The county of a customer’s shipping address.
         */
        shippingCounty?: pulumi.Input<string>;
        /**
         * The postal code of a customer’s shipping address.
         */
        shippingPostalCode?: pulumi.Input<string>;
        /**
         * The province of a customer’s shipping address.
         */
        shippingProvince?: pulumi.Input<string>;
        /**
         * The state of a customer’s shipping address.
         */
        shippingState?: pulumi.Input<string>;
        /**
         * The state in which a customer lives.
         */
        state?: pulumi.Input<string>;
    }
    /**
     * The content of message template that applies to email channel subtype.
     */
    interface MessageTemplateEmailMessageTemplateContentArgs {
        /**
         * The body to use in email messages.
         */
        body: pulumi.Input<inputs.wisdom.MessageTemplateEmailMessageTemplateContentBodyArgs>;
        /**
         * The email headers to include in email messages.
         */
        headers: pulumi.Input<pulumi.Input<inputs.wisdom.MessageTemplateEmailMessageTemplateHeaderArgs>[]>;
        /**
         * The subject line, or title, to use in email messages.
         */
        subject: pulumi.Input<string>;
    }
    /**
     * The body to use in email messages.
     */
    interface MessageTemplateEmailMessageTemplateContentBodyArgs {
        /**
         * The message body, in HTML format, to use in email messages that are based on the message template. We recommend using HTML format for email clients that render HTML content. You can include links, formatted text, and more in an HTML message.
         */
        html?: pulumi.Input<inputs.wisdom.MessageTemplateBodyContentProviderArgs>;
        /**
         * The message body, in plain text format, to use in email messages that are based on the message template. We recommend using plain text format for email clients that don't render HTML content and clients that are connected to high-latency networks, such as mobile devices.
         */
        plainText?: pulumi.Input<inputs.wisdom.MessageTemplateBodyContentProviderArgs>;
    }
    /**
     * The email header to include in email messages.
     */
    interface MessageTemplateEmailMessageTemplateHeaderArgs {
        /**
         * The name of the email header.
         */
        name?: pulumi.Input<string>;
        /**
         * The value of the email header.
         */
        value?: pulumi.Input<string>;
    }
    /**
     * The configuration information of the user groups that the message template is accessible to.
     */
    interface MessageTemplateGroupingConfigurationArgs {
        /**
         * The criteria used for grouping Amazon Q in Connect users.
         */
        criteria: pulumi.Input<string>;
        /**
         * The list of values that define different groups of Amazon Q in Connect users.
         */
        values: pulumi.Input<pulumi.Input<string>[]>;
    }
    /**
     * The content of message template that applies to SMS channel subtype.
     */
    interface MessageTemplateSmsMessageTemplateContentArgs {
        /**
         * The body to use in SMS messages.
         */
        body: pulumi.Input<inputs.wisdom.MessageTemplateSmsMessageTemplateContentBodyArgs>;
    }
    /**
     * The body to use in SMS messages.
     */
    interface MessageTemplateSmsMessageTemplateContentBodyArgs {
        /**
         * The message body to use in SMS messages.
         */
        plainText?: pulumi.Input<inputs.wisdom.MessageTemplateBodyContentProviderArgs>;
    }
    /**
     * The system attributes that are used with the message template.
     */
    interface MessageTemplateSystemAttributesArgs {
        /**
         * The CustomerEndpoint attribute.
         */
        customerEndpoint?: pulumi.Input<inputs.wisdom.MessageTemplateSystemEndpointAttributesArgs>;
        /**
         * The name of the task.
         */
        name?: pulumi.Input<string>;
        /**
         * The SystemEndpoint attribute.
         */
        systemEndpoint?: pulumi.Input<inputs.wisdom.MessageTemplateSystemEndpointAttributesArgs>;
    }
    /**
     * The system endpoint attributes that are used with the message template.
     */
    interface MessageTemplateSystemEndpointAttributesArgs {
        /**
         * The customer's phone number if used with customerEndpoint, or the number the customer dialed to call your contact center if used with systemEndpoint.
         */
        address?: pulumi.Input<string>;
    }
}
export declare namespace workspaces {
    interface WorkspacesPoolApplicationSettingsArgs {
        /**
         * The path prefix for the S3 bucket where users’ persistent application settings are stored.
         */
        settingsGroup?: pulumi.Input<string>;
        /**
         * Enables or disables persistent application settings for users during their pool sessions.
         */
        status: pulumi.Input<enums.workspaces.WorkspacesPoolApplicationSettingsStatus>;
    }
    interface WorkspacesPoolCapacityArgs {
        /**
         * The desired number of user sessions for the WorkSpaces in the pool.
         */
        desiredUserSessions: pulumi.Input<number>;
    }
    interface WorkspacesPoolTimeoutSettingsArgs {
        /**
         * Specifies the amount of time, in seconds, that a streaming session remains active after users disconnect. If users try to reconnect to the streaming session after a disconnection or network interruption within the time set, they are connected to their previous session. Otherwise, they are connected to a new session with a new streaming instance.
         */
        disconnectTimeoutInSeconds?: pulumi.Input<number>;
        /**
         * The amount of time in seconds a connection will stay active while idle.
         */
        idleDisconnectTimeoutInSeconds?: pulumi.Input<number>;
        /**
         * Specifies the maximum amount of time, in seconds, that a streaming session can remain active. If users are still connected to a streaming instance five minutes before this limit is reached, they are prompted to save any open documents before being disconnected. After this time elapses, the instance is terminated and replaced by a new instance.
         */
        maxUserDurationInSeconds?: pulumi.Input<number>;
    }
}
export declare namespace workspacesthinclient {
    interface EnvironmentMaintenanceWindowArgs {
        /**
         * The desired time zone maintenance window.
         */
        applyTimeOf?: pulumi.Input<enums.workspacesthinclient.EnvironmentMaintenanceWindowApplyTimeOf>;
        /**
         * The date of maintenance window.
         */
        daysOfTheWeek?: pulumi.Input<pulumi.Input<enums.workspacesthinclient.EnvironmentDayOfWeek>[]>;
        /**
         * The hour end time of maintenance window.
         */
        endTimeHour?: pulumi.Input<number>;
        /**
         * The minute end time of maintenance window.
         */
        endTimeMinute?: pulumi.Input<number>;
        /**
         * The hour start time of maintenance window.
         */
        startTimeHour?: pulumi.Input<number>;
        /**
         * The minute start time of maintenance window.
         */
        startTimeMinute?: pulumi.Input<number>;
        /**
         * The type of maintenance window.
         */
        type: pulumi.Input<enums.workspacesthinclient.EnvironmentMaintenanceWindowType>;
    }
    /**
     * A key-value pair to associate with a resource.
     */
    interface EnvironmentTagArgs {
        /**
         * The key name of the tag. You can specify a value that is 1 to 128 Unicode characters in length and cannot be prefixed with aws:. You can use any of the following characters: the set of Unicode letters, digits, whitespace, _, ., /, =, +, and -.
         */
        key: pulumi.Input<string>;
        /**
         * The value for the tag. You can specify a value that is 1 to 256 Unicode characters in length and cannot be prefixed with aws:. You can use any of the following characters: the set of Unicode letters, digits, whitespace, _, ., /, =, +, and -.
         */
        value: pulumi.Input<string>;
    }
}
export declare namespace workspacesweb {
    interface DataProtectionSettingsCustomPatternArgs {
        /**
         * The keyword regex for the customer pattern. After there is a match to the pattern regex, the keyword regex is used to search within the proximity of the match. If there is a keyword match, then the match is confirmed. If no keyword regex is provided, the pattern regex match will automatically be confirmed. The format must follow JavaScript regex format. The pattern must be enclosed between slashes, and can have flags behind the second slash. For example, "/ab+c/gi"
         */
        keywordRegex?: pulumi.Input<string>;
        /**
         * The pattern description for the customer pattern.
         */
        patternDescription?: pulumi.Input<string>;
        /**
         * The pattern name for the custom pattern.
         */
        patternName: pulumi.Input<string>;
        /**
         * The pattern regex for the customer pattern. The format must follow JavaScript regex format. The pattern must be enclosed between slashes, and can have flags behind the second slash. For example: "/ab+c/gi".
         */
        patternRegex: pulumi.Input<string>;
    }
    interface DataProtectionSettingsInlineRedactionConfigurationArgs {
        /**
         * The global confidence level for the inline redaction configuration. This indicates the certainty of data type matches in the redaction process. Confidence level 3 means high confidence, and requires a formatted text pattern match in order for content to be redacted. Confidence level 2 means medium confidence, and redaction considers both formatted and unformatted text, and adds keyword associate to the logic. Confidence level 1 means low confidence, and redaction is enforced for both formatted pattern + unformatted pattern without keyword. This is applied to patterns that do not have a pattern-level confidence level. Defaults to confidence level 2.
         */
        globalConfidenceLevel?: pulumi.Input<number>;
        /**
         * The global enforced URL configuration for the inline redaction configuration. This is applied to patterns that do not have a pattern-level enforced URL list.
         */
        globalEnforcedUrls?: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * The global exempt URL configuration for the inline redaction configuration. This is applied to patterns that do not have a pattern-level exempt URL list.
         */
        globalExemptUrls?: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * The inline redaction patterns to be enabled for the inline redaction configuration.
         */
        inlineRedactionPatterns: pulumi.Input<pulumi.Input<inputs.workspacesweb.DataProtectionSettingsInlineRedactionPatternArgs>[]>;
    }
    interface DataProtectionSettingsInlineRedactionPatternArgs {
        /**
         * The built-in pattern from the list of preconfigured patterns. Either a customPattern or builtInPatternId is required. To view the entire list of data types and their corresponding built-in pattern IDs, see [Base inline redaction](https://docs.aws.amazon.com/workspaces-web/latest/adminguide/base-inline-redaction.html) .
         */
        builtInPatternId?: pulumi.Input<string>;
        /**
         * The confidence level for inline redaction pattern. This indicates the certainty of data type matches in the redaction process. Confidence level 3 means high confidence, and requires a formatted text pattern match in order for content to be redacted. Confidence level 2 means medium confidence, and redaction considers both formatted and unformatted text, and adds keyword associate to the logic. Confidence level 1 means low confidence, and redaction is enforced for both formatted pattern + unformatted pattern without keyword. This overrides the global confidence level.
         */
        confidenceLevel?: pulumi.Input<number>;
        /**
         * The configuration for a custom pattern. Either a customPattern or builtInPatternId is required.
         */
        customPattern?: pulumi.Input<inputs.workspacesweb.DataProtectionSettingsCustomPatternArgs>;
        /**
         * The enforced URL configuration for the inline redaction pattern. This will override the global enforced URL configuration.
         */
        enforcedUrls?: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * The exempt URL configuration for the inline redaction pattern. This will override the global exempt URL configuration for the inline redaction pattern.
         */
        exemptUrls?: pulumi.Input<pulumi.Input<string>[]>;
        /**
         * The redaction placeholder that will replace the redacted text in session for the inline redaction pattern.
         */
        redactionPlaceHolder: pulumi.Input<inputs.workspacesweb.DataProtectionSettingsRedactionPlaceHolderArgs>;
    }
    interface DataProtectionSettingsRedactionPlaceHolderArgs {
        /**
         * The redaction placeholder text that will replace the redacted text in session for the custom text redaction placeholder type.
         */
        redactionPlaceHolderText?: pulumi.Input<string>;
        /**
         * The redaction placeholder type that will replace the redacted text in session.
         */
        redactionPlaceHolderType: pulumi.Input<enums.workspacesweb.DataProtectionSettingsRedactionPlaceHolderType>;
    }
    interface IpAccessSettingsIpRuleArgs {
        /**
         * The description of the IP rule.
         */
        description?: pulumi.Input<string>;
        /**
         * A single IP address or an IP address range in CIDR notation
         */
        ipRange: pulumi.Input<string>;
    }
    interface UserSettingsCookieSpecificationArgs {
        /**
         * The domain of the cookie.
         */
        domain: pulumi.Input<string>;
        /**
         * The name of the cookie.
         */
        name?: pulumi.Input<string>;
        /**
         * The path of the cookie.
         */
        path?: pulumi.Input<string>;
    }
    interface UserSettingsCookieSynchronizationConfigurationArgs {
        /**
         * The list of cookie specifications that are allowed to be synchronized to the remote browser.
         */
        allowlist: pulumi.Input<pulumi.Input<inputs.workspacesweb.UserSettingsCookieSpecificationArgs>[]>;
        /**
         * The list of cookie specifications that are blocked from being synchronized to the remote browser.
         */
        blocklist?: pulumi.Input<pulumi.Input<inputs.workspacesweb.UserSettingsCookieSpecificationArgs>[]>;
    }
    interface UserSettingsToolbarConfigurationArgs {
        /**
         * The list of toolbar items to be hidden.
         */
        hiddenToolbarItems?: pulumi.Input<pulumi.Input<enums.workspacesweb.UserSettingsToolbarItem>[]>;
        /**
         * The maximum display resolution that is allowed for the session.
         */
        maxDisplayResolution?: pulumi.Input<enums.workspacesweb.UserSettingsMaxDisplayResolution>;
        /**
         * The type of toolbar displayed during the session.
         */
        toolbarType?: pulumi.Input<enums.workspacesweb.UserSettingsToolbarType>;
        /**
         * The visual mode of the toolbar.
         */
        visualMode?: pulumi.Input<enums.workspacesweb.UserSettingsVisualMode>;
    }
}
export declare namespace xray {
    interface GroupInsightsConfigurationArgs {
        /**
         * Set the InsightsEnabled value to true to enable insights or false to disable insights.
         */
        insightsEnabled?: pulumi.Input<boolean>;
        /**
         * Set the NotificationsEnabled value to true to enable insights notifications. Notifications can only be enabled on a group with InsightsEnabled set to true.
         */
        notificationsEnabled?: pulumi.Input<boolean>;
    }
    interface SamplingRuleArgs {
        /**
         * Matches attributes derived from the request.
         */
        attributes?: pulumi.Input<{
            [key: string]: pulumi.Input<string>;
        }>;
        /**
         * The percentage of matching requests to instrument, after the reservoir is exhausted.
         */
        fixedRate: pulumi.Input<number>;
        /**
         * Matches the hostname from a request URL.
         */
        host: pulumi.Input<string>;
        /**
         * Matches the HTTP method from a request URL.
         */
        httpMethod: pulumi.Input<string>;
        /**
         * The priority of the sampling rule.
         */
        priority: pulumi.Input<number>;
        /**
         * A fixed number of matching requests to instrument per second, prior to applying the fixed rate. The reservoir is not used directly by services, but applies to all services using the rule collectively.
         */
        reservoirSize: pulumi.Input<number>;
        /**
         * Matches the ARN of the AWS resource on which the service runs.
         */
        resourceArn: pulumi.Input<string>;
        /**
         * The ARN of the sampling rule. Specify a rule by either name or ARN, but not both.
         *
         * > Specifying a sampling rule by name is recommended, as specifying by ARN will be deprecated in future.
         */
        ruleArn?: pulumi.Input<string>;
        /**
         * The name of the sampling rule. Specify a rule by either name or ARN, but not both.
         */
        ruleName?: pulumi.Input<string>;
        /**
         * Matches the name that the service uses to identify itself in segments.
         */
        serviceName: pulumi.Input<string>;
        /**
         * Matches the origin that the service uses to identify its type in segments.
         */
        serviceType: pulumi.Input<string>;
        /**
         * Matches the path from a request URL.
         */
        urlPath: pulumi.Input<string>;
        /**
         * The version of the sampling rule format (1)
         */
        version?: pulumi.Input<number>;
    }
    interface SamplingRuleRecordArgs {
        /**
         * When the rule was created, in Unix time seconds.
         */
        createdAt?: pulumi.Input<string>;
        /**
         * When the rule was modified, in Unix time seconds.
         */
        modifiedAt?: pulumi.Input<string>;
        samplingRule?: pulumi.Input<inputs.xray.SamplingRuleArgs>;
    }
    interface SamplingRuleUpdateArgs {
        /**
         * Matches attributes derived from the request.
         */
        attributes?: pulumi.Input<{
            [key: string]: pulumi.Input<string>;
        }>;
        /**
         * The percentage of matching requests to instrument, after the reservoir is exhausted.
         */
        fixedRate?: pulumi.Input<number>;
        /**
         * Matches the hostname from a request URL.
         */
        host?: pulumi.Input<string>;
        /**
         * Matches the HTTP method from a request URL.
         */
        httpMethod?: pulumi.Input<string>;
        /**
         * The priority of the sampling rule.
         */
        priority?: pulumi.Input<number>;
        /**
         * A fixed number of matching requests to instrument per second, prior to applying the fixed rate. The reservoir is not used directly by services, but applies to all services using the rule collectively.
         */
        reservoirSize?: pulumi.Input<number>;
        /**
         * Matches the ARN of the AWS resource on which the service runs.
         */
        resourceArn?: pulumi.Input<string>;
        ruleArn?: pulumi.Input<string>;
        ruleName?: pulumi.Input<string>;
        /**
         * Matches the name that the service uses to identify itself in segments.
         */
        serviceName?: pulumi.Input<string>;
        /**
         * Matches the origin that the service uses to identify its type in segments.
         */
        serviceType?: pulumi.Input<string>;
        /**
         * Matches the path from a request URL.
         */
        urlPath?: pulumi.Input<string>;
    }
}
